(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     23131,        511]
NotebookOptionsPosition[     22540,        487]
NotebookOutlinePosition[     22884,        502]
CellTagsIndexPosition[     22841,        499]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.6123016877684298`*^9, 3.6123016882354565`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Helper", " ", "function", " ", "mimic", " ", "hlsl", " ", "intrinsic"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Saturate", "[", "X_", "]"}], " ", "=", " ", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"Min", "[", 
        RowBox[{"X", ",", " ", "1"}], "]"}], ",", " ", "0"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SmoothStep", "[", "X_", "]"}], "=", 
     RowBox[{
      RowBox[{"3", 
       RowBox[{"X", "^", "2"}]}], " ", "-", " ", 
      RowBox[{"2", " ", 
       RowBox[{"X", "^", "3"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Lerp", "[", 
      RowBox[{"A_", ",", " ", "B_", ",", " ", "X_"}], "]"}], " ", "=", 
     RowBox[{"A", " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"B", "-", "A"}], ")"}], "*", "X"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5929034861619806`*^9, 3.592903529245163*^9}, {
  3.592915751427203*^9, 3.592915782392254*^9}, {3.612245704674383*^9, 
  3.61224570549743*^9}, {3.6122909839162045`*^9, 3.6122909980680137`*^9}, {
  3.6123009467640467`*^9, 3.612300964226045*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.612302035599324*^9, 3.612302042257705*^9}, 
   3.612302136496095*^9, {3.6123023330353365`*^9, 3.6123023342254047`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Plot", " ", "several", " ", "windows", " ", "function"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Windows1", "[", 
      RowBox[{"X_", ",", " ", "lightRadius_", ",", " ", "exponent1_"}], "]"}],
      " ", "=", " ", 
     RowBox[{
      RowBox[{"Saturate", "[", 
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "^", "exponent1"}], " ", "/", " ", 
           RowBox[{"lightRadius", "^", "exponent1"}]}], ")"}]}], ")"}], "]"}],
       "^", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Windows2", "[", 
      RowBox[{"X_", ",", " ", "lightRadius_", ",", " ", "exponent2_"}], "]"}],
      " ", "=", " ", 
     RowBox[{"Saturate", "[", 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "^", "exponent2"}], " ", "/", " ", 
          RowBox[{"lightRadius", "^", "exponent2"}]}], ")"}]}], ")"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Windows3", "[", 
      RowBox[{"X_", ",", " ", "lightRadius_"}], "]"}], " ", "=", " ", 
     RowBox[{"SmoothStep", "[", 
      RowBox[{"Saturate", "[", 
       RowBox[{"1", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"X", "^", "2"}], "/", 
          RowBox[{"lightRadius", "^", "2"}]}], ")"}]}], "]"}], "]"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"Windows1", "[", 
          RowBox[{"x", ",", " ", "lightRadius", ",", " ", "exponent1"}], 
          "]"}], ",", " ", 
         RowBox[{"Windows2", "[", 
          RowBox[{"x", ",", " ", "lightRadius", ",", " ", "exponent2"}], 
          "]"}], ",", " ", 
         RowBox[{"Windows3", "[", 
          RowBox[{"x", ",", " ", "lightRadius"}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "0", ",", " ", "15"}], "}"}], ",", " ", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "1"}], "}"}]}], ",", " ", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<distance\>\"", ",", "\"\<falloff\>\""}], "}"}]}]}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Commented", " ", "because", " ", "it", " ", "slow", " ", "down", " ", 
        "everything"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{",", " ", 
        RowBox[{"PlotLegend", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<Windows1\>\"", ",", "\"\<Windows2\>\"", ",", 
           "\"\<Windows3\>\""}], "}"}]}], ",", 
        RowBox[{"LegendPosition", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0.18", ",", " ", "0"}], "}"}]}]}], "  ", "*)"}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "lightRadius", ",", " ", "10", ",", " ", "\"\<lightRadius\>\""}], 
        "}"}], ",", "1", ",", " ", "15"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"exponent1", ",", " ", "4", ",", " ", "\"\<exponent1\>\""}], 
        "}"}], ",", "1", ",", " ", "20"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"exponent2", ",", " ", "20", ",", " ", "\"\<exponent2\>\""}], 
        "}"}], ",", "1", ",", " ", "20"}], "}"}]}], "\[IndentingNewLine]", 
    "]"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6123010136538725`*^9, 3.612301162885408*^9}, {
  3.6123012116841993`*^9, 3.612301429404652*^9}, {3.6123014637726173`*^9, 
  3.612301473188156*^9}, {3.6123015362787647`*^9, 3.6123015604201455`*^9}, {
  3.612301621008611*^9, 3.612301671567503*^9}, {3.612301807838297*^9, 
  3.6123018080373087`*^9}, {3.612301866597658*^9, 3.612301882437564*^9}, {
  3.6123019190186567`*^9, 3.6123019328304462`*^9}, {3.61230201384408*^9, 
  3.612302056733533*^9}, {3.612302093459634*^9, 3.6123022284453545`*^9}, {
  3.6123023485032215`*^9, 3.612302438189351*^9}, {3.612302639684876*^9, 
  3.6123026551707616`*^9}, {3.6123028767734365`*^9, 3.612302876813439*^9}, {
  3.6123036364808893`*^9, 3.6123036527498198`*^9}, {3.6123036918860583`*^9, 
  3.612303693381144*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`exponent1$$ = 4, $CellContext`exponent2$$ = 
    20, $CellContext`lightRadius$$ = 10, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`lightRadius$$], 10, "lightRadius"}, 1, 15}, {{
       Hold[$CellContext`exponent1$$], 4, "exponent1"}, 1, 20}, {{
       Hold[$CellContext`exponent2$$], 20, "exponent2"}, 1, 20}}, 
    Typeset`size$$ = {360., {111., 114.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`lightRadius$634899$$ = 
    0, $CellContext`exponent1$634900$$ = 0, $CellContext`exponent2$634901$$ = 
    0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`exponent1$$ = 4, $CellContext`exponent2$$ = 
        20, $CellContext`lightRadius$$ = 10}, "ControllerVariables" :> {
        Hold[$CellContext`lightRadius$$, $CellContext`lightRadius$634899$$, 
         0], 
        Hold[$CellContext`exponent1$$, $CellContext`exponent1$634900$$, 0], 
        Hold[$CellContext`exponent2$$, $CellContext`exponent2$634901$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[{
         $CellContext`Windows1[$CellContext`x, $CellContext`lightRadius$$, \
$CellContext`exponent1$$], 
         $CellContext`Windows2[$CellContext`x, $CellContext`lightRadius$$, \
$CellContext`exponent2$$], 
         $CellContext`Windows3[$CellContext`x, $CellContext`lightRadius$$]}, \
{$CellContext`x, 0, 15}, PlotRange -> {0, 1}, 
        AxesLabel -> {"distance", "falloff"}], 
      "Specifications" :> {{{$CellContext`lightRadius$$, 10, "lightRadius"}, 
         1, 15}, {{$CellContext`exponent1$$, 4, "exponent1"}, 1, 
         20}, {{$CellContext`exponent2$$, 20, "exponent2"}, 1, 20}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{411., {184., 189.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.612302423989539*^9, 3.612302439191408*^9}, {
   3.612303647555523*^9, 3.612303654796937*^9}, 3.612303695150245*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Show", " ", "that", " ", "windows1", " ", "have", " ", "derivative", " ", 
    "a", " ", "0", " ", "and", " ", "when", " ", "crossing", " ", "the", " ", 
    "0", " ", "line", " ", "at", " ", "0"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", "X_", "]"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"X", "^", "4"}], "/", " ", 
         RowBox[{"lightRadius", "^", "4"}]}], ")"}]}], ")"}], "^", "2"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"F", "'"}], "[", "0", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"F", "'"}], "[", "lightRadius", "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6123026584669504`*^9, 3.61230281458588*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Draw", " ", "several", " ", "falloff"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"t", " ", "=", " ", 
          RowBox[{"1", " ", "/", " ", 
           RowBox[{"lightRadius", "^", "2"}]}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"1", "/", " ", 
          RowBox[{"(", 
           RowBox[{"x", "^", "2"}], ")"}]}]}], " ", ",", "  ", 
        RowBox[{"(*", " ", "reference", " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "/", " ", 
           RowBox[{"(", 
            RowBox[{"1", " ", "-", " ", "t"}], ")"}]}], ")"}], "*", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", " ", "/", " ", 
            RowBox[{"(", 
             RowBox[{"x", " ", "^", "2"}], ")"}]}], " ", "-", " ", "t"}], 
          ")"}]}], " ", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Windows1", "[", 
          RowBox[{"x", ",", " ", "lightRadius", ",", " ", "4"}], "]"}], "*", 
         "  ", 
         RowBox[{"1", "/", " ", 
          RowBox[{"(", 
           RowBox[{"x", "^", "2"}], ")"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Windows2", "[", 
          RowBox[{"x", ",", " ", "lightRadius", ",", " ", "20"}], "]"}], "*", 
         "  ", 
         RowBox[{"1", "/", " ", 
          RowBox[{"(", 
           RowBox[{"x", "^", "2"}], ")"}]}]}]}], "\[IndentingNewLine]", "}"}],
       ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", " ", "0", ",", " ", "20"}], "}"}], ",", " ", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0.025"}], "}"}]}]}], "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Commented", " ", "because", " ", "it", " ", "slow", " ", "down", " ", 
       "everything"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{",", 
       RowBox[{"PlotLegend", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Reference\>\"", ",", "\"\<SCale and Bias\>\"", ",", 
          "\"\<Windows1\>\"", ",", "\"\<Windows2\>\""}], "}"}]}], ",", 
       RowBox[{"LegendPosition", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0.15", ",", " ", "0"}], "}"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "]"}], ",", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "lightRadius", ",", " ", "40", ",", " ", "\"\<lightRadius\>\""}], 
       "}"}], ",", "1.0001", ",", " ", "80"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"exponent1", ",", " ", "4", ",", " ", "\"\<exponent1\>\""}], 
       "}"}], ",", "1", ",", " ", "20"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"exponent2", ",", " ", "20", ",", " ", "\"\<exponent2\>\""}], 
       "}"}], ",", "1", ",", " ", "20"}], "}"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5928952635119934`*^9, 3.5928953722371674`*^9}, {
   3.5928957247547407`*^9, 3.5928957634148045`*^9}, {3.592895815079881*^9, 
   3.592895857969951*^9}, {3.592896040226246*^9, 3.5928960624862814`*^9}, {
   3.5928960990063405`*^9, 3.592896108876356*^9}, {3.5928961658184495`*^9, 
   3.5928961662484503`*^9}, {3.592896199935505*^9, 3.5928962394585667`*^9}, 
   3.5928963186886945`*^9, {3.5928963536537514`*^9, 3.592896361014763*^9}, {
   3.592897547812687*^9, 3.592897563825712*^9}, {3.592897822712132*^9, 
   3.5928978434351654`*^9}, {3.5928978886262393`*^9, 3.592898058776515*^9}, {
   3.5928981072775946`*^9, 3.592898185840723*^9}, 3.592898553057316*^9, {
   3.592899943246581*^9, 3.5929000026266775`*^9}, {3.5929000357067313`*^9, 
   3.5929000367667327`*^9}, {3.5929000776777983`*^9, 
   3.5929000789578004`*^9}, {3.5929001356178155`*^9, 
   3.5929002432773085`*^9}, {3.5929002833653755`*^9, 
   3.5929003175364304`*^9}, {3.5929035383486834`*^9, 3.59290357587883*^9}, {
   3.5929047441703568`*^9, 3.5929048899895964`*^9}, {3.592904926829262*^9, 
   3.592904935509759*^9}, {3.5929049860436487`*^9, 3.5929050252998343`*^9}, {
   3.5929064440281963`*^9, 3.5929064603872237`*^9}, {3.5929064994372864`*^9, 
   3.5929065208263216`*^9}, {3.592906556076379*^9, 3.5929066182954793`*^9}, {
   3.5929067830467515`*^9, 3.5929068544168663`*^9}, {3.592906896308934*^9, 
   3.592906934225996*^9}, {3.5929070983758235`*^9, 3.592907140052207*^9}, {
   3.592907410864973*^9, 3.5929074865090957`*^9}, {3.592907524157157*^9, 
   3.5929075441881895`*^9}, {3.5929153238175063`*^9, 3.592915347218543*^9}, {
   3.592915422605666*^9, 3.5929154718467464`*^9}, {3.5929155021767955`*^9, 
   3.592915528938839*^9}, {3.5929156289240036`*^9, 3.592915741637187*^9}, {
   3.592915791308268*^9, 3.592915815559306*^9}, {3.5929159597375374`*^9, 
   3.5929159650885468`*^9}, 3.592916046893675*^9, {3.592916246178996*^9, 
   3.592916248308999*^9}, {3.592916314298106*^9, 3.5929163591281805`*^9}, 
   3.5929164267052937`*^9, {3.5929164662663546`*^9, 3.5929164793843765`*^9}, {
   3.5929165098354235`*^9, 3.5929165204884415`*^9}, {3.592916578114535*^9, 
   3.592916580855539*^9}, {3.5929166285536127`*^9, 3.5929166415216312`*^9}, {
   3.5929166831076975`*^9, 3.592916731564776*^9}, {3.592916834264941*^9, 
   3.592916835809944*^9}, {3.592917923069657*^9, 3.592917950673703*^9}, {
   3.5929180725158973`*^9, 3.592918082015913*^9}, {3.592918271635224*^9, 
   3.592918328107315*^9}, {3.59300222615935*^9, 3.593002234630363*^9}, {
   3.5930024828367815`*^9, 3.5930025277608557`*^9}, {3.594185116919275*^9, 
   3.594185223186414*^9}, 3.5941852926395316`*^9, {3.5941853318575954`*^9, 
   3.594185348439623*^9}, {3.6122466885016527`*^9, 3.612246729247983*^9}, {
   3.6122474876583614`*^9, 3.6122475510659885`*^9}, {3.6122477098750715`*^9, 
   3.6122477862584405`*^9}, {3.6122478707392726`*^9, 
   3.6122478910104322`*^9}, {3.612247955326111*^9, 3.612247955442117*^9}, {
   3.6122479992306223`*^9, 3.6122480044049177`*^9}, {3.6122481695263624`*^9, 
   3.6122481705004177`*^9}, {3.6122492833890715`*^9, 
   3.6122492936356573`*^9}, {3.612249401762842*^9, 3.6122494128674774`*^9}, {
   3.6122494643474216`*^9, 3.612249503142641*^9}, {3.612249621270397*^9, 
   3.6122496306509337`*^9}, {3.612249661131677*^9, 3.612249681346833*^9}, {
   3.6122497180429325`*^9, 3.6122497366509967`*^9}, {3.6122501044050303`*^9, 
   3.6122501623233423`*^9}, {3.612250193732139*^9, 3.612250199037442*^9}, {
   3.6122519111883717`*^9, 3.6122519376528854`*^9}, {3.6122519742099767`*^9, 
   3.612251990396902*^9}, {3.612257217668885*^9, 3.6122572806854897`*^9}, 
   3.612257369217553*^9, {3.6122574034215097`*^9, 3.612257403867535*^9}, {
   3.6122591652002773`*^9, 3.6122591721036725`*^9}, {3.612264155141686*^9, 
   3.612264201800355*^9}, {3.61226439543543*^9, 3.612264397390542*^9}, {
   3.612264428527323*^9, 3.6122644725428405`*^9}, {3.612264664203803*^9, 
   3.6122646652048597`*^9}, {3.6122649338862276`*^9, 3.612264965599042*^9}, {
   3.612265202401586*^9, 3.612265213189203*^9}, {3.6122653527281837`*^9, 
   3.6122653881832123`*^9}, {3.612265744856612*^9, 3.6122657802916393`*^9}, {
   3.612265849961624*^9, 3.612265850647663*^9}, {3.6122663708204155`*^9, 
   3.612266375878705*^9}, {3.612290950577297*^9, 3.6122909531284432`*^9}, {
   3.6122910217753696`*^9, 3.6122910749964137`*^9}, {3.612291234194519*^9, 
   3.612291236024624*^9}, 3.6122912995802593`*^9, {3.6122914891881037`*^9, 
   3.612291492427289*^9}, {3.6122915659784966`*^9, 3.612291567421579*^9}, {
   3.612300973448573*^9, 3.6123010107597065`*^9}, {3.6123025311986713`*^9, 
   3.612302576077238*^9}, {3.6123026064039726`*^9, 3.61230261614853*^9}, {
   3.612302844219575*^9, 3.6123028931883755`*^9}, {3.612302924268153*^9, 
   3.6123029773161874`*^9}, {3.612303437420504*^9, 3.612303444044883*^9}, {
   3.6123034923656464`*^9, 3.612303508269556*^9}, {3.6123035620516324`*^9, 
   3.6123036199409437`*^9}, {3.6123037809261513`*^9, 3.612303814749086*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`exponent1$$ = 4, $CellContext`exponent2$$ = 
    20, $CellContext`lightRadius$$ = 40, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`lightRadius$$], 40, "lightRadius"}, 1.0001, 80}, {{
       Hold[$CellContext`exponent1$$], 4, "exponent1"}, 1, 20}, {{
       Hold[$CellContext`exponent2$$], 20, "exponent2"}, 1, 20}}, 
    Typeset`size$$ = {360., {130., 133.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`lightRadius$635095$$ = 
    0, $CellContext`exponent1$635096$$ = 0, $CellContext`exponent2$635097$$ = 
    0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`exponent1$$ = 4, $CellContext`exponent2$$ = 
        20, $CellContext`lightRadius$$ = 40}, "ControllerVariables" :> {
        Hold[$CellContext`lightRadius$$, $CellContext`lightRadius$635095$$, 
         0], 
        Hold[$CellContext`exponent1$$, $CellContext`exponent1$635096$$, 0], 
        Hold[$CellContext`exponent2$$, $CellContext`exponent2$635097$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Plot[{$CellContext`t = 1/$CellContext`lightRadius$$^2; 
         1/$CellContext`x^2, (1/(1 - $CellContext`t)) (
          1/$CellContext`x^2 - $CellContext`t), \
$CellContext`Windows1[$CellContext`x, $CellContext`lightRadius$$, 4] (
          1/$CellContext`x^2), $CellContext`Windows2[$CellContext`x, \
$CellContext`lightRadius$$, 20] (1/$CellContext`x^2)}, {$CellContext`x, 0, 
         20}, PlotRange -> {0, 0.025}, 
        PlotLegends`PlotLegend -> {
         "Reference", "SCale and Bias", "Windows1", "Windows2"}, 
        PlotLegends`LegendPosition -> {0.15, 0}], 
      "Specifications" :> {{{$CellContext`lightRadius$$, 40, "lightRadius"}, 
         1.0001, 80}, {{$CellContext`exponent1$$, 4, "exponent1"}, 1, 
         20}, {{$CellContext`exponent2$$, 20, "exponent2"}, 1, 20}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{411., {203., 208.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.612250145419376*^9, 3.61225019934346*^9}, 
   3.612251938340925*^9, {3.612251974707005*^9, 3.6122519915379677`*^9}, 
   3.612257219136969*^9, {3.612257253662944*^9, 3.612257281843556*^9}, 
   3.612257369893592*^9, 3.612257404495571*^9, 3.6122591725987005`*^9, 
   3.612259210938894*^9, {3.6122641761988907`*^9, 3.612264202886417*^9}, {
   3.6122644003407106`*^9, 3.6122644243780856`*^9}, 3.612264474653961*^9, 
   3.612264665888899*^9, {3.612264939919573*^9, 3.612264966057068*^9}, 
   3.6122650786845093`*^9, {3.612265203743663*^9, 3.6122652144122725`*^9}, {
   3.6122653649008803`*^9, 3.6122653892502728`*^9}, {3.612265763555682*^9, 
   3.612265782413761*^9}, 3.6122658512016954`*^9, 3.6122663775658016`*^9, {
   3.612291048814916*^9, 3.6122910758344617`*^9}, 3.612291237689719*^9, 
   3.6122913023674183`*^9, 3.612291494203391*^9, 3.612291568705652*^9, 
   3.6123025805944963`*^9, {3.6123028676209135`*^9, 3.6123028940174227`*^9}, 
   3.612302963291385*^9, {3.612303439681633*^9, 3.6123034456439743`*^9}, {
   3.612303503813301*^9, 3.612303510159664*^9}, {3.612303565875851*^9, 
   3.612303578410568*^9}, {3.612303614056607*^9, 3.612303624514205*^9}, 
   3.6123037881485643`*^9}]
}, Open  ]]
},
WindowSize->{1904, 945},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 183, 3, 66, "Input"],
Cell[743, 25, 1236, 34, 106, "Input"],
Cell[1982, 61, 168, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[2175, 67, 4508, 110, 286, "Input"],
Cell[6686, 179, 2713, 51, 404, "Output"]
}, Open  ]],
Cell[9414, 233, 889, 24, 132, "Input"],
Cell[CellGroupData[{
Cell[10328, 261, 8164, 150, 312, "Input"],
Cell[18495, 413, 4029, 71, 442, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
