(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    192200,       4121]
NotebookOptionsPosition[    189956,       4049]
NotebookOutlinePosition[    190302,       4064]
CellTagsIndexPosition[    190259,       4061]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Helper", " ", "function", " ", "mimic", " ", "hlsl", " ", "intrinsic"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Saturate", "[", "X_", "]"}], " ", "=", " ", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"Min", "[", 
        RowBox[{"X", ",", " ", "1"}], "]"}], ",", " ", "0"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SmoothStep", "[", "X_", "]"}], "=", 
     RowBox[{
      RowBox[{"3", 
       RowBox[{"X", "^", "2"}]}], " ", "-", " ", 
      RowBox[{"2", " ", 
       RowBox[{"X", "^", "3"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Lerp", "[", 
      RowBox[{"A_", ",", " ", "B_", ",", " ", "X_"}], "]"}], " ", "=", 
     RowBox[{"A", " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"B", "-", "A"}], ")"}], "*", "X"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Slerp", "[", 
     RowBox[{"A_", ",", " ", "B_", ",", " ", "X_"}], "]"}], ":=", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"angle", " ", "=", " ", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{"A", ",", "B"}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"angle", " ", "\[Equal]", " ", "\[Pi]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "-", "X"}], ")"}], "*", "angle"}], "]"}], " ", 
             "/", " ", 
             RowBox[{"Sin", "[", "angle", "]"}]}], ")"}], "*", "A"}], " ", 
          "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"X", " ", "*", " ", "angle"}], "]"}], " ", "/", " ", 
             RowBox[{"Sin", "[", "angle", "]"}]}], ")"}], "*", "B"}]}]}], " ",
         "]"}]}], "}"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Helper", " ", "function", " ", "for", " ", "sphericql", " ", 
     "coordinate"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SphVec", "[", 
     RowBox[{"theta_", ",", " ", "phi_"}], "]"}], " ", ":=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "phi", "]"}], " ", 
       RowBox[{"Sin", "[", "theta", "]"}]}], ",", " ", 
      RowBox[{
       RowBox[{"Sin", "[", "phi", "]"}], 
       RowBox[{"Sin", "[", "theta", "]"}]}], ",", " ", 
      RowBox[{"Cos", "[", "theta", "]"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6153884225594406`*^9, 3.615388422855978*^9}, {
  3.6153938107771573`*^9, 3.6153938205443974`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Misc", " ", "helper"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Allow", " ", "to", " ", "draw", " ", "an", " ", "hemisphere"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"hemisphere", "=", 
     RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"0.5", "*", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Cos", "[", "u", "]"}], " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], ",", 
           RowBox[{
            RowBox[{"Sin", "[", "u", "]"}], " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], ",", 
           RowBox[{"Cos", "[", "v", "]"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", 
          RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", 
          RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", 
        RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
        RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
        RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Generate", " ", "random", " ", "transformation"}], " ", "-", 
     " ", 
     RowBox[{"right", " ", "handed", " ", "matrix", " ", "TRS"}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GetRandomTransform", "[", 
     RowBox[{"Scaling_", ",", " ", "maxDistance_"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"Composition", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"TranslationTransform", "[", 
         RowBox[{"maxDistance", "*", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RandomReal", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], "]"}], " ", ",", 
            " ", 
            RowBox[{"RandomReal", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], "]"}], ",", " ", 
            RowBox[{"RandomReal", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], "]"}]}], " ", 
           "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Composition", "[", "\[IndentingNewLine]", " ", 
         RowBox[{
          RowBox[{"RotationTransform", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], "]"}], "*", "2", 
             "\[Pi]"}], ",", " ", 
            RowBox[{"Normalize", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"RandomReal", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], "]"}], " ", ",",
                " ", 
               RowBox[{"RandomReal", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], "]"}], " ", ",",
                " ", 
               RowBox[{"RandomReal", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], "]"}]}], " ", 
              "}"}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"ScalingTransform", "[", "Scaling", "]"}]}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
      "\[IndentingNewLine]", "}"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.613304418329157*^9, 3.6133044248475294`*^9}, {
  3.6153938700171795`*^9, 3.6153938752153397`*^9}, {3.6153947901675243`*^9, 
  3.615394825960069*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Geometric", " ", "tools", " ", "for", " ", "plane"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RayPlaneIntersection", "[", 
     RowBox[{
     "rayOrigin_", ",", " ", "rayDirection_", ",", " ", "planeOrigin_", ",", 
      " ", "planeNormal_"}], "]"}], " ", ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"dist", "=", 
        RowBox[{
         RowBox[{"Dot", "[", 
          RowBox[{"planeNormal", ",", 
           RowBox[{"planeOrigin", "-", "rayOrigin"}]}], "]"}], "/", 
         RowBox[{"Dot", "[", 
          RowBox[{"planeNormal", ",", "rayDirection"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"val", " ", "=", " ", 
        RowBox[{"rayOrigin", "+", 
         RowBox[{"rayDirection", "*", "dist"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"val", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
      RowBox[{"val", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
      RowBox[{"val", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ProjectOnPlane", "[", 
     RowBox[{"pos_", ",", "planeOrigin_", ",", "planeNormal_"}], "]"}], ":=", 
    " ", 
    RowBox[{"RayPlaneIntersection", "[", 
     RowBox[{"pos", ",", 
      RowBox[{"-", "planeNormal"}], ",", "planeOrigin", ",", "planeNormal"}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"closestPointRect", "[", 
     RowBox[{
     "pos_", ",", "planeOrigin_", ",", "right_", ",", "up_", ",", 
      "halfWidth_", ",", "halfHeight_"}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"dir", "=", 
        RowBox[{"pos", "-", "planeOrigin"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"dist2D", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Clip", "[", 
           RowBox[{
            RowBox[{"Dot", "[", 
             RowBox[{"dir", ",", "right"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "halfWidth"}], ",", "halfWidth"}], "}"}]}], "]"}], 
          ",", " ", 
          RowBox[{"Clip", "[", 
           RowBox[{
            RowBox[{"Dot", "[", 
             RowBox[{"dir", ",", "up"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "halfHeight"}], ",", "halfHeight"}], "}"}]}], 
           "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"val", " ", "=", " ", 
        RowBox[{"planeOrigin", "+", 
         RowBox[{
          RowBox[{"dist2D", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "*", "right"}], "+", 
         RowBox[{
          RowBox[{"dist2D", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "*", "up"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"val", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
      RowBox[{"val", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
      RowBox[{"val", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "return", " ", "1", " ", "if", " ", "the", " ", "point", " ", "is", " ", 
     "in", " ", "rect", " ", "else", " ", "0"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IsInRect", "[", 
     RowBox[{
     "pos_", ",", "planeOrigin_", ",", "right_", ",", "up_", ",", 
      "halfWidth_", ",", "halfHeight_"}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dir", "=", 
        RowBox[{"pos", "-", "planeOrigin"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"dotX", " ", "=", " ", 
        RowBox[{"Abs", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{"dir", ",", "right"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dotY", " ", "=", " ", 
        RowBox[{"Abs", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{"dir", ",", "up"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"dotX", " ", ">", " ", "halfWidth"}], " ", "||", "  ", 
          RowBox[{"dotY", " ", ">", " ", "halfHeight"}]}], ",", " ", "0", ",",
          " ", "1"}], "]"}]}], "\[IndentingNewLine]", "}"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "return", " ", "1", " ", "if", " ", "the", " ", "ray", " ", "intersect", 
     " ", "the", " ", "rect", " ", "taking", " ", "into", " ", "account", " ",
      "the", " ", "plane", " ", "orientation"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"rayDirection", " ", "must", " ", "be", " ", "normalized"}], " ", 
    "*)"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IsRayPlaneIntersect", "[", 
     RowBox[{
     "rayOrigin_", ",", " ", "rayDirection_", ",", " ", "planeOrigin_", ",", 
      "planeNormal_", ",", " ", "right_", ",", "up_", ",", "halfWidth_", ",", 
      "halfHeight_"}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"IntersectionPos", " ", "=", " ", 
        RowBox[{"RayPlaneIntersection", "[", 
         RowBox[{
         "rayOrigin", ",", " ", "rayDirection", ",", " ", "planeOrigin", ",", 
          " ", "planeNormal"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
       RowBox[{"val", " ", "=", " ", 
        RowBox[{"IsInRect", "[", 
         RowBox[{
         "IntersectionPos", ",", " ", "planeOrigin", ",", " ", "right", ",", 
          " ", "up", ",", " ", "halfWidth", ",", " ", "halfHeight"}], "]"}]}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Only", " ", "valid", " ", "the", " ", "interersection", " ", "is", 
         " ", "the", " ", "ray", " ", "is", " ", "on", " ", "the", " ", 
         "right", " ", "side", " ", "of", " ", "the", " ", "plane"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dot", "[", 
           RowBox[{"rayDirection", ",", " ", 
            RowBox[{"-", "planeNormal"}]}], "]"}], "\[GreaterEqual]", " ", 
          "0"}], ",", " ", "val", ",", " ", "0"}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.6132842136735163`*^9, 3.6132842286223717`*^9}, {
  3.6132850383846874`*^9, 3.613285084179307*^9}, {3.61538811385824*^9, 
  3.6153882206433*^9}, {3.6153890926755342`*^9, 3.615389094938822*^9}, {
  3.6153898792109118`*^9, 3.6153898799039993`*^9}, {3.615393788864875*^9, 
  3.6153937891449103`*^9}, {3.6153938856816688`*^9, 3.6153939011536336`*^9}, {
  3.61539396089622*^9, 3.6153939627504554`*^9}, {3.6153941039598866`*^9, 
  3.615394253087824*^9}, {3.6153964962296667`*^9, 3.615396603003725*^9}, {
  3.615396635795889*^9, 3.6153966517799187`*^9}, {3.6153967829735785`*^9, 
  3.6153968024305487`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Solid", " ", "angle", " ", "and", " ", "form", " ", "factor"}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "rectangular", " ", "right", " ", "pyramid", " ", "solid", " ", "angle"}],
     " ", "-", " ", 
    RowBox[{"no", " ", "horizon"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"RectangularPyramidSolidAngle", "[", 
    RowBox[{"dist_", ",", " ", "lightSize_"}], "]"}], " ", ":=", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"0.5", " ", "*", 
        RowBox[{"lightSize", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"b", " ", "=", " ", 
       RowBox[{"0.5", " ", "*", 
        RowBox[{"lightSize", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"h", " ", "=", " ", "dist"}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{"4", " ", "*", " ", 
       RowBox[{"ArcSin", "[", " ", 
        RowBox[{"a", " ", "*", " ", 
         RowBox[{"b", " ", "/", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "^", "2"}], "+", 
              RowBox[{"h", "^", "2"}]}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"b", "^", "2"}], "+", 
              RowBox[{"h", "^", "2"}]}], ")"}]}], "]"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.6132842912269526`*^9, 3.6132843046017175`*^9}, 
   3.6153939725842037`*^9, {3.6153942733123913`*^9, 3.6153943274317636`*^9}, {
   3.615394642566781*^9, 3.615394644822568*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"rectangular", " ", "oriented", " ", "true", " ", "solid", " ", 
    RowBox[{"angle", " ", ":", " ", 
     RowBox[{
      RowBox[{"An", " ", "Area"}], "-", 
      RowBox[{
      "Preserving", " ", "Parametrization", " ", "for", " ", "Spherical", " ",
        "Rectangles"}], " ", "-", " ", 
      RowBox[{"no", " ", "horizon"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RectangleSolidAngle", "[", 
     RowBox[{
     "worldPos_", ",", "p0_", ",", "p1_", ",", " ", "p2_", ",", "p3_"}], 
     "]"}], " ", ":=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"v0", "=", 
        RowBox[{"p0", "-", "worldPos"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"v1", "=", 
        RowBox[{"p1", "-", "worldPos"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"v2", "=", 
        RowBox[{"p2", "-", "worldPos"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"v3", "=", 
        RowBox[{"p3", "-", "worldPos"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"n0", " ", "=", " ", 
        RowBox[{"Normalize", "[", 
         RowBox[{"Cross", "[", 
          RowBox[{"v0", ",", "v1"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"n1", " ", "=", " ", 
        RowBox[{"Normalize", "[", 
         RowBox[{"Cross", "[", 
          RowBox[{"v1", ",", "v2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"n2", " ", "=", " ", 
        RowBox[{"Normalize", "[", 
         RowBox[{"Cross", "[", 
          RowBox[{"v2", ",", "v3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"n3", " ", "=", " ", 
        RowBox[{"Normalize", "[", 
         RowBox[{"Cross", "[", 
          RowBox[{"v3", ",", "v0"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"g0", " ", "=", " ", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{
           RowBox[{"-", "n0"}], ",", " ", "n1"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"g1", " ", "=", " ", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{
           RowBox[{"-", "n1"}], ",", " ", "n2"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"g2", " ", "=", " ", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{
           RowBox[{"-", "n2"}], ",", " ", "n3"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"g3", " ", "=", " ", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{
           RowBox[{"-", "n3"}], ",", " ", "n0"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
       "g0", " ", "+", " ", "g1", " ", "+", " ", "g2", " ", "+", " ", "g3", 
        " ", "-", " ", 
        RowBox[{"2", "\[Pi]"}]}]}], "  ", "\[IndentingNewLine]", "}"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Extenstion", " ", "of", " ", "above", " ", "function", " ", "taking", 
     " ", "other", " ", "parameter"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RectangleSolidAngleExt", "[", 
     RowBox[{
     "pos_", ",", "planeOrigin_", ",", "right_", ",", "up_", ",", 
      "halfWidth_", ",", "halfHeight_"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"p0", " ", "=", " ", 
        RowBox[{"planeOrigin", " ", "-", " ", 
         RowBox[{"halfWidth", " ", "*", "right"}], " ", "+", " ", 
         RowBox[{"halfHeight", " ", "*", "up"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", " ", "=", " ", 
        RowBox[{"planeOrigin", " ", "-", " ", 
         RowBox[{"halfWidth", "*", "right"}], " ", "-", " ", 
         RowBox[{"halfHeight", " ", "*", "up"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p2", " ", "=", " ", 
        RowBox[{"planeOrigin", " ", "+", " ", 
         RowBox[{"halfWidth", " ", "*", "right"}], " ", "-", " ", 
         RowBox[{"halfHeight", " ", "*", "up"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p3", " ", "=", " ", 
        RowBox[{"planeOrigin", " ", "+", " ", 
         RowBox[{"halfWidth", " ", "*", "right"}], " ", "+", " ", 
         RowBox[{"halfHeight", " ", "*", "up"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"RectangleSolidAngle", "[", 
        RowBox[{"pos", ",", "p0", ",", "p1", ",", " ", "p2", ",", "p3"}], 
        "]"}]}], "\[IndentingNewLine]", "}"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Brute", " ", "force", " ", "monte", " ", "carlo", " ", "integration", 
     " ", "of", " ", "the", " ", "visibility", " ", "function", " ", "to", 
     " ", "get", " ", "the", " ", "solid", " ", "angle", " ", "for", " ", 
     "rectangle", " ", "with", " ", "horizon"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "This", " ", "assume", " ", "that", " ", "worldNormal", " ", "is", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RectangleSolidAngleMC", "[", 
     RowBox[{
     "worldPos_", ",", " ", "planeOrigin_", ",", " ", "planeNormal_", ",", 
      " ", "right_", ",", "up_", ",", "halfWidth_", ",", "halfHeight_"}], 
     "]"}], " ", ":=", "\n", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"solidAngleIntegrale", " ", "=", " ", "0"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dtheta", " ", "=", " ", "0.01"}], ";", "\[IndentingNewLine]", 
       RowBox[{"dphi", " ", "=", " ", "0.01"}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", " ", "[", 
        RowBox[{
         RowBox[{"theta", " ", "=", " ", "0"}], ",", " ", 
         RowBox[{"theta", " ", "<", " ", 
          RowBox[{"\[Pi]", "/", "2"}]}], ",", " ", 
         RowBox[{
          RowBox[{"theta", " ", "+=", " ", "dtheta"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"phi", " ", "=", "0"}], ",", " ", 
            RowBox[{"phi", " ", "<", " ", 
             RowBox[{"2", "\[Pi]"}]}], ",", " ", 
            RowBox[{
             RowBox[{"phi", " ", "+=", " ", "dphi"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"dir", "=", "  ", 
              RowBox[{"SphVec", "[", 
               RowBox[{"theta", ",", "phi"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"solidAngleIntegrale", " ", "+=", "  ", 
              RowBox[{
               RowBox[{"IsRayPlaneIntersect", "[", 
                RowBox[{
                "worldPos", ",", " ", "dir", ",", " ", "planeOrigin", ",", 
                 " ", "planeNormal", ",", " ", "right", ",", "up", ",", 
                 "halfWidth", ",", "halfHeight"}], "]"}], "*", " ", 
               RowBox[{"Sin", "[", "theta", "]"}]}]}]}]}], 
           "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "If", " ", "the", " ", "plane", " ", "if", " ", "facing", " ", "away",
          " ", "from", " ", "the", " ", "surface", " ", "discard"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dot", "[", 
           RowBox[{
            RowBox[{"Normalize", "[", 
             RowBox[{"planePos", " ", "-", " ", "worldPos"}], "]"}], ",", " ", 
            RowBox[{"-", "planeNormal"}]}], "]"}], "  ", "\[GreaterEqual]", 
          "  ", "0"}], ",", "  ", 
         RowBox[{
         "solidAngleIntegrale", " ", "*", " ", "dtheta", " ", "*", " ", 
          "dphi"}], ",", " ", "0"}], "]"}]}], "\[IndentingNewLine]", "}"}], 
     "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6132843247828712`*^9, 3.6132843250718884`*^9}, 
   3.6132845315787*^9, {3.6153943134329863`*^9, 3.615394330688678*^9}, {
   3.615394615280816*^9, 3.6153946212440734`*^9}, {3.6153952394100704`*^9, 
   3.6153952538564053`*^9}, {3.6153963451259785`*^9, 3.615396350741192*^9}, {
   3.6153963870608034`*^9, 3.6153963891245656`*^9}, {3.6153972264698954`*^9, 
   3.6153972897099257`*^9}, {3.615397337334473*^9, 3.6153973525104003`*^9}, 
   3.615399830405053*^9, 3.615399925662649*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Form", " ", "factor", " ", "to", " ", "compute", " ", "the", " ", 
    "rectangular", " ", "irradiance", " ", "integral", " ", "when", " ", 
    "rectangular", " ", "plane", " ", "is", " ", "above", " ", "the", " ", 
    "horizon"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"QuadFormFactor", "[", 
     RowBox[{
     "worldPos_", ",", " ", "worldNormal_", ",", "planeOrigin_", ",", " ", 
      "planeNormal_", ",", " ", "p0_", ",", "p1_", ",", " ", "p2_", ",", 
      "p3_"}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\n", 
      RowBox[{
       RowBox[{"v0", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{"p0", "-", "worldPos"}], "]"}]}], ";", "\n", 
       RowBox[{"v1", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{"p1", "-", "worldPos"}], "]"}]}], ";", "\n", 
       RowBox[{"v2", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{"p2", "-", "worldPos"}], "]"}]}], ";", "\n", 
       RowBox[{"v3", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{"p3", "-", "worldPos"}], "]"}]}], ";", "\[IndentingNewLine]",
        " ", 
       RowBox[{"fD1", "=", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{"v0", ",", "v1"}], "]"}], "]"}]}], ";", "\n", " ", 
       RowBox[{"fD2", "=", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{"v1", ",", "v2"}], "]"}], "]"}]}], ";", "\n", 
       RowBox[{"fD3", "=", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{"v2", ",", "v3"}], "]"}], "]"}]}], ";", "\n", 
       RowBox[{"fD4", "=", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"Dot", "[", 
          RowBox[{"v3", ",", "v0"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\n", 
       RowBox[{"vCross1", "=", 
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{"Cross", "[", 
           RowBox[{"v0", ",", "v1"}], "]"}], "]"}], "*", "fD1"}]}], ";", "\n", 
       RowBox[{"vCross2", "=", 
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{"Cross", "[", 
           RowBox[{"v1", ",", "v2"}], "]"}], "]"}], "*", "fD2"}]}], ";", "\n", 
       RowBox[{"vCross3", "=", 
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{"Cross", "[", 
           RowBox[{"v2", ",", "v3"}], "]"}], "]"}], "*", "fD3"}]}], ";", "\n", 
       RowBox[{"vCross4", "=", 
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{"Cross", "[", 
           RowBox[{"v3", ",", "v0"}], "]"}], "]"}], "*", "fD4"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"val", "=", 
        RowBox[{"Dot", "[", 
         RowBox[{"worldNormal", ",", 
          RowBox[{
          "vCross1", "+", "vCross2", "+", "vCross3", "+", "vCross4"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "If", " ", "the", " ", "plane", " ", "if", " ", "facing", " ", "away",
          " ", "from", " ", "the", " ", "surface", " ", "discard"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "analyic", " ", "solution", "  ", "require", " ", "\"\<* \[Pi]\>\""}],
         " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dot", "[", 
           RowBox[{
            RowBox[{"Normalize", "[", 
             RowBox[{"planePos", " ", "-", " ", "worldPos"}], "]"}], ",", " ", 
            RowBox[{"-", "planeNormal"}]}], "]"}], " ", ">", " ", "0"}], ",", 
         " ", 
         RowBox[{"val", " ", "*", " ", 
          RowBox[{"\[Pi]", " ", "/", " ", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], " ", ")"}]}]}], ",", " ", "0"}], " ", 
        "]"}]}], "\[IndentingNewLine]", "}"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6132851441547375`*^9, 3.6132851859331264`*^9}, {
  3.6153962115165124`*^9, 3.6153962336908283`*^9}, {3.6153962660669394`*^9, 
  3.615396330394608*^9}, {3.6153966712188873`*^9, 3.6153966718504677`*^9}, {
  3.6153967606187396`*^9, 3.6153967660744324`*^9}, {3.615396872124899*^9, 
  3.615396876762988*^9}, {3.615397176691074*^9, 3.6153971809671173`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "One", " ", "shot", " ", "approximate", " ", "local", " ", "shading", " ",
      "paper"}], " ", "-", " ", 
    RowBox[{"analytic", " ", "solution", " ", "for", " ", "MRP"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"OneShotApproximateLocalShading", "[", 
    RowBox[{
    "pos_", ",", " ", "normal_", ",", " ", "planeOrigin_", ",", " ", 
     "planeNormal_", ",", "halfWidth_", ",", "halfHeight_"}], "]"}], " ", ":=",
    "\n", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"pp0", " ", "=", " ", 
       RowBox[{"RayPlaneIntersection", "[", 
        RowBox[{
        "pos", ",", " ", "normal", ",", " ", "planeOrigin", ",", " ", 
         "planeNormal"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"pp1", " ", "=", " ", 
       RowBox[{"ProjectOnPlane", "[", 
        RowBox[{"pos", ",", " ", "planeOrigin", ",", " ", "planeNormal"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"etha", "=", 
       RowBox[{"ArcCos", "[", 
        RowBox[{"Dot", "[", 
         RowBox[{
          RowBox[{"Normalize", "[", 
           RowBox[{"pos", "-", "pp0"}], "]"}], ",", 
          RowBox[{"Normalize", "[", 
           RowBox[{"pp1", "-", "pp0"}], "]"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"theta", "=", 
       RowBox[{"0.5", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"ArcCos", "[", 
           RowBox[{"0.5", "*", 
            RowBox[{"Cos", "[", "etha", "]"}]}], "]"}], "-", "etha"}], 
         ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"t", "=", 
       RowBox[{
        RowBox[{"Length", "[", 
         RowBox[{"pp1", "-", "pos"}], "]"}], "/", 
        RowBox[{"Tan", "[", 
         RowBox[{"theta", "+", "etha"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"val", " ", "=", " ", 
       RowBox[{"pp1", "+", 
        RowBox[{"t", "*", 
         RowBox[{"Normalize", "[", 
          RowBox[{"pp0", "-", "pp1"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Fit", " ", "on", " ", "the", " ", "plane"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"val", " ", "=", " ", 
       RowBox[{"closestPointRect", "[", 
        RowBox[{
        "val", ",", " ", "planePos", ",", " ", "right", ",", " ", "up", ",", 
         " ", "halfWidth", ",", " ", "halfHeight"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"val", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
     RowBox[{"val", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
     RowBox[{"val", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], "\[IndentingNewLine]", 
    "}"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.6133052029840364`*^9, 3.613305222418148*^9}, {
  3.6153946958410463`*^9, 3.6153947001845975`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Mathematica", " ", "is", " ", "right", " ", "handed", " ", "with", " ", 
    "translation", " ", "in", " ", "column"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Rectangular", " ", "light", " ", "sampling", " ", "for", " ", "monte", 
     " ", "carlo", " ", 
     RowBox[{"integration", ".", " ", "Return"}], " ", "a", " ", "point", " ", 
     RowBox[{"(", "3", ")"}]}], ",", " ", 
    RowBox[{"a", " ", "normal", " ", 
     RowBox[{"(", "3", ")"}], " ", "and", " ", "the", " ", "pdf", " ", 
     RowBox[{"(", "1", ")"}], " ", "on", " ", "the", " ", "rectangular", " ", 
     "light"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RectangularLight", "[", 
     RowBox[{"u_", ",", " ", "localToWorld_", ",", " ", "lightSize_"}], "]"}],
     ":=", " ", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"P", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"u", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", " ", "0.5"}], ")"}], " ", 
           "*", " ", 
           RowBox[{"lightSize", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"u", "[", 
              RowBox[{"[", "2", "]"}], "]"}], " ", "-", " ", "0.5"}], ")"}], 
           " ", "*", " ", 
           RowBox[{"lightSize", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", "0", ",", " ", "1"}], 
         "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Ns", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0", ",", " ", 
          RowBox[{"-", "1"}], ",", " ", "0"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"P", " ", "=", " ", 
        RowBox[{"localToWorld", ".", "P"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"Ns", " ", "=", " ", 
        RowBox[{"localToWorld", ".", "Ns"}]}], " ", ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"pdf", " ", "=", " ", 
        RowBox[{"1", " ", "/", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"lightSize", "[", 
            RowBox[{"[", "1", "]"}], "]"}], " ", "*", " ", 
           RowBox[{"lightSize", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"P", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
      RowBox[{"P", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
      RowBox[{"P", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", " ", 
      RowBox[{"Ns", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"Ns", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
      RowBox[{"Ns", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", " ", "pdf"}], 
     "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Brute", " ", "force", " ", "integration", " ", "of", " ", "a", " ", 
      "light", " ", "base", " ", "on", " ", "monte", " ", "carlo", " ", 
      RowBox[{"integration", ".", " ", "All"}], " ", "calculation", " ", 
      "are", " ", "in", " ", "local", " ", "space"}], ",", " ", 
     RowBox[{"normal", " ", "is", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], ",", " ", 
     RowBox[{"world", " ", "position", " ", "is", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Return", " ", "irradiance", " ", 
     RowBox[{"(", "1", ")"}], " ", "and", " ", "MRP", " ", "position", " ", 
     RowBox[{"(", "3", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntegrateRectangularLight", "[", 
     RowBox[{
     "sampleCount_", ",", " ", "localToWorld_", ",", " ", "lightSize_"}], 
     "]"}], ":=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"irradiance", " ", "=", " ", "0"}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"maxVal", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"MRPVal", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"MRPPosition", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Samples", " ", "loop"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"For", " ", "[", " ", 
        RowBox[{
         RowBox[{"sampleIt", " ", "=", " ", "0"}], ",", " ", 
         RowBox[{"sampleIt", " ", "<", " ", "sampleCount"}], ",", " ", 
         RowBox[{
          RowBox[{"sampleIt", "++"}], ";", " ", "\[IndentingNewLine]", 
          RowBox[{"u", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"sampleIt", " ", "/", " ", "sampleCount"}], ",", " ", 
             RowBox[{"RandomReal", "[", "]"}]}], "}"}]}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"sampleShape", " ", "=", " ", 
           RowBox[{"RectangularLight", "[", 
            RowBox[{"u", ",", " ", "localToWorld", ",", " ", "lightSize"}], 
            "]"}]}], ";", " ", "\[IndentingNewLine]", 
          RowBox[{"P", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"sampleShape", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
             RowBox[{"sampleShape", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
             RowBox[{"sampleShape", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], " ", "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Ns", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"sampleShape", "[", 
              RowBox[{"[", "4", "]"}], "]"}], ",", " ", 
             RowBox[{"sampleShape", "[", 
              RowBox[{"[", "5", "]"}], "]"}], ",", " ", 
             RowBox[{"sampleShape", "[", 
              RowBox[{"[", "6", "]"}], "]"}]}], " ", "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"pdf", " ", "=", " ", 
           RowBox[{"sampleShape", "[", 
            RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"sqrDist", " ", "=", " ", 
           RowBox[{"P", ".", "P"}]}], " ", ";", "\[IndentingNewLine]", 
          RowBox[{"L", " ", "=", " ", 
           RowBox[{"Normalize", "[", "P", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"val", " ", "=", " ", 
           RowBox[{
            RowBox[{"Clip", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"L", ".", "Ns"}]}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
            RowBox[{
             RowBox[{"Clip", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}], ".", 
                "L"}], ",", " ", 
               RowBox[{"{", 
                RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "/", " ", 
             RowBox[{"(", 
              RowBox[{"sqrDist", " ", "*", " ", "pdf"}], ")"}]}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"Keep", " ", "max"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"val", " ", "\[GreaterEqual]", " ", "maxVal"}], ",", 
            RowBox[{
             RowBox[{"maxVal", "=", "val"}], ";", 
             RowBox[{"MRPPosition", "=", "P"}]}], ",", " ", "0"}], "]"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"irradiance", " ", "+=", " ", "val"}]}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"irradiance", " ", "/", " ", "sampleCount"}]}], ",", " ", 
      RowBox[{"MRPPosition", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"MRPPosition", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
      RowBox[{"MRPPosition", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "\[IndentingNewLine]", 
     "}"}]}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.6132843504913425`*^9, 3.6132843813351064`*^9}, {
  3.613284421131383*^9, 3.6132845597363105`*^9}, {3.613284619280716*^9, 
  3.6132846879996467`*^9}, {3.6132847403226395`*^9, 3.613284816791013*^9}, {
  3.6132848525730596`*^9, 3.6132850131352434`*^9}, {3.6153947499699197`*^9, 
  3.6153947507405176`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Error", " ", "metric", " ", "to", " ", "estimate", " ", "which", " ", 
    "method", " ", "is", " ", "the", " ", "best"}], ",", " ", 
   RowBox[{
   "when", " ", "irradiance", " ", "reference", " ", "is", " ", "0", " ", 
    "we", " ", "just", " ", "return", " ", "0"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.615402310186445*^9, 3.615402346071002*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ErrorMetric", "[", 
    RowBox[{"val_", ",", " ", "ref_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ref", " ", "\[Equal]", " ", "0"}], ",", " ", "0", ",", " ", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"val", " ", "-", " ", "ref"}], "]"}], "/", " ", "ref"}]}], 
      "]"}], "\[IndentingNewLine]", "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ErrorMetric2", "[", 
   RowBox[{"val_", ",", " ", "ref_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"Abs", "[", 
     RowBox[{"val", " ", "-", " ", "ref"}], "]"}], "\[IndentingNewLine]", 
    "}"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6154022689562097`*^9, 3.6154023052798223`*^9}, {
  3.615402595191636*^9, 3.6154025995596905`*^9}, {3.615403035463544*^9, 
  3.6154030801992245`*^9}, {3.6154032703673725`*^9, 3.6154032706074033`*^9}, {
  3.6154036764474382`*^9, 3.615403680727482*^9}, {3.61540772398341*^9, 
  3.6154077319034157`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Function", " ", "to", " ", "evaluate", " ", "irradiance", " ", "for", " ",
     "rectangular", " ", 
    RowBox[{"light", ".", " ", "Provide"}], " ", "reference", " ", "result", 
    " ", "and", " ", "approximation", " ", "with", " ", "various", " ", 
    "method"}], "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "maxDistance", " ", "allow", " ", "to", " ", "generate", " ", "the", " ", 
    "rectangle", " ", "plane", " ", "in", " ", "at", " ", "mot", " ", "at", 
    " ", "the", " ", "limit", " ", "define", " ", "from", " ", "the", " ", 
    "worldPosition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "SelectOnly", " ", "allow", " ", "to", " ", "force", " ", "the", " ", 
     "generation", " ", "of", " ", "the", " ", "plane", " ", "to", " ", "be", 
     " ", "above", " ", "the", " ", "horizon", " ", 
     RowBox[{"(", "1", ")"}]}], ",", " ", 
    RowBox[{"or", " ", "cross", " ", "horizon", " ", 
     RowBox[{"(", "2", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "preComputeMatrix", " ", "and", " ", "worldLightMatrix", " ", "allow", " ",
     "to", " ", "specify", " ", "a", " ", "matrix", " ", "for", " ", 
    "rectangle", " ", "plane", " ", "rather", " ", "than", " ", "generating", 
    " ", "a", " ", "random", " ", "one"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"EvaluateDiffuseRectangularLight", "[", 
     RowBox[{
     "width_", ",", " ", "height_", ",", " ", "maxDistance_", ",", " ", 
      "SelectOnly_", ",", " ", 
      RowBox[{"preComputeMatrix_:", "0"}], ",", "  ", 
      RowBox[{"worldLightMatrix_", " ", ":", 
       RowBox[{"ScalingTransform", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", "1", ",", " ", "0"}], "}"}], "]"}]}]}], "]"}],
     ":=", " ", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"worldPos", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"worldNormal", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Generate", " ", "a", " ", "random", " ", "rectangular", " ", "light",
          " ", "facing", " ", "the", " ", "light", " ", 
         RowBox[{"(", 
          RowBox[{"other", " ", "case", " ", "are", " ", "0"}], " "}]}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"preComputeMatrix", " ", ">", " ", "0"}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", "true", " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"m", " ", "=", " ", "worldLightMatrix"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"right", " ", "=", " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{
             RowBox[{"TransformationMatrix", "[", "m", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"1", ";;", "3"}], ",", "1"}], "]"}], "]"}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"up", " ", "=", " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{
             RowBox[{"TransformationMatrix", "[", "m", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"1", ";;", "3"}], ",", "2"}], "]"}], "]"}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"forward", " ", "=", " ", 
           RowBox[{"Normalize", "[", 
            RowBox[{"Cross", "[", 
             RowBox[{"right", ",", " ", "up"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"planeNormal", " ", "=", " ", 
           RowBox[{"-", "forward"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"planePos", "  ", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"TransformationMatrix", "[", "m", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"1", ";;", "3"}], ",", "4"}], "]"}], "]"}], " ", "+", 
            "  ", 
            RowBox[{"0.5", "*", "width", " ", "*", " ", "right"}], " ", "+", 
            " ", 
            RowBox[{"0.5", "*", "height", " ", "*", " ", "up"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "calculate", " ", "coordinate", " ", "of", " ", "rectangle", " ", 
            "corner"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"V0", " ", "=", " ", 
           RowBox[{"planePos", " ", "-", " ", 
            RowBox[{"0.5", " ", "*", " ", "width", " ", "*", "right"}], " ", 
            "+", " ", 
            RowBox[{"0.5", "*", "height", " ", "*", "up"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"V1", " ", "=", " ", 
           RowBox[{"planePos", " ", "-", " ", 
            RowBox[{"0.5", " ", "*", " ", "width", " ", "*", "right"}], " ", 
            "-", " ", 
            RowBox[{"0.5", "*", "height", " ", "*", "up"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"V2", " ", "=", " ", 
           RowBox[{"planePos", " ", "+", " ", 
            RowBox[{"0.5", " ", "*", " ", "width", " ", "*", "right"}], " ", 
            "-", " ", 
            RowBox[{"0.5", "*", "height", " ", "*", "up"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"V3", " ", "=", " ", 
           RowBox[{"planePos", " ", "+", " ", 
            RowBox[{"0.5", " ", "*", " ", "width", " ", "*", "right"}], " ", 
            "+", " ", 
            RowBox[{"0.5", "*", "height", " ", "*", "up"}]}]}]}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", "false", " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"notGood", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"notGood", " ", "==", " ", "0"}], ",", " ", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"m", "=", " ", 
              RowBox[{"GetRandomTransform", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"width", ",", " ", "height", ",", " ", "0"}], "}"}], 
                ",", " ", "maxDistance"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"right", " ", "=", " ", 
              RowBox[{"Normalize", "[", 
               RowBox[{
                RowBox[{"TransformationMatrix", "[", "m", "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"1", ";;", "3"}], ",", "1"}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"up", " ", "=", " ", 
              RowBox[{"Normalize", "[", 
               RowBox[{
                RowBox[{"TransformationMatrix", "[", "m", "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"1", ";;", "3"}], ",", "2"}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"forward", " ", "=", " ", 
              RowBox[{"Normalize", "[", 
               RowBox[{"Cross", "[", 
                RowBox[{"right", ",", " ", "up"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"planeNormal", " ", "=", " ", 
              RowBox[{"-", "forward"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"planePos", "  ", "=", 
              RowBox[{
               RowBox[{
                RowBox[{"TransformationMatrix", "[", "m", "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"1", ";;", "3"}], ",", "4"}], "]"}], "]"}], " ", 
               "+", "  ", 
               RowBox[{"0.5", "*", "width", " ", "*", " ", "right"}], " ", 
               "+", " ", 
               RowBox[{"0.5", "*", "height", " ", "*", " ", "up"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
               RowBox[{
               "Regenerate", " ", "if", " ", "plane", " ", "facing", " ", 
                "away", " ", "for", " ", "surface", " ", "normal"}], ",", " ", 
               RowBox[{"it", " ", "will", " ", "be", " ", "0"}]}], " ", 
              "*)"}], "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", 
                   RowBox[{"worldPos", " ", "-", " ", "planePos"}], "]"}], 
                  ",", " ", "planeNormal"}], "]"}], " ", ">", " ", "0"}], ",",
                " ", 
               RowBox[{"notGood", " ", "=", " ", "1"}], ",", " ", 
               RowBox[{"notGood", " ", "=", "0"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
              "calculate", " ", "coordinate", " ", "of", " ", "rectangle", 
               " ", "corner"}], " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"V0", " ", "=", " ", 
              RowBox[{"planePos", " ", "-", " ", 
               RowBox[{"0.5", " ", "*", " ", "width", " ", "*", "right"}], 
               " ", "+", " ", 
               RowBox[{"0.5", "*", "height", " ", "*", "up"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"V1", " ", "=", " ", 
              RowBox[{"planePos", " ", "-", " ", 
               RowBox[{"0.5", " ", "*", " ", "width", " ", "*", "right"}], 
               " ", "-", " ", 
               RowBox[{"0.5", "*", "height", " ", "*", "up"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"V2", " ", "=", " ", 
              RowBox[{"planePos", " ", "+", " ", 
               RowBox[{"0.5", " ", "*", " ", "width", " ", "*", "right"}], 
               " ", "-", " ", 
               RowBox[{"0.5", "*", "height", " ", "*", "up"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"V3", " ", "=", " ", 
              RowBox[{"planePos", " ", "+", " ", 
               RowBox[{"0.5", " ", "*", " ", "width", " ", "*", "right"}], 
               " ", "+", " ", 
               RowBox[{"0.5", "*", "height", " ", "*", "up"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
              "Regenerate", " ", "if", " ", "request", " ", "the", " ", 
               "rectangular", " ", "light", " ", "is", " ", "above", " ", 
               "the", " ", "horizon"}], " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"SelectOnly", " ", "==", "  ", "1"}], " ", "&&", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", "V0", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", "<", " ", "0"}], " ", "||", 
                  " ", 
                  RowBox[{
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", "V1", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", "<", " ", "0"}], " ", "||", 
                  " ", 
                  RowBox[{
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", "V2", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", "<", " ", "0"}], " ", "||", 
                  " ", 
                  RowBox[{
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", "V3", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", "<", " ", "0"}]}], ")"}]}], 
               ",", " ", 
               RowBox[{"notGood", " ", "=", " ", "0"}], ","}], " ", "]"}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"SelectOnly", " ", "==", "  ", "2"}], " ", "&&", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", "V0", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", ">", " ", "0"}], " ", "&&", 
                  " ", 
                  RowBox[{
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", "V1", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", ">", " ", "0"}], " ", "&&", 
                  " ", 
                  RowBox[{
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", "V2", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", ">", " ", "0"}], " ", "&&", 
                  " ", 
                  RowBox[{
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", "V3", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", ">", " ", "0"}]}], ")"}]}], 
               ",", " ", 
               RowBox[{"notGood", " ", "=", " ", "0"}], ","}], " ", "]"}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
              "Regenerate", " ", "if", " ", "rectangular", " ", "light", " ", 
               "is", " ", "below", " ", "the", " ", "horizon", " ", "it", " ",
                "will", " ", "be", " ", "0"}], " ", "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Dot", "[", 
                   RowBox[{
                    RowBox[{"Normalize", "[", "V0", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", "<", " ", "0"}], " ", "&&", 
                 " ", 
                 RowBox[{
                  RowBox[{"Dot", "[", 
                   RowBox[{
                    RowBox[{"Normalize", "[", "V1", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", "<", " ", "0"}], " ", "&&", 
                 " ", 
                 RowBox[{
                  RowBox[{"Dot", "[", 
                   RowBox[{
                    RowBox[{"Normalize", "[", "V2", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", "<", " ", "0"}], " ", "&&", 
                 " ", 
                 RowBox[{
                  RowBox[{"Dot", "[", 
                   RowBox[{
                    RowBox[{"Normalize", "[", "V3", "]"}], ",", " ", 
                    "worldNormal"}], "]"}], " ", "<", " ", "0"}]}], ")"}], 
               ",", " ", 
               RowBox[{"notGood", " ", "=", " ", "0"}], ","}], " ", "]"}], 
             ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "solidAngle", " ", "calculation", " ", "use", " ", "in", " ", 
         "several", " ", "method"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"solidAngle", " ", "=", " ", 
        RowBox[{"RectangleSolidAngle", "[", 
         RowBox[{
         "worldPos", ",", " ", "V0", ",", " ", "V1", ",", " ", "V2", ",", " ",
           "V3"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
       RowBox[{"solidAngleHorizon", " ", "=", " ", 
        RowBox[{"RectangleSolidAngleMC", "[", 
         RowBox[{
         "worldPos", ",", " ", "planePos", ",", "  ", "planeNormal", ",", " ",
           "right", ",", "up", ",", "  ", 
          RowBox[{"0.5", " ", "*", " ", "width"}], " ", ",", " ", 
          RowBox[{"0.5", "*", "height"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"True", " ", "integration"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"localToWorld", " ", "=", 
        RowBox[{"{", "\[IndentingNewLine]", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"right", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
            RowBox[{"up", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
            RowBox[{"forward", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
            RowBox[{"planePos", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"right", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
            RowBox[{"up", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
            RowBox[{"forward", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
            RowBox[{"planePos", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"right", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", " ", 
            RowBox[{"up", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", " ", 
            RowBox[{"forward", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", " ", 
            RowBox[{"planePos", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "0", ",", " ", "0", ",", " ", "0"}], 
           "}"}]}], "\[IndentingNewLine]", "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"reference", " ", "=", 
        RowBox[{"IntegrateRectangularLight", "[", 
         RowBox[{"10000", ",", " ", "localToWorld", ",", " ", 
          RowBox[{"{", 
           RowBox[{"width", ",", " ", "height", ",", " ", "0"}], "}"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"referenceIrradiance", " ", "=", " ", 
        RowBox[{"reference", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"referenceMRP", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"reference", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
          RowBox[{"reference", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", " ", 
          RowBox[{"reference", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Irradiance", " ", "with", " ", "best", " ", "MRP"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"referenceMRPIrradiance", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "referenceMRP", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", "  ", 
         "solidAngle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"referenceMRPIrradianceHorizon", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "referenceMRP", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", "  ", 
         "solidAngleHorizon"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Drobot", " ", "GPU", " ", "Pro", " ", "5", " ", "method"}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"pyramidSolidAngleNormalized", " ", "=", " ", 
          RowBox[{
           RowBox[{"RectangularPyramidSolidAngle", "[", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"planePos", " ", "-", " ", "worldPos"}], "]"}], ",", 
             " ", 
             RowBox[{"{", 
              RowBox[{"width", ",", " ", "height"}], "}"}]}], "]"}], " ", "/",
            " ", 
           RowBox[{"(", 
            RowBox[{"2", " ", "*", " ", "\[Pi]"}], ")"}]}]}], ";"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"pp0", " ", "=", " ", 
        RowBox[{"RayPlaneIntersection", "[", 
         RowBox[{
         "worldPos", ",", " ", "worldNormal", ",", " ", "planePos", ",", " ", 
          "planeNormal"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"p0", " ", "=", " ", 
        RowBox[{"closestPointRect", "[", 
         RowBox[{
         "pp0", ",", " ", "planePos", ",", " ", "right", ",", " ", "up", ",", 
          " ", 
          RowBox[{"0.5", "*", "width"}], ",", " ", 
          RowBox[{"0.5", "*", "height"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p1", " ", "=", " ", 
        RowBox[{"closestPointRect", "[", 
         RowBox[{
         "worldPos", ",", " ", "planePos", ",", " ", "right", ",", " ", "up", 
          ",", " ", 
          RowBox[{"0.5", "*", "width"}], ",", " ", 
          RowBox[{"0.5", "*", "height"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"DrobotMRP", " ", "=", " ", 
        RowBox[{"0.5", " ", "*", " ", 
         RowBox[{"(", 
          RowBox[{"p0", "+", "p1"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DrobotIrradiance", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "DrobotMRP", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DrobotIrradianceHorizon", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "DrobotMRP", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngleHorizon"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Simplied", " ", "version", " ", "of", " ", "Drobot"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"clampAngle", " ", "=", " ", 
        RowBox[{"0.0000001", " ", "+", " ", 
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{"worldNormal", ",", " ", "planeNormal"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"d0", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{
          RowBox[{"-", "planeNormal"}], "+", 
          RowBox[{"worldNormal", "*", "clampAngle"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"d1", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{"worldNormal", "-", 
          RowBox[{"planeNormal", "*", "clampAngle"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"finalDir", "=", 
        RowBox[{"0.5", "*", 
         RowBox[{"(", 
          RowBox[{"d0", "+", "d1"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"simplifiedDrobotMRP", "=", 
        RowBox[{"RayPlaneIntersection", "[", 
         RowBox[{
         "worldPos", ",", "finalDir", ",", "planePos", ",", "planeNormal"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"simplifiedDrobotMRP", "=", 
        RowBox[{"closestPointRect", "[", 
         RowBox[{
         "simplifiedDrobotMRP", ",", "planePos", ",", " ", "right", ",", " ", 
          "up", ",", " ", 
          RowBox[{"0.5", "*", "width"}], ",", " ", 
          RowBox[{"0.5", "*", "height"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"simplifiedDrobotIrradiance", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "simplifiedDrobotMRP", "]"}], ",", " ",
              "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"simplifiedDrobotIrradianceHorizon", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "simplifiedDrobotMRP", "]"}], ",", " ",
              "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngleHorizon"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"OneShotApproximateLocalShading", " ", "paper"}], " ", "*)"}],
        "\[IndentingNewLine]", 
       RowBox[{"oneShotMRP", " ", "=", " ", 
        RowBox[{"OneShotApproximateLocalShading", "[", 
         RowBox[{
         "worldPos", ",", " ", "worldNormal", ",", " ", "planePos", ",", 
          "planeNormal", ",", " ", 
          RowBox[{"0.5", "*", "width"}], ",", " ", 
          RowBox[{"0.5", "*", "height"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"oneShotMRPIrradiance", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "oneShotMRP", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"oneShotMRPIrradianceHorizon", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "oneShotMRP", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngleHorizon"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Simple", " ", "approximation", " ", "by", " ", "directly", " ", 
         "taking", " ", "the", " ", "plane", " ", "position", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"doesn", "'"}], "t", " ", "handle", " ", "the", " ", 
           "horizon"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"planePosMRPIrradiance", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "planePos", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"planePosMRPIrradianceHorizon", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "planePos", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngleHorizon"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "approximation", " ", "by", " ", "taking", " ", "the", " ", "average",
          " ", "of", " ", "the", " ", "cosine", " ", "at", " ", "four", " ", 
         "rectangular", " ", "angle"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"averageCosine4Irradiance", " ", "=", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"0.25", "*", 
            RowBox[{"(", " ", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "V0", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", " ", "0"}], "]"}], " ", "+", 
              "\[IndentingNewLine]", " ", 
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "V1", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", " ", "0"}], "]"}], " ", "+", 
              " ", "\[IndentingNewLine]", 
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "V2", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", " ", "0"}], "]"}], " ", "+", 
              " ", "\[IndentingNewLine]", 
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "V3", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", " ", "0"}], "]"}]}], 
             "\[IndentingNewLine]", ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], "*", " ", 
         "solidAngle"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "approximation", " ", "by", " ", "taking", " ", "the", " ", "average",
          " ", "of", " ", "the", " ", "cosine", " ", "at", " ", "four", " ", 
         "rectangular", " ", "angle"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"averageCosine5Irradiance", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"0.2", "*", 
            RowBox[{"(", " ", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "V0", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", " ", "0"}], "]"}], " ", "+", 
              " ", "\[IndentingNewLine]", 
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "V1", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", " ", "0"}], "]"}], " ", "+", 
              " ", "\[IndentingNewLine]", 
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "V2", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", " ", "0"}], "]"}], " ", "+", 
              " ", "\[IndentingNewLine]", 
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "V3", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", " ", "0"}], "]"}], " ", "+", 
              " ", "\[IndentingNewLine]", 
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{"Dot", "[", 
                 RowBox[{
                  RowBox[{"Normalize", "[", "planePos", "]"}], ",", " ", 
                  "worldNormal"}], "]"}], ",", "0"}], "]"}]}], ")"}]}], ",", 
           " ", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", 
         "solidAngle"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Form", " ", "factor", " ", 
         RowBox[{"solution", ".", " ", "Only"}], " ", "work", " ", "when", 
         " ", "above", " ", "the", " ", "horizon"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"formFactorIrradiance", " ", "=", " ", 
        RowBox[{"QuadFormFactor", "[", 
         RowBox[{
         "worldPos", ",", " ", "worldNormal", ",", " ", "planePos", ",", " ", 
          "planeNormal", ",", " ", "V0", ",", "V1", ",", "V2", ",", "V3"}], 
         "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Weight", " ", "sum", " ", "of", " ", "cosines"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"WeightSum", " ", "=", " ", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "V0", "]"}], ",", " ", "worldNormal"}],
             "]"}], ",", " ", "0"}], "]"}], " ", "+", " ", 
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "V1", "]"}], ",", " ", "worldNormal"}],
             "]"}], ",", " ", "0"}], "]"}], " ", "+", " ", 
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "V2", "]"}], ",", " ", "worldNormal"}],
             "]"}], ",", " ", "0"}], "]"}], " ", "+", " ", 
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "V3", "]"}], ",", " ", "worldNormal"}],
             "]"}], ",", " ", "0"}], "]"}], " ", "+", " ", 
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "planePos", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", "0"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"w0", " ", "=", "  ", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "V0", "]"}], ",", " ", "worldNormal"}],
             "]"}], ",", " ", "0"}], "]"}], " ", "/", " ", "WeightSum"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"w1", " ", "=", "  ", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "V1", "]"}], ",", " ", "worldNormal"}],
             "]"}], ",", " ", "0"}], "]"}], " ", "/", " ", "WeightSum"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"w2", " ", "=", "  ", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "V2", "]"}], ",", " ", "worldNormal"}],
             "]"}], ",", " ", "0"}], "]"}], " ", "/", " ", "WeightSum"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"w3", " ", "=", "  ", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "V3", "]"}], ",", " ", "worldNormal"}],
             "]"}], ",", " ", "0"}], "]"}], " ", "/", " ", "WeightSum"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"w4", " ", "=", "  ", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "planePos", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", " ", "0"}], "]"}], " ", "/", " ", 
         "WeightSum"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"weightMRP", " ", "=", " ", 
        RowBox[{
         RowBox[{"w0", " ", "*", " ", "V0"}], "+", " ", 
         RowBox[{"w1", "*", " ", "V1"}], " ", "+", " ", 
         RowBox[{"w2", " ", "*", " ", "V2"}], " ", "+", " ", 
         RowBox[{"w3", " ", "*", " ", "V3"}], " ", "+", " ", 
         RowBox[{"w4", "*", "planePos"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"weightMRPIrradiance", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "weightMRP", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"weightMRPIrradianceHorizon", " ", "=", " ", 
        RowBox[{
         RowBox[{"Clip", "[", 
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             RowBox[{"Normalize", "[", "weightMRP", "]"}], ",", " ", 
             "worldNormal"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "1"}], "}"}]}], "]"}], " ", "*", " ", 
         "solidAngleHorizon"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Draw", " ", "result"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Graphics3D", "[", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Point", "[", "worldPos", "]"}], ",", "\[IndentingNewLine]",
           "hemisphere", ",", "\[IndentingNewLine]", 
          RowBox[{"GeometricTransformation", "[", 
           RowBox[{
            RowBox[{"Cuboid", "[", "]"}], ",", " ", "m"}], "]"}], ",", "  ", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "widget", " ", "for", " ", "local", " ", "frame", " ", "of", " ", 
            "the", " ", "plane"}], " ", "*)"}], "\[IndentingNewLine]", "Red", 
          ",", " ", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{"planePos", ",", " ", 
             RowBox[{"planePos", " ", "+", " ", 
              RowBox[{"3", " ", "*", " ", "right"}]}]}], "}"}], "]"}], ",", 
          " ", "\[IndentingNewLine]", "Green", ",", " ", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{"planePos", ",", " ", 
             RowBox[{"planePos", " ", "+", " ", 
              RowBox[{"3", " ", "*", " ", "up"}]}]}], "}"}], "]"}], ",", " ", 
          "\[IndentingNewLine]", "Blue", ",", " ", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{"planePos", ",", " ", 
             RowBox[{"planePos", " ", "+", " ", 
              RowBox[{"3", " ", "*", " ", "forward"}]}]}], "}"}], "]"}], ",", 
          "\[IndentingNewLine]", "Gray", ",", " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
             "referenceMRP"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Purple", ",", " ", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
               "DrobotMRP"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
            "Yellow", ",", " ", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
               "simplifiedDrobotMRP"}], "}"}], "]"}], ",", 
            "\[IndentingNewLine]", "Red", ",", " ", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
               "oneShotMRP"}], "}"}], "]"}], ","}], "*)"}], 
          "\[IndentingNewLine]", "Red", ",", " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
             "weightMRP"}], "}"}], "]"}]}], "\[IndentingNewLine]", "}"}], 
        "]"}]}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "\"\<referenceIrradiance\>\"", ",", " ", "referenceIrradiance", 
            ",", " ", "0", ",", " ", "0"}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<formFactorIrradiance\>\"", ",", " ", "formFactorIrradiance", 
            ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "formFactorIrradiance", " ", ",", "referenceIrradiance"}], "]"}],
             ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "formFactorIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<solidAngle\>\"", ",", " ", "solidAngle", ",", " ", "0", ",", 
            " ", "0"}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<referenceMRPIrradiance\>\"", ",", " ", 
            "referenceMRPIrradiance", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "referenceMRPIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "referenceMRPIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<DrobotIrradiance\>\"", ",", " ", "DrobotIrradiance", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{"DrobotIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{"DrobotIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<simplifiedDrobotIrradiance\>\"", ",", " ", 
            "simplifiedDrobotIrradiance", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "simplifiedDrobotIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "simplifiedDrobotIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<oneShotMRPIrradiance\>\"", ",", " ", "oneShotMRPIrradiance", 
            ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "oneShotMRPIrradiance", " ", ",", "referenceIrradiance"}], "]"}],
             ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "oneShotMRPIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<planePosMRPIrradiance\>\"", ",", " ", "planePosMRPIrradiance",
             ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "planePosMRPIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "planePosMRPIrradiance", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<weightMRPIrradiance\>\"", ",", " ", "weightMRPIrradiance", 
            ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{"weightMRPIrradiance", " ", ",", "referenceIrradiance"}],
              "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{"weightMRPIrradiance", " ", ",", "referenceIrradiance"}],
              "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<solidAngleHorizon\>\"", ",", " ", "solidAngleHorizon", ",", 
            " ", "0", ",", " ", "0"}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<referenceMRPIrradianceHorizon\>\"", ",", " ", 
            "referenceMRPIrradianceHorizon", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "referenceMRPIrradianceHorizon", " ", ",", 
              "referenceIrradiance"}], "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "referenceMRPIrradianceHorizon", " ", ",", 
              "referenceIrradiance"}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<DrobotIrradianceHorizon\>\"", ",", " ", 
            "DrobotIrradianceHorizon", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "DrobotIrradianceHorizon", " ", ",", "referenceIrradiance"}], 
             "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "DrobotIrradianceHorizon", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<simplifiedDrobotIrradianceHorizon\>\"", ",", " ", 
            "simplifiedDrobotIrradianceHorizon", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "simplifiedDrobotIrradianceHorizon", " ", ",", 
              "referenceIrradiance"}], "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "simplifiedDrobotIrradianceHorizon", " ", ",", 
              "referenceIrradiance"}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<oneShotMRPIrradianceHorizon\>\"", ",", " ", 
            "oneShotMRPIrradianceHorizon", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "oneShotMRPIrradianceHorizon", " ", ",", "referenceIrradiance"}],
              "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "oneShotMRPIrradianceHorizon", " ", ",", "referenceIrradiance"}],
              "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<planePosMRPIrradianceHorizon\>\"", ",", " ", 
            "planePosMRPIrradianceHorizon", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "planePosMRPIrradianceHorizon", " ", ",", 
              "referenceIrradiance"}], "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "planePosMRPIrradianceHorizon", " ", ",", 
              "referenceIrradiance"}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<weightMRPIrradianceHorizon\>\"", ",", " ", 
            "weightMRPIrradianceHorizon", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "weightMRPIrradianceHorizon", " ", ",", "referenceIrradiance"}], 
             "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "weightMRPIrradianceHorizon", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<solidAngle\>\"", ",", " ", "solidAngle", ",", " ", "0", ",", 
            " ", "0"}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<averageCosine4Irradiance\>\"", ",", " ", 
            "averageCosine4Irradiance", ",", " ", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "averageCosine4Irradiance", " ", ",", "referenceIrradiance"}], 
             "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "averageCosine4Irradiance", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<averageCosine5Irradiance\>\"", ",", " ", 
            "averageCosine5Irradiance", ",", 
            RowBox[{"ErrorMetric", "[", 
             RowBox[{
             "averageCosine5Irradiance", " ", ",", "referenceIrradiance"}], 
             "]"}], ",", " ", 
            RowBox[{"ErrorMetric2", "[", 
             RowBox[{
             "averageCosine5Irradiance", " ", ",", "referenceIrradiance"}], 
             "]"}]}], "}"}]}], "\[IndentingNewLine]", "}"}], ",", " ", 
        RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}], "\[IndentingNewLine]",
      "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6132848539471383`*^9, 3.6132848625756316`*^9}, 
   3.613284895607521*^9, {3.613304615543437*^9, 3.6133046767469378`*^9}, {
   3.6133047104908676`*^9, 3.6133048156118803`*^9}, {3.6133050059067645`*^9, 
   3.6133050301621513`*^9}, {3.6133051158440523`*^9, 
   3.6133051912343645`*^9}, {3.6133052405481853`*^9, 
   3.6133052615713873`*^9}, {3.613305296323375*^9, 3.613305302810746*^9}, {
   3.613305403302494*^9, 3.61330550009103*^9}, {3.6133055315168276`*^9, 
   3.613305535067031*^9}, {3.613305567851906*^9, 3.613305770412492*^9}, {
   3.613305813062931*^9, 3.6133060543117294`*^9}, {3.613306097013172*^9, 
   3.6133061123990517`*^9}, {3.6133063552829447`*^9, 
   3.6133063719158955`*^9}, {3.6133064054968166`*^9, 
   3.6133064356975436`*^9}, {3.6133064963950157`*^9, 3.6133065124309325`*^9}, 
   3.613307403240884*^9, {3.613307447016388*^9, 3.6133074781351676`*^9}, {
   3.6133075700244236`*^9, 3.6133075773108406`*^9}, {3.6133076228794465`*^9, 
   3.613307748608638*^9}, {3.6133077941442423`*^9, 3.613307859631988*^9}, {
   3.6133079072647123`*^9, 3.6133079547134266`*^9}, {3.613308008748517*^9, 
   3.6133080108596377`*^9}, {3.613308043397499*^9, 3.6133080681809163`*^9}, {
   3.6133170113204346`*^9, 3.613317011480444*^9}, {3.613317134132459*^9, 
   3.6133171738607316`*^9}, {3.613317622206375*^9, 3.613317687002082*^9}, {
   3.613317757972141*^9, 3.6133177846606674`*^9}, {3.613317972443408*^9, 
   3.6133181130984526`*^9}, {3.613318143377185*^9, 3.613318152072682*^9}, {
   3.6133182146892633`*^9, 3.6133182892895308`*^9}, 3.613318391145356*^9, {
   3.6133185585229297`*^9, 3.613318559154966*^9}, {3.613318598619223*^9, 
   3.6133186042905474`*^9}, {3.6133186424747314`*^9, 3.613318646105939*^9}, {
   3.613318699846013*^9, 3.613318719513138*^9}, {3.613319332490198*^9, 
   3.6133194052023573`*^9}, {3.6133194619066005`*^9, 3.613319470067067*^9}, {
   3.6133195183638296`*^9, 3.6133195199259186`*^9}, {3.613319655946699*^9, 
   3.613319662561077*^9}, {3.6133197004082417`*^9, 3.6133197157941217`*^9}, {
   3.6133197649009304`*^9, 3.6133197671870613`*^9}, {3.613320093114703*^9, 
   3.613320096794914*^9}, {3.6133204703492804`*^9, 3.6133204709003115`*^9}, {
   3.613320512732704*^9, 3.613320519983119*^9}, {3.6133205528119965`*^9, 
   3.613320554667103*^9}, {3.6133233169080935`*^9, 3.6133233192642283`*^9}, {
   3.6133236185573473`*^9, 3.613323619458399*^9}, {3.6133244451106234`*^9, 
   3.613324456575279*^9}, {3.6133244899761896`*^9, 3.6133246564417105`*^9}, {
   3.6133247072216153`*^9, 3.6133247441257257`*^9}, {3.6133258659468904`*^9, 
   3.6133258673949733`*^9}, {3.61332772216606*^9, 3.6133278474782276`*^9}, 
   3.613327929533921*^9, 3.613327974680503*^9, {3.613328726485504*^9, 
   3.613328760021422*^9}, 3.6133287933903303`*^9, {3.6133289294391117`*^9, 
   3.613329003229333*^9}, {3.61332907696455*^9, 3.613329148630649*^9}, {
   3.6133297932525196`*^9, 3.613329840349213*^9}, {3.613330852693116*^9, 
   3.613330869509078*^9}, {3.6133310453201337`*^9, 3.6133310464872007`*^9}, {
   3.613332474062853*^9, 3.6133324880696545`*^9}, {3.6133325244397345`*^9, 
   3.6133327052000732`*^9}, {3.613332797421348*^9, 3.613332848135249*^9}, {
   3.6133329078136625`*^9, 3.6133331769440556`*^9}, {3.613333903200595*^9, 
   3.613333934963412*^9}, {3.613334041425501*^9, 3.6133341259213343`*^9}, {
   3.6133343030194635`*^9, 3.61333430348849*^9}, {3.6133366257733173`*^9, 
   3.6133367338955016`*^9}, {3.61333863624831*^9, 3.6133387392081985`*^9}, {
   3.6133387727321167`*^9, 3.6133388090421934`*^9}, {3.6134043772946157`*^9, 
   3.613404486580867*^9}, {3.613404690794547*^9, 3.613404727423642*^9}, {
   3.613404805033081*^9, 3.613404812015481*^9}, 3.6134048878668194`*^9, {
   3.613406031738245*^9, 3.6134060506343255`*^9}, {3.6134064477650404`*^9, 
   3.6134064643149867`*^9}, {3.613406656949005*^9, 3.613406669263709*^9}, {
   3.613406734470439*^9, 3.613406794401867*^9}, 3.6134068487199736`*^9, {
   3.613406879824753*^9, 3.6134070309653974`*^9}, {3.6134070623701935`*^9, 
   3.6134071133991127`*^9}, {3.613407152674359*^9, 3.6134072085245533`*^9}, {
   3.613407330034503*^9, 3.613407384787635*^9}, {3.613407415635399*^9, 
   3.6134074278730993`*^9}, {3.613407462316069*^9, 3.61340749501894*^9}, {
   3.6134075564204516`*^9, 3.613407624521347*^9}, {3.613407709818226*^9, 
   3.6134077636473045`*^9}, {3.6134078165343294`*^9, 3.613407907896555*^9}, {
   3.6153922562982635`*^9, 3.6153923435778465`*^9}, {3.615393129987708*^9, 
   3.615393135524411*^9}, {3.615394884733032*^9, 3.6153948919319468`*^9}, {
   3.6153961693161535`*^9, 3.615396200731143*^9}, {3.615396406843816*^9, 
   3.61539642105262*^9}, {3.6154000730833693`*^9, 3.6154002341253185`*^9}, {
   3.6154002642441435`*^9, 3.6154002662208943`*^9}, {3.615401052468235*^9, 
   3.615401228913641*^9}, {3.6154012764341755`*^9, 3.6154012800906396`*^9}, {
   3.6154019604670362`*^9, 3.615401992975664*^9}, 3.615402035968624*^9, {
   3.615402367534727*^9, 3.615402434138685*^9}, {3.6154024851001563`*^9, 
   3.6154025109469385`*^9}, {3.6154040834851255`*^9, 3.615404104427785*^9}, {
   3.6154077454686384`*^9, 3.615407809630786*^9}, {3.615521127206865*^9, 
   3.615521138656819*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Evaluation", " ", "function", " ", "to", " ", "play"}], ",", " ", 
    RowBox[{
     RowBox[{
     "get", " ", "a", " ", "feeling", " ", "of", " ", "how", " ", "thing", 
      " ", "work", " ", "etc"}], "..."}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"EvaluateDiffuseRectangularLight", "[", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{"{", 
       RowBox[{"0.1", ",", " ", "10"}], "}"}], "]"}], ",", " ", 
     RowBox[{"RandomReal", "[", 
      RowBox[{"{", 
       RowBox[{"0.1", ",", " ", "10"}], "}"}], "]"}], ",", " ", 
     RowBox[{"RandomReal", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", " ", "10"}], "}"}], "]"}], ",", "1"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 3}},
 CellChangeTimes->{
  3.6133244184881*^9, {3.613324760264649*^9, 3.613324766424001*^9}, {
   3.6133323021610208`*^9, 3.6133323427933445`*^9}, 3.613333196817192*^9, 
   3.613333248657157*^9, 3.6133339960969086`*^9, 3.613334651833414*^9, 
   3.6133359430242662`*^9, {3.613336034208482*^9, 3.6133360431519933`*^9}, {
   3.6133388340646243`*^9, 3.61333884395219*^9}, 3.613404839732066*^9, {
   3.6134049934618587`*^9, 3.613404993604867*^9}, {3.61340502424562*^9, 
   3.6134050291969028`*^9}, 3.613407315525673*^9, 3.6134079509400167`*^9, 
   3.6134080386780353`*^9, 3.6153928201768665`*^9, {3.615394992887766*^9, 
   3.615395064831402*^9}, 3.6153969165995464`*^9, 3.6153969697757993`*^9, {
   3.6153974493121924`*^9, 3.6153974509594016`*^9}, {3.615399946607809*^9, 
   3.6153999727691307`*^9}, 3.6154004974237537`*^9, 3.615401887280243*^9, {
   3.61540267971987*^9, 3.615402680215433*^9}, {3.615531883370224*^9, 
   3.6155319232817926`*^9}, {3.615537666068548*^9, 3.6155376734514856`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   Graphics3DBox[{Point3DBox[{0, 0, 0}], GraphicsComplex3DBox[CompressedData["
1:eJzVWXdU1VcSRjSuJWYjRuNaNgpZO8oSy6rkDXrceESxoCbHGkuMLSZR41pQ
wC5gA1FUELuLKx41djBvgoIFPWIEXbBhSywBG2pUFPf3eHMvJ1/OPe/sX5vl
H877mDd35pu5c2eG+sO+Chrh7ubmdrSMm1tZ63eLrhsTu/85xN6u+LX1k0dv
dCv5bBsyec+k6OBD3HvG4HtxvqX40YEzb3+fdpIfe06acyj7ksZHxQyuub4w
i4NS/xRwpFyuxuc8ar3c+szb7nsnryvM0niXzckHrO/zluFj/2jp0/j6Ht4V
433zOCzq5tqlwYc0Xvd1iX3s5vwJM8izQT8b7GGD/Wzwlw38aBz41Pg3lcb1
Kh44w674bDKl5Pvk2Tc2NTUthe9mvtto8JgrGm82aEHCXI+T/PT+O3N21L6k
8TV3yz2OmpjFfs8GRDT/LEfj8yrHZlmfuXK2z0rr7xqPeFhpv/V9TuIbGXM8
Tmr866h2Ha3zuPPtxb9wWorGfUKc/iieDfJs0M8Ge9hgPxv8ZQM/Ggc+NV4x
bERl9gy2q/yMHFQSP6rSqNmaaVsPaj4VXs6rz9Uj5U6wz+Zi7zPPczX+7ebp
EWee/8A73JudnRFxXuMb7+RUD4k4z5/fXtvK+rvGt/1SY5D1fY4+8F0dS5/G
a9Xzi3f4k1Nw/cmUrQc1nurlzCfFs0GeDfrZYA8b7GeDv2zgR+PAp8YTeri/
2XjhZLu670+d94cSrvntOtZpn85Phfu7/yE9Z2+65lPhb9d/6RXvm8kDlnfM
Hb8kS+M5US+rTViSxRer71ka55upcd+alYoc/ry5ILC2pU/jxeG91jryKW9B
foejnfZpvOxh531WPBvk2aCfDfawwX42+MsGfkrxX/Op8S621vW6HZtgV/Wz
VWFJ/aIPxm0a8bfDu/R9V/ilLz+q49czVeenwiMulM+pfe245lPhLUrueyY/
uRY9zPq7xpu83+ZjR/4cWJ8f075nqsbrJt9KdNxff88D/m0O79J42wfOeqp4
NsizQT8b7GGD/Wzwlw38aBz41PiN/HFp33uOsav3qMaWkveD2k4PHzl8f6Ku
nwo/XndTpL3mAX3fFf7iZOJPDn9Ufiq8xevggY58UHwq3JmfJ7ja+Y6Z39U8
oPFT7zS87qinnpNyM4fuT9T42M+c75ni2SDPBv1ssIcN9rPBXzbwo3HgU+Pz
0o9+/cPp/nb1vof0LHm/6dqFjy/V7r9Kv0cK3/3AI2qYpV/VT4W/PXJxjCOf
1H1XeNx7x+c47rPKT4UHxo5+f6pV3xSfCv+ihM8U7p7ZpF2t/qs0HhDt7CcU
zwZ5Nuhngz1ssJ8N/rKBH40Dnxp3+/VPmPPX1d877vb/hgv/NuRf4kUYL4kv
YXwlHwjzQfKHMH8k3wjzTfKTMD8ln7UfBnm8L4T3BezB+0h4H8FfvO+E9x34
1LjUExvWE6k/hPVH6hVhvZL6RljfpB4S1kOpn4T1U+otYb2V+qx5Nshj/Ses
/2APvi+E7wv4i+8X4fsFfGpc3kcbvo/ynhK+p/L+Er6/8l4TvtfyvhO+79IP
EPYD0j8Q9g/Sb2ieDfLYzxD2M2AP9kuE/RL4i/0YYT8GfGpc+j0b9nvSHxL2
h9JPEvaT0n8S9p/SrxL2q9LfEva30g8T9sPSP2ueDfLYnxP252AP9v+E/T/4
i/MF4XwBfGpc5hcbzi8y7xDOOzIfEc5HMk8RzlMyfxHOXzKvEc5rMt8Rzncy
D2qeDfI4bxLOm2APzrOE8yz4i/My4bwMfGpc5nEbzuMyvxPO7zLvE877sh8g
3A/IPoFwnyD7B8L9g+wrCPcVst/QPBvkcX9CuD8Be3A/Q7ifAX9x/0O4/wE+
NS77JRvul2QfRbiPkv0V4f5K9l2E+y7ZjxHux2SfRrhPk/0b4f5N9nWaZ4M8
7gMJ94FgD+4bCfeN4C/uMwn3mcCnxpPr+rSclTSV1y3KXLY0OImaJvdfNONU
Hk3MCuhRdC+aCzp2H3C/yjaNP6py8eyJ0AROWzl5qfvfEzXeqPMOiui0iYum
DC0M77RJ4289u3rCkuOKsXXrWN/T+OLWj0Isvdyu9/LZL+5Fa9zZvyVxzwd9
L4QkTTXhbNDDhnPZYCcb/GIDDxoH3hAnxEUPoR45l/BcsZPQTvGL0C/hgZAH
4Y2QN8AxLoRxgXMx7oRxB78wrwjzCnjTeOjAOV1jLB6rnTt2J3BVHtX1DE3a
vzWJij9dND+rYIa9y6rLoQ45hYM8G+Q1fuq+X36z2eE87dkTr5SHpfbAABSm
5qDwduUrfZG3ki8Wr42plLXVpXxI62OZRVfW8+ng+XtzRm1xKT/s08xnlhxn
e40Otr7nUv7OGxOOWHbwRV7WeWzeSpfys2o/b2/5ycWzxnZuOjvcpXy/nWn3
dm9N0vuB/1I/G+TdDPa7lAd+XMoD/y7lIb4u5SF/XMq70EOoR+whtEf8IvRL
+CHkR3gm5FniRRgvibu21yBPBv1ksIcM9pPBX40DP1gfyHDfbXjfQV7XjaD6
zt+qnqj3UXB2gTPghDjYo8+dEnqjha/fRPY/fcc2LjCervi8zKhTmEfZ/wjI
uP5sLv9l+Ort5+auLsXfeuGdGb+Un67osjl9dKzGG/hkVMkfuZx7Rr2q16j+
Mo2HDi3YQfVW8fDUqIWP0yM1fuxwQYOKK+K4w5nGFRtkhGrcGfd4HnB3Q1Db
1H4ab/9NuV6WfZzcavtcH8tehQf96+l5yz7ubV/u7rBX4WsWZ9+w7ON++7LP
nbbsVXjjwTHjLft4y5D09J8texVuK07t8iQ9kpeu3hzssFfh9YesSGyYEcp7
PN0rOuw14GTQQ4ZzyWAnGfwy8WDijQ08syEubIgjG+LOhjzROOQV4oS48EnI
s+gn1C88E8ZL7CS0U/gnjLv4S+ivxIUwf4Q3Qt4kXoR5KPwT8i9xJMxniSNh
HAHHfCDMBzgX84owr8AvzE/C/ATeMM8J8xzigveF8L5A3MmQJ2TIK43DQxem
3rsJAcu+Sng6i897X66aW7NUj+AkOLvS03ddIb27cDEnZU7fc6r7Sq1HcBLc
pZ5bAb4N9neL4aF703P3dYvRegQnwV3qGf/JqwLHeX+dmL+ghnW+khecBHep
5+TMJa0c/u9KiNy4xuJDyQtOgrvUUz12yNkq8+O52wcZr3P3jdZ6BCfBTXrc
DHrYoMcUd60H/GKDXy71AM9s4NmlHog7G+LuUg/kIRvy0KUeuBdsuBcu9fSO
bjsmxXqPWvr5HLT9lEdze7zXseveeMRZ4aAgTOn5neNu/2tc+CTkE3DN//UK
fh/aXgTYF+9wzlWqj60w1beqv/XelAnce9vRR6j4irxN5HXfC3rIoIcMevBc
QvmuO2+O9fYIsde81S7N8VnZD/LazqxRxf0vW3Uh49uPjjrqAeAkuEkecUI9
B7uXnM9ij+6rBSfExX4b2g96COSVv6Z7oeMO+hn0E+qfd7fNy5f3oik4N71B
pzLp9LLMzZyAllfon1lX45pbc03ZPoPC9weW/h9Q5NkgzyjfvHPTJa2sPuaT
k3U6txq1l6pWeDWsw8Lf6GGDHjboYdBDBj2EeoCwMMWb6Ce0E3B9rvfoDSlX
rXzIDipIbZRQmrcFtuH3+qQspBk9Gi0M8CqV71UwrqjWj8NtHQ5uXxXgVcrb
l4cCBja3+pYaizzGh+9MpZDrD/ec4ys08vHKfz/K30Z9+/+4dl3hEe2Xd1DR
tplnNtDBredHJ8SlafzDzdV3V7DH0udPh05bMTmVlZ7W/Tz8HfLbigIuDbue
rHkozo/zj0zYSJMa+v08snyp/H8A5GTjcQ==
      "], {
       {EdgeForm[None], GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxNmgn4l1MWx98rJbLvS6VVJXuWSKJ9X5VKCEVpRSJZyh4hLYgiiVKKEFpU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          "]]]}, {}, {}, {}, {}},
      VertexNormals->CompressedData["
1:eJztWPk/ldv3pzRpHkhRNGiW0kBFq9IklcotdaU0a5BGt5FIuJFK3UhSZCoU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       "]], 
     GeometricTransformation3DBox[
      CuboidBox[{0, 0, 0}], {{{7.2139303958044225`, -0.32719072199659477`, 
       0.}, {0.21465759189134256`, 5.919622269077525, 0.}, {
       1.4934735039548137`, 0.7296006461209248, 
       0.}}, {-4.745367747567985, -2.925048598535896, 1.8692817055216449`}}], 
     {RGBColor[1, 0, 0], 
      Arrow3DBox[{{-1.3019979106640727`, 0.1420913319485384, 
       2.9808187805595137`}, {1.6344613807262047`, 0.22946856538336513`, 
       3.588743158327824}}]}, 
     {RGBColor[0, 1, 0], 
      Arrow3DBox[{{-1.3019979106640727`, 0.1420913319485384, 
       2.9808187805595137`}, {-1.4663222551029549`, 3.115091430350156, 
       3.3472446594609746`}}]}, 
     {RGBColor[0, 0, 1], 
      Arrow3DBox[{{-1.3019979106640727`, 0.1420913319485384, 
       2.9808187805595137`}, {-1.8937785624536043`, -0.2498724852352071, 
       5.8956361035124125`}}]}, 
     {GrayLevel[0.5], 
      Line3DBox[{{0, 0, 0}, {-0.5010781740188891, -0.30785168309537186`, 
        3.082920349583303}}]}, 
     {RGBColor[1, 0, 0], 
      Line3DBox[{{0, 0, 0}, {-0.5003753174829516, 0.2998980014841617, 
        3.164788884286951}}]}},
    AutomaticImageSize->True,
    ImageSize->{155.63601553399238`, 127.4825941068559},
    ViewPoint->{3.0639813597654104`, -1.435293344603923, 0.04417286436031787},
    ViewVertical->{0.5266529396880062, -0.30010028970400887`, 
     1.0415416337737575`},
    ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], ",", 
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "1.7057363409281687`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "1.708391239777473`", 
       "0.001556453236998869`", "0.0026548988493042547`"},
      {"\<\"solidAngle\"\>", "2.1569166453524975`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "2.118712567075858`", 
       "0.2421102348813008`", "0.4129762261476895`"},
      {"\<\"DrobotIrradiance\"\>", "2.141991888693534`", 
       "0.2557579019087901`", "0.4362555477653651`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "2.1415509186578054`", 
       "0.2554993801049523`", "0.4358145777296367`"},
      {"\<\"oneShotMRPIrradiance\"\>", "2.1519816005483148`", 
       "0.2616144411728507`", "0.44624525962014605`"},
      {"\<\"planePosMRPIrradiance\"\>", "1.974705321551198`", 
       "0.15768496816845157`", "0.2689689806230293`"},
      {"\<\"weightMRPIrradiance\"\>", "2.1211814971438963`", 
       "0.24355766260433012`", "0.41544515621572753`"},
      {"\<\"solidAngleHorizon\"\>", "2.1576223644872563`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "2.1194057862611526`", 
       "0.24251663953403696`", "0.4136694453329839`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "2.142692724613924`", 
       "0.2561687719263736`", "0.43695638368575507`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "2.1422516102977043`", 
       "0.2559101655370769`", "0.43651526936953555`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "2.1526857049913066`", 
       "0.2620272273849383`", "0.4469493640631379`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "1.975351423167564`", 
       "0.1580637498129901`", "0.26961508223939523`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "2.1218755241356466`", 
       "0.24396454083931732`", "0.4161391832074779`"},
      {"\<\"solidAngle\"\>", "2.1569166453524975`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "1.1459594934009445`", 
       "0.3281731379555554`", "0.5597768475272242`"},
      {"\<\"averageCosine5Irradiance\"\>", "1.3117086590309952`", 
       "0.23100151673075403`", "0.3940276818971735`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"]}], "}"}]], "Output",
 CellChangeTimes->{{3.613332343571389*^9, 3.6133323792104278`*^9}, {
   3.6133327110784097`*^9, 3.6133327164817185`*^9}, {3.6133331937060146`*^9, 
   3.6133332609538603`*^9}, {3.6133339496092496`*^9, 3.613334005549449*^9}, {
   3.6133341426262894`*^9, 3.6133342088750787`*^9}, 3.6133344663218036`*^9, {
   3.6133345134665003`*^9, 3.6133345427191734`*^9}, {3.6133345912639503`*^9, 
   3.6133346201085997`*^9}, {3.613334653752524*^9, 3.6133346770128546`*^9}, {
   3.6133359530638404`*^9, 3.613336269967966*^9}, {3.613336319700811*^9, 
   3.6133363828644238`*^9}, {3.6133364425488377`*^9, 
   3.6133366201809974`*^9}, {3.6133366749221287`*^9, 3.613336680057422*^9}, {
   3.613336738341756*^9, 3.6133367563107834`*^9}, {3.613337707408183*^9, 
   3.6133377213809824`*^9}, 3.61333781365526*^9, {3.6133388269912195`*^9, 
   3.6133388615291953`*^9}, {3.6133390048893948`*^9, 
   3.6133391278124256`*^9}, {3.6134047641027403`*^9, 
   3.6134047879661055`*^9}, {3.6134048220480547`*^9, 3.613404913215269*^9}, {
   3.613404952552519*^9, 3.613405030862998*^9}, 3.613405075057526*^9, 
   3.6134060547585616`*^9, {3.6134062566771107`*^9, 3.613406283448642*^9}, 
   3.6134063321714287`*^9, 3.613406797326034*^9, 3.613406853971274*^9, 
   3.6134068985658245`*^9, 3.6134069405552263`*^9, {3.6134069817305813`*^9, 
   3.613407009050144*^9}, 3.613407070086635*^9, {3.613407108917856*^9, 
   3.6134071166773*^9}, 3.61340718084297*^9, {3.6134072110256968`*^9, 
   3.6134072807716856`*^9}, {3.613407316947755*^9, 3.613407363422413*^9}, {
   3.613407470683548*^9, 3.6134075215354567`*^9}, {3.6134076286755843`*^9, 
   3.6134076807245617`*^9}, {3.613407766964494*^9, 3.613407810659993*^9}, 
   3.6134079098086643`*^9, {3.6134079518650703`*^9, 3.6134081496323814`*^9}, 
   3.6134081901456985`*^9, {3.615392718461951*^9, 3.615392746827553*^9}, 
   3.615392826413159*^9, 3.615392890193758*^9, 3.615393226096412*^9, 
   3.615393421907277*^9, {3.615393482709498*^9, 3.6153935055368967`*^9}, 
   3.6153935594357405`*^9, {3.6153936277939215`*^9, 3.6153937712786417`*^9}, {
   3.615394903781451*^9, 3.615394982081394*^9}, {3.6153950626136203`*^9, 
   3.6153950711367025`*^9}, {3.6153951167499948`*^9, 3.615395136212966*^9}, 
   3.6153953570450087`*^9, {3.6153967163556185`*^9, 3.6153967341203747`*^9}, {
   3.6153969113918853`*^9, 3.6153969958296075`*^9}, {3.615397442859373*^9, 
   3.6153974567036314`*^9}, {3.6153999538192244`*^9, 
   3.6154000017763147`*^9}, {3.61540021696914*^9, 3.61540024295144*^9}, 
   3.615400273736849*^9, 3.615400382590172*^9, 3.615400512426159*^9, 
   3.6154006072021933`*^9, 3.615400735450479*^9, 3.615400821881954*^9, 
   3.6154009253910985`*^9, 3.6154009667253475`*^9, {3.61540122362597*^9, 
   3.6154012355869884`*^9}, 3.6154012882016697`*^9, 3.6154014186587353`*^9, 
   3.6154015010076923`*^9, 3.6154018934360247`*^9, 3.6154020030399427`*^9, 
   3.6154020430350213`*^9, 3.6154025186654186`*^9, 3.615402611953765*^9, {
   3.615402673245548*^9, 3.615402686146186*^9}, {3.615402721317652*^9, 
   3.6154027348878756`*^9}, {3.6154030698174057`*^9, 3.615403093363896*^9}, 
   3.6154031724964447`*^9, 3.615403694819271*^9, 3.6154037729121876`*^9, 
   3.6154041160017543`*^9, 3.6154078262443953`*^9, {3.6154101348770547`*^9, 
   3.615410180177807*^9}, 3.6155211043589635`*^9, 3.615521149384181*^9, {
   3.6155374810865583`*^9, 3.61553776822402*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "To", " ", "be", " ", "able", " ", "to", " ", "specify", " ", "a", " ", 
    "dedicated", " ", "matrix", " ", "for", " ", "reproductible", " ", 
    "result"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"A", " ", "=", " ", 
   RowBox[{"GetRandomTransform", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", " ", "5", ",", " ", "0"}], "}"}], ",", " ", "10"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6133184009769187`*^9, 3.6133184013279386`*^9}, {
   3.6133243779527817`*^9, 3.613324394023701*^9}, {3.613328864992426*^9, 
   3.613328865144435*^9}, 3.61539256599909*^9}],

Cell[BoxData[
 RowBox[{"TransformationFunction", "[", 
  RowBox[{"(", 
   TagBox[GridBox[{
      {"6.723497415248749`", 
       RowBox[{"-", "0.0431838437129381`"}], "0.`", 
       RowBox[{"-", "2.7425108141269616`"}]},
      {"0.33668245149161996`", "4.948140770442001`", "0.`", 
       "3.2509841941813455`"},
      {"1.9186525047545888`", 
       RowBox[{"-", "0.7169644841495539`"}], "0.`", "3.144525260158817`"},
      {"0.`", "0.`", "0.`", "1.`"}
     },
     AutoDelete->False,
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {-2 -> True}, 
       "Rows" -> {{False}}, "RowsIndexed" -> {-2 -> True}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    #& ], ")"}], "]"}]], "Output",
 CellChangeTimes->{{3.6153926685486126`*^9, 3.6153926838865604`*^9}, {
   3.615395363275299*^9, 3.615395388711029*^9}, 3.615397044624304*^9, 
   3.615397101167984*^9, {3.6154008545326004`*^9, 3.6154008705881395`*^9}, 
   3.6155211068837843`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EvaluateDiffuseRectangularLight", "[", 
  RowBox[{
  "7", ",", " ", "5", ",", " ", "10", ",", " ", "1", ",", " ", "1", ",", " ", 
   "A"}], "]"}]], "Input",
 CellChangeTimes->{
  3.613318404097097*^9, 3.6133185791681104`*^9, {3.6133186822240047`*^9, 
   3.613318684744149*^9}, {3.613318747967765*^9, 3.613318773153206*^9}, {
   3.6133192478483567`*^9, 3.6133192508315277`*^9}, {3.6133195452563677`*^9, 
   3.6133195745200415`*^9}, {3.6133196930558214`*^9, 
   3.6133196945919094`*^9}, {3.6133244056963687`*^9, 3.613324406600421*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   Graphics3DBox[{Point3DBox[{0, 0, 0}], GraphicsComplex3DBox[CompressedData["
1:eJzVWXdU1VcSRjSuJWYjRuNaNgpZO8oSy6rkDXrceESxoCbHGkuMLSZR41pQ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      "], {
       {EdgeForm[None], GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxNmgn4l1MWx98rJbLvS6VVJXuWSKJ9X5VKCEVpRSJZyh4hLYgiiVKKEFpU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          "]]]}, {}, {}, {}, {}},
      VertexNormals->CompressedData["
1:eJztWPk/ldv3pzRpHkhRNGiW0kBFq9IklcotdaU0a5BGt5FIuJFK3UhSZCoU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       "]], 
     GeometricTransformation3DBox[
      CuboidBox[{0, 0, 0}], {{{6.723497415248749, -0.0431838437129381, 0.}, {
       0.33668245149161996`, 4.948140770442001, 0.}, {
       1.9186525047545888`, -0.7169644841495539, 0.}}, {-2.7425108141269616`, 
       3.2509841941813455`, 3.144525260158817}}], 
     {RGBColor[1, 0, 0], 
      Arrow3DBox[{{0.597645971640941, 5.893395805148154, 3.745369270461334}, {
       3.4791448638904026`, 6.037688284358849, 4.567648915356157}}]}, 
     {RGBColor[0, 1, 0], 
      Arrow3DBox[{{0.597645971640941, 5.893395805148154, 3.745369270461334}, {
       0.5717356654131782, 8.862280267413354, 3.3151905799716017`}}]}, 
     {RGBColor[0, 0, 1], 
      Arrow3DBox[{{0.597645971640941, 5.893395805148154, 
       3.745369270461334}, {-0.23679563206557885`, 6.29948043938529, 
       6.598227920980175}}]}, 
     {GrayLevel[0.5], 
      Line3DBox[{{0, 0, 0}, {-0.8693881014739644, 3.349787454467589, 
        3.678336857937605}}]}, 
     {RGBColor[1, 0, 0], 
      Line3DBox[{{0, 0, 0}, {0.9274763114977428, 5.325370077194777, 
        3.922696905541467}}]}}], ",", 
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "0.24701519946473488`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "0.24622326441574624`", 
       "0.0032060174867972065`", "0.0007919350489886401`"},
      {"\<\"solidAngle\"\>", "0.4373398147013754`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "0.31852255960726594`", 
       "0.28948566848308377`", "0.07150736014253106`"},
      {"\<\"DrobotIrradiance\"\>", "0.32356906549044456`", 
       "0.309915609207841`", "0.07655386602570968`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "0.32332398684122865`", 
       "0.30892344900981683`", "0.07630878737649377`"},
      {"\<\"oneShotMRPIrradiance\"\>", "0.3240728291612759`", 
       "0.3119550127422104`", "0.07705762969654101`"},
      {"\<\"planePosMRPIrradiance\"\>", "0.2337207997997124`", 
       "0.05382016853145293`", "0.013294399665022494`"},
      {"\<\"weightMRPIrradiance\"\>", "0.25686247093138315`", 
       "0.03986504266938485`", "0.009847271466648266`"},
      {"\<\"solidAngleHorizon\"\>", "0.4368494930829161`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "0.318165449434141`", 
       "0.2880399672715843`", "0.07115024996940611`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "0.32320629744934365`", 
       "0.30844700305774575`", "0.07619109798460877`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "0.3229614935689823`", 
       "0.3074559552157837`", "0.07594629410424741`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "0.3237094963277411`", 
       "0.31048412012377186`", "0.07669429686300622`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "0.23345876474831043`", 
       "0.0548809739068702`", "0.013556434716424454`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "0.2565744906967125`", 
       "0.03869920252960936`", "0.009559291231977629`"},
      {"\<\"solidAngle\"\>", "0.4373398147013754`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "0.21548156662882129`", 
       "0.12765867405829612`", "0.031533632835913594`"},
      {"\<\"averageCosine5Irradiance\"\>", "0.21912941326299953`", 
       "0.11289097295292737`", "0.027885786201735346`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"]}], "}"}]], "Output",
 CellChangeTimes->{{3.613318410603469*^9, 3.613318421409087*^9}, {
   3.6133184667306795`*^9, 3.613318476951264*^9}, {3.613318574302832*^9, 
   3.6133186167702613`*^9}, {3.613318652538307*^9, 3.6133186858692136`*^9}, {
   3.6133187254384766`*^9, 3.613318801007799*^9}, 3.6133190743834352`*^9, {
   3.6133192420270243`*^9, 3.613319269177577*^9}, {3.613319412375767*^9, 
   3.613319431939886*^9}, 3.613319474171302*^9, {3.6133195235701275`*^9, 
   3.613319575939122*^9}, {3.613319621370721*^9, 3.6133196283901224`*^9}, {
   3.6133196592648883`*^9, 3.613319711498876*^9}, {3.613319754888358*^9, 
   3.613319771216292*^9}, 3.613320059324771*^9, 3.6133203690034833`*^9, 
   3.613320430043975*^9, 3.61332047629462*^9, {3.6133205300276933`*^9, 
   3.613320558392316*^9}, 3.6133233384593267`*^9, 3.6133236233176193`*^9, 
   3.6133236842771063`*^9, 3.61332466867741*^9, {3.6133248133676863`*^9, 
   3.613324821811169*^9}, {3.613328856126919*^9, 3.6133288869916844`*^9}, {
   3.6133290199422884`*^9, 3.61332905230114*^9}, {3.6133291614113803`*^9, 
   3.6133291770072722`*^9}, {3.613331009448082*^9, 3.613331065467286*^9}, {
   3.613334733994114*^9, 3.613334750944083*^9}, {3.6133377265302773`*^9, 
   3.6133377319365864`*^9}, {3.615392579255774*^9, 3.615392645900737*^9}, {
   3.6153926802495985`*^9, 3.6153926912049894`*^9}, {3.6153931688156385`*^9, 
   3.6153932113645415`*^9}, 3.615393426585871*^9, 3.61539363927938*^9, {
   3.615395370476714*^9, 3.6153953946477833`*^9}, 3.615396698689376*^9, 
   3.6153970519722366`*^9, 3.6153971082618847`*^9, 3.6153973076091986`*^9, 
   3.6153973758453636`*^9, 3.615397433553191*^9, 3.615399939704432*^9, {
   3.615400861707512*^9, 3.615400877353998*^9}, 3.615521113297599*^9, 
   3.6155211566216*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "report", " ", "with", " ", "average", " ", 
    "of", " ", "high", " ", "number", " ", "of", " ", "random", " ", "test"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"GenerateReport", "[", 
    RowBox[{"Num_", ",", " ", "Above_", ",", " ", "MaxDistance_"}], "]"}], 
   " ", ":=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"Little", " ", "trick"}], ",", " ", 
      RowBox[{
      "to", " ", "conserve", " ", "the", " ", "format", " ", "of", " ", "the",
        " ", "Grid", " ", "of", " ", "the", " ", "initial", " ", "function", 
       " ", "init", " ", "result", " ", "to", " ", "the", " ", "grid"}]}], 
     " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"width", " ", "=", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", " ", "10"}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"height", " ", "=", " ", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", " ", "10"}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"distance", " ", "=", " ", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", "MaxDistance"}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"result", " ", "=", 
       RowBox[{
        RowBox[{"EvaluateDiffuseRectangularLight", "[", 
         RowBox[{
         "width", ",", " ", "height", ",", " ", "distance", ",", " ", 
          "Above"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "calculate", " ", "the", " ", "average", " ", "of", " ", "all", " ", 
         "the", " ", "calculation"}], " ", "-", " ", "Init"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"averageIrradiance", "=", " ", 
       RowBox[{
        RowBox[{"result", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"averageRelative", "=", " ", 
       RowBox[{
        RowBox[{"result", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"averageDifference", "=", " ", 
       RowBox[{
        RowBox[{"result", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"worstCase", "=", " ", 
       RowBox[{
        RowBox[{"result", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"count", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", "Loop", " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"iterator", " ", "=", " ", 
       RowBox[{"Num", " ", "-", " ", "1"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"iterator", " ", ">", " ", "0"}], ",", " ", 
        RowBox[{
         RowBox[{"iterator", "--"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"width", " ", "=", 
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"0.1", ",", " ", "10"}], "}"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"height", " ", "=", " ", 
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"0.1", ",", " ", "10"}], "}"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"distance", " ", "=", " ", 
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"5", ",", " ", "25"}], "}"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "accumualte", " ", "average", " ", "of", " ", "the", " ", "second", 
           " ", "column", " ", "of", " ", "the", " ", "Grid"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"temp", " ", "=", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"EvaluateDiffuseRectangularLight", "[", 
             RowBox[{
             "width", ",", " ", "height", ",", " ", "distance", ",", " ", 
              "Above"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "Exclude", " ", "case", " ", "which", " ", "cause", " ", "high", 
           " ", "value", " ", "and", " ", "hide", " ", "the", " ", "other", 
           " ", "calcul"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"temp", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], " ", ">", " ", "0.001"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"averageIrradiance", " ", "+=", 
             RowBox[{"temp", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"averageRelative", " ", "+=", 
             RowBox[{"temp", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "3"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"averageDifference", " ", "+=", 
             RowBox[{"temp", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"worstCase", " ", "=", " ", 
             RowBox[{"MapThread", "[", 
              RowBox[{"Max", ",", 
               RowBox[{"{", 
                RowBox[{"worstCase", ",", 
                 RowBox[{"temp", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "4"}], "]"}], "]"}]}], "}"}]}], 
              "]"}]}], " ", ";", 
            RowBox[{"count", " ", "+=", " ", "1"}]}], ","}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Draw", " ", "result"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"result", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", " ", "2"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"averageIrradiance", " ", "*", " ", 
        RowBox[{"(", 
         RowBox[{"1", "/", "count"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"result", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", " ", "3"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"averageRelative", " ", "*", " ", 
        RowBox[{"(", 
         RowBox[{"1", "/", "count"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"result", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", " ", "4"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"averageDifference", " ", "*", " ", 
        RowBox[{"(", 
         RowBox[{"1", "/", "count"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      " ", "result"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Column", "[", "worstCase", "]"}]}], "\[IndentingNewLine]", 
    "}"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 3}},
 CellChangeTimes->{{3.613319830120661*^9, 3.6133199153125334`*^9}, {
   3.613319954624782*^9, 3.6133199989293165`*^9}, {3.6133203920668025`*^9, 
   3.61332039307286*^9}, {3.613320438441455*^9, 3.613320446504916*^9}, {
   3.613320562393544*^9, 3.6133205685138946`*^9}, {3.6133232741216464`*^9, 
   3.613323303345318*^9}, {3.613323344769687*^9, 3.6133233953865824`*^9}, {
   3.6133234299215574`*^9, 3.6133234664576473`*^9}, {3.6133235045948286`*^9, 
   3.613323569842561*^9}, {3.6133236087377853`*^9, 3.613323839193967*^9}, {
   3.6133238828754654`*^9, 3.6133240561553764`*^9}, {3.613324129419567*^9, 
   3.6133242326994743`*^9}, {3.613324348283085*^9, 3.613324370484355*^9}, {
   3.6133244233543787`*^9, 3.6133244411133947`*^9}, {3.6133251925873766`*^9, 
   3.6133252960682955`*^9}, {3.6133254222555127`*^9, 
   3.6133254538753214`*^9}, {3.6133254963327494`*^9, 
   3.6133255049642434`*^9}, {3.6133255517019167`*^9, 
   3.6133256164526205`*^9}, {3.613325737973571*^9, 3.613325765605151*^9}, {
   3.6133258387243333`*^9, 3.613325842548552*^9}, {3.613325887476122*^9, 
   3.613326008918068*^9}, {3.613326101037337*^9, 3.613326127196833*^9}, {
   3.6133261606517467`*^9, 3.613326190643462*^9}, {3.6133262548041315`*^9, 
   3.613326283485772*^9}, {3.6133263171816998`*^9, 3.6133263617252474`*^9}, {
   3.613329313447076*^9, 3.613329338404504*^9}, {3.6133301187101345`*^9, 
   3.6133302576850834`*^9}, {3.6133307245317855`*^9, 3.613330726652907*^9}, {
   3.6133312889340677`*^9, 3.613331289204083*^9}, {3.6133347982217875`*^9, 
   3.6133347983427944`*^9}, {3.6133348440454082`*^9, 
   3.6133348442214184`*^9}, {3.613337521187532*^9, 3.6133375701303315`*^9}, {
   3.6133376206602216`*^9, 3.6133376692209992`*^9}, {3.613337739709031*^9, 
   3.613337771652858*^9}, 3.6133378609979677`*^9, {3.613337906421566*^9, 
   3.6133379068695917`*^9}, 3.6133379647659035`*^9, {3.61333816314925*^9, 
   3.61333817415688*^9}, {3.6133388977412663`*^9, 3.6133389650051136`*^9}, {
   3.61333907735754*^9, 3.6133390780695806`*^9}, {3.61540789187973*^9, 
   3.6154079114292126`*^9}, {3.61540795802913*^9, 3.6154079781661873`*^9}, {
   3.6155318534069195`*^9, 3.615531866510083*^9}, {3.61553778688739*^9, 
   3.615537833105259*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Diagram", " ", "below", " ", "show", " ", "method", " ", "name"}],
    ",", " ", 
   RowBox[{"average", " ", "irradiance"}], ",", " ", 
   RowBox[{"average", " ", "relative", " ", "error"}], ",", " ", 
   RowBox[{"average", " ", "absolute", " ", "error"}], ",", " ", 
   RowBox[{"worst", " ", "case", " ", "relative", " ", "error"}]}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.6133262038322163`*^9, 3.613326220448167*^9}, {
  3.615653722646515*^9, 3.6156537311650968`*^9}, {3.6156538615681562`*^9, 
  3.615653896101041*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "light", " ", "above", " ", "and", " ", "crossing", " ", "the", " ", 
    "horizon", " ", "from", " ", "near", " ", "to", " ", "far", " ", 
    "range"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.615653903898031*^9, 3.615653910813409*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GenerateReport", "[", 
   RowBox[{"10000", ",", " ", "0", ",", "25"}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.6133392582728877`*^9, 3.6133392608720365`*^9}, {
  3.6133394714480805`*^9, 3.6133394715840883`*^9}, {3.6155378550025396`*^9, 
  3.6155378554180927`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "0.09766840611299929`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "0.09354136534507386`", 
       "0.022761213219856767`", "0.004663897878145972`"},
      {"\<\"solidAngle\"\>", "0.18363949300101912`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "0.13481615681112707`", 
       "0.3140460876036441`", "0.03895966992628986`"},
      {"\<\"DrobotIrradiance\"\>", "0.14229351810500526`", 
       "0.2996318213356862`", "0.05017328383527178`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "0.1455602287116842`", 
       "0.32482460245750205`", "0.04842013262975262`"},
      {"\<\"oneShotMRPIrradiance\"\>", "0.14215936972160256`", 
       "0.3135356280115668`", "0.05065720444782286`"},
      {"\<\"planePosMRPIrradiance\"\>", "0.09227960051470893`", 
       "0.08394562063250806`", "0.02424870668787505`"},
      {"\<\"weightMRPIrradiance\"\>", "0.12965415070699743`", 
       "7.961020167895035`", "0.10375614001064747`"},
      {"\<\"solidAngleHorizon\"\>", "0.1676135313931144`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "0.12563408246359556`", 
       "0.25766633908345554`", "0.030293735123270573`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "0.13143371263621506`", 
       "0.2602518652525184`", "0.039339071587841494`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "0.13428194516636233`", 
       "0.2703311406793807`", "0.03726351613391232`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "0.1308249930425062`", 
       "0.2712305371427941`", "0.03935489886870698`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "0.08854497966076484`", 
       "0.08938801438271211`", "0.022113516422377685`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "0.11821447965469878`", 
       "8.012850491253126`", "0.1039673716761614`"},
      {"\<\"solidAngle\"\>", "0.18363949300101912`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "0.08072591301959575`", 
       "0.06254892122062897`", "0.02095335706713055`"},
      {"\<\"averageCosine5Irradiance\"\>", "0.08303665051861812`", 
       "0.05282850100897588`", "0.019095566143746846`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"], ",", 
   TagBox[GridBox[{
      {"0"},
      {"2.372507967862175`"},
      {"0"},
      {"4.5272251710676015`"},
      {"5.208106292752193`"},
      {"4.212445179742334`"},
      {"4.664885879298285`"},
      {"3.4755259188744647`"},
      {"3.3717445136456425`"},
      {"0"},
      {"2.9250888691807897`"},
      {"2.9425319434176616`"},
      {"2.9425315270233843`"},
      {"2.520690774118258`"},
      {"3.2141564772768065`"},
      {"3.371320265597156`"},
      {"0"},
      {"2.938659295618955`"},
      {"2.9303115099344788`"}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Column"]}], "}"}]], "Output",
 CellChangeTimes->{3.613339346591939*^9, 3.6133441184758754`*^9, 
  3.6154807747149906`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Only", " ", "light", " ", "above", " ", "the", " ", "horizon", " ", 
    "from", " ", "near", " ", "to", " ", "far", " ", "range"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.6156537432486315`*^9, 3.6156537739005237`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenerateReport", "[", 
  RowBox[{"1000", ",", " ", "1", ",", "25"}], "]"}]], "Input",
 CellChangeTimes->{{3.6133232268319416`*^9, 3.613323227791997*^9}, {
   3.613323368280032*^9, 3.613323371416211*^9}, {3.6133234514397883`*^9, 
   3.6133234522798367`*^9}, {3.613323496552369*^9, 3.6133235283201857`*^9}, 
   3.61332382194398*^9, {3.613324266264394*^9, 3.6133242669604335`*^9}, {
   3.6133243116249886`*^9, 3.6133243116639905`*^9}, 3.6133248416243024`*^9, {
   3.613324909752199*^9, 3.6133249104482393`*^9}, {3.613326294224386*^9, 
   3.6133262949444275`*^9}, {3.613326440728766*^9, 3.6133264410007815`*^9}, {
   3.6133301096576166`*^9, 3.6133301103686576`*^9}, {3.613330158681421*^9, 
   3.6133301626806498`*^9}, {3.613330286977759*^9, 3.6133302873047776`*^9}, 
   3.613330445512827*^9, {3.6133310784100266`*^9, 3.6133310785600348`*^9}, 
   3.613331118792336*^9, 3.613331253097018*^9, {3.613331296802518*^9, 
   3.6133312970965347`*^9}, 3.6133313397369733`*^9, {3.61333143898565*^9, 
   3.613331440056711*^9}, {3.6133378824321938`*^9, 3.6133378832082386`*^9}, 
   3.613337982263904*^9, {3.6133392525365596`*^9, 3.6133392538556347`*^9}, {
   3.6133394727121525`*^9, 3.6133394728481607`*^9}, 3.6155211724211063`*^9, {
   3.615537847666608*^9, 3.61553784807366*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "0.09686455427030326`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "0.09683705840418852`", 
       "0.0021173841545749144`", "0.0005084505464609225`"},
      {"\<\"solidAngle\"\>", "0.14211521633256088`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "0.1155287488318386`", 
       "0.17001533413214628`", "0.02144802854474352`"},
      {"\<\"DrobotIrradiance\"\>", "0.11893784687599444`", 
       "0.17391019172804245`", "0.02397350358478479`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "0.11949474009643464`", 
       "0.17768466815868517`", "0.023449405779003153`"},
      {"\<\"oneShotMRPIrradiance\"\>", "0.11845167533269244`", 
       "0.1753185463932321`", "0.024571847246179244`"},
      {"\<\"planePosMRPIrradiance\"\>", "0.09845531580871843`", 
       "0.03878993538741203`", "0.009153079307373604`"},
      {"\<\"weightMRPIrradiance\"\>", "0.10596679125241394`", 
       "0.06317254998940905`", "0.009899389867956052`"},
      {"\<\"solidAngleHorizon\"\>", "0.1422908896703971`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "0.11567397129560325`", 
       "0.17172067284577097`", "0.021565653684739623`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "0.11908831133975417`", 
       "0.176266392355905`", "0.02412351117317649`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "0.11964444368014607`", 
       "0.17928192098077067`", "0.02358555726965036`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "0.11860154293476824`", 
       "0.17714055513615204`", "0.024705867932700173`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "0.09857603805573618`", 
       "0.042802471420967894`", "0.009209321653402606`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "0.10609765496186266`", 
       "0.06735671075064494`", "0.010027953673307909`"},
      {"\<\"solidAngle\"\>", "0.14211521633256088`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "0.07855615181788307`", 
       "0.0431690569409515`", "0.0183130150023315`"},
      {"\<\"averageCosine5Irradiance\"\>", "0.08253598461605026`", 
       "0.036712981865577074`", "0.014402996676608238`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"], ",", 
   TagBox[GridBox[{
      {"0"},
      {"0.05787636515217298`"},
      {"0"},
      {"1.3486703668159423`"},
      {"1.3691442398080262`"},
      {"1.3685605814580049`"},
      {"1.3690287468796107`"},
      {"1.149029986920644`"},
      {"0.6647850579694747`"},
      {"0"},
      {"1.3546609085029182`"},
      {"1.3751649023123544`"},
      {"1.3745803852939922`"},
      {"1.3750492394726868`"},
      {"1.1547268210408501`"},
      {"0.6697694791004976`"},
      {"0"},
      {"1.7026624693255918`"},
      {"1.2646152406741287`"}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Column"]}], "}"}]], "Output",
 CellChangeTimes->{{3.613323528779212*^9, 3.6133235715696597`*^9}, 
   3.6133236108389053`*^9, {3.613323652949314*^9, 3.613323699898*^9}, {
   3.613323742776452*^9, 3.613323833970668*^9}, {3.613323904614709*^9, 
   3.6133239189345274`*^9}, 3.6133240622947273`*^9, 3.6133241717819896`*^9, 
   3.6133242358386536`*^9, 3.6133242702936244`*^9, 3.6133243177123365`*^9, {
   3.6133248438584304`*^9, 3.613324912580361*^9}, 3.613325261412313*^9, 
   3.61332530244766*^9, 3.613325457551532*^9, 3.613325508098423*^9, {
   3.61332558742196*^9, 3.613325613168432*^9}, {3.613325742047804*^9, 
   3.6133257694693723`*^9}, 3.6133258458717422`*^9, {3.6133258764514914`*^9, 
   3.613326013013302*^9}, 3.6133261306150284`*^9, {3.61332616665709*^9, 
   3.613326193425621*^9}, 3.6133262276275773`*^9, {3.6133262588533635`*^9, 
   3.6133263097142725`*^9}, 3.613326372837883*^9, {3.6133264228247423`*^9, 
   3.613326437109559*^9}, 3.6133267292322674`*^9, 3.613330111550725*^9, {
   3.61333015552824*^9, 3.61333019835369*^9}, 3.6133302541788826`*^9, 
   3.613330314828352*^9, 3.6133307182604265`*^9, {3.613331084083351*^9, 
   3.6133311110718946`*^9}, 3.613331164421946*^9, {3.613331283466755*^9, 
   3.6133313018228045`*^9}, 3.6133313533097496`*^9, 3.613331882139997*^9, 
   3.6133347958356504`*^9, 3.613335348229246*^9, 3.613337749849611*^9, {
   3.6133378803960776`*^9, 3.6133378842552986`*^9}, 3.6133379310149727`*^9, {
   3.613337970865252*^9, 3.613337990785392*^9}, 3.613338969962397*^9, 
   3.6133391402721386`*^9, 3.613339300523304*^9, 3.6133487937652864`*^9, 
   3.6155269837640533`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Only", " ", "light", " ", "crossing", " ", "the", " ", "horizon", " ", 
    "from", " ", "near", " ", "to", " ", "far", " ", "range"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.615653780636879*^9, 3.6156537849564276`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenerateReport", "[", 
  RowBox[{"1000", ",", " ", "2", ",", "25"}], "]"}]], "Input",
 CellChangeTimes->{{3.6133248930742455`*^9, 3.6133249620081882`*^9}, 
   3.6133250687692947`*^9, 3.613326369767707*^9, {3.6133264469951243`*^9, 
   3.6133264564976683`*^9}, 3.6133303852413793`*^9, {3.6133304513051577`*^9, 
   3.6133304601126614`*^9}, {3.613336766993395*^9, 3.6133367932878985`*^9}, 
   3.6133376093125725`*^9, {3.6133376885221033`*^9, 3.6133376888801236`*^9}, {
   3.613337829120145*^9, 3.6133378411278315`*^9}, {3.613338012143613*^9, 
   3.613338023896285*^9}, {3.613338972600548*^9, 3.613338975183696*^9}, 
   3.6133391582801685`*^9, {3.6133394740322285`*^9, 3.6133394741682363`*^9}, 
   3.615521173805282*^9, {3.61553785012292*^9, 3.6155378508980184`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "0.1377387273637429`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "0.1194669797744398`", 
       "0.13982982626722743`", "0.019581655976221822`"},
      {"\<\"solidAngle\"\>", "0.3988778934437757`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "0.246486182790585`", 
       "1.27405935133166`", "0.10880024536367415`"},
      {"\<\"DrobotIrradiance\"\>", "0.2541607604092371`", 
       "1.0894603431684022`", "0.14349940818350898`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "0.27755576354890144`", 
       "1.2428266574978144`", "0.14074574055401298`"},
      {"\<\"oneShotMRPIrradiance\"\>", "0.2563129870500898`", 
       "1.164668523109033`", "0.14624873641591424`"},
      {"\<\"planePosMRPIrradiance\"\>", "0.12163686286311201`", 
       "0.33583024185658505`", "0.07306518971180177`"},
      {"\<\"weightMRPIrradiance\"\>", "0.26515302924929673`", 
       "1.2190163242709198`", "0.1344848671166139`"},
      {"\<\"solidAngleHorizon\"\>", "0.3240537342891472`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "0.20626460854950313`", 
       "0.8771764624835597`", "0.06981928271300615`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "0.21285306603737997`", 
       "0.8440378680122265`", "0.1025004038561845`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "0.2292412217525667`", 
       "0.8934641914473513`", "0.09278647696935252`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "0.21268131066927573`", 
       "0.8950835091175475`", "0.10283722744922523`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "0.10038541483122078`", 
       "0.3403493553930819`", "0.06336441958257527`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "0.2130841393322667`", 
       "0.8023359110945849`", "0.0830744862379982`"},
      {"\<\"solidAngle\"\>", "0.3988778934437757`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "0.1164979679120626`", 
       "0.23111704969252475`", "0.045815099679157284`"},
      {"\<\"averageCosine5Irradiance\"\>", "0.1175257469022726`", 
       "0.18454907458404385`", "0.04676535505212125`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"], ",", 
   TagBox[GridBox[{
      {"0"},
      {"0.7691443219786187`"},
      {"0"},
      {"2.043804967294958`"},
      {"3.279757965795069`"},
      {"2.322297244279165`"},
      {"3.3620977000638694`"},
      {"3.279568406206975`"},
      {"3.1805131592433087`"},
      {"0"},
      {"1.9095871315362127`"},
      {"2.018421828263086`"},
      {"2.0156783574226247`"},
      {"1.5892632947951824`"},
      {"2.4164807138089928`"},
      {"1.4707413994188228`"},
      {"0"},
      {"1.9334953671348458`"},
      {"2.0289645667574763`"}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Column"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6133359508357134`*^9, 3.613336772772725*^9, 3.6133372572994385`*^9, 
   3.6133376557872305`*^9, {3.6133376897021704`*^9, 3.613337700059763*^9}, {
   3.6133377537228327`*^9, 3.61333778130441*^9}, {3.6133378300091953`*^9, 
   3.613337842055885*^9}, {3.613337993398541*^9, 3.6133380200550656`*^9}, 
   3.6133384787553015`*^9, 3.613338980475999*^9, 3.613339148782625*^9, 
   3.6133392074099784`*^9, 3.6133537078013535`*^9, 3.6155323444482737`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Only", " ", "light", " ", "above", " ", "the", " ", "horizon", " ", 
    "medium", " ", "range"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{
  3.6153923328209805`*^9, {3.6156537885743866`*^9, 3.615653823612336*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenerateReport", "[", 
  RowBox[{"1000", ",", " ", "1", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.6155378629700513`*^9, 3.6155378631215706`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "0.0950132608363705`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "0.09515136064731017`", 
       "0.0021163591349561807`", "0.0004026866018198012`"},
      {"\<\"solidAngle\"\>", "0.14207401570415906`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "0.11765411164785945`", 
       "0.18563345451806534`", "0.024394444090998973`"},
      {"\<\"DrobotIrradiance\"\>", "0.12024595409524738`", 
       "0.18657135468929809`", "0.026620535912050502`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "0.12079725643585447`", 
       "0.19396236660407648`", "0.02631698296039905`"},
      {"\<\"oneShotMRPIrradiance\"\>", "0.11832151153503877`", 
       "0.19217297702183486`", "0.025500840036181964`"},
      {"\<\"planePosMRPIrradiance\"\>", "0.09068384426215287`", 
       "0.03846637063008917`", "0.00924360577881765`"},
      {"\<\"weightMRPIrradiance\"\>", "0.09803602767755189`", 
       "0.06012673051545555`", "0.009827698928017478`"},
      {"\<\"solidAngleHorizon\"\>", "0.14223944659766258`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "0.11778753193615951`", 
       "0.1876020325764356`", "0.024509752600844245`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "0.1203818587386511`", 
       "0.1889039331330119`", "0.026755858454512903`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "0.12093441746420502`", 
       "0.19642126488679487`", "0.026447684377142653`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "0.11845559326359215`", 
       "0.19404872472664236`", "0.025616891930331755`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "0.09078554900055691`", 
       "0.0422812616120801`", "0.00926081153357547`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "0.09814581625313966`", 
       "0.06410794734786941`", "0.009891648848528693`"},
      {"\<\"solidAngle\"\>", "0.14207401570415906`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "0.0762197205274836`", 
       "0.0422292155952127`", "0.01880340837094179`"},
      {"\<\"averageCosine5Irradiance\"\>", "0.07911254527441765`", 
       "0.0373717396929481`", "0.015946052677557974`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"], ",", 
   TagBox[GridBox[{
      {"0"},
      {"0.04548989032620154`"},
      {"0"},
      {"1.677554979816727`"},
      {"1.6710257780610211`"},
      {"1.6709168982751077`"},
      {"1.5799641210393132`"},
      {"0.9132595353912651`"},
      {"0.9290805423438036`"},
      {"0"},
      {"1.681442851400572`"},
      {"1.6749079482310352`"},
      {"1.674798973369377`"},
      {"1.5837667745685113`"},
      {"0.9129232308764264`"},
      {"0.9274688307523344`"},
      {"0"},
      {"2.001036734543972`"},
      {"1.7300022110905813`"}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Column"]}], "}"}]], "Output",
 CellChangeTimes->{3.6155392244359355`*^9, 3.6155454264999976`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Only", " ", "light", " ", "crossing", " ", "the", " ", "horizon", " ", 
    "medium", " ", "range"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.6156538035982943`*^9, 3.615653817444553*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenerateReport", "[", 
  RowBox[{"1000", ",", " ", "2", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.6155378730328293`*^9, 3.615537873208351*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "0.12779082232065964`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "0.11744408048554737`", 
       "0.1566172201174837`", "0.01840317737832189`"},
      {"\<\"solidAngle\"\>", "0.3882621525202841`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "0.23213725391786855`", 
       "1.3380265354707157`", "0.10455414187124668`"},
      {"\<\"DrobotIrradiance\"\>", "0.24810697133532342`", 
       "1.1226490222117451`", "0.13707006009830677`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "0.26795348411444775`", 
       "1.3231362047642925`", "0.14087969600908615`"},
      {"\<\"oneShotMRPIrradiance\"\>", "0.24953138378610518`", 
       "1.2318544613660134`", "0.14133596135010046`"},
      {"\<\"planePosMRPIrradiance\"\>", "0.12464736603361748`", 
       "0.3528990312338865`", "0.06463300489254416`"},
      {"\<\"weightMRPIrradiance\"\>", "0.25013068477519057`", 
       "1.2828683486064427`", "0.12242258025931156`"},
      {"\<\"solidAngleHorizon\"\>", "0.3152860147075161`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "0.19322189693865072`", 
       "0.8946902796289453`", "0.06565094663842459`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "0.20883549797273093`", 
       "0.8455613533276519`", "0.09797405274595582`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "0.222318924166799`", 
       "0.912895611245388`", "0.09551456757766395`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "0.2077515052989641`", 
       "0.9175697017309951`", "0.09965843347559433`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "0.11011951304509514`", 
       "0.37543431452957565`", "0.05883123636422041`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "0.20382707747683287`", 
       "0.8233933138637226`", "0.07630434263127875`"},
      {"\<\"solidAngle\"\>", "0.3882621525202841`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "0.10999537059230388`", 
       "0.23560203883339265`", "0.03709202451372407`"},
      {"\<\"averageCosine5Irradiance\"\>", "0.1129257696805667`", 
       "0.18099950787722816`", "0.032427715270403376`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"], ",", 
   TagBox[GridBox[{
      {"0"},
      {"1.4633142986173104`"},
      {"0"},
      {"2.0917020059570386`"},
      {"4.608221675240525`"},
      {"4.605281935639335`"},
      {"3.0116336932881254`"},
      {"1.8771414453713127`"},
      {"3.1139222174849035`"},
      {"0"},
      {"1.6179518880301158`"},
      {"4.106250875324892`"},
      {"4.103551077574518`"},
      {"1.6132312230143482`"},
      {"1.821307364801191`"},
      {"1.4822486473600458`"},
      {"0"},
      {"1.7454850699333497`"},
      {"1.213813946274486`"}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Column"]}], "}"}]], "Output",
 CellChangeTimes->{3.615551284028309*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Only", " ", "light", " ", "above", " ", "the", " ", "horizon", " ", 
    "near", " ", "range"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.6156538278998804`*^9, 3.6156538411245604`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenerateReport", "[", 
  RowBox[{"1000", ",", " ", "1", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.6155521509593954`*^9, 3.615552151783*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "0.08995604063815828`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "0.09012914421022902`", 
       "0.0023888379117810387`", "0.0005327486568258789`"},
      {"\<\"solidAngle\"\>", "0.13593852988348623`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "0.10883900527512748`", 
       "0.18319892219466577`", "0.02087563044575657`"},
      {"\<\"DrobotIrradiance\"\>", "0.11142585198864725`", 
       "0.18904292851204815`", "0.023744442916439897`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "0.11249453401363349`", 
       "0.19048446727065493`", "0.023046322077857125`"},
      {"\<\"oneShotMRPIrradiance\"\>", "0.11025338856371293`", 
       "0.19176103417207283`", "0.023191053161669434`"},
      {"\<\"planePosMRPIrradiance\"\>", "0.08912847512172922`", 
       "0.04347250965522686`", "0.0094097084269848`"},
      {"\<\"weightMRPIrradiance\"\>", "0.09666966231616175`", 
       "0.06474756448944831`", "0.010703322191553821`"},
      {"\<\"solidAngleHorizon\"\>", "0.13611599636830468`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "0.1089759206495256`", 
       "0.18563858080588197`", "0.02100434784052124`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "0.11156127136799858`", 
       "0.1912482255197801`", "0.023874686323111915`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "0.11263443881881105`", 
       "0.19296229592139658`", "0.023183317113241876`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "0.1103861142529799`", 
       "0.1941336547485922`", "0.023311919092600095`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "0.08923050650147782`", 
       "0.047354198178501165`", "0.009439740062165978`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "0.0967846024682811`", 
       "0.06901213267029599`", "0.01080163716272173`"},
      {"\<\"solidAngle\"\>", "0.13593852988348623`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "0.07483264901846871`", 
       "0.04250590863216753`", "0.015128626195231825`"},
      {"\<\"averageCosine5Irradiance\"\>", "0.07769181423912085`", 
       "0.03722794286124506`", "0.01236499715983336`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"], ",", 
   TagBox[GridBox[{
      {"0"},
      {"0.05548986530680522`"},
      {"0"},
      {"0.9868470910091538`"},
      {"1.0902222988947845`"},
      {"1.0902222909498913`"},
      {"0.991671535475448`"},
      {"0.7928989578658627`"},
      {"0.7756640733522516`"},
      {"0"},
      {"0.9869349115137942`"},
      {"1.090314078481893`"},
      {"1.0903140705366956`"},
      {"0.9917595407475377`"},
      {"0.792879298398319`"},
      {"0.7756437538199737`"},
      {"0"},
      {"1.0357433867968266`"},
      {"0.9330949582907966`"}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Column"]}], "}"}]], "Output",
 CellChangeTimes->{3.6155581326239705`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Only", " ", "light", " ", "crossing", " ", "the", " ", "horizon", " ", 
    "near", " ", "range"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.6156538310077753`*^9, 3.615653836116424*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenerateReport", "[", 
  RowBox[{"1000", ",", " ", "2", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.6155521605191097`*^9, 3.615552163296462*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\<\"referenceIrradiance\"\>", "0.17129458299751174`", "0", "0"},
      {"\<\"formFactorIrradiance\"\>", "0.14471252081224253`", 
       "0.18851407974099088`", "0.027730550218691953`"},
      {"\<\"solidAngle\"\>", "0.48329881493248183`", "0", "0"},
      {"\<\"referenceMRPIrradiance\"\>", "0.3115017535098923`", 
       "1.3229333141635484`", "0.14091015161312126`"},
      {"\<\"DrobotIrradiance\"\>", "0.34363491284062236`", 
       "1.1346803282828288`", "0.19356374964765027`"},
      {"\<\"simplifiedDrobotIrradiance\"\>", "0.3555268340184591`", 
       "1.3106430938720501`", "0.18475536174936072`"},
      {"\<\"oneShotMRPIrradiance\"\>", "0.34133845451011463`", 
       "1.2054897228915757`", "0.19142121242182655`"},
      {"\<\"planePosMRPIrradiance\"\>", "0.14310219068980023`", 
       "0.33854721117033376`", "0.10663388941679539`"},
      {"\<\"weightMRPIrradiance\"\>", "0.32914715493884805`", 
       "1.2607402044904774`", "0.16835329360231618`"},
      {"\<\"solidAngleHorizon\"\>", "0.3857569597576814`", "0", "0"},
      {"\<\"referenceMRPIrradianceHorizon\"\>", "0.25283519702291707`", 
       "0.8878519272274713`", "0.08346376950635949`"},
      {"\<\"DrobotIrradianceHorizon\"\>", "0.2759785557969068`", 
       "0.8487114625128087`", "0.12598463380530459`"},
      {"\<\"simplifiedDrobotIrradianceHorizon\"\>", "0.2859966971646508`", 
       "0.902476892035051`", "0.11536433186124055`"},
      {"\<\"oneShotMRPIrradianceHorizon\"\>", "0.27205025055161436`", 
       "0.8936061483522718`", "0.1222250798713037`"},
      {"\<\"planePosMRPIrradianceHorizon\"\>", "0.11898071728837109`", 
       "0.3544860164094179`", "0.09206532893440078`"},
      {"\<\"weightMRPIrradianceHorizon\"\>", "0.25754993831845663`", 
       "0.8068717007851269`", "0.09862861512126668`"},
      {"\<\"solidAngle\"\>", "0.48329881493248183`", "0", "0"},
      {"\<\"averageCosine4Irradiance\"\>", "0.14288316955635977`", 
       "0.2313918747743284`", "0.05208672641893011`"},
      {"\<\"averageCosine5Irradiance\"\>", "0.1429269737830479`", 
       "0.1862973536668263`", "0.05586085389995979`"}
     },
     AutoDelete->False,
     GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Grid"], ",", 
   TagBox[GridBox[{
      {"0"},
      {"1.7420822921825438`"},
      {"0"},
      {"2.6508942621753033`"},
      {"4.4278943117142715`"},
      {"3.18375918560565`"},
      {"4.364955683041589`"},
      {"3.4700022247825637`"},
      {"3.761751386600531`"},
      {"0"},
      {"2.5595630600211083`"},
      {"2.6363229330424898`"},
      {"2.635653209668543`"},
      {"1.8498070247055565`"},
      {"2.388211868836144`"},
      {"1.5445768819266623`"},
      {"0"},
      {"2.2496691810516096`"},
      {"2.0950642768375887`"}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
    "Column"]}], "}"}]], "Output",
 CellChangeTimes->{3.6155636151176586`*^9}]
}, Open  ]]
},
WindowSize->{1904, 1162},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 2950, 83, 152, "Input"],
Cell[3510, 105, 4117, 104, 332, "Input"],
Cell[7630, 211, 7302, 172, 740, "Input"],
Cell[14935, 385, 1891, 46, 220, "Input"],
Cell[16829, 433, 8695, 198, 992, "Input"],
Cell[25527, 633, 4345, 103, 472, "Input"],
Cell[29875, 738, 2926, 75, 280, "Input"],
Cell[32804, 815, 8750, 202, 700, "Input"],
Cell[41557, 1019, 423, 9, 31, "Input"],
Cell[41983, 1030, 1232, 29, 192, "Input"],
Cell[43218, 1061, 54482, 1188, 3372, "Input"],
Cell[CellGroupData[{
Cell[97725, 2253, 1817, 37, 83, "Input"],
Cell[99545, 2292, 26148, 433, 324, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[125730, 2730, 655, 15, 52, "Input"],
Cell[126388, 2747, 992, 22, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127417, 2774, 557, 10, 31, "Input"],
Cell[127977, 2786, 21743, 361, 324, "Output"]
}, Open  ]],
Cell[149735, 3150, 10043, 222, 763, "Input"],
Cell[159781, 3374, 584, 12, 31, "Input"],
Cell[160368, 3388, 329, 7, 52, "Input"],
Cell[CellGroupData[{
Cell[160722, 3399, 326, 7, 52, "Input"],
Cell[161051, 3408, 3197, 69, 324, "Output"]
}, Open  ]],
Cell[164263, 3480, 316, 7, 52, "Input"],
Cell[CellGroupData[{
Cell[164604, 3491, 1288, 18, 31, "Input"],
Cell[165895, 3511, 4701, 89, 324, "Output"]
}, Open  ]],
Cell[170611, 3603, 317, 7, 52, "Input"],
Cell[CellGroupData[{
Cell[170953, 3614, 786, 11, 31, "Input"],
Cell[171742, 3627, 3554, 74, 324, "Output"]
}, Open  ]],
Cell[175311, 3704, 303, 7, 52, "Input"],
Cell[CellGroupData[{
Cell[175639, 3715, 179, 3, 31, "Input"],
Cell[175821, 3720, 3190, 68, 324, "Output"]
}, Open  ]],
Cell[179026, 3791, 279, 6, 52, "Input"],
Cell[CellGroupData[{
Cell[179330, 3801, 177, 3, 31, "Input"],
Cell[179510, 3806, 3136, 68, 324, "Output"]
}, Open  ]],
Cell[182661, 3877, 276, 6, 52, "Input"],
Cell[CellGroupData[{
Cell[182962, 3887, 173, 3, 31, "Input"],
Cell[183138, 3892, 3169, 68, 324, "Output"]
}, Open  ]],
Cell[186322, 3963, 277, 6, 52, "Input"],
Cell[CellGroupData[{
Cell[186624, 3973, 176, 3, 31, "Input"],
Cell[186803, 3978, 3137, 68, 324, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
