(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1052629,      17697]
NotebookOptionsPosition[   1049659,      17597]
NotebookOutlinePosition[   1050009,      17612]
CellTagsIndexPosition[   1049966,      17609]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Helper", " ", "functions"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SphVec", "[", 
    RowBox[{"theta_", ",", " ", "phi_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "phi", "]"}], " ", 
      RowBox[{"Sin", "[", "theta", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{"Sin", "[", "phi", "]"}], 
      RowBox[{"Sin", "[", "theta", "]"}]}], ",", " ", 
     RowBox[{"Cos", "[", "theta", "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6043271954978313`*^9, 3.604327220929286*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"linear", " ", "interpolation"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Lerp", "[", 
    RowBox[{"A_", ",", " ", "B_", ",", " ", "X_"}], "]"}], " ", "=", 
   RowBox[{"A", " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"B", "-", "A"}], ")"}], "*", "X"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6043199648572626`*^9, 3.604319965387293*^9}, {
  3.6129746928149805`*^9, 3.6129746974232435`*^9}}],

Cell[BoxData[
 RowBox[{"A", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "A"}], "+", "B"}], ")"}], " ", "X"}]}]], "Output",
 CellChangeTimes->{
  3.604349087961071*^9, 3.604386874260832*^9, {3.612974679993247*^9, 
   3.6129746982162895`*^9}, 3.6239958739677973`*^9, 3.6240271733314652`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"spherical", " ", "lerp"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Slerp", "[", 
    RowBox[{"A_", ",", " ", "B_", ",", " ", "X_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"angle", " ", "=", " ", 
       RowBox[{"ArcCos", "[", 
        RowBox[{"Dot", "[", 
         RowBox[{"A", ",", "B"}], "]"}], "]"}]}], ";", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"angle", " ", "\[Equal]", " ", "\[Pi]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "X"}], ")"}], "*", "angle"}], "]"}], " ", 
            "/", " ", 
            RowBox[{"Sin", "[", "angle", "]"}]}], ")"}], "*", "A"}], " ", "+",
          " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"X", " ", "*", " ", "angle"}], "]"}], " ", "/", " ", 
            RowBox[{"Sin", "[", "angle", "]"}]}], ")"}], "*", "B"}]}]}], " ", 
       "]"}]}], "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6043863974191647`*^9, 3.6043866168294716`*^9}, {
  3.604386724099622*^9, 3.60438672989963*^9}, {3.604386850550799*^9, 
  3.604386856150807*^9}, {3.6043869035308733`*^9, 3.604386926260905*^9}, {
  3.6129746862316036`*^9, 3.61297469053585*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"BRDF", " ", "functions"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.604327210520691*^9, 3.604327219737218*^9}, {
   3.604386866990822*^9, 3.604386877700837*^9}, 3.6129747003984137`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", 
   RowBox[{"F0_", ",", " ", "Cos\[Theta]H_"}], "]"}], "=", 
  RowBox[{"F0", " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", "F0"}], ")"}], " ", "*", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "Cos\[Theta]H"}], ")"}], "^", "5"}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.604172611123061*^9, 3.6041726120291133`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "Cos\[Theta]H"}], ")"}], "5"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "F0"}], ")"}]}], "+", "F0"}]], "Output",
 CellChangeTimes->{
  3.6041726159453373`*^9, 3.604269102527836*^9, 3.604293083268638*^9, 
   3.604315921033969*^9, 3.60431997372577*^9, 3.6043204289738083`*^9, {
   3.604320799397996*^9, 3.6043208270055747`*^9}, 3.6043490905572195`*^9, 
   3.6043869489609365`*^9, 3.6239958762709293`*^9, 3.624027175547592*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"LambdaGGX1", "[", 
   RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"Roughness", "^", "2"}], "*", 
        RowBox[{
         RowBox[{"Tan", "[", 
          RowBox[{"ArcCos", "[", "Cos\[Theta]V", "]"}], "]"}], "^", "2"}]}]}],
       "]"}]}], ")"}], " ", "/", " ", "2"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GSmithGGX2Correlated", "[", 
   RowBox[{
   "Cos\[Theta]N_", ",", " ", "Cos\[Theta]V_", ",", " ", "Roughness_"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos\[Theta]N", "  ", ">", " ", "0"}], " ", "&&", " ", 
     RowBox[{"Cos\[Theta]V", " ", ">", " ", "0"}]}], ",", " ", 
    RowBox[{"1", " ", "/", " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"LambdaGGX1", "[", 
        RowBox[{"Cos\[Theta]N", ",", " ", "Roughness"}], "]"}], " ", "+", " ", 
       RowBox[{"LambdaGGX1", "[", 
        RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}]}], ")"}]}], 
    ",", " ", "0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.623995976624669*^9, 3.6239959812549343`*^9}, {
  3.6239960789425216`*^9, 3.6239960921822786`*^9}, {3.623996146630393*^9, 
  3.623996276110799*^9}, {3.6239980389276266`*^9, 3.6239980422878184`*^9}, {
  3.6239983331674557`*^9, 3.623998349743404*^9}, {3.6239984112639227`*^9, 
  3.6239984336452026`*^9}, {3.6239984939116497`*^9, 3.6239985113586483`*^9}, {
  3.6240028383385*^9, 3.624002839336557*^9}, {3.624004260931279*^9, 
  3.624004266032571*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GGXNDF", "[", 
   RowBox[{"n_", ",", " ", "L_", ",", " ", "V_", ",", " ", "Roughness_"}], 
   "]"}], "  ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", " ", "=", " ", 
      RowBox[{"Normalize", "[", 
       RowBox[{"L", " ", "+", " ", "V"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"Roughness", "^", "2"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n", ".", 
         RowBox[{"H", "^", "4"}]}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Roughness", "^", "2"}], "+", 
           RowBox[{
            RowBox[{"Tan", "[", 
             RowBox[{"ArcCos", "[", 
              RowBox[{"n", ".", "H"}], "]"}], "]"}], "^", "2"}]}], ")"}], "^",
          "2"}]}], ")"}]}]}], "}"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.604320111038624*^9, 3.60432014961983*^9}, {
  3.604320180467595*^9, 3.6043201842758126`*^9}, {3.604326462761922*^9, 
  3.6043264938567*^9}, {3.6129747222876663`*^9, 3.612974725918874*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FrGGXCorrelated", "[", 
    RowBox[{
    "n_", ",", " ", "L_", ",", " ", "V_", ",", " ", "Roughness_", ",", " ", 
     "F0_"}], "]"}], "  ", ":=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H", " ", "=", " ", 
       RowBox[{"Normalize", "[", 
        RowBox[{"L", " ", "+", " ", "V"}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"F0", ",", "  ", 
         RowBox[{"H", ".", "V"}]}], "]"}], " ", "*", " ", 
       RowBox[{"GGXNDF", "[", 
        RowBox[{"n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness"}], 
        "]"}], "*", " ", 
       RowBox[{
        RowBox[{"GSmithGGX2Correlated", "[", 
         RowBox[{
          RowBox[{"n", ".", "L"}], ",", " ", 
          RowBox[{"n", ".", "V"}], ",", " ", "Roughness"}], "]"}], " ", "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", "*", " ", 
          RowBox[{"n", ".", "L"}], "*", 
          RowBox[{"n", ".", "V"}]}], " ", ")"}]}]}]}], "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.623996288119486*^9, 3.6239963453987617`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "function", " ", "perform", " ", "a", " ", "numerical", " ", 
    "integration", " ", "of", " ", "the", " ", "GGX", " ", "BRDF", " ", "and",
     " ", "keep", " ", "the", " ", "peak", " ", 
    RowBox[{"intensity", ".", " ", "Then"}], " ", "deduced", " ", "a", " ", 
    "factor", " ", "to", " ", "reconstruct", " ", "the", " ", "offspecular", 
    " ", "peak", " ", "from", " ", "the", " ", "normal", " ", "and", " ", 
    RowBox[{"R", ".", " ", "The"}], " ", "factor", " ", "to", " ", "recover", 
    " ", "the", " ", "vector", " ", "should", " ", "be", " ", "use", " ", 
    "with", " ", 
    RowBox[{"Slerp", ".", " ", "However"}], " ", "for", " ", "performance", 
    " ", "we", " ", "can", " ", "use", " ", 
    RowBox[{"Normalize", "[", 
     RowBox[{"Lerp", "[", "]"}], "]"}], " ", 
    RowBox[{"instead", ".", " ", "In"}], " ", "the", " ", "shader", " ", 
    "code", " ", "this", " ", "will", " ", "allow", " ", "to", " ", "use", 
    " ", "directly", " ", 
    RowBox[{"Lerp", "[", "]"}], " ", "without", " ", "the", " ", "normalize", 
    " ", "as", " ", "cubemap", " ", 
    RowBox[{"don", "'"}], "t", " ", "require", " ", "the", " ", "vector", " ",
     "to", " ", "be", " ", 
    RowBox[{"normalized", ".", " ", "This"}], " ", "is", " ", "an", " ", 
    "approximation", " ", "of", " ", "slerp", " ", "Ok", " ", "for", " ", 
    "our", " ", "case"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FrGGXTestCorrelated", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_", ",", " ", "F0_"}], "]"}],
    "  ", ":=", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"dangle", " ", "=", " ", "0.01"}], ";", 
      RowBox[{"n", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"V", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"Cos\[Theta]V", " ", "*", " ", "Cos\[Theta]V"}]}], 
           "]"}]}], ",", " ", "0", ",", " ", "Cos\[Theta]V"}], "}"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"MaxTheta", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", 
      RowBox[{"MaxPhi", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", 
      RowBox[{"MaxVal", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"R", " ", "=", " ", 
       RowBox[{
        RowBox[{"2", " ", "*", " ", 
         RowBox[{"Dot", "[", 
          RowBox[{"n", ",", " ", "V"}], "]"}], " ", "*", " ", "n"}], " ", "-",
         " ", "V"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Retrieve", " ", "the", " ", "peak", " ", "intensity", " ", "of", " ", 
        "the", " ", "GGX", " ", "BRDF"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"For", " ", "[", " ", 
       RowBox[{
        RowBox[{"angle", " ", "=", " ", "0.0001"}], ",", 
        RowBox[{"angle", " ", "\[LessEqual]", " ", 
         RowBox[{"\[Pi]", "-", "0.0001"}]}], ",", 
        RowBox[{
         RowBox[{"angle", " ", "+=", " ", "dangle"}], " ", ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"theta", " ", "=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"angle", "<", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "-", " ", "angle"}], ",", " ", 
            RowBox[{"angle", " ", "-", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"phi", " ", "=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"angle", "<", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}], ",", "\[Pi]", ",", " ", "0"}], 
           "]"}]}], ";", "  ", 
         RowBox[{"L", " ", "=", "  ", 
          RowBox[{"SphVec", "[", 
           RowBox[{"theta", ",", "phi"}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"val", "=", " ", 
          RowBox[{
           RowBox[{"FrGGXCorrelated", "[", 
            RowBox[{
            "n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness", ",", 
             " ", "F0"}], "]"}], " ", "*", 
           RowBox[{"L", ".", "n"}]}]}], " ", ";", " ", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"val", " ", "\[GreaterEqual]", " ", "MaxVal"}], ",", 
           RowBox[{
            RowBox[{"MaxVal", "=", "val"}], ";", 
            RowBox[{"MaxTheta", "=", "theta"}], ";", 
            RowBox[{"MaxPhi", "=", "phi"}]}], ",", "0"}], "]"}]}]}], "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Compare", " ", "the", " ", "off", " ", "specular", " ", "peak", " ", 
        "with", " ", "the", " ", "reflection", " ", "vector", " ", "and", " ",
         "deduced", " ", "a", " ", "slerp", " ", "factor", " ", "to", " ", 
        "reconstruct", " ", "the", " ", "vector", " ", "from", " ", "normal", 
        " ", "and", " ", "R"}], " ", "*)"}], 
      RowBox[{"slerpfactor", " ", "=", " ", 
       RowBox[{
        RowBox[{"VectorAngle", "[", 
         RowBox[{"n", ",", " ", 
          RowBox[{"SphVec", "[", 
           RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}]}], "]"}], " ", "/", " ", 
        RowBox[{"VectorAngle", "[", 
         RowBox[{"n", ",", " ", "R"}], "]"}]}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"newMax", " ", "=", " ", 
       RowBox[{"Slerp", "[", 
        RowBox[{"n", ",", " ", "R", ",", " ", "slerpfactor"}], "]"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Dispplay", " ", "to", " ", "oberseve", " ", "the", " ", "behavior"}], 
       " ", "*)"}], 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Pink", ",", " ", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"n", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{"n", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
          " ", "Blue", ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"V", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{"V", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
          "Red", ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"R", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{"R", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
          "Green", ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"SphVec", "[", 
                 RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{
                RowBox[{"SphVec", "[", 
                 RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}], "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
          "Orange", ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"newMax", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{"newMax", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}]}], 
         "}"}], ",", "   ", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", " ", "1"}], "}"}]}], "}"}]}]}], "]"}]}],
      ",", "slerpfactor", ",", " ", "newMax"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6042717414098988`*^9, 3.6042717479599075`*^9}, {
   3.604272512379981*^9, 3.6042725582440453`*^9}, {3.6042726290091443`*^9, 
   3.604272635660154*^9}, {3.6042729899426513`*^9, 3.6042729912126527`*^9}, {
   3.604273714969669*^9, 3.6042737260306845`*^9}, {3.604273853969864*^9, 
   3.6042738552598658`*^9}, {3.604320376622814*^9, 3.6043203928937445`*^9}, 
   3.6043271613498783`*^9, {3.6043272555882683`*^9, 3.604327277883544*^9}, {
   3.6043273120754995`*^9, 3.6043273509617233`*^9}, 3.6043273902709723`*^9, 
   3.6043275801968355`*^9, {3.6129760313345394`*^9, 3.612976058165074*^9}, {
   3.6240035048117385`*^9, 3.624003514927317*^9}, 3.6240168998288965`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Manipulation", " ", "test", " ", "function", " ", "to", " ", "see", " ", 
    "how", " ", "the", " ", "peak", " ", "behave", " ", "depends", " ", "on", 
    " ", 
    RowBox[{"parameters", ".", " ", "Two"}], " ", "test", " ", "to", " ", 
    "do", " ", "with", " ", "F0", " ", "set", " ", "to", " ", "0.04", " ", 
    "and", " ", "with", " ", "F0", " ", "set", " ", "to", " ", "1", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"for", " ", "metal"}], ")"}], ".", " ", "With"}], " ", "F0", 
    " ", "set", " ", "to", " ", "0.04", " ", "we", " ", "notice", " ", "a", 
    " ", "discontinuity"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"FrGGXTestCorrelated", "[", 
     RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "F0"}], "]"}], 
    ",", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Roughness", ",", " ", "0.1", ",", " ", "\"\<Roughness\>\""}], 
       "}"}], ",", "0.01", ",", " ", "1.0"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "Cos\[Theta]V", ",", "0.9999", ",", " ", "\"\<Cos\[Theta]V\>\""}], 
       "}"}], ",", "0.0001", ",", "0.9999"}], "}"}], ",", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"F0", ",", " ", "1", ",", " ", "\"\<F0\>\""}], "}"}], ",", "0",
       ",", " ", "1.0"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.624003520711648*^9, 3.6240035262489643`*^9}, {
  3.6240038511795497`*^9, 3.624003852220609*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`Cos\[Theta]V$$ = 0.19, $CellContext`F0$$ = 
    1, $CellContext`Roughness$$ = 0.795, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`Roughness$$], 0.1, "Roughness"}, 0.01, 1.}, {{
       Hold[$CellContext`Cos\[Theta]V$$], 0.9999, "Cos\[Theta]V"}, 0.0001, 
      0.9999}, {{
       Hold[$CellContext`F0$$], 1, "F0"}, 0, 1.}}, Typeset`size$$ = {
    472., {88., 92.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`Roughness$43501$$ = 
    0, $CellContext`Cos\[Theta]V$43502$$ = 0, $CellContext`F0$43503$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`Cos\[Theta]V$$ = 0.9999, $CellContext`F0$$ = 
        1, $CellContext`Roughness$$ = 0.1}, "ControllerVariables" :> {
        Hold[$CellContext`Roughness$$, $CellContext`Roughness$43501$$, 0], 
        Hold[$CellContext`Cos\[Theta]V$$, $CellContext`Cos\[Theta]V$43502$$, 
         0], 
        Hold[$CellContext`F0$$, $CellContext`F0$43503$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`FrGGXTestCorrelated[$CellContext`Cos\[Theta]V$$, \
$CellContext`Roughness$$, $CellContext`F0$$], 
      "Specifications" :> {{{$CellContext`Roughness$$, 0.1, "Roughness"}, 
         0.01, 1.}, {{$CellContext`Cos\[Theta]V$$, 0.9999, "Cos\[Theta]V"}, 
         0.0001, 0.9999}, {{$CellContext`F0$$, 1, "F0"}, 0, 1.}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{523., {161., 166.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.624003521637701*^9, 3.6240035270700116`*^9}, 
   3.624003853335673*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "fiting", " ", "function", " ", "representing", 
    " ", "the", " ", "slerp", " ", "factor", " ", "to", " ", "apply", " ", 
    "between", " ", "normal", " ", "and", " ", "reflection", " ", "vector", 
    " ", "for", " ", "off", " ", "specular", " ", "peak", " ", 
    "reconstruction"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Same", " ", "function", " ", "as", " ", "above"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_", ",", " ", "F0_"}], "]"}],
    "  ", ":=", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dangle", " ", "=", " ", "0.01"}], ";", "\[IndentingNewLine]", 
      RowBox[{"n", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"V", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"Cos\[Theta]V", " ", "*", " ", "Cos\[Theta]V"}]}], 
           "]"}]}], ",", " ", "0", ",", " ", "Cos\[Theta]V"}], "}"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"MaxTheta", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", 
      RowBox[{"MaxPhi", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", 
      RowBox[{"MaxVal", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"R", " ", "=", " ", 
       RowBox[{
        RowBox[{"2", " ", "*", " ", 
         RowBox[{"Dot", "[", 
          RowBox[{"n", ",", " ", "V"}], "]"}], " ", "*", " ", "n"}], " ", "-",
         " ", "V"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", " ", "[", " ", 
       RowBox[{
        RowBox[{"angle", " ", "=", " ", "0.001"}], ",", 
        RowBox[{"angle", " ", "\[LessEqual]", " ", 
         RowBox[{"\[Pi]", "-", "0.001"}]}], ",", 
        RowBox[{
         RowBox[{"angle", " ", "+=", " ", "dangle"}], " ", ";", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"theta", " ", "=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"angle", "<", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "-", " ", "angle"}], ",", " ", 
            RowBox[{"angle", " ", "-", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}]}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"phi", " ", "=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"angle", "<", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}], ",", "\[Pi]", ",", " ", "0"}], 
           "]"}]}], ";", "  ", "\[IndentingNewLine]", 
         RowBox[{"L", " ", "=", "  ", 
          RowBox[{"SphVec", "[", 
           RowBox[{"theta", ",", "phi"}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"val", "=", " ", 
          RowBox[{
           RowBox[{"FrGGXCorrelated", "[", 
            RowBox[{
            "n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness", ",", 
             " ", "F0"}], "]"}], "*", 
           RowBox[{"L", ".", "n"}]}]}], " ", ";", " ", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"val", " ", "\[GreaterEqual]", " ", "MaxVal"}], ",", 
           RowBox[{
            RowBox[{"MaxVal", "=", "val"}], ";", 
            RowBox[{"MaxTheta", "=", "theta"}], ";", 
            RowBox[{"MaxPhi", "=", "phi"}]}], ",", "0"}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"slerpfactor", " ", "=", " ", 
       RowBox[{
        RowBox[{"VectorAngle", "[", 
         RowBox[{"n", ",", " ", 
          RowBox[{"SphVec", "[", 
           RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}]}], "]"}], " ", "/", " ", 
        RowBox[{"VectorAngle", "[", 
         RowBox[{"n", ",", " ", "R"}], "]"}]}]}]}], "\[IndentingNewLine]", 
     " ", "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.623996397565746*^9, 3.6239964083853645`*^9}, 
   3.6240169140757113`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "1"}], "]"}], 
      ",", " ", 
      RowBox[{"1", "-", "Roughness"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.623996416219813*^9, 3.6239964201120358`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJysvQdQFMv3v40554hiwABGjCjGMYsBzDlgzmLOOSEiKoo5Y0RRMCAGBARE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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFnHX8FcX3//cud/d6dz/vi10IiK0oBoKdiEEIoogiJagISBqISoOohIJi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         "]], Polygon3DBox[CompressedData["
1:eJwtnAnYVdMXxs+9fXcf95z//cwzkSFz5syikWYZKtKIKIUMjTRQKqJQyNBE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         "]], Polygon3DBox[CompressedData["
1:eJwt13mc19Mex/EvM/Mb8xszwuVekocQomudsl4SdYWEUlqlhLSq0D6tSk2l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         "]], 
        Polygon3DBox[{{2688, 1581, 1857, 3515, 2554, 2555}, {2657, 1514, 1911,
          1161, 1160, 3355}, {2677, 1540, 2423, 977, 984, 3358}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmXWgFsUaxg98wNnDmcNLd7eEgIAiqIikKCCtgoqEoBJ2d1+7A7vrYiuC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         "]], Polygon3DBox[CompressedData["
1:eJwtmnXAFOUaxZdvgXkXZmbpBgFBBUUBlTJoBBEFlBBEEVvK7hYDu65X7O5A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         "]], Polygon3DBox[CompressedData["
1:eJwt13W4l+UZB/Afec4PDhy6Q6RbGkmV0JGTntQkHRLbCJ0CbgNjs6eAATao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         "]]}]}, {}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlllsVVUUhve9PYfDuaf3lk60QjQCKtJA1KCR4baUgAMPmkiQIRqNTTWY
qBhLoQGEB30RRcCibbVUxAEjhlo1gZKq0BZFHBCsKQUqonV4ERN8UAgO35+1
H9b911l77bXXXtO+E+pWLHws7Zw7BBVAp3LO5SLnahLnMmBzyrlnYucaA+ce
QXE1eCLjXBp5CTo/8X0QfgS8LnSuH/56sIc947C3HN19WedmYCuP7d4CO+cs
P3vRKYevR+co/Ez41fCvBsbvAF+HjmDzDfAo1AT/DbiYsw/DT8J2N98ZfNsP
bsLOJfa+PMq5K/HjDDoTwE70zrG+DKxj72Rk8+GfQ/9v9FvRL0M2gn45eBP0
C/wi9kz3/I3gOOhH+PHgHezvCMznDdhphm8Du5FXc9/53Pd9vj9D/gLYhTxm
Xx7cw/dB5JvBp/CnBPn9yG9m38cpi1cLPh2AXx6Zz8PwDyR2lxjZr9jvYH9W
PqFbE1lM5oCLoSht95L9SvinwdN834POssj8qQSHipz7Fl9akA+Ap6Bt8KfB
QWgV/AlwPWdtBVvBqZzZiHwaWIKNNvhnkZ/E/lL4JcjGQu3wzcgnc/ZK5SJr
uVRO3wQ/gbL4dgBcGplv8nFMaD4Xg9nEcjolsdjXQQVQBd8hOEz8X9SdoH/Q
G522OrwIf21i8iQxH+RbJrGYKrYzwf1ZqzfVoPJfnzK709A7plpj/fnYzihE
vwr5EPIlyOdBbwVWh3Ohd+AngrnQ7BSBtWnrkTwUw/d6334ILCZnwa3YfwW+
DPvbYtOZDb8FvhV+DPz3xKUf3U5kX4H3If8azCV2b9VGMfQf/FSwLLE4DRGf
0sjs6xz143h0PoKfFdlZOjOJ7I666weBxefDwOq5Cv1PkR/H1kspmw8Lkfew
vg6+KDI/5e886vJf7v1ExnKvGiiPrJfUR+qnPYHVeSdYi/5FZI+j/1vO6uk9
bH8e2Jw5EtisET+Izmx0/kT/YfgKdLenrI51/r2QU/+g8wc6D6Gzlr17sXGX
+gv5OeQPIn/Nz5mdYGli++oT63P5qRmg2lA/LWDfLPgzgdXwDr9XNgZ873wX
WP2KVw72cfexzs5Sb6hHirG10s/SVYHVomqyJ2v9qziviW1NOmvVb8h3wrdE
Fn/lWjnXjFNfqD/WsWc0/Fx83h5bnaheFCdd7dbQ+ll9PQxujC2P2cjiBLg5
oc32L1m/W/Xs61bzUT5qr847xrz4PbS5rbdBb4TmUez77gI6fcivcZbTjYHN
/IbAcqk8fhFY3fX5XtA5Ok89ovppYf90cI30tY6BRyNbV8/2sn418hUZ60fN
KM0H1ahiqNrLR1bnjbG9W4qnYj+QsVwr5+pxvSnql6bA4vwXZ3Wzp8JZ/Wje
tPuZI5uHUjbfZxCjS4HVqnpJZ6kmjxOf86G9fYmfP9XghdDeuxpwClTIWVWh
zb0kbfns9TNCMez3vOLT5nOt923Ev7k/BybX26d5q9ovStvd9HYob3rfNvhc
NIHnc/Y2qN6e9HdsiO3dKYS/HX92B3bHd8Fdgb0pb6ueMjYXNXfV33rfbwvt
frqL6nJzYHnZAraPstmut2a9z9edod1T99XcUN+rR2rBRfjUhd4g8duteYiN
W3QO+zs44zJwF/JNyPOh2Vef6Q1t8DWm/xfqb5ZctZ/BHX6eTwotPleF9v9D
+n38XK43DPkVof13UdxvAA/7WtUcOpmx/GumVrBWin5laPNLc6wL/B+70SMn

         "]], Polygon3DBox[CompressedData["
1:eJwtllmMVUUQhs+Z6TOHey9nhm0YFjdEFBBEogmOLA4RRGM0kSigEokTNJio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         "]], Polygon3DBox[CompressedData["
1:eJwlk0tIVAEUhs/YHe/cO84EI1TkygJfKC5a5GJmDIp01cKF6SZQUnKjJYVQ
4qYUIyV0Y4W1SzSyB5TO+EoNJUSJ2pQWtcyNCrbRtPI7nMXPvec//3nec3Pr
W6qaM0SkBATBVESk2hV5kCmyg+2HRXLhfjoiP0BNQCQfLgmi6Do9kb/oPvsi
H3kv4j0JXw4miFuEy4GLYydAGu5XVOQb+bfItwlewrUQv0sDSXAE/TxxJ+GH
8D8FS9StpuY0fBb+0+QqAyk0F3n6DJFGlwJr5I7Dh8h1FN8x8Br7CjW24a6T
I6yz8vwCt0jMArhEjRiOy3Ab6K7hJ5WM82yC+w13Pmj1tY9TzDFI3HHsf/Bn
sa+i+8P7Ga0N/x7dK2rvo9sDXdjr6NqpM4U9CXrhHlFoO2q96wzj4BaaQrBP
njXsVVCEXRe2nRdQIx/UY9dSYwP/XXJ5ru30Pu9zcLMgwn4Gyd3q2zd6DDfg
Wc/f4Wewp0EYXY1re9B9rMAtg6/ErR4W6SbGp6YXtJ0Wo/uv3x/NJ1CC3Yh2
C385COFLE3NH90q+bLgYuI3dA/+WmDfaI74B+mggdhN/AtCGpNC0wT1xrGft
Xe9M59CdVwTtvvTOTtDPMzQj4Cb2OWardW32d47NqLPGo3Y7M9R8AVcasW+g
32LCsVt6iO4CufPI3Q/XBzo8y6v5h8GHgN36DbhR7Od6RwG7df1/XPKMOTaj
zlpJvqVD7M2x2nrDehsxnvf0P4Ivwz4AkdB7kQ==
         "]]}]}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt1NlvVVUYhvHF0DK2gIIyz6BCOUgrU0sRQZChCgUio7VQwbYSihgCJIwa
Bv8BmggXaAIRgoQE8NIbMEBQmQt0hgItIjKliNbpt4wXz3mf71tr7b32Ovuc
fktLZq9sFkJY6yO3eQjRk+Vv8libEDrKzerveB/+xIRTPME/aRdCozqbr+FN
PCfO552tWcS38W78mTXF6p48tW0I63lf3pXv5IP5AF7K03iC7+el1meoj/NG
vYR7nOS5+sf5aBQZv6SXLUepC2VFUgiX9caoK/kV/phX8TJeLa/KGnlN1srr
8oYslzdlHSr4LVkpb8sqeUdWy3pZIxtkrTydHEKme1TghvpbORblyLf3i3pH
eQby7L9MntAbIqcYP8ZL9B+o9/EV/D7fxYv5Pb6DF/K7fB1fzut5ivVFcY/8
qbNeyOt4A58Rnyvug4/jBdZUq4fxfF7Je/MLrtEk5zq/DjLdc41rGcJqZONZ
ixCek/Xyg5QQzsn31fmYjhko0L+nfzXOUS9DDkbqvy0f6VfhQ16IJfoz5Sw8
1q9BES+O1zWWK2fjiX4tPuKT9VfIv9R5vCNPw1HP10EOwVC0wit4z5yXZSoG
owQvIRmjjA2S0zAQKeiHdCwy1l+2RF9MRR+0Qw+8ioXm9JTN0R0T0Q1t0CWe
m/GEfAEBWfgYmfjJ/lPj+8THYBXG4h/9TnIY5lt/R/0jXlS/ga5ohucx3vhw
+bPxMvTib6E3WqAzXjdnhHxovBIDeJPM0k/iK/EO/tT7yhm+y1+zsT38D73l
6iO8vfxSFsg51v5ubK96snpp/C7RNp53PAfjeXICFsezROv4PLFnbEF8JzA6
fgf4wbW0wxGeEe+P23qzNM/K8fE5MFN9V30Fk9Rvxr3rPVBXYJ56Cr6xr6fq
ajSiHOnm/Sov45DxHPUlvpufkQn1LXkafgphkvffUFjto9Q16/Snm3NKNmAa
vyjv46A51+UvOMCvyQsY6Ry/Vp/nX8jvZZp1N+VJuEXITPrv1QirjG8nO7AT
n2M99rcK4bDf5Aa+EZuwGVuwFZ9in7WfyW1xPv/btc/4P8r6/3/9X1hUvZQ=

       "]], 
      Line3DBox[{961, 2, 1156, 2468, 1144, 1015, 2467, 1141, 1143, 1140, 1142,
        1147, 1146, 961}], Line3DBox[{963, 3, 1162, 1139, 962, 993, 963}], 
      Line3DBox[{1341, 6, 2417, 1163, 1164, 3400, 1165, 2471, 1166, 2454, 
       3376, 1167, 1168, 2456, 1169, 1170, 2457, 1171, 1172, 3377, 1173, 1174,
        3373, 1176, 966, 1345, 8, 1343, 7, 1341}], 
      Line3DBox[{1350, 11, 2420, 1177, 1178, 3403, 1179, 2475, 1180, 3635, 
       2455, 1181, 1182, 3405, 1183, 1184, 1185, 1186, 2463, 1187, 1188, 1189,
        1190, 3395, 1191, 1192, 1193, 1194, 3393, 1195, 1196, 1197, 3375, 
       1198, 1199, 1201, 970, 1352, 12, 1350}], Line3DBox[CompressedData["
1:eJwl0Mkuw1EUwOHT9l9a1DxT1FTzkEiQWAp7O9KQ9AHYeRwv42HM81zjl1h8
+d2ccxc3t1Q92jlMRcQ+uXRETU8NjvMRZ0nEORdccsU1N+wWIm71jnseeOSJ
Z1btX/SVN975oMYnX6y5860//BLZiBRpKnYZTchSRz05Nuzy2kAjTRQ48eZm
bWHFnVZt48C5XTvopItuts17tJc++hlgkC27og4xzAglquajOsY4E0yyaV7W
KaaZYZZ18zmdZ4FFllhmL/n/8z+JDCdF
       "]], 
      Line3DBox[{576, 316, 1901, 594, 1202, 1203, 1204, 1205, 1206, 3409, 
       1207, 1208, 1209, 1210, 1211, 1212, 3410, 1213, 1214, 1215, 1216, 1217,
        2478, 1218, 3379, 1219, 2479, 1220, 2461, 1221, 1222, 2481, 3412, 
       1223, 2482, 1224, 1225, 1226, 1227, 3413, 1228, 1229, 1230, 1231, 1232,
        3414, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 3415, 1241, 
       1242, 1243, 1244, 1245, 1246, 1247, 3386, 1248, 1249, 1250, 1251, 1252,
        1253, 1133, 576}], Line3DBox[{1334, 1107, 1109, 1012, 1334}], 
      Line3DBox[{1108, 1333, 1332, 1331, 1108}]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0stLlFEYwOF3nCDDitCFtBCZ1hG6jtC1RIK7CFu4CqmZpUTtAomZ1G4W
qV20cYqQ0GqTjtMk0WWapnG89BfUP1DuewYXP55zvg++c3j5UiOZoXQiIm5o
PRnxtSXiPV/pb1vEL/vE4Yg/PMY9dvOA96fYwTM8wbPs5QX2c5SDvMqLvMkr
fMjrLDDH40ciXvODZrSmt8q2Rswyxzne4mNO8Akn+ZRTfMbbnOcd3tWC9T0+
533mOc1FPmCheRe+YPpQxDLLeqmi3umjOz5q3odZ5nmt+R1e5jiHOcZzvMQ+
nmcPB5jiabbzJJPs4j+zPMrf7DSDJc9L2rVf5RttH4zYsW9wm3VuscYGq9xk
hXV+4Wf9tP7EGjf4g2VWWeJ3FllpnsVvzJjBSnL/P/gPcV9Piw==
       "]]}, {
      Line3DBox[{2484, 2875, 2876, 2768, 2995, 1513, 3371, 2994, 3040, 3842, 
       2657, 3355, 4048, 2658, 2485, 3638, 2659, 2486, 3372}], 
      Line3DBox[{2494, 3041, 3042, 2746, 2828, 2998, 2999, 3833, 2997, 2996, 
       1525, 2495, 3645, 2668, 2496, 3646, 2669, 2497, 3647, 2670, 3356, 4051,
        3637}], 
      Line3DBox[{2503, 2930, 2747, 2831, 2859, 3786, 3497, 2810, 2771, 2978, 
       3432, 3790, 2504, 3054, 3055, 1537, 2505, 3653, 2675, 2506, 3654, 2676,
        2507, 3655, 2677, 3358, 4052, 2678, 3359, 4053, 3433, 3726, 2508, 
       3434, 3727, 2509, 3435, 3728, 2510, 3656, 3378}], 
      Line3DBox[{2522, 3369, 3425}], Line3DBox[{2536, 3370, 3424}], 
      Line3DBox[{3397, 2550}], 
      Line3DBox[{2552, 2950, 2951, 2844, 2862, 3809, 2686, 3027, 3025, 3026, 
       2986, 3830, 2687, 2985, 2906, 3667, 2688, 2555, 3668, 2689, 2557, 3669,
        2690, 2559, 3670, 2691, 2561, 3671, 2692, 2563, 3673, 3674, 2693, 
       2565, 3675, 2694, 2567, 3676, 2695, 2569, 3006, 3677, 2696, 3007, 3008,
        3834, 3521, 2813, 2697, 3023, 3043, 3843, 3528, 2845, 2973, 2698, 
       2974, 3508, 3819, 2888, 2846, 2919, 2699, 2918}], 
      Line3DBox[{2573, 2952, 2953, 2843, 2887, 3808, 3507, 2572, 2884, 2904, 
       2885, 2812, 3524, 3805, 3024, 2571, 2758, 2842, 3807, 3492, 2570, 3520,
        3758, 3005, 2568, 3757, 3460, 2566, 3756, 3459, 2564, 3755, 3458, 
       3672, 2562, 3754, 3457, 2560, 3753, 3456, 2558, 3752, 3455, 2556, 3751,
        3454, 2554, 3515, 3750, 2905, 2553, 3494, 3749, 2982, 2984, 2983, 
       2551, 3506, 3818, 2886, 2841, 3012, 3011, 2949}], 
      Line3DBox[{2574, 2954, 2955, 2847, 2863, 3810, 2700, 2814, 3029, 3030, 
       3028, 3529, 3838, 2701, 3045, 2759, 3678, 2702, 2575, 3679, 2703, 2576,
        3680, 2704, 2577, 3681, 2705, 2578, 3682, 2706, 2579, 3683, 1598, 
       2580, 3684, 2707, 2581, 3685, 2708, 2582, 3686, 2709, 2583, 3495, 3687,
        2710, 2848, 3013, 3835, 3522, 2956, 2975, 2711, 2976, 3509, 3820, 
       2889, 2849, 2921, 2712, 2920}], 
      Line3DBox[{2584, 2957, 2958, 2850, 2864, 3461, 3812, 2815, 2783, 2987, 
       3831, 2713, 2585, 3688, 2714, 2586, 3689, 2715, 2587, 3690, 2716, 2588,
        3691, 2717, 2589, 3692, 2718, 2590, 3693, 3462, 3759, 2591, 1611, 
       2592, 3694, 2719, 2593, 3695, 2720, 2594, 3523, 3696, 2721, 3014, 3015,
        3016, 3697, 2851, 2959, 2722, 2960, 3828, 2869, 2870, 2784, 2923, 
       2723, 2922}], 
      Line3DBox[{2595, 2961, 2785, 2852, 2865, 3792, 3498, 2816, 2977, 2786, 
       2965, 3463, 3793, 2596, 3698, 2724, 2597, 3699, 2725, 2598, 3700, 2726,
        2599, 3701, 2727, 2600, 3702, 2728, 2601, 3703, 3464, 3760, 2602, 
       3465, 3761, 2603, 3704, 2729, 2604, 3705, 2730, 2605, 3526, 3706, 2731,
        3034, 3035, 3840, 2787, 2817, 2866, 2962, 2867, 2788, 3502, 3821, 
       2890, 2760, 2963, 2925, 2926, 2924}], 
      Line3DBox[{2606, 2964, 2790, 2853, 2868, 3794, 3499, 2818, 2791, 3466, 
       3795, 2607, 2792, 2819, 3467, 3796, 2608, 3707, 2732, 2609, 3708, 2733,
        2610, 3709, 2734, 2611, 3710, 2735, 2612, 3711, 3468, 3762, 2613, 
       3469, 3763, 2614, 3470, 3764, 2615, 3712, 2736, 2616, 3836, 3017, 2737,
        3018, 3837, 2789, 2738, 2795, 3517, 3829, 2761, 3019, 2928, 2929, 
       2927}], Line3DBox[{2630, 2871, 2763, 2966, 2762, 3789, 3518, 2629, 
       2804, 2803, 3799, 2628, 2742, 3717, 2627, 3769, 3475, 2626, 3768, 3474,
        2625, 3767, 3473, 2624, 3766, 3472, 3716, 2623, 2741, 3715, 2622, 
       2740, 3714, 2621, 2739, 3713, 2620, 3765, 3471, 2619, 3797, 2794, 2820,
        2793, 2618, 3798, 2799, 2798, 2617, 3510, 3822, 2797, 2854, 2796, 
       3020, 2967}], 
      Line3DBox[{2656, 2873, 2874, 2808, 3032, 3031, 3839, 2655, 3050, 3053, 
       3051, 3044, 3844, 3525, 2654, 3785, 3487, 2653, 3784, 3486, 2652, 3783,
        3485, 2651, 3782, 3484, 2650, 3781, 3483, 3722, 2649, 2745, 3721, 
       2648, 3780, 3482, 2647, 3779, 3481, 2646, 2911, 3037, 3841, 3039, 3038,
        2645, 2992, 2993, 3778, 2825, 2895, 2894, 2644, 2893, 3823, 3511, 
       2824, 2972, 2971, 2643, 3802, 2907, 2988, 2908, 2823, 2892, 2891, 
       2897}], Line3DBox[{2769, 2667, 3428}], 
      Line3DBox[{2805, 2968, 2764, 3021, 2765, 2969, 3800, 2631, 2800, 2821, 
       2801, 3811, 2632, 2802, 2822, 3770, 3496, 2633, 3527, 3771, 3036, 2634,
        3476, 3772, 2635, 3718, 2743, 2636, 3719, 2744, 2637, 3720, 3477, 
       3773, 2638, 3478, 3774, 2639, 3479, 3775, 2640, 3480, 3776, 2641, 3530,
        3777, 3046, 2642, 3047, 3801, 2806, 2989, 2807, 2990, 2991, 3832, 
       2909, 2766, 2970, 2767, 2896, 2872, 2910}], Line3DBox[{3427, 2912}], 
      Line3DBox[{2915, 3368, 3381}], 
      Line3DBox[{2931, 3000, 2748, 2832, 2749, 3813, 3500, 2981, 2980, 3033, 
       2773, 2979, 2774, 3846, 3052, 2512, 3057, 3048, 3056, 3049, 3845, 2513,
        3436, 3729, 2514, 3658, 2680, 2515, 3659, 2681, 2516, 3660, 2682, 
       2517, 3661, 3437, 3730, 2518, 3438, 3731, 2519, 3439, 3732, 2520, 2750,
        4054, 3488, 3360, 3787, 2751, 3367, 2752, 2932, 2521, 2942, 3636}], 
      Line3DBox[{2933, 3001, 2753, 2837, 2754, 3814, 3501, 2523, 2779, 3022, 
       2780, 3791, 2524, 3440, 3733, 2525, 3441, 3734, 2526, 3442, 3735, 2527,
        3662, 2683, 2528, 3663, 2684, 2529, 3664, 3443, 3736, 2530, 3444, 
       3737, 2531, 3445, 3738, 2532, 3446, 3739, 2533, 3489, 3806, 2838, 2755,
        2534, 3788, 2756, 2917, 2757, 2934, 2535, 3421}], 
      Line3DBox[{2943, 3009, 3010, 2840, 2881, 2880, 3804, 2537, 2945, 2946, 
       2944, 3740, 3493, 2538, 3447, 3741, 2539, 3448, 3742, 2540, 3449, 3743,
        2541, 3450, 3744, 2542, 3665, 2685, 2543, 3666, 3451, 3745, 2544, 
       3452, 3746, 2545, 3453, 3747, 2546, 3004, 3748, 3519, 2547, 3490, 3825,
        2936, 3003, 3002, 2548, 3491, 3824, 2935, 2938, 2937, 2549, 3817, 
       2882, 2883, 3365, 3422}], 
      Line3DBox[{3059, 3350, 3531, 3847, 3058, 3949, 3266, 3060, 3950, 3267, 
       3061, 3951, 3268, 3062, 3952, 3269, 3063, 3953, 3270, 3064, 3954, 3271,
        3065, 3955, 3532, 3848, 3066, 3956, 3272, 3067, 3957, 3273, 3068, 
       3958, 3274, 3069, 3959, 3275, 3070, 3960, 3276, 3071, 3633, 4046, 3277,
        3351}], 
      Line3DBox[{3073, 3533, 3849, 3072, 3534, 3850, 3074, 3961, 3278, 3075, 
       3962, 3279, 3076, 3963, 3280, 3077, 3964, 3281, 3078, 3965, 3282, 3079,
        3966, 3535, 3851, 3080, 3536, 3852, 3081, 3967, 3283, 3082, 3968, 
       3284, 3083, 3969, 3285, 3084, 3970, 3286, 3085, 3971, 3287, 3086}], 
      Line3DBox[{3088, 3537, 3853, 3087, 3538, 3854, 3089, 3539, 3855, 3090, 
       3972, 3288, 3091, 3973, 3289, 3092, 3974, 3290, 3093, 3975, 3291, 3094,
        3976, 3540, 3856, 3095, 3541, 3857, 3096, 3542, 3858, 3097, 3977, 
       3292, 3098, 3978, 3293, 3099, 3979, 3294, 3100, 3980, 3295, 3101}], 
      Line3DBox[{3103, 3543, 3859, 3102, 3544, 3860, 3104, 3545, 3861, 3105, 
       3546, 3862, 3106, 3981, 3296, 3107, 3982, 3297, 3108, 3983, 3298, 3109,
        3984, 3547, 3863, 3110, 3548, 3864, 3111, 3549, 3865, 3112, 3550, 
       3866, 3113, 3985, 3299, 3114, 3986, 3300, 3115, 3987, 3301, 3116}], 
      Line3DBox[{3118, 3551, 3867, 3117, 3552, 3868, 3119, 3553, 3869, 3120, 
       3554, 3870, 3121, 3555, 3871, 3122, 3988, 3302, 3123, 3989, 3303, 3124,
        3990, 3556, 3872, 3125, 3557, 3873, 3126, 3558, 3874, 3127, 3559, 
       3875, 3128, 3560, 3876, 3129, 3991, 3304, 3130, 3992, 3305, 3131}], 
      Line3DBox[{3133, 3561, 3877, 3132, 3562, 3878, 3134, 3563, 3879, 3135, 
       3564, 3880, 3136, 3565, 3881, 3137, 3566, 3882, 3138, 3993, 3306, 3139,
        3994, 3567, 3883, 3140, 3568, 3884, 3141, 3569, 3885, 3142, 3570, 
       3886, 3143, 3571, 3887, 3144, 3572, 3888, 3145, 3995, 3307, 3146}], 
      Line3DBox[{817, 2081, 818, 2082, 819, 2083, 820, 2084, 821, 2085, 822, 
       2086, 823, 2087, 824}], 
      Line3DBox[{3148, 3573, 3889, 3147, 3574, 3890, 3149, 3575, 3891, 3150, 
       3576, 3892, 3151, 3577, 3893, 3152, 3578, 3894, 3153, 3579, 3895, 3154,
        3996, 3580, 3896, 3155, 3581, 3897, 3156, 3582, 3898, 3157, 3583, 
       3899, 3158, 3584, 3900, 3159, 3585, 3901, 3160, 3586, 3902, 3161}], 
      Line3DBox[{3163, 2304, 3162, 3997, 3308, 3164, 3998, 3309, 3165, 3999, 
       3310, 3166, 4000, 3311, 3167, 4001, 3312, 3168, 4002, 3313, 3169, 4003,
        2312, 3170, 4004, 3314, 3171, 4005, 3315, 3172, 4006, 3316, 3173, 
       4007, 3317, 3174, 4008, 3318, 3175, 4009, 3319, 3176}], 
      Line3DBox[{831, 2095, 830, 2094, 829, 2093, 828, 2092, 827, 2091, 826, 
       2090, 825, 2089, 2088}], 
      Line3DBox[{3178, 3587, 3903, 3177, 2320, 3179, 4010, 3320, 3180, 4011, 
       3321, 3181, 4012, 3322, 3182, 4013, 3323, 3183, 4014, 3324, 3184, 4015,
        3588, 3904, 3185, 3589, 3905, 3186, 4016, 3325, 3187, 4017, 3326, 
       3188, 4018, 3327, 3189, 4019, 3328, 3190, 4020, 3329, 3191}], 
      Line3DBox[{3193, 3590, 3906, 3192, 3591, 3907, 3194, 2336, 3195, 4021, 
       3330, 3196, 4022, 3331, 3197, 4023, 3332, 3198, 4024, 3333, 3199, 4025,
        3592, 3908, 3200, 3593, 3909, 3201, 3594, 3910, 3202, 4026, 3334, 
       3203, 4027, 3335, 3204, 4028, 3336, 3205, 4029, 3337, 3206}], 
      Line3DBox[{3208, 3595, 3911, 3207, 3596, 3912, 3209, 3597, 3913, 3210, 
       2352, 3211, 4030, 3338, 3212, 4031, 3339, 3213, 4032, 3340, 3214, 4033,
        3598, 3914, 3215, 3599, 3915, 3216, 3600, 3916, 3217, 3601, 3917, 
       3218, 4034, 3341, 3219, 4035, 3342, 3220, 4036, 3343, 3221}], 
      Line3DBox[{3223, 3602, 3918, 3222, 3603, 3919, 3224, 3604, 3920, 3225, 
       3605, 3921, 3226, 2368, 3227, 4037, 3344, 3228, 4038, 3345, 3229, 4039,
        3606, 3922, 3230, 3607, 3923, 3231, 3608, 3924, 3232, 3609, 3925, 
       3233, 3610, 3926, 3234, 4040, 3346, 3235, 4041, 3347, 3236}], 
      Line3DBox[{3238, 3611, 3927, 3237, 3612, 3928, 3239, 3613, 3929, 3240, 
       3614, 3930, 3241, 3615, 3931, 3242, 2384, 3243, 4042, 3348, 3244, 4043,
        3616, 3932, 3245, 3617, 3933, 3246, 3618, 3934, 3247, 3619, 3935, 
       3248, 3620, 3936, 3249, 3621, 3937, 3250, 4044, 3349, 3251}], 
      Line3DBox[{3265, 3354, 4047, 3634, 3264, 3948, 3632, 3263, 3947, 3631, 
       3262, 3946, 3630, 3261, 3945, 3629, 3260, 3944, 3628, 3259, 3943, 3627,
        4045, 3258, 2400, 3257, 3942, 3626, 3256, 3941, 3625, 3255, 3940, 
       3624, 3254, 3939, 3623, 3253, 3938, 3622, 3252, 2411, 3352, 3353}], 
      Line3DBox[{3374, 2491, 2663, 3642, 2490, 3723, 3429, 3402}], 
      Line3DBox[{3382, 3366, 2903, 2879, 3387}], 
      Line3DBox[{3389, 2898, 3416}], Line3DBox[{3390, 2809, 3418}], 
      Line3DBox[{3391, 2811, 3419}], Line3DBox[{3392, 2899, 2666, 3408}], 
      Line3DBox[{3394, 2900, 3407}], 
      Line3DBox[{3401, 3430, 3724, 2500, 3431, 3725, 2501, 3650, 2673, 3357, 
       3404}], Line3DBox[{3406, 2901, 2941, 3827, 3364, 3411}]}, {
      Line3DBox[{1338, 1516, 3638, 1339, 1527, 3646, 1356, 1538, 3653, 1365, 
       3729, 1546, 1376, 3734, 1558, 1388, 3742, 1570, 1400, 3751, 1582, 3668,
        1412, 1593, 3679, 1424, 1605, 3689, 1437, 1617, 3699, 1450, 1629, 
       3707, 1463, 3765, 1641, 1477, 3771, 1954, 1955, 1956, 1957, 3841, 1866,
        1870, 1867, 1502}], 
      Line3DBox[{1347, 1521, 3642, 1348, 3725, 1532, 1360, 3727, 1542, 1371, 
       3731, 1552, 1382, 3737, 1564, 1394, 3746, 1576, 1406, 3756, 1588, 3675,
        1418, 1599, 3684, 1430, 1611, 1443, 3761, 1623, 1456, 3763, 1635, 
       1469, 3767, 1647, 1483, 3774, 1659, 1495, 3782, 1668, 1508}], 
      Line3DBox[CompressedData["
1:eJwV0LsrhXEcx/GvwW2xGCkdC6XcZRfKYjijsrhmcdJJiVImFhuLXf4Bf4As
6iAiOi4LocjdKQ6K1xnefT6/9+f39PQ8iaFUcrIoIsZxURwxXxLRVxqxI3vl
eUVEjzywpblufUuOyqxtRG7bxrhh/Uw+8x16OzZtA1wOR3xWtvGt2LD1O6/q
H/LQfipbnNNoxpo7XdyN7V2eoIlvxLLtmu/k3nCMen4KdViwX9kb+BXn18I7
UKunkMCDfdq9Gv4F+6jmL/kqOWGrLHwT9nDH/8ofDNrK5BN2cWv7lpOey8uk
/Q+PesaWkV/4LPxjPoc8P+f+LJawiE7+HjP6annEOv4BHnVBsg==
       "]], 
      Line3DBox[{1500, 1782, 1781, 1771, 1729, 1846, 3823, 1488, 1652, 1770, 
       3811, 1722, 1475, 1639, 3798, 1721, 1461, 1627, 3795, 1716, 1448, 1615,
        3793, 1709, 1435, 3831, 1603, 1704, 1422, 3838, 1964, 1965, 1963, 
       1962, 1701, 1410, 3830, 1580, 1904, 1698, 3749, 1398, 1568, 1695, 3740,
        1386, 1556, 3791, 1694, 1374, 1974, 1973, 1972, 3846, 1693, 1975, 
       1363, 1536, 3790, 1691, 1354, 1525, 1913, 1336, 3842, 1514, 1911, 
       1958}], Line3DBox[{1501, 1917, 1916, 1869, 1730, 3778, 1910, 1489, 
       1653, 1723, 3770, 1476, 1640, 3797, 1718, 1462, 1628, 3796, 1717, 1449,
        3698, 1616, 1436, 3688, 1604, 1423, 3678, 1592, 1685, 1411, 3667, 
       1581, 1857, 3750, 1399, 1569, 3741, 1387, 1557, 3733, 1375, 1545, 3845,
        1971, 1364, 1537, 1976, 1355, 3645, 1526, 1337, 4048, 1515, 2416}], 
      Line3DBox[{1503, 1663, 3779, 1490, 1654, 3772, 1478, 3713, 1642, 1464, 
       3708, 1630, 1451, 3700, 1618, 1438, 3690, 1606, 1425, 3680, 1594, 1413,
        3669, 1583, 3752, 1401, 1571, 3743, 1389, 1559, 3735, 1377, 3658, 
       1547, 1366, 3654, 1539, 1357, 3647, 1528, 2458}], 
      Line3DBox[{1504, 1664, 3780, 1491, 3718, 1655, 1479, 3714, 1643, 1465, 
       3709, 1631, 1452, 3701, 1619, 1439, 3691, 1607, 1426, 3681, 1595, 1414,
        3670, 1584, 3753, 1402, 1572, 3744, 1390, 3662, 1560, 1378, 3659, 
       1548, 1367, 3655, 1540, 2423, 4051, 2472}], 
      Line3DBox[{1505, 3721, 1665, 1492, 3719, 1656, 1480, 3715, 1644, 1466, 
       3710, 1632, 1453, 3702, 1620, 1440, 3692, 1608, 1427, 3682, 1596, 1415,
        3671, 1585, 3754, 1403, 3665, 1573, 1391, 3663, 1561, 1379, 3660, 
       1549, 1368, 4052, 2473}], 
      Line3DBox[{1507, 1667, 3781, 1494, 1658, 3773, 1482, 1646, 3766, 1468, 
       1634, 3762, 1455, 1622, 3760, 1442, 1610, 3759, 1429, 1598, 1417, 3674,
        1587, 3755, 1405, 1575, 3745, 1393, 1563, 3736, 1381, 1551, 3730, 
       1370, 1541, 3726, 1359, 1531, 3724, 1346, 1520, 3723, 2418}], 
      Line3DBox[{1509, 1669, 3783, 1496, 1660, 3775, 1484, 1648, 3768, 1470, 
       1636, 3764, 1457, 3704, 1624, 1444, 3694, 1612, 1431, 3685, 1600, 1419,
        3676, 1589, 3757, 1407, 1577, 3747, 1395, 1565, 3738, 1383, 1553, 
       3732, 1372, 1543, 3728, 1361, 3650, 1533, 2459}], 
      Line3DBox[{1510, 1670, 3784, 1497, 1661, 3776, 1485, 1649, 3769, 1471, 
       3712, 1637, 1458, 3705, 1625, 1445, 3695, 1613, 1432, 3686, 1601, 1420,
        3677, 1590, 1924, 1923, 3758, 1408, 1578, 1920, 1919, 3748, 1396, 
       1566, 3739, 1384, 1554, 1871, 1672, 4054, 2427, 3656, 2432, 2425, 
       2476}], Line3DBox[{1511, 1671, 3785, 1498, 1968, 1967, 3777, 1486, 
       3717, 1650, 1472, 1935, 3836, 1934, 1459, 3706, 1951, 1950, 1446, 3696,
        1931, 1930, 1433, 3687, 1700, 1699, 1745, 3834, 1926, 1684, 1925, 
       1683, 3807, 1763, 1922, 1680, 1921, 1679, 3825, 1877, 1676, 1675, 3806,
        1760, 1873, 1674, 1872, 3787, 1673, 2477}], 
      Line3DBox[{1512, 1946, 1945, 3844, 1961, 1732, 1969, 3801, 1731, 1970, 
       1908, 1725, 3799, 1724, 1473, 1714, 3837, 1936, 1713, 1942, 1937, 1751,
        1953, 1711, 3840, 1952, 1710, 1769, 1933, 3697, 1706, 1932, 1705, 
       1885, 3835, 1929, 1703, 1767, 1702, 1833, 1765, 3843, 1959, 1697, 1960,
        1696, 1939, 1938, 3805, 1743, 1897, 1898, 1682, 1876, 1681, 3824, 
       1875, 1918, 1678, 1874, 3788, 1677, 1868, 1884, 2435, 2466}], 
      Line3DBox[{1736, 1686, 1947, 1949, 3839, 1948, 1734, 1894, 1966, 1895, 
       1733, 1864, 3832, 1909, 1863, 1727, 1799, 1800, 1726, 3789, 1890, 1889,
        1720, 1887, 1888, 3829, 1719, 1798, 1797, 1715, 1795, 1796, 3821, 
       1712, 1794, 1793, 1708, 1791, 3828, 1886, 1792, 1707, 1790, 1906, 1789,
        1768, 3820, 1836, 1900, 1837, 1748, 1835, 1859, 1834, 1766, 3819, 
       1829, 1899, 1830, 1746, 1828, 1858, 1827, 3808, 1764, 1823, 1824, 1742,
        1822, 3817, 1821, 2483}], Line3DBox[{2470, 1737}], 
      Line3DBox[{1978, 2201, 3949, 1979, 3850, 2215, 2007, 3854, 2230, 2022, 
       3860, 2245, 2037, 3868, 2260, 2052, 3878, 2275, 2067, 3890, 2290, 2082,
        2305, 3997, 2097, 2320, 2112, 3907, 2335, 2127, 3912, 2350, 2142, 
       3919, 2365, 2157, 3928, 2380, 2172, 3938, 2395, 2187}], 
      Line3DBox[{1980, 2202, 3950, 1981, 2216, 3961, 2008, 3855, 2231, 2023, 
       3861, 2246, 2038, 3869, 2261, 2053, 3879, 2276, 2068, 3891, 2291, 2083,
        2306, 3998, 2098, 2321, 4010, 2113, 2336, 2128, 3913, 2351, 2143, 
       3920, 2366, 2158, 3929, 2381, 2173, 3939, 2396, 2188}], 
      Line3DBox[{1982, 2203, 3951, 1983, 2217, 3962, 2009, 2232, 3972, 2024, 
       3862, 2247, 2039, 3870, 2262, 2054, 3880, 2277, 2069, 3892, 2292, 2084,
        2307, 3999, 2099, 2322, 4011, 2114, 2337, 4021, 2129, 2352, 2144, 
       3921, 2367, 2159, 3930, 2382, 2174, 3940, 2397, 2189}], 
      Line3DBox[{1984, 2204, 3952, 1985, 2218, 3963, 2010, 2233, 3973, 2025, 
       2248, 3981, 2040, 3871, 2263, 2055, 3881, 2278, 2070, 3893, 2293, 2085,
        2308, 4000, 2100, 2323, 4012, 2115, 2338, 4022, 2130, 2353, 4030, 
       2145, 2368, 2160, 3931, 2383, 2175, 3941, 2398, 2190}], 
      Line3DBox[{1986, 2205, 3953, 1987, 2219, 3964, 2011, 2234, 3974, 2026, 
       2249, 3982, 2041, 2264, 3988, 2056, 3882, 2279, 2071, 3894, 2294, 2086,
        2309, 4001, 2101, 2324, 4013, 2116, 2339, 4023, 2131, 2354, 4031, 
       2146, 2369, 4037, 2161, 2384, 2176, 3942, 2399, 2191}], 
      Line3DBox[{1988, 2206, 3954, 1989, 2220, 3965, 2012, 2235, 3975, 2027, 
       2250, 3983, 2042, 2265, 3989, 2057, 2280, 3993, 2072, 3895, 2295, 2087,
        2310, 4002, 2102, 2325, 4014, 2117, 2340, 4024, 2132, 2355, 4032, 
       2147, 2370, 4038, 2162, 2385, 4042, 2177, 2400, 2192}], 
      Line3DBox[{1990, 2207, 3955, 1992, 2221, 3966, 2013, 2236, 3976, 2028, 
       2251, 3984, 2043, 2266, 3990, 2058, 2281, 3994, 2073, 2296, 3996, 2088,
        2311, 4003, 2103, 2326, 4015, 2118, 2341, 4025, 2133, 2356, 4033, 
       2148, 2371, 4039, 2163, 2386, 4043, 2178, 2401, 4045, 2193}], 
      Line3DBox[{1994, 2209, 3956, 1995, 3852, 2223, 2015, 3857, 2238, 2030, 
       3864, 2253, 2045, 3873, 2268, 2060, 3884, 2283, 2075, 3897, 2298, 2090,
        2313, 4004, 2105, 3905, 2328, 2120, 3909, 2343, 2135, 3915, 2358, 
       2150, 3923, 2373, 2165, 3933, 2388, 2180, 3944, 2403, 2195}], 
      Line3DBox[{1996, 2210, 3957, 1997, 2224, 3967, 2016, 3858, 2239, 2031, 
       3865, 2254, 2046, 3874, 2269, 2061, 3885, 2284, 2076, 3898, 2299, 2091,
        2314, 4005, 2106, 2329, 4016, 2121, 3910, 2344, 2136, 3916, 2359, 
       2151, 3924, 2374, 2166, 3934, 2389, 2181, 3945, 2404, 2196}], 
      Line3DBox[{1998, 2211, 3958, 1999, 2225, 3968, 2017, 2240, 3977, 2032, 
       3866, 2255, 2047, 3875, 2270, 2062, 3886, 2285, 2077, 3899, 2300, 2092,
        2315, 4006, 2107, 2330, 4017, 2122, 2345, 4026, 2137, 3917, 2360, 
       2152, 3925, 2375, 2167, 3935, 2390, 2182, 3946, 2405, 2197}], 
      Line3DBox[{2000, 2212, 3959, 2001, 2226, 3969, 2018, 2241, 3978, 2033, 
       2256, 3985, 2048, 3876, 2271, 2063, 3887, 2286, 2078, 3900, 2301, 2093,
        2316, 4007, 2108, 2331, 4018, 2123, 2346, 4027, 2138, 2361, 4034, 
       2153, 3926, 2376, 2168, 3936, 2391, 2183, 3947, 2406, 2198}], 
      Line3DBox[{2002, 2213, 3960, 2003, 2227, 3970, 2019, 2242, 3979, 2034, 
       2257, 3986, 2049, 2272, 3991, 2064, 3888, 2287, 2079, 3901, 2302, 2094,
        2317, 4008, 2109, 2332, 4019, 2124, 2347, 4028, 2139, 2362, 4035, 
       2154, 2377, 4040, 2169, 3937, 2392, 2184, 3948, 2407, 2199}], 
      Line3DBox[{2004, 2409, 2410, 4046, 2005, 2228, 3971, 2020, 2243, 3980, 
       2035, 2258, 3987, 2050, 2273, 3992, 2065, 2288, 3995, 2080, 3902, 2303,
        2095, 2318, 4009, 2110, 2333, 4020, 2125, 2348, 4029, 2140, 2363, 
       4036, 2155, 2378, 4041, 2170, 2393, 4044, 2185, 4047, 2412, 2413, 
       2414}], Line3DBox[{2186, 2394, 2411, 2171, 2379, 3927, 2156, 2364, 
       3918, 2141, 2349, 3911, 2126, 2334, 3906, 2111, 2319, 3903, 2096, 2304,
        2081, 2289, 3889, 2066, 2274, 3877, 2051, 2259, 3867, 2036, 2244, 
       3859, 2021, 2229, 3853, 2006, 2214, 3849, 1977, 2200, 3847, 2408, 
       2415}], Line3DBox[{2194, 2402, 3943, 2179, 2387, 3932, 2164, 2372, 
       3922, 2149, 2357, 3914, 2134, 2342, 3908, 2119, 2327, 3904, 2104, 2312,
        2089, 2297, 3896, 2074, 2282, 3883, 2059, 2267, 3872, 2044, 2252, 
       3863, 2029, 2237, 3856, 2014, 2222, 3851, 1993, 2208, 3848, 1991}], 
      Line3DBox[{2460, 2434, 1883, 2480}], 
      Line3DBox[{2464, 3827, 2433, 1882, 2465}], 
      Line3DBox[{2474, 4053, 1369, 1550, 3661, 1380, 1562, 3664, 1392, 1574, 
       3666, 1404, 1586, 3672, 3673, 1416, 1597, 3683, 1428, 1609, 3693, 1441,
        1621, 3703, 1454, 1633, 3711, 1467, 1645, 3716, 1481, 1657, 3720, 
       1493, 1666, 3722, 1506}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsnXk0l9+79z+GMiUNhogUGZoMTUi60qCZIqQREUIKJWSIisqYMkQSCZWK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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{437.00764628393415`, 193.04609770875604`},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{2.586847289449654, 2.181192945376716, 0.024868375614878865`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.6239965083910847`*^9, 3.623998683821512*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Function", " ", "seems", " ", "to", " ", "follow", " ", "a", " ", "gamma",
     " ", "function"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}], "^", "5"}], " ", "*", " ", "0.5"}], 
     " ", "+", " ", "0.5"}], " ", ",", "  ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.624016556598215*^9, 3.624016628632368*^9}, {
  3.6240166696407137`*^9, 3.6240167200325956`*^9}, {3.6240170458962507`*^9, 
  3.6240170602480717`*^9}, {3.6240174719617777`*^9, 3.624017478976179*^9}, {
  3.6240177024089584`*^9, 3.624017706424188*^9}, {3.6240178834563437`*^9, 
  3.624017900453333*^9}, {3.6240268381232924`*^9, 3.624026857240386*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd2Hk0F18UAHD7nl0iS8iaNpTdrUi2QiUpUaL8REq0KEsilUgl/GyllJIt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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{{3.6240166988583846`*^9, 3.6240167205306244`*^9}, {
   3.6240170515875764`*^9, 3.62401706091611*^9}, 3.6240174796682186`*^9, {
   3.6240177031480007`*^9, 3.624017706764208*^9}, {3.624017886836537*^9, 
   3.6240179007343683`*^9}, 3.6240271847471185`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Fit", " ", "the", " ", "one", " ", "extremun", " ", "curve", " ", "from",
      " ", "the", " ", "previous", " ", "function", " ", "for", " ", 
     "Cos\[Theta]V"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"1.", " ", "For", " ", "Cos\[Theta]V"}], " ", "=", " ", 
     RowBox[{
     "0", " ", "the", " ", "function", " ", "is", " ", "1.", " ", "We", " ", 
      "will", " ", "fit", " ", "a", " ", "function", " ", "based", " ", "on", 
      " ", "Cos\[Theta]V", " ", "variation", " ", "to", " ", "get", " ", 
      "the", " ", "interpolation", " ", "factor", " ", "curve", " ", 
      "between", " ", "1", " ", "and", " ", "the", " ", 
      RowBox[{"extremun", ".", " ", "We"}], " ", "perform", " ", "two", " ", 
      RowBox[{"fitting", ".", " ", "One"}], " ", "simple", " ", "and", " ", 
      "one", " ", "complex", " ", "more", " ", "accurate"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FitFrGGXSimple1Correlated", "[", "Roughness_", "]"}], "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "Roughness"}], ")"}], "^", "a"}], " ", "/.", " ", 
     RowBox[{"FindFit", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", " ", 
           RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
            RowBox[{"0.9", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0.001", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "xx"}], ")"}], "^", "a"}], " ", ",", 
       RowBox[{"{", "a", "}"}], ",", "xx"}], "]"}]}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.623997198860577*^9, 3.6239972084081235`*^9}, {
  3.6240169403212123`*^9, 3.6240169406892333`*^9}, {3.6240268712971897`*^9, 
  3.624026875600436*^9}, {3.6240269493046513`*^9, 3.6240270407528825`*^9}}],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   RowBox[{"1", "-", "Roughness"}], ")"}], "0.28651339292087713`"]], "Output",
 CellChangeTimes->{3.6239972115923057`*^9, 3.6240271884683313`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FitFrGGXComplex1Correlated", "[", "Roughness_", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"b", "*", "Roughness"}], "+", "c"}], "]"}]}], " ", "/.", " ", 
    RowBox[{"FindFit", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", " ", 
          RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
           RowBox[{"0.91", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0.001", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
      ",", 
      RowBox[{"a", "*", 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"b", "*", "xx"}], "+", "c"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", " ", "b", ",", " ", "c"}], "}"}], ",", "xx"}], 
     "]"}]}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.623997221029845*^9, 3.6239972315754485`*^9}}],

Cell[BoxData[
 RowBox[{"0.2939124054864653`", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"41.5345387009932`", "\[VeryThinSpace]", "-", 
    RowBox[{"41.10875641306948`", " ", "Roughness"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.6239972348766375`*^9, 3.6240271913234944`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Check", " ", "the", " ", "accuracy", " ", "of", " ", "the", " ", 
   "fitting"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6129766110396967`*^9, 3.6129766134708357`*^9}, {
  3.612976779590337*^9, 3.612976785446672*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FitFrGGXSimple1Correlated", "[", "x", "]"}], ",", " ", 
      RowBox[{"FitFrGGXComplex1Correlated", "[", "x", "]"}], ",", " ", 
      RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
       RowBox[{"0.999", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.623997262392211*^9, 3.623997276479017*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnk41PsXx6VIqSaFn6tIihKim1IM70gbLWSkxSVGWSJG0nIlZYnqCj9r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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwtlHs01AkAhYdqmpYoVGrZ7bHZ9dq21LIae5O0FZVXptISMUWJKL2EiUWM
nt6rUikrKikSQowhqQwzGs0w3s/fo9SyyU5r9+w955577jnf398irwAnH1UG
g+E+2X/XsPaHWyv6RGD8l7fQUrowz7Ob8NHuTmIZRWOh4dn4gLRmhJun5jOy
aSS6cAiSFiPWNtw80J3GqykHznCWtSDPokKvTJdGXl7amtozr8F0rnhdW0/B
oVVr5eIXUnzDuM7LDaeQ8jnLOtL4DdT4bDremIKNQa1RZKQMrKJ95koJiaLG
lQ4HBXJwtvXc4ESSaDhces5jYTvMYk2e7DUgkZORoMb2UUDrhTFsGwgc6Tp6
X+bYgV0xMm1eIIG9wav8MpQdqPPkuolZBKyEuk+brnZC/5n9/s4bw+hJYi3l
b+lC+01X1WPLh1HuUzmqM96FXvnnA6mlQwgdu8zVTu9G0r1Zncs3DEGNGdud
+EsPrL7/EyGCQZxqSVHGD/Yg4MyoU+baQSzODohxiu1FvY3qJ6OyAaR+cNbP
WNkH9VXj6exFAxiZ4u7oJulDlQ31dn5MP/TPH754ObIfd8sbn6qL+2DSnn9o
m8EAknlOVwa+7oO/SWG5vGYA04KFTCPPXkSM1ej2Bw1idCGvPD28ByFRE7P2
6gzh55tHVi9O7YbVWcz1qx7CWGTh4GZeF8xTN51hBwyjsNLq2gz7TszxPpke
pUnAWhp4/w/VDljs+CBcrUXAR5L7lPNRgZ1b/N+P6BBw/nHkpCupQKaFh73n
AgJl/CoZW6KA0UwbpdXSSd783fK8LAXWFH3hNWZJYIH+vHXqaxU4wEo39OMS
GLmlPjs6pB2CvOLirU8I7ChRbC+oloOyuF0qrSBwBeHd3CI5dGt+L/esImBX
95eKVo4c/m1hguBaAqsL6gV2Z+WYq2HbmCIi0D/yrNtuuxy+AaJ+RS8BbY0i
s6AhGTRWDM0N1CChr+R3kUwZOI++PHLeg4SKr1As12vF6T2CQnUvEptNM1xZ
M1txV9N/NNZ78sfVnTD4W4qp+8qP8nxJzEly3WrZJkW+rueJoGASwmuSzCcZ
UrBO3Ap3iSGhx+W06s+XooS9PE73HolTlhfTzjJfo3egtT7xPoktK6zz2z60
YFbSabXZD0n0ejRq63W3gEs282c8JuE+79pabkULtK6EnBuvIpG9ObTA5GgL
9n8uTZS3kCh1m7nau1sCvar1VzOVJLQN1MxP3hHDMnMJ4aRCITygaeJxihg7
whg/TZtKofjq7lAFT4xky5Im3xkUQuayytq2iaH5wJRppkPheGl1UuZEM1Sz
dPxrDCl0HClJnG7bjIHfuiyHXCg0JrsN+VSIwPSuiMngUIhwE4WP3RRh6doM
8ZadFNoCz0Vx+SJ4KbcdfOBBYfPt6N2y7SLIQp5dC/Wj0ORcnzvnbSNe7s1n
aUZQ6EvN9jo0rxEPNoa1mOVSUB9zUNFIaIC0vPnjozsULJ8KdT84N0BpZqjP
zqewcfp1RuSCBmz6SrxnXSGF6CVOM1NuPUfXiOE7lwoKdT7C5OMl9dDKkKiF
NFNIDIvLWtxYB4vZxsvGJRQih4fvq1+og3t0hFOYlEK20QwbvmMdbgcap0W3
URh2KLFeL6qFtS3PIKWfQjt5fEPocyECKRPr4k8U5l/YFxWXI0DyntPebCWF
WRO8htl7BCiTvo6pZNCw1HWdr6MnAKv69Mu6aTRySrivePxqXE2RurVq0jBK
yOPVcqvwck1UyPgSGsGK1jiGsgKml2S5bHsaNYXnBNquhUjexXistpXGpW9v
LIiOfQiGwVLhG0cao8zOpsriBxAXH+w4xqGRkNMU+qtWAULbVeYUek16NUUS
Eep4B/WG34WZHqcxna9pbeN8GSvf28dPnKQR5GOfWhmchitlh1Kfh03yWY9a
HWKSELS1tMA3iobpI3bzBfV4+KkO20Un0P/7nMH4B+zp+F4=
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxFyX1Q0gccx3HSLNLUBsbhUzOaOTfEWro4Dvtp3sy5ZqY0vfVMM5vTSFOW
yzonWrDKnOgRhMOzhnbabEuFnoxE01uaZYk4mE9pior2YHWpw9U/3+8fn3vf
6z4r+YLYRDsSiZT0bu/ruY+m2cePIQp09Ivd+gmCqjpu+8PnBHiA7awXe5SA
TbFeQrXgd3COn0sqX14Drpwnyhxba8EenTvSswOv43+1Ivg85za4P6RqjSWh
EawpLz/WuLgZ7O26Njxd3AJuPficyyL+Bi8wRNboWtrADht0xsLwDrC6Leh8
/cwDMMXGW1TI7QT7+BecEsgfgYt58RPWqcfgDvsUSXygAVxdLQ9tkXSDY3oo
QYx2I1g2fzFM9Ok/4PDVLZ+IRCZw/YOgmINNZnBbxo2zu316wZeUZ5y4iX3g
zMEf/zRt7QcnHQ5OVtrQIXfpdzpVA+ChErLv6ehBcEOi7rXbDDr7Tel+quIJ
2GmR+EnxpiHwMYPMdsqCZlQITsaKh8HnpuO8lUFPwV/MJWhm89Av7Hdt3d6F
rksRZBL96CNdOfJV4+jKwPxys/UpcW0HNTJYOUz0SCRVJc/QjkNnaqNfojkb
im4tfo1WvlB0ZM2i/1NfGBgnjYBzj9z1r6WhyVGWtGwmmmJl2TknoL0LM4pK
ReiPNJTct4/RzN4radtWj4JTmXUN5mZ0zptm+ki6BTwbMuBWoUcL8+aWJbmN
gUcjvu70C0V/u+Q36egPaGlyxHTrz+i2e5O8SzL0y277vYkKtMcQPXVl6Rgh
fuVp9LWYibBnAVn/qtAH5jbmy8vR9W6ppR9UohcGyOokl9FlO8eHs7TokAKC
lqxHc6jNW+Lcx8Hrz0VJuAL08u+OKvJcJ8ApZIV/8n50U7VWu+UW+nvBw5G+
YbTLZ2O0Qy5WMLvB5P52mZUgb2KENq5rJ/hR7V65VPRpQ8OHTjS0hn+FUUxH
Lz0q/Vjtjd4jFbK0DPSSJi7HzET/NW0XQVqPXvjN2Z2RX6HjNZ6ZhbvR17lr
f6HXoL0aI1RlNvRo/iBnjDcJvvrlccO6KjRF2eUkfIQ+NMkM086ibxq7T+pI
U2CyPvd+qwOaxTY+30xG8y4HLH/oiP6JIWJvc0arZMbtPa5TxApr0QKPinTi
8xSWxeKOvh+aJ5xZhbZZAn/1ZKMDpKYq7mb0AV1GzAo1+oLV+dX8PPp/bzU6
FA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0.001, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.623997281359296*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Now", " ", "perform", " ", "the", " ", "fitting", " ", "of", " ", "a", 
    " ", "curve", " ", "varying", " ", "with", " ", 
    RowBox[{"Cos\[Theta]V", ".", " ", "We"}], " ", "chose", " ", "to", " ", 
    "fit", " ", "at", " ", "Roughness", " ", "of", " ", "0.9", " ", "to", " ",
     "get", " ", "the", " ", "shape", " ", "of", " ", "the", " ", 
    RowBox[{"curve", ".", " ", "For"}], " ", "lower", " ", "roughness", " ", 
    "it", " ", "should", " ", "fit", " ", "anyways", " ", "as", " ", "the", 
    " ", "variation", " ", "is", " ", "small"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.624027200001991*^9, 3.6240272002250032`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "^", "a"}], " ", "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", "0.377369"}], ")"}]}], "+", "0.377369"}], "/.", " ", 
  RowBox[{"FindFit", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", " ", 
        RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
         RowBox[{"x", ",", " ", "0.9", ",", " ", "1"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0.001", ",", "0.999", ",", "0.01"}], "}"}]}], "]"}],
     ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "xx"}], ")"}], "^", "a"}], " ", "*", 
      RowBox[{"(", 
       RowBox[{"1", "-", "0.377369"}], ")"}]}], "+", "0.377369"}], ",", 
    RowBox[{"{", "a", "}"}], ",", "xx"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6240269265673513`*^9, 3.624026945272421*^9}, {
   3.6240270531525917`*^9, 3.6240270535036116`*^9}, 3.6240271641069374`*^9}],

Cell[BoxData[
 RowBox[{"0.377369`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.6226309999999999`", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], 
    "10.864878331300458`"]}]}]], "Output",
 CellChangeTimes->{{3.6240271690592213`*^9, 3.6240271941906586`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Resue", " ", "previous", " ", "result", " ", "to", " ", "interpolate", 
    " ", "between", " ", "1", " ", "and", " ", "FitFrGGXSimple1"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FitFrGGXSimpleCorrelated", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"FitFrGGXSimple1", "[", "Roughness", "]"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"FitFrGGXSimple1", "[", "Roughness", "]"}]}], ")"}], "*", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], 
      "10.864878331300458"]}]}]}]}]], "Input",
 CellChangeTimes->{{3.6042947825925436`*^9, 3.604294799474571*^9}, {
   3.6042948490496554`*^9, 3.60429488118571*^9}, {3.6042950135049267`*^9, 
   3.6042950153049293`*^9}, {3.6043277099622574`*^9, 
   3.6043277174976883`*^9}, {3.6043278338183413`*^9, 3.6043278497382517`*^9}, 
   3.6043278989300656`*^9, 3.6043281880826044`*^9, {3.6043282630898943`*^9, 
   3.6043282659700594`*^9}, {3.61297689730307*^9, 3.6129769553763914`*^9}, {
   3.6240172464809675`*^9, 3.624017267144149*^9}, {3.624018029416955*^9, 
   3.6240180900004206`*^9}, {3.6240270569288073`*^9, 
   3.6240271091047916`*^9}, {3.624027198448902*^9, 3.6240272194821053`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "10.864878331300458`"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "Roughness"}], ")"}], "0.2891837804614315`"]}], 
    ")"}]}], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "-", "Roughness"}], ")"}], 
   "0.2891837804614315`"]}]], "Output",
 CellChangeTimes->{3.6129769561314344`*^9, 3.6239959911695013`*^9, 
  3.624017280468911*^9, 3.6240180918525267`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Here", " ", "is", " ", "an", " ", "even", " ", "simpler", " ", "form"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FitFrGGXSuperSimpleCorrelated", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "Roughness"}], ")"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "Roughness"}], ")"}]}], ")"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "^", " ", 
      "11"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.624021337776533*^9, 3.6240213535214334`*^9}, {
  3.624021414184903*^9, 3.6240214155929832`*^9}, {3.624022134661257*^9, 
  3.6240221714251213`*^9}, {3.624027228104598*^9, 3.6240272427764373`*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", "Roughness", "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "11"], " ", 
   "Roughness"}]}]], "Output",
 CellChangeTimes->{{3.6240213543954835`*^9, 3.624021381101011*^9}, 
   3.6240214162440205`*^9, {3.624022138024164*^9, 3.62402217244718*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FitFrGGXComplexCorrelated", "[", 
     RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"FitFrGGXComplex1", "[", "Roughness", "]"}], " ", "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"FitFrGGXComplex1", "[", "Roughness", "]"}]}], ")"}], "*", 
      " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], 
       "10.864878331300458"]}]}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.604344974286403*^9, 3.604344993339493*^9}, {
  3.6043450256993437`*^9, 3.6043450647315764`*^9}, {3.612976934808215*^9, 
  3.61297696706406*^9}, {3.6240190651523633`*^9, 3.6240190811532784`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "10.864878331300458`"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"0.29847502436794354`", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"39.41149727672321`", "\[VeryThinSpace]", "-", 
        RowBox[{"39.00289316713873`", " ", "Roughness"}]}], "]"}]}]}], 
    ")"}]}], "+", 
  RowBox[{"0.29847502436794354`", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"39.41149727672321`", "\[VeryThinSpace]", "-", 
     RowBox[{"39.00289316713873`", " ", "Roughness"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.6043449812968044`*^9, 3.604344995127595*^9}, 
   3.604345035512905*^9, 3.6043450683547835`*^9, {3.6129769454808254`*^9, 
   3.6129769699472246`*^9}, 3.623995991237505*^9, 3.624019082805373*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Compare", " ", "simple"}], ",", " ", "supersimple", ",", " ", 
    RowBox[{
     RowBox[{"complex", " ", "form", " ", "and", " ", "1"}], " ", "-", " ", 
     "roughness"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"FitFrGGXSimpleCorrelated", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], ",", 
      RowBox[{"FitFrGGXSuperSimpleCorrelated", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "Roughness"}], ")"}], " ", "*", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", "Roughness"}], "]"}], ")"}], " ", "+", 
         " ", "Roughness"}], ")"}]}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.624018816492819*^9, 3.624018820841856*^9}, {
  3.62402136395503*^9, 3.6240214075135217`*^9}, {3.6240239570096493`*^9, 
  3.624024004787382*^9}, {3.6240240600575433`*^9, 3.624024061097603*^9}, {
  3.624027249585827*^9, 3.6240272864799376`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyEnXdcT/37x7MS2XtVdiKZyapjJGnIjoyQCtmRPSKEolIZEYWQESkKkTQ0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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mgX4VUXXxe/BMxc4R+5cGiQUVEpBShAEQQQRVBS7g7BBURSVUiRUVFIk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         "]], Polygon3DBox[CompressedData["
1:eJwtmgXYVUUXhc+FM1eZkXs/BEGkFUS6FLsbTCwURVoUFROlFEQlDBADUZGW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         "]], Polygon3DBox[CompressedData["
1:eJwt1geUVdUZxfFHeZR5MDP03jtSpSOICIIiRUFAulIFBKQrvYPSO5EOaqQr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         "]], 
        Polygon3DBox[{{2813, 1339, 1441, 3748, 2647, 2648}, {2908, 1470, 1227,
          1228, 1471, 2909}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mgW4VsUahc/ZyD8/nPnPmSOIKNfA7sS6drfX7m5FxS7s7u4WEBQVUekS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         "]], Polygon3DBox[CompressedData["
1:eJwtmnWgVMUfxfftgzuLe3ff0rZiYGAStmJ3YosJioGKXehPBezGArsDREVp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         "]], Polygon3DBox[CompressedData["
1:eJwt13m8TmUeAPD32t5r7rUUkdGm0E4p0oLsIoMsqcaSNVPSIjGllBKjwihp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         "]]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt2XfgV/Mex/Efv+gc7uf383Evwr0IRVZW0d577532XkpSKhVK0dRQCqU0
aEhDu6RoI0Ule+89L+7zdV/nj2/n8ft0ft/f93vO5/Men1O4U//G/U7NyckZ
wz+5HF8NOTk7wKY0J6cuLovPy8vJOcLPe/HPSU7O63gP/gnX4Zwy+FzOqYVL
4X/hergcLoQr4etxHq6NS+NzcENcEZ+P3+I9X8N/8p4f4mP4NI4/83oL/865
J/Cr+L+JP9+z+C28Hj+D38QH8E78Nd6G1+J3cWV+/wacz9/ayvga/A7jm/Fq
fBKfxIfxX/ggfhF/g/fjF/BXeAt+Dr+N96W+Vl/iKrz/jfgs3r8avhmfja+N
OTmdOK9ofk7ONbgjLoLLcc41nHMm51zNeAfGL2f8KnwbvgwXw+3xpbg47o6v
xFfgVvgSfCVujQvj8rzntbznP3jPCvg6HHAbXAdfglvj2vhi3ARXwf/GjXFl
fCFuhCvhC3AH3BBfiqvim3DETXFV/B/cCTfGl+O2uC4ujFvhWvgi3Bk3wUVw
R9wIX4Z389k34U+4hi/iDfgjvAtvxB/jJ/BMvAPPww/jrfgxPB1vw4/jGXg7
no9n4RfwU/hR/BJul/pzjsQL8Wy8Cy/Cc/BuPBdPw1vwYjwXv4xX4kX4FbwK
P4VfxQ/i0fgZfC8eihfih/AYvBzPxpPwRtw29XcfgR/FU/FmvBw/iQ/iJXge
3oNX4IX4EH4GL8AH8NN4Pt6PO+NW+D7cJvX9Go674jZ4LL4j33NSc7MD1/0z
XJDjl5zzvuYJx4q8quMBnP8Ffk9ziWNlXjXxQMZvwLfgjngdfhq/gUvjCrgX
vhHfijvhSrgGvh1fz1ztwc/F+Cxt+dtXMF6Kz7OGsaX4COc0Sz1X78TNU8+l
IbhJ6rl0B26aeg4PxmvxMnwUd8Gt8f34bjwAz8W9cQf8EO6DO+KJuia4F56B
B+GeeDqeiO/FK3AJPnN/fr6Oz1wSD8DF8RPR9/Iqvsf86Ll1NV6OJ+Gb8ePR
96MYnoarpF4LD+OqqdfgZFwu9bqbgsunXo9TcYXU62sFnoxL4JV4Ci6JV+Gp
uh/4mejPfRNeFP2dr8NPRX/n4nhx9Pe8Hj8Zfb2uxZNw2dTrfUH0fLoGPx09
j2/Ez+EZuBRejafrHuMyeIi+L9dkafR1v4HxTcFzoxqeyHiZ1HF+Bq6eOj4c
iI6njfDB6LjcGL8SHQua4NejY3oLfDQ697TEx6PzRBu8PzqON8RvRueS1viN
6LzVCr8aHVOa4n3ROaMBPhwd35vj16LjUTM8N3qeXYHnRc/LK/Gj0XOxKJ6D
66eOadNxtdQxdhaukzpmPoLrpo516/AjuCxei2fhMngNnolL49m4XupYWhrf
qXvKtb0VD9S1xaOC57bub2HGG+jeMX4pbqi5hC/BtXXN8cW4Fi6E/x29Js/B
/4le2+dqPgfHIsWzxcHxU/OqZ3Bs0fe9MDpG/IvzL4he8//EZTjnKs5J9Zlx
MZzgmzinr+YS59yAe2q9KA7hfpp7+EbcS2sHLwiOvZpvRRlvqTXCeFnGr2b8
DMYvY7yR1gjjhaJjTcTnRcems/DluLHWDn4yOF9oXSwMzhdam4uC84XW1LDg
OKC1MDQ4Dmj+9wqOJ5oDA3GnXK/xFfgxXA7fHhxPFAcGBMcZrffR+PZcr7vx
wXlB624KHpXrNdI7OD5rXt3CZ75da5PPvDw4/mueLA3OU1pra4NzUCW8BD+C
H1YuCs6PiglrgvNFRcWE4PylObYuOGdV1loOzjUVtMaD86Pm3rPBOUV5aXVw
rinP+Ibg+Fwlz7HtPrwy8Zx9EK9PPJcfws/jHzn/CO7Kd3mb8Q9wHsdj0TVW
Z8Z/4JzXGe+Cf8JHcbd813mq93rixpz/rPIB/pnxNxjvjn/Bb+Ie+A98UnkH
/4nfwX3wqXzWD5XLcC7+SDkIn4Y/wYPwt8H1pOrKr/Eh5TXG/w7OfcqBLfkM
2xWjGP+L8XcZ74u/Yux71T8cC/CeHys/Mv5fznkb98an5Pm798cnonNtP/wO
52xnvCWuz/gC5UjcK/p66fos47iKc45zPe/HE/BaPDa75uvwUrwSH8vqAdXD
J7K6QvdxHx6Z3S/lsifxEnwYz8FP4L14XHbvdB8fwBOz+zgaj8PP4jH4Abw6
cTxTfdg3cZxTDd8Hd+DzH1K8zXcMUz3Zj/HB0ddL310xqQHjwxifgCdnddE9
+P5sXo3CY/EqPD517bQhq7UUozbhd7M+RTX423gbbsH7n8PfuoyxPNXJihOM
1+H84orBuI3qEMVX3A4XVbzEtXARxVFcA5+eeh6q/7gpdUyryfjliqnKa1lN
9ZPO42+eXoB7z/gfisuK/Rxbcc61ynX6bPga5QfcDJ/L71zNz/m8RxHcQrUB
vgjXxOfh83EpfHa+awf1Vl343eqM38fPFRgvhQcrR6sXUMzjnHqcU0zvhxvg
qxRHcSN8Hed3U17Ld75S79YtcT2ivqxr4vysvq87PhLdC+mefsJ1flnXDX+E
d+t6ai3gg7gD/hi/hNviL/ABfBv+EO/CrfFbeCtujr/Br6hWzPfcUUz4m7/7
JeP7cXvGR6Sux1RL/4L/xr+mrinUV7Zk/ObUOah24rpJtW4HXCN1H9oDl0zd
c9VPXH/+lut5UiJ1fqnL+C2pe6iGiWsi9YytE9do6u/aJq7R1Ae1x7em7rOa
4OGpa371AurJbsMTEvdq7fF4vCP1dfsOv5D6Wn2Pn8PP4w/wztTX+Qf8cupr
+yt+KfX1/CXrfzX/v8DPp76en+K9qa/n7/hj/CU+l+PvHE8rkH3nAp6vRfGp
mTVvczkW5PUnPotjwuvXXP9/Xja/f+O9fsmu/8bUcexz/tYZ2fvo/f6R/W4B
XvnZe37OeaGAP0MhfGY2rr/5e7amfuC4IfVa/oz33JM6Jv+W9dqK1X8krrnU
t/ZPXNfUx0Px4dR5ITd1XTwui1dHs7WsNT0liy2KadOymPZc4rpsYhZnZmTx
VjFWde74LPZOzmKU4lLB7Lv9xc+vpc5Np+ozps5lp3A8njpfnJE6xyinnKl8
yOtT/E+O76TOU/m6b6nzZo6+R+o8kuj3UueXqL+TOt8V5Hgsdb5L9XdS57iz
OL6fOsedzXFvdJ9WP8/3RPc1J7sPuh+n8LqL/x/B+Uv4XkPxSLwUD8P34GWJ
a5MheH7ifmgwfjzxnkQfPCtxHdcfz0nc5/XFjySu+/rh2Yn7pzvxE4n7huF4
ceI69278VOI69y68IPH+Rxc8KfG+SFc8OfF+STc8JXGd2A4/kLiuvAM/lnjf
pQeelrgubo5HJd6D6Y6nJq4lW+DRiWvGlnhM4pq6Gb4ncQ07CM/Dq/F6/H7i
PHMlroq/xj/gizh+w+tHfDHHb3n9hC9RPOAenFDcyHNt8R2+MPV90T35O1tr
Z2RrU3PszGztJNm6+jVbx2m2jgpmc1BrtkC27vQ+n+lzcDxfc4HXV/i81L+n
31c8+JGfiyg+Jx47JYsP32dr/FKOn+s74As0v3h9gc/R9eY7lNAc5vgpP3+N
C+k78foZF+Z4ep7n+eB859E/s+++PnpPRPXzyeiYrnO2EfMf55xa+CTegpvh
D4L35dQDvhEcJ5sy3j54z0E9ztboPR3VqDOj475yaDvOKZ/r3uf94D1G9Xrd
gvcl1Ed8jo/nuk88gfflugd8L6sPFXs+C96TVO/ZPXg/RP3FEbwON8ajo3Ot
cnqz4H0S9Vm7gvch6/C7LYL3RtRz1cfFc91D6V4oBqueUF2g8abaA+Gckrnu
uVQX1MN3KXcE71vW5D1fDN7PrI13Bu9P1sI7gmtC1YY5eZ5vmnddgvd51Cd2
xdVy3T9+H7wXpN65W3SsUe7uHh2PlN+7RsdT5eW+0bFJdXuf6Bikmr9fdAxS
rd4jOk6pru4dHe9U8x8L3kNWj98zOlaqBtgbvO9Xj/Eu0TFd9cad0WtMtfTA
6DmnGvuO6DmqmnxQ9LxX/d8n+Fqpf+wbnCO0XzozOI6Vw49F7zGp7vouq/kV
p48H73Vrr0B1WVs8jmu+OXifubr6vuh1pb6jf3RMVz8yIDrvqn/ZGLw3VZXz
lwXvMWr/pHpw3FDfWiN4H0x960PR9YTqPdV9mrc9+btbovc01SOMCY6H6p3v
C46H2psaFxzrtD9wf3Bs1D7V2OBYp75SfcZi5avENeMwvAg/HBwzS3POvbhz
rnv2B4Nju/Z2RgbXM+rTl0TvnanmXJ/1oTXz3SepxvtWtUpwr1GP8Veyefj/
PfvovKu+9VBwj9OQcw7iFbg+PhDc1zTAu4M/c918/47+1k7ef3vWq2pur8z2
LtT3qF/UenxPnyF6r1b94xbOWc54Da7/1uDepzbj04NzWRm8J3j/uW6eY53i
leLW1OD4X4pzFkbvq6p+HhKcL7S3r5q6N56pHBTc42hPfnhwbtKe57zg3FpV
8zk47+hZwKDgXKM9/6PB+aWJ5jZumuv9/0PRzzPUhw4OzmV6XjArOFeW13wO
ztfV8PzgfWn1THOD83sVxicG5+KSeFJwvr5Fcy84X5fA0/BAfCv+LXivWPts
E4K/o/ajRgTXtNrPuTt4jejZxKPBOb0ynhOc0yvlu19RHbWG67Mseq9c/cvs
4HlYEc8Irg3K4n3BzwVUt6zCU7TuGG8bXQcrL3SOrr3UazSPrh01Z5pG19Oa
e02ic7bmT6Povlr3vVl03az51iK6ltU8bBjdVysHTYjuGfT868Ho3kDPs8ZH
9wx65lUjuj/X538heu9ec2xX9N69YnKr6LpfOeLF6L1+xed7ons2Pa/ZGb2/
r3heNbr3VowaGd3H6jnRkOjaQnsaHaPrRfVTt0XX/dpPqBPdM2uO1Y3usTUf
akf39poD5aNrO933ctE1n+ZDrei9AN27KtF9uO5F2egaUXOjQnSfo7lRMbo3
07p4LfgZmfZg20T3MMrRraP7HM3ndtH9jPq+9tH1vXr2BtF7E4ohnaJraPWV
9aL3KXTfK0fvEWidVore11C8GhHdw2tvsFr0PoXWwsvRzxW0lrdFP+NRHB4W
Xd9o/+f56Oc92uPaHv2sSPvV46J7fj3HrBm956I5vDn6WZT20IZG1zra8xkb
vaeg5313Rdd82msaFd2H6xncA9E9qp57Hg5+Rql97z3RzzCU7zZFP8fS/t7d
0XsN2kfdGP2sS3t6+/ndzbneu74veq9Bzxw3RD8b057ejuhnV8pTw6P3NbQ3
OyZ6D0LPYV8Pfr6p/fZ7o/cp9Gz0/ui9Ej3j2x393Et1y/8A4w7cfw==
         "]], Polygon3DBox[CompressedData["
1:eJwtmnX8VVUWxX/6mPHt0XuPzxo7MRBRQQGRkFCU7kZKuhERG8RCxQIRMQBB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         "]], Polygon3DBox[CompressedData["
1:eJwt13W4VVUWAPCrDg7XmQc+HUU6xQBUUEFaurtTuhseSApISxgIgoCFlIBI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         "]]}]}, {}, {}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0rtOFGEYgOEPBUWOBhQWhCUSYowRY2NooDM0WmmgwI6GSMIxArtqRCuM
HKThdAHIDWBFh17ACgrKSS0IN2Hh84fim+f982dmdmb2Zv/Ik+GiiFgyCyL1
G4dT/rsScZVlZREtbOA93mYXO/iY3XzGHvaaQT3GPKdda1q/12/1nF7Ra/zE
DX7mVnnEO/tf9YCu1eNm13qINeagOOK79Qt9qH/oa/pI7+lCScR16339Tdfp
n7rxUsSE/qVv6Ml0Ld2kp/Sx8w+tc/pEH+m8/q2P9Uv9R5/oZue8Sns6q1+n
Pb3jfhm9aP5af2C9KXi+Hev7elt/0Zvc5DrXucplznImvX/mOMoR81w/ZR8f
8hEfsJO32M56Ztnp3Z3xo/tVc56N5q7fX2V9h5XpG7IinU+nRBtdIlrps0cL
s6Y0vSdeTu+RHjky9LhRx+L0DRwusoYXuGuzoej8//Qf3qhCiA==
       "]]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0jtLm1EAx+GjaIyJ1bpVt07GuaEVES8gUWztICjiKC3iokOtd+sFQZDi
h/DSS2zj5QsoimuLH6ARhyCYRHd16CMOP57/IS8h7yEvh8f7xkpCCGu6KA1h
0yHLrzqNh3DgfGWf28f2Bf+yyCwfWGS8ymY9455PsJ5JNrKdTexlF4c4wFF+
5D3TvNGE8jpRWUUIn5lTuT3JjCL2FPdUYU8zyhlWcpYxzjHOKs3bz7jAan5h
DRf5nEus5fLj90e9O2+1ooLOtOp3fuIkP3CE/Rxkim/5hm1M8BXr2MAYX/De
PVWywDv39495/nm8ex7x0ucbni9q3/mah3of8c7O75hhD3+zm7+Y4i47mWYH
2/XTbuUPtvA7m/mNTdzha24zyS3m3MV66dP/4j9b80XV
       "]]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0lsqBFAYB/AzTLkOXtzGdVxXQHknSZIxSJIir0QWYJoFmCyALMBkASYL
IAsgCzDu90uS3+Th3+98fQ/f1zknsbyeXIuEEDISi4bQVBpCBb85FAuhn6Mc
5CxHuMoUt7jCDDe5yzQPmOUR93nCHM+Z5xXPeMtLLtWE8MtacwusYqnUV4Rw
o27gLRt5xybes5kPjPORLXxiK9vk2bmdL+zgKzv5xgTf2cUPfjGYWSef6mpG
pcxu18W+XS9Y4CkvecwzHjLPPea4w31uM8sNprnMTU5zhcNMcYCL5vywxsw+
VrJElspD6C322cMFdnOeXZxjgjPsZJJT0uE8yXZOsI3jbOUYW4rvyjhH2Mxv
dxCJ/v+DP/JdPqk=
       "]]}, {
      Line3DBox[{2556, 2875, 1249, 2555, 3958, 2769, 2557, 3959, 2770, 2558, 
       3960, 2771, 2559, 3961, 2772, 2560, 3962, 2773, 2561, 3963, 2774, 2562,
        3964, 3681, 4073, 2563, 3965, 2775, 2564, 3966, 2776, 2565, 3967, 
       2777, 2566, 3968, 2778, 2567, 3969, 2779, 2568, 3746, 3970, 2780, 
       2876}], Line3DBox[{2570, 3682, 4074, 2569, 1264, 2571, 3971, 2781, 
       2572, 3972, 2782, 2573, 3973, 2783, 2574, 3974, 2784, 2575, 3975, 2785,
        2576, 3976, 3683, 4075, 2577, 3684, 4076, 2578, 3977, 2786, 2579, 
       3978, 2787, 2580, 3979, 2788, 2581, 3980, 2789, 2582, 3981, 2790, 
       2583}], Line3DBox[{2585, 3685, 4077, 2584, 3686, 4078, 2586, 3982, 
       2791, 2587, 3983, 2792, 2588, 3984, 2793, 2589, 3985, 2794, 2590, 3986,
        2795, 2591, 3987, 3687, 4079, 2592, 3688, 4080, 2593, 3689, 4081, 
       2594, 3988, 2796, 2595, 3989, 2797, 2596, 3990, 2798, 2597, 3991, 2799,
        2598}], 
      Line3DBox[{2600, 3690, 4082, 2599, 3691, 4083, 2601, 3692, 4084, 2602, 
       3693, 4085, 2603, 3992, 2800, 2604, 3993, 2801, 2605, 3994, 2802, 2606,
        3995, 3694, 4086, 2607, 3695, 4087, 2608, 3696, 4088, 2609, 3697, 
       4089, 2610, 3996, 2803, 2611, 3997, 2804, 2612, 3998, 2805, 2613}], 
      Line3DBox[{2615, 3698, 4090, 2614, 3699, 4091, 2616, 3700, 4092, 2617, 
       3701, 4093, 2618, 3702, 4094, 2619, 3999, 2806, 2620, 4000, 2807, 2621,
        4001, 3703, 4095, 2622, 3704, 4096, 2623, 3705, 4097, 2624, 3706, 
       4098, 2625, 3707, 4099, 2626, 4002, 2808, 2627, 4003, 2809, 2628}], 
      Line3DBox[{2630, 3708, 4100, 2629, 3709, 4101, 2631, 3710, 4102, 2632, 
       3711, 4103, 2633, 3712, 4104, 2634, 3713, 4105, 2635, 4004, 2810, 2636,
        4005, 3714, 4106, 2637, 3715, 4107, 2638, 3716, 4108, 2639, 3717, 
       4109, 2640, 3718, 4110, 2641, 3719, 4111, 2642, 4006, 2811, 2643}], 
      Line3DBox[{2646, 2878, 2940, 2947, 4163, 2812, 2920, 2880, 4007, 2813, 
       2648, 4008, 2814, 2650, 4009, 2815, 2652, 4010, 2816, 2654, 4011, 2817,
        2656, 4012, 2818, 2658, 4014, 4015, 2819, 2660, 4016, 2820, 2662, 
       4017, 2821, 2664, 4018, 2822, 2666, 4019, 2823, 2668, 4020, 2824, 2670,
        4021, 2825, 2672}], 
      Line3DBox[{2671, 4125, 3731, 2669, 4124, 3730, 2667, 4123, 3729, 2665, 
       4122, 3728, 2663, 4121, 3727, 2661, 4120, 3726, 2659, 4119, 3725, 4013,
        2657, 4118, 3724, 2655, 4117, 3723, 2653, 4116, 3722, 2651, 4115, 
       3721, 2649, 4114, 3720, 2647, 3748, 4113, 2879, 2644, 3747, 4112, 2877,
        2645}], 
      Line3DBox[{2673, 2881, 2941, 2948, 4164, 2826, 2921, 2882, 4022, 2827, 
       2674, 4023, 2828, 2675, 4024, 2829, 2676, 4025, 2830, 2677, 4026, 2831,
        2678, 4027, 2832, 2679, 4028, 1361, 2680, 4029, 2833, 2681, 4030, 
       2834, 2682, 4031, 2835, 2683, 4032, 2836, 2684, 4033, 2837, 2685, 4034,
        2838, 2686}], 
      Line3DBox[{2687, 2883, 2942, 2949, 3732, 4168, 2922, 2884, 2943, 4165, 
       2839, 2923, 2885, 4035, 2840, 2688, 4036, 2841, 2689, 4037, 2842, 2690,
        4038, 2843, 2691, 4039, 2844, 2692, 4040, 3733, 4126, 2693, 1377, 
       2694, 4041, 2845, 2695, 4042, 2846, 2696, 4043, 2847, 2697, 4044, 2848,
        2698, 4045, 2849, 2699}], 
      Line3DBox[{2700, 2886, 3007, 3009, 4146, 3761, 2924, 2887, 2944, 3755, 
       4147, 2950, 2925, 2888, 4046, 2850, 2701, 4047, 2851, 2702, 4048, 2852,
        2703, 4049, 2853, 2704, 4050, 2854, 2705, 4051, 3734, 4127, 2706, 
       3735, 4128, 2707, 4052, 2855, 2708, 4053, 2856, 2709, 4054, 2857, 2710,
        4055, 2858, 2711, 4056, 2859, 2712}], 
      Line3DBox[{2713, 3006, 3736, 4178, 3010, 2889, 2945, 3756, 4148, 2951, 
       2926, 2890, 3737, 4149, 2714, 4057, 2860, 2715, 4058, 2861, 2716, 4059,
        2862, 2717, 4060, 2863, 2718, 4061, 3738, 4129, 2719, 3739, 4130, 
       2720, 3740, 4131, 2721, 4062, 2864, 2722, 4063, 2865, 2723, 4064, 2866,
        2724, 4065, 2867, 2725}], 
      Line3DBox[{2727, 3000, 3001, 4177, 2726, 2891, 2946, 2892, 4159, 2728, 
       2893, 2894, 4150, 2729, 3741, 4132, 2730, 4066, 2868, 2731, 4067, 2869,
        2732, 4068, 2870, 2733, 4069, 3742, 4133, 2734, 3743, 4134, 2735, 
       3744, 4135, 2736, 3745, 4136, 2737, 4070, 2871, 2738, 4071, 2872, 2739,
        4072, 2873, 2740}], 
      Line3DBox[{2754, 2918, 2917, 4158, 2753, 2916, 2915, 4157, 2752, 2914, 
       4142, 3754, 2751, 3753, 4141, 2913, 2750, 3752, 4140, 2912, 2749, 4156,
        2911, 2910, 2748, 4154, 2909, 2908, 4155, 2747, 2907, 2906, 4153, 
       2746, 2905, 2904, 4152, 2745, 2903, 4139, 3751, 2744, 2902, 4138, 3750,
        2743, 3749, 4137, 2900, 2742, 4160, 2896, 2927, 2895, 2741, 4151, 
       2898, 3002, 2897, 3008, 3003}], Line3DBox[CompressedData["
1:eJwNzTcyBWAYBdBPy4yxBStAq6NgZMPYAIWOJ6cNyDnnnF+QGyo5W5JTnLnf
f2/x5ze3N7RlRUQLf9kR9zkRDwxxxy31eRG/tmv3DYNkciNK9VfuH9uFvGSA
On1Gpvm2JWWKIn2/POeML9uJPKXQ1iePOeLTlvZHrf7Qu5cD9vmwlet33Xv0
sMM2Nfp3+6Z7i242WKfa9mZbda/RxQol+pS/Xm1L3st0UqVflAu82ObkPB1U
2mblDM+2KTlNgT4hJ5ngyTYuK/RJfzS5xxjl0VamH3aP0EgxrfwDx1c+kA==

       "]], 
      Line3DBox[{3011, 3346, 3347, 3296, 3349, 3762, 4366, 3348, 3289, 4346, 
       3205, 3012, 4257, 3206, 3013, 4258, 3207, 3014, 4259, 3208, 3015, 4260,
        3209, 3016, 4261, 3210, 3017, 4262, 3763, 4179, 3018, 4263, 3211, 
       3019, 4264, 3212, 3020, 4265, 3213, 3021, 4266, 3214, 3022, 4267, 3215,
        3023, 3838, 4347, 3216, 3297}], 
      Line3DBox[{3025, 3290, 3298, 3764, 4180, 3024, 3291, 3350, 3765, 4181, 
       3026, 3377, 3378, 4372, 3217, 3027, 4268, 3218, 3028, 4269, 3219, 3029,
        4270, 3220, 3030, 4271, 3221, 3031, 4272, 3766, 4182, 3032, 3767, 
       4183, 3033, 4273, 3222, 3034, 4274, 3223, 3035, 4275, 3224, 3036, 4276,
        3225, 3037, 4277, 3226, 3038}], 
      Line3DBox[{3039, 3292, 3299, 3768, 4367, 3351, 3293, 3356, 3376, 4371, 
       3852, 3355, 3352, 3381, 1841, 3040, 4278, 3227, 3041, 4279, 3228, 3042,
        4280, 3229, 3043, 4281, 3230, 3044, 4282, 3769, 4184, 3045, 3770, 
       4185, 3046, 3771, 4186, 3047, 4283, 3231, 3048, 4284, 3232, 3049, 4285,
        3233, 3050, 4286, 3234, 3051}], 
      Line3DBox[{3053, 3294, 3300, 3295, 4187, 3052, 3353, 3357, 3354, 4188, 
       3853, 3054, 3383, 3379, 3382, 3380, 4189, 3055, 3772, 4190, 3056, 4287,
        3235, 3057, 4288, 3236, 3058, 4289, 3237, 3059, 4290, 3773, 4191, 
       3060, 3774, 4192, 3061, 3775, 4193, 3062, 3776, 4194, 3063, 4291, 3238,
        3064, 4292, 3239, 3065, 4293, 3240, 3066}], 
      Line3DBox[{3068, 3358, 3360, 3359, 2110, 3067, 3362, 3301, 3361, 3302, 
       4195, 3069, 3303, 2025, 3070, 3777, 4196, 3071, 3778, 4197, 3072, 4294,
        3241, 3073, 4295, 3242, 3074, 4296, 3779, 4198, 3075, 3780, 4199, 
       3076, 3781, 4200, 3077, 3782, 4201, 3078, 3783, 4202, 3079, 4297, 3243,
        3080, 4298, 3244, 3081}], 
      Line3DBox[{3083, 3363, 3364, 4203, 3082, 3365, 3366, 3334, 4359, 3839, 
       3084, 3304, 4348, 3840, 3085, 3784, 4204, 3086, 3785, 4205, 3087, 3786,
        4206, 3088, 4299, 3245, 3089, 4300, 3787, 4207, 3090, 3788, 4208, 
       3091, 3789, 4209, 3092, 3790, 4210, 3093, 3791, 4211, 3094, 3792, 4212,
        3095, 4301, 3246, 3096}], 
      Line3DBox[{523, 1691, 524, 712, 1692, 525, 1693, 526, 1694, 527, 1695, 
       528, 1696, 529, 1697, 530}], 
      Line3DBox[{3098, 3367, 4368, 3851, 3097, 3368, 3369, 3335, 4360, 3841, 
       3099, 3305, 4349, 3842, 3100, 3793, 4213, 3101, 3794, 4214, 3102, 3795,
        4215, 3103, 3796, 4216, 3104, 4302, 3797, 4217, 3105, 3798, 4218, 
       3106, 3799, 4219, 3107, 3800, 4220, 3108, 3801, 4221, 3109, 3802, 4222,
        3110, 3803, 4223, 3111}], 
      Line3DBox[{3112, 3370, 1914, 3371, 3306, 3336, 3344, 4364, 3247, 3328, 
       3307, 4350, 3248, 3329, 3308, 4351, 3249, 3113, 4303, 3250, 3114, 4304,
        3251, 3115, 4305, 3252, 3116, 4306, 1922, 3117, 4307, 3253, 3118, 
       4308, 3254, 3119, 4309, 3255, 3120, 4310, 3256, 3121, 4311, 3257, 3122,
        4312, 3258, 3123}], 
      Line3DBox[{537, 1705, 536, 1704, 535, 1703, 534, 1702, 533, 1701, 532, 
       1700, 531, 1699, 1698}], 
      Line3DBox[{3124, 3372, 3804, 4369, 3373, 3309, 3337, 725}], 
      Line3DBox[{3135, 3268, 4321, 3134, 3267, 4320, 3133, 3266, 4319, 3132, 
       3265, 4318, 3131, 3264, 4317, 3130, 4225, 3806, 3129, 4224, 3805, 4316,
        3128, 3263, 4315, 3127, 3262, 4314, 3126, 3261, 4313, 3125, 3260, 
       4353, 3311, 3331, 3259, 4352, 3310, 3330, 1930}], 
      Line3DBox[{3136, 3374, 3807, 4370, 3375, 3312, 3338, 3345, 4365, 3850, 
       3332, 3313, 1946, 3333, 3314, 4354, 3269, 3137, 4322, 3270, 3138, 4323,
        3271, 3139, 4324, 3272, 3140, 4325, 3808, 4226, 3141, 3809, 4227, 
       3142, 3810, 4228, 3143, 4326, 3273, 3144, 4327, 3274, 3145, 4328, 3275,
        3146, 4329, 3276, 3147}], 
      Line3DBox[{3149, 3811, 4229, 3148, 672, 2064, 700, 673, 2065, 701, 
       674}], 
      Line3DBox[{3160, 3282, 4336, 3159, 3281, 4335, 3158, 3280, 4334, 3157, 
       4233, 3815, 3156, 4232, 3814, 3155, 4231, 3813, 3154, 4230, 3812, 4333,
        3153, 3279, 4332, 3152, 3278, 4331, 3151, 3277, 4330, 3150, 1962}], 
      Line3DBox[{3162, 3816, 4234, 3161, 3315, 3339, 3316, 4235, 3163, 3317, 
       2043, 3164, 3318, 4355, 3843, 3165, 1977, 3166, 4337, 3283, 3167, 4338,
        3284, 3168, 4339, 3817, 4236, 3169, 3818, 4237, 3170, 3819, 4238, 
       3171, 3820, 4239, 3172, 3821, 4240, 3173, 4340, 3285, 3174, 4341, 3286,
        3175}], 
      Line3DBox[{3177, 3822, 4241, 3176, 3319, 3340, 2045, 3178, 3320, 3341, 
       4361, 3844, 3179, 3321, 4356, 3845, 3180, 3823, 4242, 3181, 1992, 3182,
        4342, 3287, 3183, 4343, 3824, 4243, 3184, 3825, 4244, 3185, 3826, 
       4245, 3186, 3827, 4246, 3187, 3828, 4247, 3188, 3829, 4248, 3189, 4344,
        3288, 3190}], 
      Line3DBox[{3204, 3327, 4358, 3849, 3203, 4256, 3837, 3202, 4255, 3836, 
       3201, 4254, 3835, 3200, 4253, 3834, 3199, 4252, 3833, 3198, 4251, 3832,
        4345, 3197, 2008, 3196, 4250, 3831, 3195, 4249, 3830, 3194, 3848, 
       4357, 3326, 3193, 3847, 4363, 3343, 3325, 3192, 3846, 4362, 3342, 3324,
        3191, 2048, 3322, 3323}], 
      Line3DBox[{3385, 3676, 3854, 4373, 3384, 4475, 3592, 3386, 4476, 3593, 
       3387, 4477, 3594, 3388, 4478, 3595, 3389, 4479, 3596, 3390, 4480, 3597,
        3391, 4481, 3855, 4374, 3392, 4482, 3598, 3393, 4483, 3599, 3394, 
       4484, 3600, 3395, 4485, 3601, 3396, 4486, 3602, 3397, 3956, 4572, 3603,
        3677}], 
      Line3DBox[{3399, 3856, 4375, 3398, 3857, 4376, 3400, 4487, 3604, 3401, 
       4488, 3605, 3402, 4489, 3606, 3403, 4490, 3607, 3404, 4491, 3608, 3405,
        4492, 3858, 4377, 3406, 3859, 4378, 3407, 4493, 3609, 3408, 4494, 
       3610, 3409, 4495, 3611, 3410, 4496, 3612, 3411, 4497, 3613, 3412}], 
      Line3DBox[{3414, 3860, 4379, 3413, 3861, 4380, 3415, 3862, 4381, 3416, 
       4498, 3614, 3417, 4499, 3615, 3418, 4500, 3616, 3419, 4501, 3617, 3420,
        4502, 3863, 4382, 3421, 3864, 4383, 3422, 3865, 4384, 3423, 4503, 
       3618, 3424, 4504, 3619, 3425, 4505, 3620, 3426, 4506, 3621, 3427}], 
      Line3DBox[{3429, 3866, 4385, 3428, 3867, 4386, 3430, 3868, 4387, 3431, 
       3869, 4388, 3432, 4507, 3622, 3433, 4508, 3623, 3434, 4509, 3624, 3435,
        4510, 3870, 4389, 3436, 3871, 4390, 3437, 3872, 4391, 3438, 3873, 
       4392, 3439, 4511, 3625, 3440, 4512, 3626, 3441, 4513, 3627, 3442}], 
      Line3DBox[{3444, 3874, 4393, 3443, 3875, 4394, 3445, 3876, 4395, 3446, 
       3877, 4396, 3447, 3878, 4397, 3448, 4514, 3628, 3449, 4515, 3629, 3450,
        4516, 3879, 4398, 3451, 3880, 4399, 3452, 3881, 4400, 3453, 3882, 
       4401, 3454, 3883, 4402, 3455, 4517, 3630, 3456, 4518, 3631, 3457}], 
      Line3DBox[{3459, 3884, 4403, 3458, 3885, 4404, 3460, 3886, 4405, 3461, 
       3887, 4406, 3462, 3888, 4407, 3463, 3889, 4408, 3464, 4519, 3632, 3465,
        4520, 3890, 4409, 3466, 3891, 4410, 3467, 3892, 4411, 3468, 3893, 
       4412, 3469, 3894, 4413, 3470, 3895, 4414, 3471, 4521, 3633, 3472}], 
      Line3DBox[{897, 2220, 898, 2221, 899, 2222, 900, 2223, 901, 2224, 902, 
       2225, 903, 2226, 904}], 
      Line3DBox[{3474, 3896, 4415, 3473, 3897, 4416, 3475, 3898, 4417, 3476, 
       3899, 4418, 3477, 3900, 4419, 3478, 3901, 4420, 3479, 3902, 4421, 3480,
        4522, 3903, 4422, 3481, 3904, 4423, 3482, 3905, 4424, 3483, 3906, 
       4425, 3484, 3907, 4426, 3485, 3908, 4427, 3486, 3909, 4428, 3487}], 
      Line3DBox[{3489, 2443, 3488, 4523, 3634, 3490, 4524, 3635, 3491, 4525, 
       3636, 3492, 4526, 3637, 3493, 4527, 3638, 3494, 4528, 3639, 3495, 4529,
        2451, 3496, 4530, 3640, 3497, 4531, 3641, 3498, 4532, 3642, 3499, 
       4533, 3643, 3500, 4534, 3644, 3501, 4535, 3645, 3502}], 
      Line3DBox[{911, 2234, 910, 2233, 909, 2232, 908, 2231, 907, 2230, 906, 
       2229, 905, 2228, 2227}], 
      Line3DBox[{3504, 3910, 4429, 3503, 2459, 3505, 4536, 3646, 3506, 4537, 
       3647, 3507, 4538, 3648, 3508, 4539, 3649, 3509, 4540, 3650, 3510, 4541,
        3911, 4430, 3511, 3912, 4431, 3512, 4542, 3651, 3513, 4543, 3652, 
       3514, 4544, 3653, 3515, 4545, 3654, 3516, 4546, 3655, 3517}], 
      Line3DBox[{3519, 3913, 4432, 3518, 3914, 4433, 3520, 2475, 3521, 4547, 
       3656, 3522, 4548, 3657, 3523, 4549, 3658, 3524, 4550, 3659, 3525, 4551,
        3915, 4434, 3526, 3916, 4435, 3527, 3917, 4436, 3528, 4552, 3660, 
       3529, 4553, 3661, 3530, 4554, 3662, 3531, 4555, 3663, 3532}], 
      Line3DBox[{3534, 3918, 4437, 3533, 3919, 4438, 3535, 3920, 4439, 3536, 
       2491, 3537, 4556, 3664, 3538, 4557, 3665, 3539, 4558, 3666, 3540, 4559,
        3921, 4440, 3541, 3922, 4441, 3542, 3923, 4442, 3543, 3924, 4443, 
       3544, 4560, 3667, 3545, 4561, 3668, 3546, 4562, 3669, 3547}], 
      Line3DBox[{3549, 3925, 4444, 3548, 3926, 4445, 3550, 3927, 4446, 3551, 
       3928, 4447, 3552, 2507, 3553, 4563, 3670, 3554, 4564, 3671, 3555, 4565,
        3929, 4448, 3556, 3930, 4449, 3557, 3931, 4450, 3558, 3932, 4451, 
       3559, 3933, 4452, 3560, 4566, 3672, 3561, 4567, 3673, 3562}], 
      Line3DBox[{3564, 3934, 4453, 3563, 3935, 4454, 3565, 3936, 4455, 3566, 
       3937, 4456, 3567, 3938, 4457, 3568, 2523, 3569, 4568, 3674, 3570, 4569,
        3939, 4458, 3571, 3940, 4459, 3572, 3941, 4460, 3573, 3942, 4461, 
       3574, 3943, 4462, 3575, 3944, 4463, 3576, 4570, 3675, 3577}], 
      Line3DBox[{3591, 3680, 4573, 3957, 3590, 4474, 3955, 3589, 4473, 3954, 
       3588, 4472, 3953, 3587, 4471, 3952, 3586, 4470, 3951, 3585, 4469, 3950,
        4571, 3584, 2539, 3583, 4468, 3949, 3582, 4467, 3948, 3581, 4466, 
       3947, 3580, 4465, 3946, 3579, 4464, 3945, 3578, 2550, 3678, 3679}]}, {
      Line3DBox[{1042, 1250, 3958, 1043, 1264, 1071, 4078, 1279, 1086, 4083, 
       1294, 1101, 4091, 1309, 1116, 4101, 1324, 1131, 4113, 1441, 1339, 4007,
        1146, 1443, 1354, 4022, 1161, 1445, 1495, 1369, 4165, 1176, 1448, 
       1497, 4147, 1529, 1530, 1191, 1450, 1498, 4148, 1531, 1532, 1206, 1452,
        4159, 1499, 1412, 1221, 1454, 4160, 1500, 1427, 1236, 4169, 1537, 
       1436, 1512, 1575, 1576, 1243}], 
      Line3DBox[{1044, 1251, 3959, 1045, 1265, 3971, 1072, 1280, 3982, 1087, 
       4084, 1295, 1102, 4092, 1310, 1117, 4102, 1325, 1132, 4114, 1340, 4008,
        1147, 1355, 4023, 1162, 1446, 1370, 4035, 1177, 1449, 1384, 4046, 
       1192, 1451, 4149, 1398, 1207, 1453, 4150, 1413, 1222, 4137, 1456, 1509,
        1428, 1237, 1538, 4143, 1457, 1513, 1533, 1534, 1244}], 
      Line3DBox[{1046, 1252, 3960, 1047, 1266, 3972, 1073, 1281, 3983, 1088, 
       4085, 1296, 1103, 4093, 1311, 1118, 4103, 1326, 1133, 4115, 1341, 4009,
        1148, 1356, 4024, 1163, 1371, 4036, 1178, 1385, 4047, 1193, 1399, 
       4057, 1208, 4132, 1414, 1223, 4138, 1458, 1510, 1459, 1501, 1539, 4170,
        1460, 1514, 1461, 1540, 1488}], 
      Line3DBox[{1048, 1253, 3961, 1049, 1267, 3973, 1074, 1282, 3984, 1089, 
       1297, 3992, 1104, 4094, 1312, 1119, 4104, 1327, 1134, 4116, 1342, 4010,
        1149, 1357, 4025, 1164, 1372, 4037, 1179, 1386, 4048, 1194, 1400, 
       4058, 1209, 1415, 4066, 1224, 4139, 1462, 1463, 1502, 1541, 4171, 1464,
        1515, 1465, 1542, 1489}], 
      Line3DBox[{1050, 1254, 3962, 1051, 1268, 3974, 1075, 1283, 3985, 1090, 
       1298, 3993, 1105, 1313, 3999, 1120, 4105, 1328, 1135, 4117, 1343, 4011,
        1150, 1358, 4026, 1165, 1373, 4038, 1180, 1387, 4049, 1195, 1401, 
       4059, 1210, 1416, 4067, 1225, 1466, 4152, 1467, 1503, 4161, 1543, 1544,
        1516, 1568, 1567, 1562}], 
      Line3DBox[{1052, 1255, 3963, 1053, 1269, 3975, 1076, 1284, 3986, 1091, 
       1299, 3994, 1106, 1314, 4000, 1121, 1329, 4004, 1136, 4118, 1344, 4012,
        1151, 1359, 4027, 1166, 1374, 4039, 1181, 1388, 4050, 1196, 1402, 
       4060, 1211, 1417, 4068, 1226, 1468, 4153, 1469, 1504, 1545, 4172, 1546,
        1517, 1570, 1569, 1563}], 
      Line3DBox[{1054, 1256, 3964, 1056, 1270, 3976, 1077, 1285, 3987, 1092, 
       1300, 3995, 1107, 1315, 4001, 1122, 1330, 4005, 1137, 1345, 4013, 4014,
        1152, 1360, 4028, 1167, 1375, 4040, 1182, 1389, 4051, 1197, 1403, 
       4061, 1212, 1418, 4069, 1227, 1470, 4155, 1472, 1505, 1547, 4173, 1548,
        1518, 1572, 1571, 1564}], 
      Line3DBox[{1058, 1258, 3965, 1059, 4076, 1272, 1079, 4080, 1287, 1094, 
       4087, 1302, 1109, 4096, 1317, 1124, 4107, 1332, 1139, 4120, 1347, 4016,
        1154, 1362, 4029, 1169, 1377, 1184, 4128, 1391, 1199, 4130, 1405, 
       1214, 4134, 1420, 1229, 1473, 4156, 1430, 1239, 4174, 1551, 1552, 1520,
        1578, 1435, 1246}], 
      Line3DBox[{1060, 1259, 3966, 1061, 1273, 3977, 1080, 4081, 1288, 1095, 
       4088, 1303, 1110, 4097, 1318, 1125, 4108, 1333, 1140, 4121, 1348, 4017,
        1155, 1363, 4030, 1170, 1378, 4041, 1185, 1392, 4052, 1200, 4131, 
       1406, 1215, 4135, 1421, 1230, 4140, 1474, 1431, 1240, 1553, 4144, 1475,
        1521, 1579, 1580, 1247}], 
      Line3DBox[{1062, 1260, 3967, 1063, 1274, 3978, 1081, 1289, 3988, 1096, 
       4089, 1304, 1111, 4098, 1319, 1126, 4109, 1334, 1141, 4122, 1349, 4018,
        1156, 1364, 4031, 1171, 1379, 4042, 1186, 1393, 4053, 1201, 1407, 
       4062, 1216, 4136, 1422, 1231, 4141, 1476, 1432, 1241, 1554, 4145, 1477,
        1522, 1581, 1582, 1248}], 
      Line3DBox[{1064, 1261, 3968, 1065, 1275, 3979, 1082, 1290, 3989, 1097, 
       1305, 3996, 1112, 4099, 1320, 1127, 4110, 1335, 1142, 4123, 1350, 4019,
        1157, 1365, 4032, 1172, 1380, 4043, 1187, 1394, 4054, 1202, 1408, 
       4063, 1217, 1423, 4070, 1232, 4142, 1478, 1479, 1506, 1555, 4175, 1480,
        1523, 1481, 1573, 1565}], 
      Line3DBox[{1066, 1262, 3969, 1067, 1276, 3980, 1083, 1291, 3990, 1098, 
       1306, 3997, 1113, 1321, 4002, 1128, 4111, 1336, 1143, 4124, 1351, 4020,
        1158, 1366, 4033, 1173, 1381, 4044, 1188, 1395, 4055, 1203, 1409, 
       4064, 1218, 1424, 4071, 1233, 1482, 4157, 1483, 1507, 4162, 1556, 1484,
        1524, 1485, 1574, 1566}], 
      Line3DBox[{1068, 1438, 1439, 3970, 1069, 1277, 3981, 1084, 1292, 3991, 
       1099, 1307, 3998, 1114, 1322, 4003, 1129, 1337, 4006, 1144, 4125, 1352,
        4021, 1159, 1367, 4034, 1174, 1382, 4045, 1189, 1396, 4056, 1204, 
       1410, 4065, 1219, 1425, 4072, 1234, 1486, 4158, 1487, 1508, 1557, 4176,
        1558, 1525, 1560, 1559, 1490}], 
      Line3DBox[{1242, 1433, 1511, 1536, 4166, 1535, 1235, 1426, 4151, 1455, 
       1220, 1411, 4177, 1561, 1205, 1397, 4178, 1584, 1586, 1585, 1190, 1383,
        1583, 4146, 1496, 1447, 1175, 1368, 4168, 1528, 1494, 1444, 1160, 
       4164, 1353, 1527, 1493, 1442, 1145, 4163, 1338, 1526, 1492, 1440, 4112,
        1130, 1323, 4100, 1115, 1308, 4090, 1100, 1293, 4082, 1085, 1278, 
       4077, 1070, 1263, 4074, 1041, 1249, 1437, 1491}], 
      Line3DBox[{1245, 1434, 1577, 1519, 1550, 4167, 1549, 1238, 1429, 4154, 
       1471, 1228, 1419, 4133, 1213, 1404, 4129, 1198, 1390, 4127, 1183, 1376,
        4126, 1168, 1361, 1153, 4015, 1346, 4119, 1138, 1331, 4106, 1123, 
       1316, 4095, 1108, 1301, 4086, 1093, 1286, 4079, 1078, 1271, 4075, 1057,
        1257, 4073, 1055}], Line3DBox[CompressedData["
1:eJwVzr9KQmEcxvGfQ52jVFhG9D90laDBhnKIai8K2gqi1sgLELwAwwsIugCh
CwjaG5pbHMVFEQmCSBCCPg1fnuf5vu97OMWb2vl9JiJOUZmO6CYRBUzyEbt2
T7/Qi/LM3ksj9lFGYT6iKnecXTs70o9x6f6hPOBr/EDecgm3jBO7wSfeD/WU
W8GV3uJTfqRnuVXc6U/8p8zZa6jrM+4981//nVtHU3/lvuWcPevOhny03/mx
zNubaOsdbiIf/N8Ct4UXu8//ykW7hDf9h8v5XsZewjY++Cn8AXQPI3w=
       "]], 
      Line3DBox[{1590, 1812, 4257, 1591, 2111, 1826, 4372, 1618, 2090, 1841, 
       1633, 2112, 4189, 1856, 1648, 2025, 1871, 1663, 4348, 2027, 1886, 1678,
        4349, 2029, 1901, 1693, 2031, 2059, 1916, 4350, 1708, 2034, 2061, 
       1931, 4352, 1723, 2037, 2063, 1946, 1738, 2040, 2065, 1961, 1753, 2043,
        2067, 2080, 2081, 1768, 4361, 2046, 2069, 2083, 2084, 1783, 4363, 
       2050, 2071, 2004, 1798}], 
      Line3DBox[{1592, 1813, 4258, 1593, 1827, 4268, 1619, 1842, 4278, 1634, 
       4190, 1857, 1649, 4196, 1872, 1664, 4204, 1887, 1679, 4213, 1902, 1694,
        2032, 1917, 4351, 1709, 2035, 1932, 4353, 1724, 2038, 1947, 4354, 
       1739, 2041, 1962, 1754, 4355, 2044, 1976, 1769, 4356, 2047, 1990, 1784,
        4357, 2051, 2005, 1799}], 
      Line3DBox[{1594, 1814, 4259, 1595, 1828, 4269, 1620, 1843, 4279, 1635, 
       1858, 4287, 1650, 4197, 1873, 1665, 4205, 1888, 1680, 4214, 1903, 1695,
        1918, 4303, 1710, 1933, 4313, 1725, 1948, 4322, 1740, 1963, 4330, 
       1755, 1977, 1770, 4242, 1991, 1785, 4249, 2006, 1800}], 
      Line3DBox[{1596, 1815, 4260, 1597, 1829, 4270, 1621, 1844, 4280, 1636, 
       1859, 4288, 1651, 1874, 4294, 1666, 4206, 1889, 1681, 4215, 1904, 1696,
        1919, 4304, 1711, 1934, 4314, 1726, 1949, 4323, 1741, 1964, 4331, 
       1756, 1978, 4337, 1771, 1992, 1786, 4250, 2007, 1801}], 
      Line3DBox[{1598, 1816, 4261, 1599, 1830, 4271, 1622, 1845, 4281, 1637, 
       1860, 4289, 1652, 1875, 4295, 1667, 1890, 4299, 1682, 4216, 1905, 1697,
        1920, 4305, 1712, 1935, 4315, 1727, 1950, 4324, 1742, 1965, 4332, 
       1757, 1979, 4338, 1772, 1993, 4342, 1787, 2008, 1802}], 
      Line3DBox[{1600, 1817, 4262, 1602, 1831, 4272, 1623, 1846, 4282, 1638, 
       1861, 4290, 1653, 1876, 4296, 1668, 1891, 4300, 1683, 1906, 4302, 1698,
        1921, 4306, 1713, 1936, 4316, 1728, 1951, 4325, 1743, 1966, 4333, 
       1758, 1980, 4339, 1773, 1994, 4343, 1788, 2009, 4345, 1803}], 
      Line3DBox[{1604, 1819, 4263, 1605, 4183, 1833, 1625, 4185, 1848, 1640, 
       4192, 1863, 1655, 4199, 1878, 1670, 4208, 1893, 1685, 4218, 1908, 1700,
        1923, 4307, 1715, 4225, 1938, 1730, 4227, 1953, 1745, 4231, 1968, 
       1760, 4237, 1982, 1775, 4244, 1996, 1790, 4252, 2011, 1805}], 
      Line3DBox[{1606, 1820, 4264, 1607, 1834, 4273, 1626, 4186, 1849, 1641, 
       4193, 1864, 1656, 4200, 1879, 1671, 4209, 1894, 1686, 4219, 1909, 1701,
        1924, 4308, 1716, 1939, 4317, 1731, 4228, 1954, 1746, 4232, 1969, 
       1761, 4238, 1983, 1776, 4245, 1997, 1791, 4253, 2012, 1806}], 
      Line3DBox[{1608, 1821, 4265, 1609, 1835, 4274, 1627, 1850, 4283, 1642, 
       4194, 1865, 1657, 4201, 1880, 1672, 4210, 1895, 1687, 4220, 1910, 1702,
        1925, 4309, 1717, 1940, 4318, 1732, 1955, 4326, 1747, 4233, 1970, 
       1762, 4239, 1984, 1777, 4246, 1998, 1792, 4254, 2013, 1807}], 
      Line3DBox[{1610, 1822, 4266, 1611, 1836, 4275, 1628, 1851, 4284, 1643, 
       1866, 4291, 1658, 4202, 1881, 1673, 4211, 1896, 1688, 4221, 1911, 1703,
        1926, 4310, 1718, 1941, 4319, 1733, 1956, 4327, 1748, 1971, 4334, 
       1763, 4240, 1985, 1778, 4247, 1999, 1793, 4255, 2014, 1808}], 
      Line3DBox[{1612, 1823, 4267, 1613, 1837, 4276, 1629, 1852, 4285, 1644, 
       1867, 4292, 1659, 1882, 4297, 1674, 4212, 1897, 1689, 4222, 1912, 1704,
        1927, 4311, 1719, 1942, 4320, 1734, 1957, 4328, 1749, 1972, 4335, 
       1764, 1986, 4340, 1779, 4248, 2000, 1794, 4256, 2015, 1809}], 
      Line3DBox[{1614, 2022, 2023, 4347, 1615, 1838, 4277, 1630, 1853, 4286, 
       1645, 1868, 4293, 1660, 1883, 4298, 1675, 1898, 4301, 1690, 4223, 1913,
        1705, 1928, 4312, 1720, 1943, 4321, 1735, 1958, 4329, 1750, 1973, 
       4336, 1765, 1987, 4341, 1780, 2001, 4344, 1795, 4358, 2052, 2053, 
       2054}], Line3DBox[{1796, 2002, 2048, 1781, 1988, 4241, 1766, 1974, 
       4234, 1751, 1959, 4229, 1736, 1944, 4370, 2104, 2103, 1721, 1929, 4369,
        2102, 2101, 1706, 1914, 2100, 2099, 1691, 1899, 2098, 2097, 4368, 
       1676, 1884, 2096, 4203, 2095, 1661, 1869, 2094, 2110, 2109, 1646, 1854,
        2108, 2092, 4187, 2020, 1631, 1839, 4367, 2089, 2019, 1616, 1824, 
       4180, 2017, 1587, 1810, 4366, 2086, 2085, 2088, 2087, 2021}], 
      Line3DBox[{1804, 2010, 4251, 1789, 1995, 4243, 1774, 1981, 4236, 1759, 
       1967, 4230, 1744, 1952, 4226, 1729, 1937, 4224, 1714, 1922, 1699, 1907,
        4217, 1684, 1892, 4207, 1669, 1877, 4198, 1654, 1862, 4191, 1639, 
       1847, 4184, 1624, 1832, 4182, 1603, 1818, 4179, 1601}], 
      Line3DBox[{2117, 2340, 4475, 2118, 4376, 2354, 2146, 4380, 2369, 2161, 
       4386, 2384, 2176, 4394, 2399, 2191, 4404, 2414, 2206, 4416, 2429, 2221,
        2444, 4523, 2236, 2459, 2251, 4433, 2474, 2266, 4438, 2489, 2281, 
       4445, 2504, 2296, 4454, 2519, 2311, 4464, 2534, 2326}], 
      Line3DBox[{2119, 2341, 4476, 2120, 2355, 4487, 2147, 4381, 2370, 2162, 
       4387, 2385, 2177, 4395, 2400, 2192, 4405, 2415, 2207, 4417, 2430, 2222,
        2445, 4524, 2237, 2460, 4536, 2252, 2475, 2267, 4439, 2490, 2282, 
       4446, 2505, 2297, 4455, 2520, 2312, 4465, 2535, 2327}], 
      Line3DBox[{2121, 2342, 4477, 2122, 2356, 4488, 2148, 2371, 4498, 2163, 
       4388, 2386, 2178, 4396, 2401, 2193, 4406, 2416, 2208, 4418, 2431, 2223,
        2446, 4525, 2238, 2461, 4537, 2253, 2476, 4547, 2268, 2491, 2283, 
       4447, 2506, 2298, 4456, 2521, 2313, 4466, 2536, 2328}], 
      Line3DBox[{2123, 2343, 4478, 2124, 2357, 4489, 2149, 2372, 4499, 2164, 
       2387, 4507, 2179, 4397, 2402, 2194, 4407, 2417, 2209, 4419, 2432, 2224,
        2447, 4526, 2239, 2462, 4538, 2254, 2477, 4548, 2269, 2492, 4556, 
       2284, 2507, 2299, 4457, 2522, 2314, 4467, 2537, 2329}], 
      Line3DBox[{2125, 2344, 4479, 2126, 2358, 4490, 2150, 2373, 4500, 2165, 
       2388, 4508, 2180, 2403, 4514, 2195, 4408, 2418, 2210, 4420, 2433, 2225,
        2448, 4527, 2240, 2463, 4539, 2255, 2478, 4549, 2270, 2493, 4557, 
       2285, 2508, 4563, 2300, 2523, 2315, 4468, 2538, 2330}], 
      Line3DBox[{2127, 2345, 4480, 2128, 2359, 4491, 2151, 2374, 4501, 2166, 
       2389, 4509, 2181, 2404, 4515, 2196, 2419, 4519, 2211, 4421, 2434, 2226,
        2449, 4528, 2241, 2464, 4540, 2256, 2479, 4550, 2271, 2494, 4558, 
       2286, 2509, 4564, 2301, 2524, 4568, 2316, 2539, 2331}], 
      Line3DBox[{2129, 2346, 4481, 2131, 2360, 4492, 2152, 2375, 4502, 2167, 
       2390, 4510, 2182, 2405, 4516, 2197, 2420, 4520, 2212, 2435, 4522, 2227,
        2450, 4529, 2242, 2465, 4541, 2257, 2480, 4551, 2272, 2495, 4559, 
       2287, 2510, 4565, 2302, 2525, 4569, 2317, 2540, 4571, 2332}], 
      Line3DBox[{2133, 2348, 4482, 2134, 4378, 2362, 2154, 4383, 2377, 2169, 
       4390, 2392, 2184, 4399, 2407, 2199, 4410, 2422, 2214, 4423, 2437, 2229,
        2452, 4530, 2244, 4431, 2467, 2259, 4435, 2482, 2274, 4441, 2497, 
       2289, 4449, 2512, 2304, 4459, 2527, 2319, 4470, 2542, 2334}], 
      Line3DBox[{2135, 2349, 4483, 2136, 2363, 4493, 2155, 4384, 2378, 2170, 
       4391, 2393, 2185, 4400, 2408, 2200, 4411, 2423, 2215, 4424, 2438, 2230,
        2453, 4531, 2245, 2468, 4542, 2260, 4436, 2483, 2275, 4442, 2498, 
       2290, 4450, 2513, 2305, 4460, 2528, 2320, 4471, 2543, 2335}], 
      Line3DBox[{2137, 2350, 4484, 2138, 2364, 4494, 2156, 2379, 4503, 2171, 
       4392, 2394, 2186, 4401, 2409, 2201, 4412, 2424, 2216, 4425, 2439, 2231,
        2454, 4532, 2246, 2469, 4543, 2261, 2484, 4552, 2276, 4443, 2499, 
       2291, 4451, 2514, 2306, 4461, 2529, 2321, 4472, 2544, 2336}], 
      Line3DBox[{2139, 2351, 4485, 2140, 2365, 4495, 2157, 2380, 4504, 2172, 
       2395, 4511, 2187, 4402, 2410, 2202, 4413, 2425, 2217, 4426, 2440, 2232,
        2455, 4533, 2247, 2470, 4544, 2262, 2485, 4553, 2277, 2500, 4560, 
       2292, 4452, 2515, 2307, 4462, 2530, 2322, 4473, 2545, 2337}], 
      Line3DBox[{2141, 2352, 4486, 2142, 2366, 4496, 2158, 2381, 4505, 2173, 
       2396, 4512, 2188, 2411, 4517, 2203, 4414, 2426, 2218, 4427, 2441, 2233,
        2456, 4534, 2248, 2471, 4545, 2263, 2486, 4554, 2278, 2501, 4561, 
       2293, 2516, 4566, 2308, 4463, 2531, 2323, 4474, 2546, 2338}], 
      Line3DBox[{2143, 2548, 2549, 4572, 2144, 2367, 4497, 2159, 2382, 4506, 
       2174, 2397, 4513, 2189, 2412, 4518, 2204, 2427, 4521, 2219, 4428, 2442,
        2234, 2457, 4535, 2249, 2472, 4546, 2264, 2487, 4555, 2279, 2502, 
       4562, 2294, 2517, 4567, 2309, 2532, 4570, 2324, 4573, 2551, 2552, 
       2553}], Line3DBox[{2325, 2533, 2550, 2310, 2518, 4453, 2295, 2503, 
       4444, 2280, 2488, 4437, 2265, 2473, 4432, 2250, 2458, 4429, 2235, 2443,
        2220, 2428, 4415, 2205, 2413, 4403, 2190, 2398, 4393, 2175, 2383, 
       4385, 2160, 2368, 4379, 2145, 2353, 4375, 2116, 2339, 4373, 2547, 
       2554}], Line3DBox[{2333, 2541, 4469, 2318, 2526, 4458, 2303, 2511, 
       4448, 2288, 2496, 4440, 2273, 2481, 4434, 2258, 2466, 4430, 2243, 2451,
        2228, 2436, 4422, 2213, 2421, 4409, 2198, 2406, 4398, 2183, 2391, 
       4389, 2168, 2376, 4382, 2153, 2361, 4377, 2132, 2347, 4374, 
       2130}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXk4lV3bwG2em6gUkchQMpSh0XUqNAgZQhJlHjKEJJKpTBUyRiFD5jEz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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{374.42726369926726`, 134.20729265237804`},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{3.014786516829526, 1.517725923153658, 0.23993807561599093`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{
  3.6240188231526423`*^9, {3.62402137199649*^9, 3.6240214187991667`*^9}, 
   3.624022182472784*^9, 3.624024008754609*^9, 
   3.624024071157178*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "compare", " ", "the", " ", "fitting", " ", "result", " ", "with", " ", 
    "original", " ", "curve"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "1"}], "]"}], 
      ",", " ", 
      RowBox[{"FitFrGGXSimpleCorrelated", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}]}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6042949117477655`*^9, 3.604294930346796*^9}, {
   3.6043278767787986`*^9, 3.6043279040663595`*^9}, {3.6043282522342734`*^9, 
   3.6043282693382516`*^9}, {3.6043284138825192`*^9, 3.60432841424254*^9}, 
   3.604345002974044*^9, 3.604345043428358*^9, {3.6129769787197266`*^9, 
   3.612977003375137*^9}, {3.6240172937286696`*^9, 3.6240173040972624`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJysnXdUFEu3t0HMqIgZURQDiAEjiAEaxYCoGDAnjJgBA2bMERFBwZwAFVQw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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFm3fc1cTTxW8u90muN+HJRbCggKLSi9hAkaJS7GJBsWGvYMECiqhYsBcQ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         "]], Polygon3DBox[CompressedData["
1:eJw1nAncVdP3xs+93vec692n996UpEKjpEEiEiUq89BMGeOnkEyZUshMxszz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         "]], Polygon3DBox[CompressedData["
1:eJwt2Hm811Mex/Ffqd+te6/fvVdpR6VSaKNdSasl2tRg7LumIdkGYcI8ZpCU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         "]], 
        Polygon3DBox[{{2959, 1751, 2029, 3893, 2825, 2826}, {2928, 1683, 2081,
          1329, 1328, 3726}, {2948, 1709, 2694, 1145, 1152, 3729}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mgUYFVXXha/ci9wZOHPPYGMjChIqBiCCNEiHiIAgIiAoAiKhIiKIgaLY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         "]], Polygon3DBox[CompressedData["
1:eJwtm3WcHcUShZfcDcy9ZGZ2geDuGgjuEII7wSUBAoRgwSV4gODu7vrgAQ93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         "]], Polygon3DBox[CompressedData["
1:eJwt13e8j2UfB/CfFffhOPZWKaX9pIiGJpGVENnr2OPYChmZhZA9IqMe7UF7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         "]], Polygon3DBox[{{3637, 2576, 2328, 2329, 2577, 3638}}]}]}, {}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlmtslFUQhs9uOf3W3dVWjFSpUJRoIv6jIDT6QzRCBVSshkusGpsmgpJW
pIUaL4gitFKIRixFCmjxAmg1GrqF2pa2tFykiaGRqNFq1F64xMsvowajz+uc
ZL+87zdnZr4zc2bm7LVllSUVcedcH08Wz8+Rc10x54bBQ965q1g8DE7mWQmf
Cr6aNvlr4Iwc54qw+z7pXEHQuQZ0Ceci+Fz8FKIzDdEZdKaw1ox8zzjTk758
56F/K98dQX8KfrPgoynnLqI3Cv8WnVb8vJ/t3Hrk0+H5+BzA53WsKYYV6J7g
PQ9ejc5x+AR4FfxT9Pdiuw7+nTefQ2AL8ibkNcjv8hbLfHCVfKLzFLgHP43w
z9jbBPa2FD4LuwK4g68Cf0wZl+xN9HfAO9CfFGJUbkbQqQJPXObc8lzLkfx8
hawP/a/Bn8CymMXfiv3rYCP+zkeWwzr4D/hpQL6Qbz2DzXb4s+CDMeP/ond7
wvI8B9wY2Z5j8EJsquDb2MN0b2ee781ets958/8P8ono3qv9Il8EdkYWl+Lr
gTfBm+GT05ar4ZTVwwXWOsBK5EPIK8AinqfxcZLvtmDTCt8a2bnqLHQm0v8C
bEOnN+TiKFietj00IN+J7Z/O6moo2KpGHh9nsdSBLeht8hZjBziMTqfiUGzw
k+CN7O8gPkpz7Yy1/9VgNzZzwY3E8iHfWgl/Bb0e1ufErUansh8Pnk+Z7/KY
vdcif0Rnqf3zfgn6f7GnjDedNvAxnkuRLwd34f8NyfEfT9j51SqvyC9iVwwf
jczXXmQ34389dp/jf7G3Pl3ibU06Y+hW8/4wfI3qQfHAS0MMiqUL3bd4diI/
EllPqq7UU7XeaqMO7GVtl/IPtkdW/+qD/eRte7b11Afs4x10pyF7FEwSVxl4
gPfGbOvBrsi+pW+qV9Wz6rXb4pZT5XMQ+Q3OevM0/Hr48/B+/Jfjr464Fypu
dO/2liPlKoucbQn6f3g7e9XAE2Az378SPop8Utp6Yjb4ZDhr9Xd+qH/VjmLi
50aQlVzOnnlZyx7qwzx5EexnbTz7PuYtH6Ux6/n7ee8HHwALcuzc2sB2bO5A
9gtPhlju8VbDhWGGaJZsDbFvSlqfq99Vl+MTdnaahz3IK7F9G0zEbVb8jc0M
7JfB89JWa71BnkFvpure28zTDDzrbXZOhP/mre5kqz7vRH8Fst1Jm+3t8EH2
OS/Mw2Jv81Z3wkfgTTyfIPsYnQspq331hOSql6Xk7wjrV7Cnbm81qlpdFvqu
ARzAdkfS5tghbO6MLF7FfSpp+1T+r05bL8xMW02h5sawv49vNPC+OmVzSnFU
hLxui5nNWMrmqO4T3UHnMM6Ax5JWG7JV/m/B376k1VKR8gTO8lZXs73NrpqY
1c8Gb/5fBudH1suqQ8121ZVmoWLRjNKsykSWa/W6aiMVt3ouDrnVnXOQXJTo
TMAvwWr0z3i7i3XF/B6+pRrWGanucuJWe+tYWwO+4O3eaAp3h2aF5MrbZm+9
Vg++FPavOPJC/SwA50XWv7ojdNdo3mqOa77LZzf8lLfvDoBrveWkJtxdqj/V
nvwo95phD+XanaH5UB/2sMXbPSebb7zZiWtOqn6Phho+zVqatUHwbGRzYwM+
F4Q5oHmwCP+HI7sH9f9D+dTc1n2u6/jXYKve1NkrVvlUrWge7w5zW/8r3sP+
XfA4Z9ANX0x9bU7+f0W7c95mv/avc+2PzLYP/A85dzZB
         "]], Polygon3DBox[CompressedData["
1:eJxFlltsVVUQhtcprHOafXbOQQygGAJK9MH4JHdFA6jBoIkKUVERE4KJQS0a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         "]], Polygon3DBox[CompressedData["
1:eJwlkktIlWEQhudYv+fgOV7aGBgEbgQvKzVT16kQGSoWCt4100XngClqi0oN
LwtBQc+RFBdeF0GlZKBiRFKJClrgVhepmUK5ChdGPdMsXr6Zd953Zr7v/+Nr
AkX+MBFJAQ4ouSQSihCZJ5kDydEio+TlxGXgvUskxy3S7RXJJc8BSfh20Qz6
ROqoL8MtgQHyTPCX+iPydpBFPoa2lrgGRDA8j35JzJkinwTDOi9GpAF0U6uC
qwS9eDejqBOPoHlDLRFfH3EhXAFYY/4xfC+oJ78HvMwI84h0eG1X3XkGzwLe
XHRu6hWO3VHv+pszAV227gv64ZrxhsJFDsixyGe4U+KmiyKlnO+Y+41CGTv3
cIbggo7t9xLsu01zF24iyt5Ld9FdT0A6mutAPLbTGWGsz3aeZe4vfFfgdvC5
PPZu1Y69jb7RVbQV9G8hbwYH+Kbpd4M4TqyH3lf92ucIzw+QFm1vv0L8nNo0
+hfs14p/FE8XHKFscD4kCMI9JeaQT5zPwB08xeCjy/o+QTeJ4AjuMrqvaG6x
3yK1IeI/cHto2sAYup/oKMsmtSFm9+idQAn90ij4febZhtsCAfIgutvE+WAd
XR3cPv385A8cewt9k1foXpN/YPaq2/7nceY0wjWASN7xJvw1tOfM6ITrABnk
FzxWv+/Yv6T/lO6ou+q31m+aSr/HzJ3gHodoYql9QdMCNwL33fn/SWUNbphd
ihz7V/WffYv3H5wadYc=
         "]], 
        Polygon3DBox[{{3209, 1380, 1379, 2716, 1864, 3871}}]}]}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt1OuTj1UAwPFDe5F7MUnjOhNKLsmMKDv+gHjBaMbohRmvYrAa1y1ZhN1Y
19zKuNtNUWR3WaW2WiG1kl2/ZXct69q25G7FTPqcphff3/d7znmefZ7nPL/9
dR2bPmJSoxDCDB/DG4cQO4UbuKRpCK0507hUd9Z3HJDQffSc5iHcM07T8/Qj
PVTn6LbOeUuv1O11arMQxht30B11hu6ie+hs3V2/otfqXjpN5+ntzu9vXKgb
6z6ucUiP0YX6VYyzXmYujQcYv83zU0IoNzfQeIE+pW/rhTqhs7iCs/k0f8hn
eBFX8mLOQZVewtW8lM/yMq7h5XyOV/B5npoawmuuUYVa4308CJVI9zwnzeXr
/pjg/hNcYq4nv2m9QM8yf8M4V2fo63pNfD+6XmfpabpOz9RT9FXdwfnjjC/r
ZD1aX9QN3tUbulbX6cF6snNqjHvribpad9I1znvEI+1fK65MDuFSUgjP8WXe
jK+xDBUt3ROnWmuC2/oOEuY/4kw0N98Cd/UO8/f4YyxAK/OtUW6+wfgBPkEW
njL/NMqs/W38EOuRjTbmi8y35Vzj33URl+NHz7efT6IMu+M6TjjmBO/DcbRz
7m/8JT6zVsq38CsK8TMq47HWjvEuHMVNHEE+SnAapY45xJ/H6+NP/ICv8C32
WE/wd3EPcBHtXf8CT0fL+L0yPq+f5Vr+FAdwCr84YClPQzHq8H28b3wTr2O9
gldiNn7CDRzGThzEXsec4XWYH/8mtsXnN/8FP+O693l7/Hv28B/O8wXYqbfG
e7RerAvi83Az48PO3RL32Pg6NzX3JPbqZC60nsJ/GCfxE9ijA+dba8Rnjc+h
BlPRwvIo81W6GkviPjt2Cl/B1bjHxiv4fdTjWtxvc2v5AzzGX/G53ddGXogN
mIdcx63hWXHvrBcbvxffnX6Htxjn8OT4PO6lPj4TzzUYohfHd+qYdF4er6Hf
5dXxfTlmLq9CkZ7DGfFd2sf9xjPjO+OJvMl5i3hC0n/bES74iFuTGX9XdV+8
jH7oimFNvCv/k8/rbuiOHngBL6InCpz7EveOe6/z4nfG79Hr//+u/wuxV94W

       "]], 
      Line3DBox[{1129, 2, 1324, 2739, 1312, 1183, 2738, 1309, 1311, 1308, 
       1310, 1315, 1314, 1129}], 
      Line3DBox[{1131, 3, 1330, 1307, 1130, 1161, 1131}], 
      Line3DBox[{1509, 6, 2688, 1331, 1332, 3771, 1333, 2742, 1334, 2725, 
       3747, 1335, 1336, 2727, 1337, 1338, 2728, 1339, 1340, 3748, 1341, 1342,
        3744, 1344, 1134, 1513, 8, 1511, 7, 1509}], 
      Line3DBox[{1518, 11, 2691, 1345, 1346, 3774, 1347, 2746, 1348, 4005, 
       2726, 1349, 1350, 3776, 1351, 1352, 1353, 1354, 2734, 1355, 1356, 1357,
        1358, 3766, 1359, 1360, 1361, 1362, 3764, 1363, 1364, 1365, 3746, 
       1366, 1367, 1369, 1138, 1520, 12, 1518}], Line3DBox[CompressedData["
1:eJwl0EVORFEQBdCCpBPCgD2wJRbAgAXAKhjj7i6NO43TuDUuW2HEqTA4uT8l
/728+qaWhuaqiGikpjriV5YVWmsj2goR7XTQSRfd9PBQF9Er++hngEGGGGZR
f0SOMsY4E0wyxTRFMzNyljnmWchdKnpFucQyK6yylqm3LjfYZIvtnHPnHbmb
/zOzJ/d59V2SBxxyxDEl9RN5yhnnlLnIPb1LecU1N9zyoX4n7/MNeOQpz1Sv
yGde8kze8v7q77nHJ19880N14f/N/wCh+kTP
       "]], 
      Line3DBox[{576, 316, 2071, 594, 1370, 1371, 1372, 1373, 1374, 3780, 
       1375, 1376, 1377, 1378, 1379, 1380, 3781, 1381, 1382, 1383, 1384, 1385,
        2749, 1386, 3750, 1387, 2750, 1388, 2732, 1389, 1390, 2752, 3783, 
       1391, 2753, 1392, 1393, 1394, 1395, 3784, 1396, 1397, 1398, 1399, 1400,
        3785, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 3786, 1409, 
       1410, 1411, 1412, 1413, 1414, 1415, 3757, 1416, 1417, 1418, 1419, 1420,
        1421, 1301, 576}], Line3DBox[{1502, 1275, 1277, 1180, 1502}], 
      Line3DBox[{1276, 1501, 1500, 1499, 1276}]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0rtLlXEYwPEnj0OFNtQWLVpDXlIDh9RKTUpbEsNLi0aFtzwlYSKhg26R
5OKUty5qJYirf0GQZnYvMi0d6i8oHO1zcHj4fB/e874v53dO1vXuy7f3RMSo
aUiPeJ0WcZ7ziYidjIhv9szMiD88wn/MY7rrpTzEi8zmFZ5kGyt4wXPu6lpd
rYd0ix7hLU5wgPcPRNS4PqzL9RpL7GMs5nce3xcxzjJ7jp7QP0yunuS6ydNT
zN4fscHHpkOfds8T3anP6Kf6pj6r893zLPVefUJP6wpdoGd0pS7Us7rLPefs
z3VSV+kX+qj+xSb7S9bxJ1/5fo+4bRb1A86xn2NM8iGbOchL7GE5W1nERmal
zo8HeYoJ5vCv3+Iwf6d0bgupz3v3V3s9t+z39kZ8sffxM3v5iT38yDv8wG6+
Z5Jd5p3u5Crb+ZatXOENvuE1LvMql3jMOWwmdv9H/wHMk0rn
       "]]}, {
      Line3DBox[{2755, 3145, 3146, 3037, 3264, 3800, 4207, 3742, 3263, 3308, 
       4217, 2928, 3726, 4432, 2929, 2756, 4008, 2930, 2757, 3743}], 
      Line3DBox[{2765, 3309, 3310, 3014, 3096, 3267, 3268, 4209, 3266, 3265, 
       3802, 4208, 2766, 4015, 2939, 2767, 4016, 2940, 2768, 4017, 2941, 3727,
        4435, 4007}], 
      Line3DBox[{2774, 3199, 3015, 3099, 3127, 4160, 3877, 3078, 3040, 3247, 
       3805, 4164, 2775, 3322, 3323, 3806, 4223, 2776, 4024, 2946, 2777, 4025,
        2947, 2778, 4026, 2948, 3729, 4436, 2949, 3730, 4437, 3807, 4094, 
       2779, 3808, 4095, 2780, 3809, 4096, 2781, 4027, 3749}], 
      Line3DBox[{2793, 3740, 3796}], Line3DBox[{2807, 3741, 3795}], 
      Line3DBox[{3768, 2821}], 
      Line3DBox[{2823, 3219, 3220, 3112, 3130, 4183, 2957, 3296, 3294, 3295, 
       3255, 4204, 2958, 3254, 3176, 4038, 2959, 2826, 4039, 2960, 2828, 4040,
        2961, 2830, 4041, 2962, 2832, 4042, 2963, 2834, 4044, 4045, 2964, 
       2836, 4046, 2965, 2838, 4047, 2966, 2840, 3275, 4048, 2967, 3276, 3277,
        4210, 3900, 3081, 2968, 3292, 3311, 4218, 3908, 3113, 3242, 2969, 
       3243, 3886, 4192, 3158, 3114, 3188, 2970, 3187}], 
      Line3DBox[{2844, 3221, 3222, 3111, 3157, 4182, 3885, 2843, 3154, 3174, 
       3155, 3080, 3903, 4179, 3293, 2842, 3027, 3110, 4181, 3870, 2841, 3899,
        4126, 3274, 2839, 4125, 3834, 2837, 4124, 3833, 2835, 4123, 3832, 
       4043, 2833, 4122, 3831, 2831, 4121, 3830, 2829, 4120, 3829, 2827, 4119,
        3828, 2825, 3893, 4118, 3175, 2824, 3873, 4117, 3251, 3253, 3252, 
       2822, 3884, 4191, 3156, 3109, 3281, 3280, 3218}], 
      Line3DBox[{2845, 3223, 3224, 3115, 3131, 4184, 2971, 3082, 3298, 3299, 
       3297, 3314, 4214, 2972, 3313, 3028, 4049, 2973, 2846, 4050, 2974, 2847,
        4051, 2975, 2848, 4052, 2976, 2849, 4053, 2977, 2850, 4054, 3835, 
       4127, 2851, 4055, 2978, 2852, 4056, 2979, 2853, 4057, 2980, 2854, 3874,
        4058, 2981, 3116, 3282, 4211, 3901, 3225, 3244, 2982, 3245, 3887, 
       4193, 3159, 3117, 3190, 2983, 3189}], 
      Line3DBox[{2855, 3226, 3227, 3118, 3132, 3836, 4186, 3083, 3052, 3256, 
       4205, 2984, 2856, 4059, 2985, 2857, 4060, 2986, 2858, 4061, 2987, 2859,
        4062, 2988, 2860, 4063, 2989, 2861, 4064, 3837, 4128, 2862, 3838, 
       4129, 2863, 4065, 2990, 2864, 4066, 2991, 2865, 3902, 4067, 2992, 3283,
        3284, 3285, 4068, 3119, 3228, 2993, 3229, 4202, 3139, 3140, 3053, 
       3192, 2994, 3191}], 
      Line3DBox[{2866, 3230, 3054, 3120, 3133, 3134, 4215, 3084, 3246, 3055, 
       3234, 3839, 4166, 2867, 4069, 2995, 2868, 4070, 2996, 2869, 4071, 2997,
        2870, 4072, 2998, 2871, 4073, 2999, 2872, 4074, 3840, 4130, 2873, 
       3841, 4131, 2874, 3842, 4132, 2875, 4075, 3000, 2876, 3906, 4076, 3001,
        3302, 3303, 4216, 3056, 3085, 3135, 3231, 3136, 3057, 3880, 4194, 
       3160, 3029, 3232, 3194, 3195, 3193}], 
      Line3DBox[{2877, 3233, 3059, 3121, 3137, 4167, 3878, 3086, 3060, 3843, 
       4168, 2878, 3061, 3087, 3844, 4169, 2879, 4077, 3002, 2880, 4078, 3003,
        2881, 4079, 3004, 2882, 4080, 3005, 2883, 4081, 3845, 4133, 2884, 
       3846, 4134, 2885, 3847, 4135, 2886, 3848, 4136, 2887, 4212, 3286, 3006,
        3287, 4213, 3058, 3007, 3064, 3896, 4203, 3030, 3288, 3197, 3198, 
       3196}], Line3DBox[{2901, 3141, 3032, 3235, 3031, 4163, 3897, 2900, 
       3073, 3072, 4172, 2899, 4142, 3854, 2898, 4141, 3853, 2897, 4140, 3852,
        2896, 4139, 3851, 2895, 4138, 3850, 4085, 2894, 3010, 4084, 2893, 
       3009, 4083, 2892, 3008, 4082, 2891, 4137, 3849, 2890, 4170, 3063, 3088,
        3062, 2889, 4171, 3068, 3067, 2888, 3888, 4195, 3066, 3122, 3065, 
       3289, 3236}], 
      Line3DBox[{2927, 3143, 3144, 3076, 3300, 4174, 3905, 2926, 3319, 3321, 
       3320, 3312, 4219, 3904, 2925, 4159, 3866, 2924, 4158, 3865, 2923, 4157,
        3864, 2922, 4156, 3863, 2921, 4155, 3862, 4090, 2920, 3013, 4089, 
       2919, 4154, 3861, 2918, 4153, 3860, 2917, 3894, 4152, 3305, 3307, 3306,
        2916, 3261, 3262, 4151, 3093, 3165, 3164, 2915, 3889, 4196, 3163, 
       3092, 3241, 3240, 2914, 4175, 3177, 3257, 3178, 3091, 3162, 3161, 
       3167}], Line3DBox[{3038, 2938, 3799}], 
      Line3DBox[{3074, 3237, 3033, 3290, 3034, 3238, 4173, 2902, 3069, 3089, 
       3070, 4185, 2903, 3071, 3090, 4143, 3875, 2904, 3304, 4144, 3907, 2905,
        3855, 4145, 2906, 4086, 3011, 2907, 4087, 3012, 2908, 4088, 3856, 
       4146, 2909, 3857, 4147, 2910, 3858, 4148, 2911, 3859, 4149, 2912, 3909,
        4150, 3315, 2913, 3316, 3876, 4220, 3258, 3075, 3259, 3260, 4206, 
       3179, 3035, 3239, 3036, 3166, 3142, 3180}], Line3DBox[{3798, 3181}], 
      Line3DBox[{3184, 3739, 3752}], 
      Line3DBox[{3200, 3269, 3016, 3100, 3017, 4187, 3879, 3250, 3249, 3301, 
       3042, 3248, 3043, 4222, 3910, 2783, 3325, 3317, 3324, 3318, 4221, 2784,
        3810, 4097, 2785, 4029, 2951, 2786, 4030, 2952, 2787, 4031, 2953, 
       2788, 4032, 3811, 4098, 2789, 3812, 4099, 2790, 3813, 4100, 2791, 3018,
        3019, 4197, 3731, 4161, 3020, 3738, 3021, 3201, 2792, 3211, 4006}], 
      Line3DBox[{3202, 3270, 3022, 3105, 3023, 3138, 4177, 2794, 3048, 3291, 
       3049, 4165, 2795, 3814, 4101, 2796, 3815, 4102, 2797, 3816, 4103, 2798,
        4033, 2954, 2799, 4034, 2955, 2800, 4035, 3817, 4104, 2801, 3818, 
       4105, 2802, 3819, 4106, 2803, 3820, 4107, 2804, 3867, 4180, 3106, 3024,
        2805, 4162, 3025, 3186, 3026, 3203, 2806, 3792}], 
      Line3DBox[{3212, 3278, 3279, 3108, 3151, 3150, 4178, 2808, 3214, 3215, 
       3213, 4108, 3872, 2809, 3821, 4109, 2810, 3822, 4110, 2811, 3823, 4111,
        2812, 3824, 4112, 2813, 4036, 2956, 2814, 4037, 3825, 4113, 2815, 
       3826, 4114, 2816, 3827, 4115, 2817, 3273, 4116, 3898, 2818, 3868, 4199,
        3205, 3272, 3271, 2819, 3869, 4198, 3204, 3207, 3206, 2820, 4190, 
       3152, 3153, 3736, 3793}], 
      Line3DBox[{3327, 3609, 3911, 4224, 3326, 4306, 3526, 3328, 4307, 3527, 
       3329, 4308, 3528, 3330, 4309, 3529, 3331, 4310, 3530, 3332, 4311, 3531,
        3333, 4312, 3912, 4225, 3334, 4313, 3532, 3335, 4314, 3533, 3336, 
       4315, 3534, 3337, 4316, 3535, 3338, 4317, 3536, 3339, 3986, 4400, 3537,
        3610}], 
      Line3DBox[{3341, 3913, 4226, 3340, 3914, 4227, 3342, 4318, 3538, 3343, 
       4319, 3539, 3344, 4320, 3540, 3345, 4321, 3541, 3346, 4322, 3542, 3347,
        4323, 3915, 4228, 3348, 3916, 4229, 3349, 4324, 3543, 3350, 4325, 
       3544, 3351, 4326, 3545, 3352, 4327, 3546, 3353, 4328, 3547, 3354}], 
      Line3DBox[{3356, 3917, 4230, 3355, 3918, 4231, 3357, 3919, 4232, 3358, 
       4329, 3548, 3359, 4330, 3549, 3360, 4331, 3550, 3361, 4332, 3551, 3362,
        4333, 3920, 4233, 3363, 3921, 4234, 3364, 3922, 4235, 3365, 4334, 
       3552, 3366, 4335, 3553, 3367, 4336, 3554, 3368, 4337, 3555, 3369}], 
      Line3DBox[{3371, 3923, 4236, 3370, 3924, 4237, 3372, 3925, 4238, 3373, 
       3926, 4239, 3374, 4338, 3556, 3375, 4339, 3557, 3376, 4340, 3558, 3377,
        4341, 3927, 4240, 3378, 3928, 4241, 3379, 3929, 4242, 3380, 3930, 
       4243, 3381, 4342, 3559, 3382, 4343, 3560, 3383, 4344, 3561, 3384}], 
      Line3DBox[{3386, 3931, 4244, 3385, 3932, 4245, 3387, 3933, 4246, 3388, 
       3934, 4247, 3389, 3935, 4248, 3390, 4345, 3562, 3391, 4346, 3563, 3392,
        4347, 3936, 4249, 3393, 3937, 4250, 3394, 3938, 4251, 3395, 3939, 
       4252, 3396, 3940, 4253, 3397, 4348, 3564, 3398, 4349, 3565, 3399}], 
      Line3DBox[{3401, 3941, 4254, 3400, 3942, 4255, 3402, 3943, 4256, 3403, 
       3944, 4257, 3404, 3945, 4258, 3405, 3946, 4259, 3406, 4350, 3566, 3407,
        4351, 3947, 4260, 3408, 3948, 4261, 3409, 3949, 4262, 3410, 3950, 
       4263, 3411, 3951, 4264, 3412, 3952, 4265, 3413, 4352, 3567, 3414}], 
      Line3DBox[{817, 1017, 2246, 818, 2247, 819, 2248, 820, 2249, 821, 2250, 
       822, 2251, 823, 2252, 824, 2253, 2254, 825, 2255, 826, 2256, 827, 2257,
        828, 2258, 829, 2259, 830, 2260, 831}], 
      Line3DBox[{3416, 3611, 3612, 4266, 3415, 3613, 4401, 3987, 3417, 3953, 
       4267, 3418, 3954, 4268, 3419, 3955, 4269, 3420, 3956, 4270, 3421, 3957,
        4271, 3422, 4353, 3958, 4272, 3423, 3959, 4273, 3424, 3960, 4274, 
       3425, 3961, 4275, 3426, 3962, 4276, 3427, 3963, 4277, 3428, 3964, 4278,
        3429}], 
      Line3DBox[{3430, 3614, 3666, 3671, 3965, 4415, 3648, 3615, 4402, 3568, 
       3431, 4354, 3569, 3432, 4355, 3570, 3433, 4356, 3571, 3434, 4357, 3572,
        3435, 4358, 3573, 3436, 4359, 3966, 4279, 3437, 4360, 3574, 3438, 
       4361, 3575, 3439, 4362, 3576, 3440, 4363, 3577, 3441, 4364, 3578, 3442,
        4365, 3579, 3443}], 
      Line3DBox[{3444, 3616, 3667, 1039, 4416, 3649, 3617, 3668, 3967, 4417, 
       3650, 3618, 4403, 3580, 3445, 4366, 3581, 3446, 4367, 3582, 3447, 4368,
        3583, 3448, 4369, 3584, 3449, 4370, 3968, 4280, 3450, 3969, 4281, 
       3451, 4371, 3585, 3452, 4372, 3586, 3453, 4373, 3587, 3454, 4374, 3588,
        3455, 4375, 3589, 3456}], 
      Line3DBox[{3457, 3619, 3723, 3724, 3725, 4418, 3651, 3620, 3669, 3672, 
       4423, 3996, 3652, 3621, 3970, 4282, 3458, 4376, 3590, 3459, 4377, 3591,
        3460, 4378, 3592, 3461, 4379, 3593, 3462, 4380, 3971, 4283, 3463, 
       3972, 4284, 3464, 3973, 4285, 3465, 4381, 3594, 3466, 4382, 3595, 3467,
        4383, 3596, 3468, 4384, 3597, 3469}], 
      Line3DBox[{3470, 1112, 2684, 1127, 953, 2603, 1000, 954, 4286, 3471, 
       3974, 4287, 3472, 4385, 3598, 3473, 4386, 3599, 3474, 4387, 3600, 3475,
        4388, 3975, 4288, 3476, 3976, 4289, 3477, 3977, 4290, 3478, 3978, 
       4291, 3479, 4389, 3601, 3480, 4390, 3602, 3481, 4391, 3603, 3482}], 
      Line3DBox[{3484, 3717, 3718, 4292, 3483, 3622, 3670, 3623, 4293, 3485, 
       3624, 3625, 4294, 3486, 3979, 4295, 3487, 3980, 4296, 3488, 4392, 3604,
        3489, 4393, 3605, 3490, 4394, 3981, 4297, 3491, 3982, 4298, 3492, 
       3983, 4299, 3493, 3984, 4300, 3494, 3985, 4301, 3495, 4395, 3606, 3496,
        4396, 3607, 3497}], 
      Line3DBox[{3511, 3646, 3645, 4399, 3510, 3644, 4414, 3995, 3509, 3643, 
       4412, 3994, 3508, 3993, 4411, 3642, 3507, 3992, 4410, 3641, 3506, 4305,
        3640, 3639, 3505, 4304, 3638, 3637, 4398, 3504, 3636, 3635, 4397, 
       3503, 3634, 4409, 3991, 3502, 3633, 4407, 3990, 3501, 3989, 4406, 3632,
        3500, 3988, 4404, 3630, 3499, 4303, 3627, 3653, 3626, 3498, 4302, 
       3628, 3719, 1125, 3720}], Line3DBox[CompressedData["
1:eJwVzEcyRGEUBtBrASgzUwtQRqpMlAFaa90tzGS65dAt58yEPcgWIWf7ct7g
1L33+9776wrlvlJFRBT5q4w4r4q4oJczumsiHqojfnUn7lN6uJfldcf2H92h
eZR8T7P8wNznW7dr7pGT580dtvnSbZnt8jvv5eybbPCpu5W16dbdWdZY5UOX
lS/bV+hiiTIp+bt+0V4iw0LyjfzGe2+6Ofc8nVzLMrpZ+6tu2pwhTZN8ypzk
RVc0J5L/5B1mgXGedWNmq/zKeyn7KCM86S5ljbphdwNDDPKoS8v77QPUU0sL
/xN4M30=
       "]], Line3DBox[{3745, 2762, 2934, 4012, 2761, 4091, 3801, 3773}], 
      Line3DBox[{3753, 3737, 3173, 3149, 3758}], 
      Line3DBox[{3760, 3168, 3787}], Line3DBox[{3761, 3077, 3789}], 
      Line3DBox[{3762, 3079, 3790}], Line3DBox[{3763, 3169, 2937, 3779}], 
      Line3DBox[{3765, 3170, 3778}], 
      Line3DBox[{3772, 3803, 4092, 2771, 3804, 4093, 2772, 4020, 2944, 3728, 
       3775}], Line3DBox[{3777, 3171, 3210, 4201, 3735, 3782}]}, {
      Line3DBox[{1506, 1685, 4008, 1507, 1696, 4016, 1524, 1707, 4024, 1533, 
       4097, 1716, 1544, 4102, 1728, 1556, 4110, 1740, 1568, 4119, 1752, 4039,
        1580, 1764, 4050, 1592, 1776, 4060, 1605, 1788, 4070, 1618, 1800, 
       4077, 1631, 4137, 1812, 1645, 4144, 2124, 1825, 1658, 4152, 2038, 1836,
        1671}], 
      Line3DBox[{1515, 1690, 4012, 1516, 4093, 1701, 1528, 4095, 1711, 1539, 
       4099, 1722, 1550, 4105, 1734, 1562, 4114, 1746, 1574, 4124, 1758, 4046,
        1586, 1770, 4055, 1598, 4129, 1782, 1611, 4131, 1794, 1624, 4134, 
       1806, 1637, 4139, 1818, 1651, 4147, 1831, 1664, 4156, 1842, 1677}], 
      Line3DBox[CompressedData["
1:eJwV0D0rxWEch/Gf4SDl4Wyko4iBjbIii0liIZRikUJSDqVExxsweSbPq7Ja
SbGQwTMvQDnKwORzhqvrvr/X+d/DqR6e7JnIi4hRZPIjGgoifjCNb3SVRWQ5
rVXxF8ZRWhjRqZXwmJa0FTsv84j9nd8wqCV4Fx32DL/iJfe29otW36W1HdsS
npGyPXG7/ol+fdt9EY94QLO9z/7BW+4LuEOlb2+53t6r33OLbdM2jxtUuF/z
kJ7Sr7DhPodL9NgvOGk/x7rzLI7RrR1xwn6Ktdz/gwH7IZd7+4D/EhEn+qpz
mzbD+9hDVtvSpux1fl+LJjTiTVvRJrWa3FtFEWf4B2iEOjU=
       "]], 
      Line3DBox[{1669, 1835, 1953, 1943, 2018, 2017, 4196, 1656, 1823, 1942, 
       4185, 1895, 1643, 1810, 4171, 1894, 1629, 1798, 4168, 1889, 1616, 1786,
        4166, 1882, 1603, 4205, 1774, 1877, 1590, 4214, 1762, 2130, 2129, 
       1874, 1578, 4204, 1750, 2074, 1871, 4117, 1566, 1738, 1868, 4108, 1554,
        1726, 4165, 1867, 1542, 1714, 2138, 2137, 4222, 2140, 2139, 1531, 
       1705, 4164, 1865, 1522, 1694, 4208, 2083, 1504, 4217, 1683, 2081, 
       2125}], Line3DBox[{1670, 2087, 2086, 2040, 1902, 4151, 2080, 1657, 
       1824, 1896, 4143, 1644, 1811, 4170, 1891, 1630, 1799, 4169, 1890, 1617,
        4069, 1787, 1604, 4059, 1775, 1591, 4049, 1763, 1859, 1579, 4038, 
       1751, 2029, 4118, 1567, 1739, 4109, 1555, 1727, 4101, 1543, 1715, 4221,
        2136, 1532, 1706, 4223, 2141, 1523, 4015, 1695, 1505, 4432, 1684, 
       2687}], Line3DBox[{1672, 1837, 4153, 1659, 1826, 4145, 1646, 4082, 
       1813, 1632, 4078, 1801, 1619, 4071, 1789, 1606, 4061, 1777, 1593, 4051,
        1765, 1581, 4040, 1753, 4120, 1569, 1741, 4111, 1557, 1729, 4103, 
       1545, 4029, 1717, 1534, 4025, 1708, 1525, 4017, 1697, 2729}], 
      Line3DBox[{1673, 1838, 4154, 1660, 4086, 1827, 1647, 4083, 1814, 1633, 
       4079, 1802, 1620, 4072, 1790, 1607, 4062, 1778, 1594, 4052, 1766, 1582,
        4041, 1754, 4121, 1570, 1742, 4112, 1558, 4033, 1730, 1546, 4030, 
       1718, 1535, 4026, 1709, 2694, 4435, 2743}], 
      Line3DBox[{1674, 4089, 1839, 1661, 4087, 1828, 1648, 4084, 1815, 1634, 
       4080, 1803, 1621, 4073, 1791, 1608, 4063, 1779, 1595, 4053, 1767, 1583,
        4042, 1755, 4122, 1571, 4036, 1743, 1559, 4034, 1731, 1547, 4031, 
       1719, 1536, 4436, 2744}], 
      Line3DBox[{1676, 1841, 4155, 1663, 1830, 4146, 1650, 1817, 4138, 1636, 
       1805, 4133, 1623, 1793, 4130, 1610, 1781, 4128, 1597, 1769, 4127, 1585,
        4045, 1757, 4123, 1573, 1745, 4113, 1561, 1733, 4104, 1549, 1721, 
       4098, 1538, 1710, 4094, 1527, 1700, 4092, 1514, 1689, 4091, 2689}], 
      Line3DBox[{1678, 1843, 4157, 1665, 1832, 4148, 1652, 1819, 4140, 1638, 
       1807, 4135, 1625, 1795, 4132, 1612, 4065, 1783, 1599, 4056, 1771, 1587,
        4047, 1759, 4125, 1575, 1747, 4115, 1563, 1735, 4106, 1551, 1723, 
       4100, 1540, 1712, 4096, 1529, 4020, 1702, 2730}], 
      Line3DBox[{1679, 1844, 4158, 1666, 1833, 4149, 1653, 1820, 4141, 1639, 
       1808, 4136, 1626, 4075, 1796, 1613, 4066, 1784, 1600, 4057, 1772, 1588,
        4048, 1760, 2094, 2093, 4126, 1576, 1748, 2090, 2089, 4116, 1564, 
       1736, 4107, 1552, 1724, 2041, 4197, 1846, 2698, 4027, 2703, 2696, 
       2747}], Line3DBox[{1680, 1845, 4159, 1667, 2133, 2132, 4150, 1654, 
       1821, 4142, 1640, 2105, 4212, 2104, 1627, 4076, 2121, 2120, 1614, 4067,
        2101, 2100, 1601, 4058, 1873, 1872, 1917, 4210, 2096, 1858, 2095, 
       1857, 4181, 1935, 2092, 1854, 2091, 1853, 4199, 2047, 1850, 1849, 4180,
        1932, 2043, 1848, 2042, 4161, 1847, 2748}], 
      Line3DBox[{1681, 2116, 2115, 4219, 2128, 1904, 2134, 1903, 4220, 2135, 
       2078, 1898, 4172, 1897, 1641, 1887, 4213, 2106, 1886, 2112, 2107, 1923,
        2123, 1884, 4216, 2122, 1883, 1941, 2103, 4068, 1879, 2102, 1878, 
       2055, 4211, 2099, 1876, 1939, 1875, 2004, 1937, 4218, 2126, 1870, 2127,
        1869, 2109, 2108, 4179, 1915, 2067, 2068, 1856, 2046, 1855, 4198, 
       2045, 2088, 1852, 2044, 4162, 1851, 2039, 2054, 2706, 2737}], 
      Line3DBox[{1908, 1860, 2117, 2119, 2118, 4174, 1906, 2064, 2131, 2065, 
       1905, 2036, 4206, 2079, 2035, 1900, 1970, 1971, 1899, 4163, 2060, 2059,
        1893, 2057, 2058, 4203, 1892, 1969, 1968, 1888, 1966, 1967, 4194, 
       1885, 1965, 1964, 1881, 1962, 4202, 2056, 1963, 1880, 1961, 2076, 1960,
        1940, 4193, 2007, 2070, 2008, 1920, 2006, 2031, 2005, 1938, 4192, 
       2000, 2069, 2001, 1918, 1999, 2030, 1998, 4182, 1936, 1994, 1995, 1914,
        1993, 4190, 1992, 2754}], Line3DBox[{2741, 1909}], 
      Line3DBox[{2143, 2353, 4306, 2144, 4227, 2367, 2172, 4231, 2382, 2187, 
       4237, 2397, 2202, 4245, 2412, 2217, 4255, 2427, 2232, 4401, 2547, 2442,
        2247, 2549, 2457, 4402, 2262, 2551, 2600, 4417, 2472, 2277, 2554, 
       2602, 4423, 2632, 2487, 2292, 2556, 2603, 2633, 2502, 2307, 2558, 4293,
        2604, 2517, 2322, 2560, 4303, 2605, 2532, 2337, 4405, 2640, 2641, 
       2615, 2676, 2540, 2345}], 
      Line3DBox[{2145, 2354, 4307, 2146, 2368, 4318, 2173, 4232, 2383, 2188, 
       4238, 2398, 2203, 4246, 2413, 2218, 4256, 2428, 2233, 4267, 2443, 2248,
        2458, 4354, 2263, 2552, 2473, 4403, 2278, 2555, 4282, 2488, 2293, 
       2557, 4286, 2503, 2308, 2559, 4294, 2518, 2323, 4404, 2562, 2613, 2533,
        2338, 4419, 2642, 2563, 2616, 2634, 2635, 2346}], 
      Line3DBox[{2147, 2355, 4308, 2148, 2369, 4319, 2174, 2384, 4329, 2189, 
       4239, 2399, 2204, 4247, 2414, 2219, 4257, 2429, 2234, 4268, 2444, 2249,
        2459, 4355, 2264, 2474, 4366, 2279, 2489, 4376, 2294, 4287, 2504, 
       2309, 4295, 2519, 2324, 4406, 2564, 2534, 2339, 2643, 4425, 2565, 2617,
        2636, 2637, 2347}], 
      Line3DBox[{2149, 2356, 4309, 2150, 2370, 4320, 2175, 2385, 4330, 2190, 
       2400, 4338, 2205, 4248, 2415, 2220, 4258, 2430, 2235, 4269, 2445, 2250,
        2460, 4356, 2265, 2475, 4367, 2280, 2490, 4377, 2295, 2505, 4385, 
       2310, 4296, 2520, 2325, 4407, 2566, 2567, 2606, 2644, 4408, 2568, 2618,
        2569, 2645, 2594}], 
      Line3DBox[{2151, 2357, 4310, 2152, 2371, 4321, 2176, 2386, 4331, 2191, 
       2401, 4339, 2206, 2416, 4345, 2221, 4259, 2431, 2236, 4270, 2446, 2251,
        2461, 4357, 2266, 2476, 4368, 2281, 2491, 4378, 2296, 2506, 4386, 
       2311, 2521, 4392, 2326, 4409, 2570, 2571, 2607, 4426, 2646, 2572, 2619,
        2573, 2669, 2664}], 
      Line3DBox[{2153, 2358, 4311, 2154, 2372, 4322, 2177, 2387, 4332, 2192, 
       2402, 4340, 2207, 2417, 4346, 2222, 2432, 4350, 2237, 4271, 2447, 2252,
        2462, 4358, 2267, 2477, 4369, 2282, 2492, 4379, 2297, 2507, 4387, 
       2312, 2522, 4393, 2327, 2574, 4397, 2575, 2608, 4427, 2647, 2648, 2620,
        2671, 2670, 2665}], 
      Line3DBox[{2155, 2359, 4312, 2157, 2373, 4323, 2178, 2388, 4333, 2193, 
       2403, 4341, 2208, 2418, 4347, 2223, 2433, 4351, 2238, 2448, 4353, 2253,
        2463, 4359, 2268, 2478, 4370, 2283, 2493, 4380, 2298, 2508, 4388, 
       2313, 2523, 4394, 2328, 2576, 4398, 2578, 2609, 2649, 4422, 2650, 2621,
        2673, 2672, 2666}], 
      Line3DBox[{2159, 2361, 4313, 2160, 4229, 2375, 2180, 4234, 2390, 2195, 
       4241, 2405, 2210, 4250, 2420, 2225, 4261, 2435, 2240, 4273, 2450, 2255,
        2465, 4360, 2270, 4281, 2480, 2285, 4284, 2495, 2300, 4289, 2510, 
       2315, 4298, 2525, 2330, 2579, 4305, 2536, 2341, 4420, 2653, 2654, 2623,
        2678, 2542, 2349}], 
      Line3DBox[{2161, 2362, 4314, 2162, 2376, 4324, 2181, 4235, 2391, 2196, 
       4242, 2406, 2211, 4251, 2421, 2226, 4262, 2436, 2241, 4274, 2451, 2256,
        2466, 4361, 2271, 2481, 4371, 2286, 4285, 2496, 2301, 4290, 2511, 
       2316, 4299, 2526, 2331, 4410, 2580, 2537, 2342, 4421, 2655, 2581, 2624,
        2679, 2680, 2350}], 
      Line3DBox[{2163, 2363, 4315, 2164, 2377, 4325, 2182, 2392, 4334, 2197, 
       4243, 2407, 2212, 4252, 2422, 2227, 4263, 2437, 2242, 4275, 2452, 2257,
        2467, 4362, 2272, 2482, 4372, 2287, 2497, 4381, 2302, 4291, 2512, 
       2317, 4300, 2527, 2332, 4411, 2582, 2538, 2343, 2656, 4429, 2583, 2625,
        2681, 2682, 2351}], 
      Line3DBox[{2165, 2364, 4316, 2166, 2378, 4326, 2183, 2393, 4335, 2198, 
       2408, 4342, 2213, 4253, 2423, 2228, 4264, 2438, 2243, 4276, 2453, 2258,
        2468, 4363, 2273, 2483, 4373, 2288, 2498, 4382, 2303, 2513, 4389, 
       2318, 4301, 2528, 2333, 4412, 2584, 2585, 2610, 2657, 4413, 2586, 2626,
        2587, 2674, 2667}], 
      Line3DBox[{2167, 2365, 4317, 2168, 2379, 4327, 2184, 2394, 4336, 2199, 
       2409, 4343, 2214, 2424, 4348, 2229, 4265, 2439, 2244, 4277, 2454, 2259,
        2469, 4364, 2274, 2484, 4374, 2289, 2499, 4383, 2304, 2514, 4390, 
       2319, 2529, 4395, 2334, 4414, 2588, 2589, 2611, 4430, 2658, 2590, 2627,
        2591, 2675, 2668}], 
      Line3DBox[{2169, 2544, 2545, 4400, 2170, 2380, 4328, 2185, 2395, 4337, 
       2200, 2410, 4344, 2215, 2425, 4349, 2230, 2440, 4352, 2245, 4278, 2455,
        2260, 2470, 4365, 2275, 2485, 4375, 2290, 2500, 4384, 2305, 2515, 
       4391, 2320, 2530, 4396, 2335, 2592, 4399, 2593, 2612, 4431, 2659, 2660,
        2628, 2662, 2661, 2595}], 
      Line3DBox[{2344, 2539, 2614, 2639, 4424, 2638, 2336, 2531, 4302, 2561, 
       2321, 2516, 4292, 2663, 2306, 2501, 2684, 2686, 2685, 2291, 2486, 4418,
        2683, 2601, 2553, 2276, 2471, 4416, 2631, 2599, 2550, 2261, 2456, 
       4415, 2630, 2598, 2548, 2246, 2441, 2629, 2597, 4266, 2546, 2231, 2426,
        4254, 2216, 2411, 4244, 2201, 2396, 4236, 2186, 2381, 4230, 2171, 
       2366, 4226, 2142, 2352, 4224, 2543, 2596}], 
      Line3DBox[{2348, 2541, 2677, 2622, 2652, 4428, 2651, 2340, 2535, 4304, 
       2577, 2329, 2524, 4297, 2314, 2509, 4288, 2299, 2494, 4283, 2284, 2479,
        4280, 2269, 2464, 4279, 2254, 2449, 4272, 2239, 2434, 4260, 2224, 
       2419, 4249, 2209, 2404, 4240, 2194, 2389, 4233, 2179, 2374, 4228, 2158,
        2360, 4225, 2156}], Line3DBox[{2731, 2705, 2053, 2751}], 
      Line3DBox[{2735, 4201, 2704, 2052, 2736}], 
      Line3DBox[{2745, 4437, 1537, 1720, 4032, 1548, 1732, 4035, 1560, 1744, 
       4037, 1572, 1756, 4043, 4044, 1584, 1768, 4054, 1596, 1780, 4064, 1609,
        1792, 4074, 1622, 1804, 4081, 1635, 1816, 4085, 1649, 1829, 4088, 
       1662, 1840, 4090, 1675}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXdUVEuX/42gAqKgiIISVAQJSlYUQ2+VJAgoyQQICIhkJaigBAFJkhEF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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{411.9963678074415, 243.0010263755938},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{2.455549083657965, 2.0186563871118164`, 1.1598728760166936`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.604345138701807*^9, 3.6129770554551153`*^9, 
  3.6239960586953635`*^9, 3.6240174233933477`*^9, 3.624018191207209*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "1"}], "]"}], 
      ",", " ", 
      RowBox[{"FitFrGGXComplexCorrelated", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}]}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.624018841278386*^9, 3.6240188559053545`*^9}, {
  3.6240190908018303`*^9, 3.6240190972011967`*^9}, {3.624019228425702*^9, 
  3.624019229408758*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyUnXc8lu37x0laKu3SUNpSmkpDV6WhQUN7aGsaDSmloS2hpK2hQaKlUkQi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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNm3kcVdP+/vc+Tvsc7X06BxkKpaRBGmhQGmieUCoiRaPmQoVKg+bBmCGR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         "]], Polygon3DBox[CompressedData["
1:eJw1nAfUFMXahGfXZWdgZtlVMaEiQUFQkGgAA0oGEVCSCAqoZBWVICAgiICo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         "]], Polygon3DBox[CompressedData["
1:eJwt2HncllMex/FLnp774X6qOyWJwhQtSmlRCfGopr3U016iUiktWijtJU2I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         "]], 
        Polygon3DBox[{{3048, 1829, 2107, 3953, 2914, 2915}, {3017, 1761, 2159,
          1332, 1331, 3777}, {3037, 1787, 2702, 1074, 1081, 3780}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmXXAFdUWxa/cy8c3A2fuHAVBKTGfXc9uVOwA7KAUEExEJex46bOwu57x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         "]], Polygon3DBox[CompressedData["
1:eJxFmnW8VdW+xbfsfTZnrsOe6xwQUEExwPbaHUiaiFI2Ip0qWIR56z1vqSgq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         "]], Polygon3DBox[CompressedData["
1:eJwt1ne4T2UcAPCDXO6P+7uuhFCS9i6hJUpGZEchEYlolzSfdj1N+2rvlIaW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         "]]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtkEtOAkEQhkuGBnt4iE8QUBiYhUdQj+HGjSsPoBeQREm8hYr4voYP9pIQ
YeMJlBg8AV+lZlH5vv670lM10fHpwUlKRGIqoKZpkT6ScSL7oYiHE7gOP8mL
cCUnsgXfyXepO/Jzb54l/4IR7JGn4U5G5AUv4HvcLcIxbMBn8jys8WYbDshL
+Ab+iv8yzy09jvMMf8RD/B9/wnN4lf5t+EF/C36TL8O30PwIHob2LX2/yd0I
LyU7PuBdb2fNY92RusIXYMfbLrpvMfkPFbhG3eCBsz7t/2GucuL6Ri3p0d5L
bzPrnDpbnewPnpEPA9tX/889fkG2yf01vuqs1FNwyVl/Fc4BsSYvyw==
         "]], Polygon3DBox[CompressedData["
1:eJwlj0tOwlAUhk/aXo23IT5AactA6oA1AMtgCSwAF2ACA1kGxAf42AYqc0wI
OHEH2qIr4Ds5g5P7/f953rx/3RsEInJBRMS7F7kLRXInchaLtHgPSazxmnDk
LP9NXMHDI5F7+IeaKvUZ3id6SqRwQqzgCVGHU2pi3mf0mN4E7dFP6Ft0yf5T
Z/Pf4BHeA/zL/Bq1BV7gbP4NuYW3fcd4J+QrvK+h3ay3L8m/oC/hRmw9es+5
s1m6c47eRXaL/uHA2U79m96ot/1FdvuWnhKe4XXgD29/+cfLyG/QBfyI14a/
vM3WHV14D3UHLYU=
         "]], 
        Polygon3DBox[{{2652, 926, 1307, 1308, 2754}, {2753, 1302, 1283, 926, 
         2428}, {2757, 1315, 1316, 980, 2647}, {2433, 930, 1262, 1288, 
         2617}, {2432, 2431, 2836, 1287, 2616}, {2434, 931, 1263, 1289, 
         2618}, {2755, 1309, 1285, 928, 2429}, {2756, 1310, 1292, 935, 
         2437}}]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmAeUVdUVhu+UN3Pfm/fmzcVYokmUqoCidKTFJK4kNixZibREQ0ATNUDo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         "]], Polygon3DBox[CompressedData["
1:eJwtmHeUVdUVxu885jj3vpl334zGEk1iAwtYEUVELEsTExNN4h8Jin2ZxCQI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         "]], Polygon3DBox[CompressedData["
1:eJwt1VeMVVUUxvEz4GUYysAkRhN9QFRUIKJ0EIYnE8UHBUsEGwhKEWUgREED
aqjDNLoCgiAdRXpHiiJVGNrQhjrUAIJUNQrqb2f78N171v98a+129t41O+W8
2LNckiS9KEVNKydJHf/NKiZJc+pVLUnqYfdjTcRNKQd7wX8lie9I6kwl6Uly
sYo4LUnWidfSBXEX3tmeZ9HkSkkysXqSnFCvtfjZVGwrtLktM0naitvQdjXW
yi3Fb1VIkuwKsf3Qjwny92trIt8Eelf9Q/g1niZ0L19d8W66IM7XpsfkYT/F
dA5rTLqf1BTX1O6wDH3h22487aomyU78LE9D0lTygHim/qRLmsR3J8yP+CB+
lacR3YPVqRz7HMYUxraF97r+XdLGEnF1+VnUFesr/y3j7If3pVbitt5V1Yf3
xN3pgMZrqedVUt+7BtRT7h7sojZbVojvgqcP/rz3Y+X8ieV4calazFmnnfbq
HdePHbxn5OXqm7+khvgAvlp8lrdc+SQpNAdD5Y4zL9ux8/o0lOdBysUWYL9g
7fly+SZje7ErWA+sFl8+tgwrxt7ASvkWauMIndGXQdgwbBLfHr7dVCPLOsnN
w5aId8p9na8B9jW2ASvDPsAOy12gVimdUm8g1pBvCt9PfKf4emIPYcOxRdgO
7DWsUO48rAy7g32M1eebiK3Ejoc1wJ7EJmDLsWNYd6we9iW2GDuCdcVamci6
dxlnKs51WKunsUfMbzbWksbpZ752Z8ot9f4PuX3kPq7eF9hCrBTrghXwtpPz
Km1Ki/vuCb7xfEs9H+XrxtcIm4r9jJ3GcrCt2CvyXqZR6tzQ5lPYXL5dfJf5
+vE1w2ZjO7FL2EdYC2w+VoJdw/pjTbFZ2A7sIvYh1gSbhm3FzmK9sebYHKwY
+xXrixVp+3vsFPYP9kkYG/YddhI7QbWt+SFsvr4eppP6/TlfS/UW8O3nuS53
QJhnbBF2ELuJfYYdlbtcXhldkZuLHcdWik+H/YflYZvDuSE+IZ7rG89R6xjf
ivD90FV8ON8jeIE2VmhjlzbexLKxhdgB7Ab2KdYY+wbbjJ3BemGn1HtGnfuS
eG6FvT+ExvJt4zvHN0TeYKwI+wFbQ3ebg87y93vfWl+eo2KePHyK52VqLk3F
c2OUff2v+gPE/Wl0OIfUXMN3Tq3yxlak1hHeZWE+w5ipvlr7+VaF/ceXxlcQ
1kj+bfWGqDWYRoi3VIln3D7xXtoq7in3lv4dktuiUpy/cLZXFk8Tz+E7nxn3
9FcZcVxhfOvNex42Azss/l2N3LAnsekZsV6oOywznnfh3OtGlbE2/59n6Z7f
xjrSdG3NrB7vm3DvdKKyKpGH9x1ogz0zxvst4SwJ60rtsIIq8fv7NiOeN+Hc
2ahWXb4x2KaKcQ3CWlTkGy9vqrrlKsZ7ZobnLuHOScW7b1x6nOelleK3HL7p
oqz4DYZv8XIqrkFgj2ljpDbW8+yV25GnNjYK+xHbF8aI1cFGYxuxEqxT1fhd
hu/zt1T81kdkxb0d9vhLYX3S4n39qNwRcteGscntIG8ftpj3GPZ3OMexfLop
70Yq7pNRWfH8DOdoWSruxXxslv/3xT1S8V4ab7wl4S7Dj6t3O6ybvL1hX2JH
sb/CN44NpnPyzqbiuV+oXrb57y3ulYp3X7gDwz0Q7oPTqXieF2TF/VFoHKvU
W01rrdEgbCg2T3xQGwMz474O+/taKu7jkXL/A9mjV1E=
         "]], 
        Polygon3DBox[{{3298, 1383, 1382, 2724, 1942, 3931}}]}]}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt1HmQzmUAwPEnU0TCVP8006j+aLHtruWVtdgOEUVl144mW84cS6jcXa5Y
R4WO1YmSLRUVkRrlvrfixWIv7WCakgzRMc7PM9Mf3/1+n+f3/J73d7zv3tp/
ZN6IK0II4/zJrRVC7Nr8D990TQiNeKJxir5Z/2VBc52hD9UP4axxjq7Q53Q3
fUzf4JwCfVzfqPs6Z2jcU4/VE/QtepKeoVP0bD1fp+liXaIvOD9hvEoX6Ayf
sVmv0at0Fgod32suh1sbD+Fk7RD2mWtjvFfv16f1Pl2m9/MBLuODfIAP8UEu
j/cWjYp4b1zJlVzFVVzN1XyYD/MvvLFOCG19RgVqjFdzNsqx3f0kza3UCWxx
/WW8yVwqL3f863hd5k8aL9FJfUIX6936uC7SP+nf9Hhdqn/VY5xfGJ+97q17
6SO6u+6qa3QH3V7vcE61cbreqit1Y50V3yHne34N431eFcL7V3p+WIBHMQpd
cL0FmbweG/AZPsd15rtxG2zBVizD0QbukfNwJ7ZjBxpZ/yV/hR64GzuxCw0d
W8ErkY97UIoz9vqRe+Naa57mV3CpXghP8Wy8jCGYhfrWzOSRKMJuzMBgHLPX
dP4U0zACU/A66jlvKg/EZCzFJDyJ5zEPda15gQfgOSzGsxiKsfjD/nN4HPrh
PSTxLprD4TDPc35b78E76Itn8Crq2L8zZ2A8PsQE9MdonLDBXO6KLLyITzAR
T2AM/rTmNc5FDl7CY/jd/CD+GV/g8XhtnuE3fMTnluoCvQ3n9fB4jbyZazne
Kz5L4xLehI0Yhh9wyt7r+AN8j7UoxLc46dh3XIy3MB/p8V3G37hn8YZ+E/fF
d2ptGi/EIlw0foBb4yMswQVz3bk91uBj/Oe6HuG70BPtUGPdw3wH/nX8nHGr
+F3TqVxl3ImbxXfvWrL9ruvyTIMOrqtj3Neapnx/3EMn+CH8bU1bfhBndTa3
xFHP6YxxC72TU7jCeffybbBtyPQ5MhTFdSZaIoFWKI/flav9dvwmmxg3RTOk
4nakIR2nnJvBmTit+8R34v9Ru///r18GDE3SdA==
       "]], 
      Line3DBox[{1058, 2, 1327, 2772, 1241, 1112, 2771, 1238, 1240, 1237, 
       1239, 1244, 1243, 1058}], 
      Line3DBox[{1060, 3, 1333, 1236, 1059, 1090, 1060}], 
      Line3DBox[{1587, 6, 2696, 1334, 1335, 3831, 1336, 2803, 1337, 2758, 
       3807, 1338, 1339, 2760, 1340, 1341, 2761, 1342, 1343, 3808, 1344, 1345,
        3804, 1347, 1063, 1591, 8, 1589, 7, 1587}], 
      Line3DBox[{1596, 11, 2699, 1348, 1349, 3834, 1350, 2807, 1351, 4066, 
       2759, 1352, 1353, 3836, 1354, 1355, 1356, 1357, 2767, 1358, 1359, 1360,
        1361, 3826, 1362, 1363, 1364, 1365, 3824, 1366, 1367, 1368, 3806, 
       1369, 1370, 1372, 1067, 1598, 12, 1596}], Line3DBox[CompressedData["
1:eJwl0EdKQ1EUgOGjRAgKEZfgllyAAxegK3Fi77333mKMGnvvfSao4FB0kJGf
OPj44b7zzn288qqaiuqCiKgkWRiR15yD2uKIuqKIehpopIlmWkiWRrRqG+10
0EkX3bylInq0lz76GWCQIYZ5NzOio4wxzgSTlNg/pdPMMMsc83x6b0EXWWKZ
Fc5886qu8Womreuk7MroBlk22eLHzLbm2GGXPfb59uxADznimBPK7Dr9u4tz
Lrjky/yVXnPDLXd8OL/XBx554pkX0on/f/4LMlNFZQ==
       "]], 
      Line3DBox[{576, 316, 2149, 594, 1373, 1374, 1375, 1376, 1377, 3840, 
       1378, 1379, 1380, 1381, 1382, 1383, 3841, 1384, 1385, 1386, 1387, 1388,
        2810, 1389, 3810, 1390, 2811, 1391, 2765, 1392, 1393, 2813, 3843, 
       1394, 2814, 1395, 1396, 1397, 1398, 3844, 1399, 1400, 1401, 1402, 1403,
        3845, 1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411, 3846, 1412, 
       1413, 1414, 1415, 1416, 1417, 1418, 3817, 1419, 1420, 1421, 1422, 1423,
        1424, 1230, 576}], Line3DBox[{1580, 1204, 1206, 1109, 1580}], 
      Line3DBox[{1205, 1579, 1578, 1577, 1205}]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0NsqRGEYBuBvLCMp7sEtOeGUHBM3IOXYnUiSNCRJst8bk90wxhr7/Qxy
5Fk5eHveb7X6//Wtzr7BroFcRPRKvjlirSkix0IS0d0eUTL3s8ZhNjjKcj7i
UoptEVc8YYXXcqpXeSNnesqanOu3vJML/Z4PUtYf+ZSdmZ0nz/qLVPRXvmVn
6+/8kKr+yXp2j97gl6T6N3+yO/Xf7A77jPvmxE4jrNthiCnHOiLmPW/xzrE5
Ycm82mo38wqPuMxDLvGAi9znAvc4x4Ls6rPc4Qy3Oc0tTnGTk9zgBNfZ4zuL
yf///wOGw046
       "]], Line3DBox[CompressedData["
1:eJwl0r9OU3EcxuFvOW2hLS3YCvgfCggrXoFegSTuOjij7ugV6OLgokDYid4A
3oAsuBkXC6i1RSAxCggCLc+JwyfPe9rzS9uT1h8+ufc4ExGLelmOqCURyxzn
SiWiw1t677U77GrNnmVkIz7bD+wWH/GQz5hz9gVf8WP6ut7ot9Y1X4hY4Lti
xEku4lRn6qiryEdkNFCK6GGirHLKa8+5XvapoKJKuuD+fpZVSc+r5d7B9D1V
1XZd40Vt20Mccm6YIxq2L/Fyem1f4U/3XeU17djXeUO79ijHVNcv1+Oc0KRu
akrT6fa7sp5Zw+8e81xes8rnTPiU+57fHJu8z0+8yw+8zVXO8C3rXGKVx+kz
U8X33fYZXZXtNjvqt1s8U8n+wVMV7SZPVLC/85/67F59s4+Vt7/ySDl7i3+V
tTd5qMTe4IF67Ab3lbG/MPgnPZP8/6+dAwXUS7k=
       "]], Line3DBox[CompressedData["
1:eJwl0MdNg0EQQOExTtgm5wwGhKiHCwc4UQAUQE5dkHM5ICHgQgVkKuAbcXh6
b63d+UdurqwtrBYiYglvpYijYsQ91msRx/yADX3Cy/WIVz7Fpt/OeIvPeZt3
cKF3+ZL3+Ir3+ZoP+IYP+ZYXzXvkqu/e8Xwlor0cMYcpdGEWMxhtRExyGyYw
4vzrXUMP6x9d10P6W7+YXXP+0s+6VX/qJ13Vfe59OFd0r37XZT2OHucmlzCN
7pzj3VjukW9RxEDu6G5n7pN75Cy05Lfc7+eO3AmDOReF8v///AdedCZI
       "]]}, {
      Line3DBox[{2844, 3234, 3235, 3126, 3353, 3860, 4268, 3793, 3352, 3397, 
       4278, 3017, 3777, 4482, 3018, 2845, 4069, 3019, 2846, 3803}], 
      Line3DBox[{2854, 3398, 3399, 3103, 3185, 3356, 3357, 4270, 3355, 3354, 
       3862, 4269, 2855, 4076, 3028, 2856, 4077, 3029, 2857, 4078, 3030, 3778,
        4485, 4068}], 
      Line3DBox[{2863, 3288, 3104, 3188, 3216, 4221, 3937, 3167, 3129, 3336, 
       3865, 4225, 2864, 3411, 3412, 3866, 4284, 2865, 4085, 3035, 2866, 4086,
        3036, 2867, 4087, 3037, 3780, 4486, 3038, 3781, 4487, 3867, 4155, 
       2868, 3868, 4156, 2869, 3869, 4157, 2870, 4088, 3809}], 
      Line3DBox[{2882, 3791, 3856}], Line3DBox[{2896, 3792, 3855}], 
      Line3DBox[{3828, 2910}], 
      Line3DBox[{2912, 3308, 3309, 3201, 3219, 4244, 3046, 3385, 3383, 3384, 
       3344, 4265, 3047, 3343, 3265, 4099, 3048, 2915, 4100, 3049, 2917, 4101,
        3050, 2919, 4102, 3051, 2921, 4103, 3052, 2923, 4105, 4106, 3053, 
       2925, 4107, 3054, 2927, 4108, 3055, 2929, 3364, 4109, 3056, 3365, 3366,
        4271, 3960, 3170, 3057, 3381, 3400, 4279, 3968, 3202, 3331, 3058, 
       3332, 3946, 4253, 3247, 3203, 3277, 3059, 3276}], 
      Line3DBox[{2933, 3310, 3311, 3200, 3246, 4243, 3945, 2932, 3243, 3263, 
       3244, 3169, 3963, 4240, 3382, 2931, 3116, 3199, 4242, 3930, 2930, 3959,
        4187, 3363, 2928, 4186, 3894, 2926, 4185, 3893, 2924, 4184, 3892, 
       4104, 2922, 4183, 3891, 2920, 4182, 3890, 2918, 4181, 3889, 2916, 4180,
        3888, 2914, 3953, 4179, 3264, 2913, 3933, 4178, 3340, 3342, 3341, 
       2911, 3944, 4252, 3245, 3198, 3370, 3369, 3307}], 
      Line3DBox[{2934, 3312, 3313, 3204, 3220, 4245, 3060, 3171, 3387, 3388, 
       3386, 3403, 4275, 3061, 3402, 3117, 4110, 3062, 2935, 4111, 3063, 2936,
        4112, 3064, 2937, 4113, 3065, 2938, 4114, 3066, 2939, 4115, 3895, 
       4188, 2940, 4116, 3067, 2941, 4117, 3068, 2942, 4118, 3069, 2943, 3934,
        4119, 3070, 3205, 3371, 4272, 3961, 3314, 3333, 3071, 3334, 3947, 
       4254, 3248, 3206, 3279, 3072, 3278}], 
      Line3DBox[{2944, 3315, 3316, 3207, 3221, 3896, 4247, 3172, 3141, 3345, 
       4266, 3073, 2945, 4120, 3074, 2946, 4121, 3075, 2947, 4122, 3076, 2948,
        4123, 3077, 2949, 4124, 3078, 2950, 4125, 3897, 4189, 2951, 3898, 
       4190, 2952, 4126, 3079, 2953, 4127, 3080, 2954, 3962, 4128, 3081, 3372,
        3373, 3374, 4129, 3208, 3317, 3082, 3318, 4263, 3228, 3229, 3142, 
       3281, 3083, 3280}], 
      Line3DBox[{2955, 3319, 3143, 3209, 3222, 3223, 4276, 3173, 3335, 3144, 
       3323, 3899, 4227, 2956, 4130, 3084, 2957, 4131, 3085, 2958, 4132, 3086,
        2959, 4133, 3087, 2960, 4134, 3088, 2961, 4135, 3900, 4191, 2962, 
       3901, 4192, 2963, 3902, 4193, 2964, 4136, 3089, 2965, 3966, 4137, 3090,
        3391, 3392, 4277, 3145, 3174, 3224, 3320, 3225, 3146, 3940, 4255, 
       3249, 3118, 3321, 3283, 3284, 3282}], 
      Line3DBox[{2966, 3322, 3148, 3210, 3226, 4228, 3938, 3175, 3149, 3903, 
       4229, 2967, 3150, 3176, 3904, 4230, 2968, 4138, 3091, 2969, 4139, 3092,
        2970, 4140, 3093, 2971, 4141, 3094, 2972, 4142, 3905, 4194, 2973, 
       3906, 4195, 2974, 3907, 4196, 2975, 3908, 4197, 2976, 4273, 3375, 3095,
        3376, 4274, 3147, 3096, 3153, 3956, 4264, 3119, 3377, 3286, 3287, 
       3285}], Line3DBox[{2990, 3230, 3121, 3324, 3120, 4224, 3957, 2989, 
       3162, 3161, 4233, 2988, 4203, 3914, 2987, 4202, 3913, 2986, 4201, 3912,
        2985, 4200, 3911, 2984, 4199, 3910, 4146, 2983, 3099, 4145, 2982, 
       3098, 4144, 2981, 3097, 4143, 2980, 4198, 3909, 2979, 4231, 3152, 3177,
        3151, 2978, 4232, 3157, 3156, 2977, 3948, 4256, 3155, 3211, 3154, 
       3378, 3325}], 
      Line3DBox[{3016, 3232, 3233, 3165, 3389, 4235, 3965, 3015, 3408, 3410, 
       3409, 3401, 4280, 3964, 3014, 4220, 3926, 3013, 4219, 3925, 3012, 4218,
        3924, 3011, 4217, 3923, 3010, 4216, 3922, 4151, 3009, 3102, 4150, 
       3008, 4215, 3921, 3007, 4214, 3920, 3006, 3954, 4213, 3394, 3396, 3395,
        3005, 3350, 3351, 4212, 3182, 3254, 3253, 3004, 3949, 4257, 3252, 
       3181, 3330, 3329, 3003, 4236, 3266, 3346, 3267, 3180, 3251, 3250, 
       3256}], Line3DBox[{3127, 3027, 3859}], 
      Line3DBox[{3163, 3326, 3122, 3379, 3123, 3327, 4234, 2991, 3158, 3178, 
       3159, 4246, 2992, 3160, 3179, 4204, 3935, 2993, 3393, 4205, 3967, 2994,
        3915, 4206, 2995, 4147, 3100, 2996, 4148, 3101, 2997, 4149, 3916, 
       4207, 2998, 3917, 4208, 2999, 3918, 4209, 3000, 3919, 4210, 3001, 3969,
        4211, 3404, 3002, 3405, 3936, 4281, 3347, 3164, 3348, 3349, 4267, 
       3268, 3124, 3328, 3125, 3255, 3231, 3269}], Line3DBox[{3858, 3270}], 
      Line3DBox[{3273, 3790, 3812}], 
      Line3DBox[{3289, 3358, 3105, 3189, 3106, 4248, 3939, 3339, 3338, 3390, 
       3131, 3337, 3132, 4283, 3970, 2872, 3414, 3406, 3413, 3407, 4282, 2873,
        3870, 4158, 2874, 4090, 3040, 2875, 4091, 3041, 2876, 4092, 3042, 
       2877, 4093, 3871, 4159, 2878, 3872, 4160, 2879, 3873, 4161, 2880, 3107,
        3108, 4258, 3782, 4222, 3109, 3789, 3110, 3290, 2881, 3300, 4067}], 
      Line3DBox[{3291, 3359, 3111, 3194, 3112, 3227, 4238, 2883, 3137, 3380, 
       3138, 4226, 2884, 3874, 4162, 2885, 3875, 4163, 2886, 3876, 4164, 2887,
        4094, 3043, 2888, 4095, 3044, 2889, 4096, 3877, 4165, 2890, 3878, 
       4166, 2891, 3879, 4167, 2892, 3880, 4168, 2893, 3927, 4241, 3195, 3113,
        2894, 4223, 3114, 3275, 3115, 3292, 2895, 3852}], 
      Line3DBox[{3301, 3367, 3368, 3197, 3240, 3239, 4239, 2897, 3303, 3304, 
       3302, 4169, 3932, 2898, 3881, 4170, 2899, 3882, 4171, 2900, 3883, 4172,
        2901, 3884, 4173, 2902, 4097, 3045, 2903, 4098, 3885, 4174, 2904, 
       3886, 4175, 2905, 3887, 4176, 2906, 3362, 4177, 3958, 2907, 3928, 4260,
        3294, 3361, 3360, 2908, 3929, 4259, 3293, 3296, 3295, 2909, 4251, 
       3241, 3242, 3787, 3853}], 
      Line3DBox[{3472, 3696, 3697, 4295, 3471, 3983, 4296, 3473, 3984, 4297, 
       3474, 3985, 4298, 3475, 3986, 4299, 3476, 4405, 3647, 3477, 4406, 3648,
        3478, 4407, 3987, 4300, 3479, 3988, 4301, 3480, 3989, 4302, 3481, 
       3990, 4303, 3482, 3991, 4304, 3483, 4408, 3649, 3484, 4409, 3650, 
       3485}], Line3DBox[{3487, 3698, 3699, 4305, 3486, 3992, 4306, 3488, 
       3993, 4307, 3489, 3994, 4308, 3490, 3995, 4309, 3491, 3996, 4310, 3492,
        4410, 3651, 3493, 4411, 3997, 4311, 3494, 3998, 4312, 3495, 3999, 
       4313, 3496, 4000, 4314, 3497, 4001, 4315, 3498, 4002, 4316, 3499, 4412,
        3652, 3500}], 
      Line3DBox[{817, 960, 2324, 818, 1056, 2325, 819, 2326, 820, 2327, 821, 
       2328, 822, 2329, 823, 2330, 824, 2331, 2332, 825, 2333, 826, 2334, 827,
        2335, 828, 2336, 829, 2337, 830, 2338, 831}], 
      Line3DBox[{3514, 4329, 4014, 3513, 4328, 4013, 3512, 4327, 4012, 3511, 
       4326, 4011, 3510, 4325, 4010, 3509, 4324, 4009, 3508, 4323, 4008, 4413,
        3507, 4322, 4007, 3506, 4321, 4006, 3505, 4320, 4005, 3504, 4319, 
       4004, 3503, 4318, 4003, 3502, 4055, 4481, 3776, 3501, 4317, 3700, 3753,
        3761, 3760, 3754}], 
      Line3DBox[{3515, 3701, 3740, 3757, 4015, 4475, 3756, 3755, 3775, 4474, 
       3653, 3516, 4414, 3654, 3517, 4415, 3655, 3518, 4416, 3656, 3519, 4417,
        3657, 3520, 4418, 3658, 3521, 4419, 4016, 4330, 3522, 4420, 3659, 
       3523, 4421, 3660, 3524, 4422, 3661, 3525, 4423, 3662, 3526, 4424, 3663,
        3527, 4425, 3664, 3528}], 
      Line3DBox[{3529, 3702, 3741, 1037, 4476, 3759, 3758, 4017, 4331, 3530, 
       4426, 3665, 3531, 4427, 3666, 3532, 4428, 3667, 3533, 4429, 3668, 3534,
        4430, 3669, 3535, 4431, 4018, 4332, 3536, 4019, 4333, 3537, 4432, 
       3670, 3538, 4433, 3671, 3539, 4434, 3672, 3540, 4435, 3673, 3541, 4436,
        3674, 3542}], 
      Line3DBox[{3544, 3703, 3721, 4020, 4334, 3543, 4021, 4335, 3545, 4022, 
       4336, 3546, 4437, 3675, 3547, 4438, 3676, 3548, 4439, 3677, 3549, 4440,
        3678, 3550, 4441, 4023, 4337, 3551, 4024, 4338, 3552, 4025, 4339, 
       3553, 4442, 3679, 3554, 4443, 3680, 3555, 4444, 3681, 3556, 4445, 3682,
        3557}], 
      Line3DBox[{3559, 944, 4340, 3558, 963, 4341, 3560, 4026, 4342, 3561, 
       4027, 4343, 3562, 4446, 3683, 3563, 4447, 3684, 3564, 4448, 3685, 3565,
        4449, 4028, 4344, 3566, 4029, 4345, 3567, 4030, 4346, 3568, 4031, 
       4347, 3569, 4450, 3686, 3570, 4451, 3687, 3571, 4452, 3688, 3572}], 
      Line3DBox[{3574, 3704, 3722, 3705, 4348, 3573, 3706, 3723, 3707, 4349, 
       3575, 3726, 3727, 4350, 3576, 4032, 4351, 3577, 4033, 4352, 3578, 4453,
        3689, 3579, 4454, 3690, 3580, 4455, 4034, 4353, 3581, 4035, 4354, 
       3582, 4036, 4355, 3583, 4037, 4356, 3584, 4038, 4357, 3585, 4456, 3691,
        3586, 4457, 3692, 3587}], 
      Line3DBox[{3589, 3708, 3724, 3709, 4358, 3588, 3710, 3725, 3711, 4359, 
       3590, 3728, 3737, 4470, 4047, 3591, 3731, 4465, 4048, 3592, 4051, 4477,
        3762, 3593, 4053, 4479, 3772, 3594, 4458, 3693, 3595, 4459, 4039, 
       4360, 3596, 4040, 4361, 3597, 4041, 4362, 3598, 4042, 4363, 3599, 4043,
        4364, 3600, 4044, 4365, 3601, 4460, 3768, 3769, 3602}], 
      Line3DBox[{3616, 3733, 3770, 3771, 4478, 4052, 3615, 3752, 4473, 4050, 
       3614, 4503, 4065, 3613, 4502, 4064, 3612, 4501, 3802, 3611, 4500, 3801,
        3610, 4499, 3800, 4461, 3609, 4498, 4063, 3608, 3751, 3773, 4054, 
       4480, 3774, 3607, 3766, 3767, 3763, 4466, 3765, 3764, 3606, 3749, 3750,
        4472, 3739, 3748, 3747, 3605, 3746, 4471, 4049, 3738, 3745, 3744, 
       3604, 4045, 4464, 3730, 3743, 3742, 3603, 4366, 3713, 3729, 3712, 
       3732}], Line3DBox[{3805, 2851, 3023, 4073, 2850, 4152, 3861, 3833}], 
      Line3DBox[{3813, 3788, 3262, 3238, 3818}], 
      Line3DBox[{3820, 3257, 3847}], Line3DBox[{3821, 3166, 3849}], 
      Line3DBox[{3822, 3168, 3850}], Line3DBox[{3823, 3258, 3026, 3839}], 
      Line3DBox[{3825, 3259, 3838}], 
      Line3DBox[{3832, 3863, 4153, 2860, 3864, 4154, 2861, 4081, 3033, 3779, 
       3835}], Line3DBox[{3837, 3260, 3299, 4262, 3786, 3842}]}, {
      Line3DBox[{1584, 1763, 4069, 1585, 1774, 4077, 1602, 1785, 4085, 1611, 
       4158, 1794, 1622, 4163, 1806, 1634, 4171, 1818, 1646, 4180, 1830, 4100,
        1658, 1842, 4111, 1670, 1854, 4121, 1683, 1866, 4131, 1696, 1878, 
       4138, 1709, 4198, 1890, 1723, 4205, 2202, 1903, 1736, 4213, 2116, 1914,
        1749}], 
      Line3DBox[{1593, 1768, 4073, 1594, 4154, 1779, 1606, 4156, 1789, 1617, 
       4160, 1800, 1628, 4166, 1812, 1640, 4175, 1824, 1652, 4185, 1836, 4107,
        1664, 1848, 4116, 1676, 4190, 1860, 1689, 4192, 1872, 1702, 4195, 
       1884, 1715, 4200, 1896, 1729, 4208, 1909, 1742, 4217, 1920, 1755}], 
      Line3DBox[CompressedData["
1:eJwV0L8rxHEcx/GPBbEYSLG4DM7vP0A5ZWB2o9OVwY9OiIFFFJPOj8HlBsqs
y2RQJuUoJTr/gMmvQ36vPAzPXq/38/X5Lt/I8NTAZEkIYQyF0hDmy0LoLQ/h
RPbIdFUIMZm3TXDd+rEckqu2hDyyJblB/Ubu8R16O/Ztce4VK3xBtvGt2LX1
udf0Q9uLfo0WdwrN2PSmi9u2P8srRPkmLNsyfCdXxCUi/DgaMGffsjfyafeT
vEC9Poo67NhT3tXyjzhHDb/BV8ukrZJ7wBm+sW77knHbL+71PLL8pxzx3Yfs
t/3gTl+wncp3vCHGF3HAz3o/gyUs/v83/hY527Q7V+E7/AF0xT2q
       "]], 
      Line3DBox[{1747, 1913, 2031, 2021, 2096, 2095, 4257, 1734, 1901, 2020, 
       4246, 1973, 1721, 1888, 4232, 1972, 1707, 1876, 4229, 1967, 1694, 1864,
        4227, 1960, 1681, 4266, 1852, 1955, 1668, 4275, 1840, 2208, 2207, 
       1952, 1656, 4265, 1828, 2152, 1949, 4178, 1644, 1816, 1946, 4169, 1632,
        1804, 4226, 1945, 1620, 1792, 2216, 2215, 4283, 2218, 2217, 1609, 
       1783, 4225, 1943, 1600, 1772, 4269, 2161, 1582, 4278, 1761, 2159, 
       2203}], Line3DBox[{1748, 2165, 2164, 2118, 1980, 4212, 2158, 1735, 
       1902, 1974, 4204, 1722, 1889, 4231, 1969, 1708, 1877, 4230, 1968, 1695,
        4130, 1865, 1682, 4120, 1853, 1669, 4110, 1841, 1937, 1657, 4099, 
       1829, 2107, 4179, 1645, 1817, 4170, 1633, 1805, 4162, 1621, 1793, 4282,
        2214, 1610, 1784, 4284, 2219, 1601, 4076, 1773, 1583, 4482, 1762, 
       2695}], Line3DBox[{1750, 1915, 4214, 1737, 1904, 4206, 1724, 4143, 
       1891, 1710, 4139, 1879, 1697, 4132, 1867, 1684, 4122, 1855, 1671, 4112,
        1843, 1659, 4101, 1831, 4181, 1647, 1819, 4172, 1635, 1807, 4164, 
       1623, 4090, 1795, 1612, 4086, 1786, 1603, 4078, 1775, 2762}], 
      Line3DBox[{1751, 1916, 4215, 1738, 4147, 1905, 1725, 4144, 1892, 1711, 
       4140, 1880, 1698, 4133, 1868, 1685, 4123, 1856, 1672, 4113, 1844, 1660,
        4102, 1832, 4182, 1648, 1820, 4173, 1636, 4094, 1808, 1624, 4091, 
       1796, 1613, 4087, 1787, 2702, 4485, 2804}], 
      Line3DBox[{1752, 4150, 1917, 1739, 4148, 1906, 1726, 4145, 1893, 1712, 
       4141, 1881, 1699, 4134, 1869, 1686, 4124, 1857, 1673, 4114, 1845, 1661,
        4103, 1833, 4183, 1649, 4097, 1821, 1637, 4095, 1809, 1625, 4092, 
       1797, 1614, 4486, 2805}], 
      Line3DBox[{1754, 1919, 4216, 1741, 1908, 4207, 1728, 1895, 4199, 1714, 
       1883, 4194, 1701, 1871, 4191, 1688, 1859, 4189, 1675, 1847, 4188, 1663,
        4106, 1835, 4184, 1651, 1823, 4174, 1639, 1811, 4165, 1627, 1799, 
       4159, 1616, 1788, 4155, 1605, 1778, 4153, 1592, 1767, 4152, 2697}], 
      Line3DBox[{1756, 1921, 4218, 1743, 1910, 4209, 1730, 1897, 4201, 1716, 
       1885, 4196, 1703, 1873, 4193, 1690, 4126, 1861, 1677, 4117, 1849, 1665,
        4108, 1837, 4186, 1653, 1825, 4176, 1641, 1813, 4167, 1629, 1801, 
       4161, 1618, 1790, 4157, 1607, 4081, 1780, 2763}], 
      Line3DBox[{1757, 1922, 4219, 1744, 1911, 4210, 1731, 1898, 4202, 1717, 
       1886, 4197, 1704, 4136, 1874, 1691, 4127, 1862, 1678, 4118, 1850, 1666,
        4109, 1838, 2172, 2171, 4187, 1654, 1826, 2168, 2167, 4177, 1642, 
       1814, 4168, 1630, 1802, 2119, 4258, 1924, 2706, 4088, 2711, 2704, 
       2808}], Line3DBox[{1758, 1923, 4220, 1745, 2211, 2210, 4211, 1732, 
       1899, 4203, 1718, 2183, 4273, 2182, 1705, 4137, 2199, 2198, 1692, 4128,
        2179, 2178, 1679, 4119, 1951, 1950, 1995, 4271, 2174, 1936, 2173, 
       1935, 4242, 2013, 2170, 1932, 2169, 1931, 4260, 2125, 1928, 1927, 4241,
        2010, 2121, 1926, 2120, 4222, 1925, 2809}], 
      Line3DBox[{1759, 2194, 2193, 4280, 2206, 1982, 2212, 1981, 4281, 2213, 
       2156, 1976, 4233, 1975, 1719, 1965, 4274, 2184, 1964, 2190, 2185, 2001,
        2201, 1962, 4277, 2200, 1961, 2019, 2181, 4129, 1957, 2180, 1956, 
       2133, 4272, 2177, 1954, 2017, 1953, 2082, 2015, 4279, 2204, 1948, 2205,
        1947, 2187, 2186, 4240, 1993, 2145, 2146, 1934, 2124, 1933, 4259, 
       2123, 2166, 1930, 2122, 4223, 1929, 2117, 2132, 2714, 2770}], 
      Line3DBox[{1986, 1938, 2195, 2197, 2196, 4235, 1984, 2142, 2209, 2143, 
       1983, 2114, 4267, 2157, 2113, 1978, 2048, 2049, 1977, 4224, 2138, 2137,
        1971, 2135, 2136, 4264, 1970, 2047, 2046, 1966, 2044, 2045, 4255, 
       1963, 2043, 2042, 1959, 2040, 4263, 2134, 2041, 1958, 2039, 2154, 2038,
        2018, 4254, 2085, 2148, 2086, 1998, 2084, 2109, 2083, 2016, 4253, 
       2078, 2147, 2079, 1996, 2077, 2108, 2076, 4243, 2014, 2072, 2073, 1992,
        2071, 4251, 2070, 2815}], Line3DBox[{2802, 1987}], 
      Line3DBox[{2426, 2615, 2656, 4366, 2629, 2414, 2603, 4358, 2627, 2399, 
       2588, 4348, 2625, 2384, 2573, 4340, 2624, 2369, 2558, 4334, 2623, 2354,
        2543, 4476, 2676, 2675, 2689, 2688, 2339, 2528, 4475, 2673, 2672, 
       2687, 2686, 2324, 2513, 4317, 2622, 2309, 2498, 4305, 2621, 2294, 2483,
        4295, 2620, 2279, 2482, 2816}], 
      Line3DBox[{2733, 2748, 2657, 2630, 4464, 2415, 2604, 2654, 4359, 2628, 
       2400, 2589, 2653, 4349, 2626, 2385, 2574, 4341, 2639, 2370, 2559, 4335,
        2355, 2544, 4331, 2674, 2340, 4474, 2529, 2671, 2325, 2514, 2694, 
       4481, 2310, 2499, 4306, 2295, 2484, 4296, 2280, 2817}], 
      Line3DBox[{2764, 2713, 2131, 2812}], 
      Line3DBox[{2768, 4262, 2712, 2130, 2769}], 
      Line3DBox[{2791, 2669, 2666, 2693, 4480, 2692, 2691, 2690, 4479, 2404, 
       4453, 2593, 2389, 4447, 2578, 2374, 4439, 2563, 2359, 4429, 2548, 2344,
        4417, 2533, 2329, 2518, 4321, 2314, 2503, 4310, 2299, 4405, 2488, 
       2284, 2821}], 
      Line3DBox[{2792, 2749, 4498, 2418, 4458, 2607, 2405, 4454, 2594, 2390, 
       4448, 2579, 2375, 4440, 2564, 2360, 4430, 2549, 2345, 4418, 2534, 2330,
        2519, 4322, 2315, 4410, 2504, 2300, 4406, 2489, 2285, 2822}], 
      Line3DBox[{2793, 4461, 2750, 2419, 4459, 2608, 2406, 4455, 2595, 2391, 
       4449, 2580, 2376, 4441, 2565, 2361, 4431, 2550, 2346, 4419, 2535, 2331,
        4413, 2520, 2316, 4411, 2505, 2301, 4407, 2490, 2286, 2823}], 
      Line3DBox[{2794, 2751, 4502, 2423, 2612, 4363, 2410, 2599, 4356, 2395, 
       2584, 4347, 2380, 4442, 2569, 2365, 4433, 2554, 2350, 4422, 2539, 2335,
        2524, 4326, 2320, 2509, 4314, 2305, 2494, 4303, 2290, 2827}], 
      Line3DBox[{2795, 2752, 4503, 2424, 2613, 4364, 2411, 2600, 4357, 2396, 
       4450, 2585, 2381, 4443, 2570, 2366, 4434, 2555, 2351, 4423, 2540, 2336,
        2525, 4327, 2321, 2510, 4315, 2306, 2495, 4304, 2291, 2828}], 
      Line3DBox[{2796, 2667, 4473, 2425, 2614, 4365, 2412, 4456, 2601, 2397, 
       4451, 2586, 2382, 4444, 2571, 2367, 4435, 2556, 2352, 4424, 2541, 2337,
        2526, 4328, 2322, 2511, 4316, 2307, 4408, 2496, 2292, 2829}], 
      Line3DBox[{2797, 2663, 2659, 2644, 4472, 2665, 2417, 2606, 2643, 4465, 
       2402, 2591, 4351, 2387, 2576, 4343, 2372, 4437, 2561, 2357, 4427, 2546,
        2342, 4415, 2531, 2327, 2516, 4319, 2312, 2501, 4308, 2297, 2486, 
       4298, 2282, 2819}], 
      Line3DBox[{2800, 2670, 2668, 2685, 2684, 4478, 2683, 2682, 4460, 2681, 
       2413, 4457, 2602, 2398, 4452, 2587, 2383, 4445, 2572, 2368, 4436, 2557,
        2353, 4425, 2542, 2338, 2527, 4329, 2323, 4412, 2512, 2308, 4409, 
       2497, 2293, 2830}], 
      Line3DBox[{2806, 4487, 1615, 1798, 4093, 1626, 1810, 4096, 1638, 1822, 
       4098, 1650, 1834, 4104, 4105, 1662, 1846, 4115, 1674, 1858, 4125, 1687,
        1870, 4135, 1700, 1882, 4142, 1713, 1894, 4146, 1727, 1907, 4149, 
       1740, 1918, 4151, 1753}], 
      Line3DBox[{2818, 2281, 4297, 2485, 2296, 4307, 2500, 2311, 4318, 2515, 
       2326, 2530, 4414, 2341, 2545, 4426, 2356, 4336, 2560, 2371, 4342, 2575,
        2386, 2640, 4350, 2590, 2401, 4470, 2641, 2655, 2605, 2416, 4471, 
       2664, 2642, 2658, 2661, 2662, 2831}], 
      Line3DBox[{2820, 2283, 4299, 2487, 2298, 4309, 2502, 2313, 4320, 2517, 
       2328, 2532, 4416, 2343, 2547, 4428, 2358, 2562, 4438, 2373, 2577, 4446,
        2388, 4352, 2592, 2403, 4477, 2677, 2678, 2679, 2680, 4466, 2645, 
       2660, 2646, 2833}], 
      Line3DBox[{2825, 2288, 4301, 2492, 2303, 4312, 2507, 2318, 4324, 2522, 
       2333, 2537, 4420, 2348, 4333, 2552, 2363, 4338, 2567, 2378, 4345, 2582,
        2393, 4354, 2597, 2408, 4361, 2610, 2421, 4500, 2838}], 
      Line3DBox[{2826, 2289, 4302, 2493, 2304, 4313, 2508, 2319, 4325, 2523, 
       2334, 2538, 4421, 2349, 2553, 4432, 2364, 4339, 2568, 2379, 4346, 2583,
        2394, 4355, 2598, 2409, 4362, 2611, 2422, 4501, 2839}], 
      Line3DBox[{2837, 4499, 2420, 2609, 4360, 2407, 2596, 4353, 2392, 2581, 
       4344, 2377, 2566, 4337, 2362, 2551, 4332, 2347, 2536, 4330, 2332, 2521,
        4323, 2317, 2506, 4311, 2302, 2491, 4300, 2287, 
       2824}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXk8lt279y9zhAYzyRTKlChTHImUFGVqLmNCkqkMJSRDCSUikqEMZcgU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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{391.7740023227821, 244.5116021242269},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{2.794965259826799, 1.734282780520269, 0.7939977541228666},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.624019001617729*^9, 3.624019127973956*^9, 
  3.6240193328106723`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Rearragne", " ", "for", " ", "more", " ", "efficient", " ", "code"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Expand", "[", 
   RowBox[{"FitFrGGXSimpleCorrelated", "[", 
    RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.624019886364691*^9, 3.6240198955132546`*^9}, {
  3.6240201620164976`*^9, 3.6240201627855415`*^9}, {3.6240201974325547`*^9, 
  3.6240202322975492`*^9}, {3.6240273066640916`*^9, 3.6240273171046886`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "10.864878331300458`"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "-", "Roughness"}], ")"}], "0.2891837804614315`"], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "10.864878331300458`"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "Roughness"}], ")"}], 
    "0.2891837804614315`"]}]}]], "Output",
 CellChangeTimes->{
  3.6240199874325123`*^9, 3.624020163415578*^9, {3.624020199186655*^9, 
   3.6240202326395683`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"HornerForm", "[", 
    RowBox[{"FitFrGGXSuperSimpleCorrelated", "[", 
     RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], "]"}], " ", "//",
    " ", "TraditionalForm"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.6240214540691843`*^9, 3.62402148547198*^9}, 
   3.624021518736883*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"1.`", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "10.864878331300458`"], 
        "-", "1"}], ")"}], " ", "Roughness"}], "+", "1"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.6240214604345484`*^9, 3.6240214858920045`*^9}, 
   3.6240215193039155`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Simplify", " ", "the", " ", "complex", " ", "expression"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"FitFrGGXComplexCorrelated", "[", 
    RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.604295223691265*^9, 3.604295225112269*^9}, {
   3.6043160081469517`*^9, 3.604316011387137*^9}, {3.604327937746286*^9, 
   3.6043279520181017`*^9}, 3.604328257042548*^9, 3.604345089901016*^9, {
   3.6129770107105565`*^9, 3.6129770262554455`*^9}, 3.6240198534577084`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "10.864878331300458`"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"0.29847502436794354`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.29847502436794354`", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "Cos\[Theta]V"}], ")"}], "10.864878331300458`"]}]}],
     ")"}], " ", 
   RowBox[{"Log", "[", 
    RowBox[{"39.41149727672321`", "\[VeryThinSpace]", "-", 
     RowBox[{"39.00289316713873`", " ", "Roughness"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.604316004643751*^9, 3.60431602665701*^9}, 
   3.604327965676883*^9, 3.604328489141824*^9, 3.6043292402297835`*^9, 
   3.6043451853914776`*^9, 3.6129771244430614`*^9, 3.623996058717365*^9, 
   3.624019854132293*^9, 3.6240273311904945`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Test", " ", "with", " ", "F0"}], " ", "-", " ", 
    RowBox[{
    "Note", " ", "the", " ", "discontinuity", " ", "of", " ", "the", " ", 
     RowBox[{"function", ".", " ", "Discontinuity"}], " ", "is", " ", 
     "expected", " ", "for", " ", "all", " ", "dieletric", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.02", " ", "-", " ", 
        RowBox[{"0.2", " ", "but", " ", "not", " ", "for", " ", "metal"}]}], 
       " ", ">", " ", 
       RowBox[{
        RowBox[{"0.5", ".", " ", "We"}], " ", "chose", " ", "to", " ", "not", 
        " ", "consider", " ", "rough", " ", "dieletric", " ", "in", " ", 
        "our", " ", "approximation", " ", "and", " ", "focus", " ", "on", " ",
         "metal", " ", "because", " ", "it", " ", "will", " ", "be", " ", 
        "barely", " ", "noticeable", " ", "for", " ", "rough", " ", 
        "dieltric", " ", "anyway"}]}], " "}]}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"GetLerpFactorFrGGXCorrelated", "[", 
     RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "0.04"}], "]"}],
     ",", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6043298660745797`*^9, 3.6043298871387844`*^9}, {
   3.612977184151477*^9, 3.6129771930309844`*^9}, {3.612977233095276*^9, 
   3.6129773999588203`*^9}, 3.6240198710517583`*^9}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJy9vWdUVknT94uBMYcx54Q65qyYcBtGZcw5Z8acc86OWUdUzBETZkVERTGA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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1m3scVlPWx89zznM/z6PGZQhDhoxLIWIoKnIrEmWM3EvGJVN40XVe45b7
kHRBGUSii3uGkXkzXVEKub1UzDszKBQmQry/b7/lj/NZ69ln73322WfvtX7r
t/azU//BvQelSZL8vpgkmeQRpSSpSR4peZyUKSrsJflJI0n2KSfJzZILJO9X
nb9XkqS36u0pvY/kSbo6Sv+tZPs8SR4pJEnXZpKsVpt91eYmyXW6DpZ+g+QW
euZc9b+z6q3T9aaui3V9rX7/LPleNUn21/0Ouh7Q75W65uj6pa6NudutridJ
59xlH0vvoWfrkckxjF/X9tJ7SY5TX6dKLte7LFB/bXSNV5suGstxqtNV8kj1
s0hl10sepesl6R9QprH2VNtR6v8iXfNV/xaVPawHdVa/P6jeLL3L7ZI3Sr6k
CV2UekxrVK+D+r5Rco2eOU/XGJUPVbt9VKeg8dyqvi+WfptktlmSPKey21T/
cD17geq+LXmd7vGhrpfsr+t29XO25EN63i80ntGS+2s886QP1hhL6v9Rtd1X
sruuptreqHn9mfreW/rlKluu3xeqTln6BbraqLyt7rfU85bp3gz1d5H0Jepz
qPrcXM9sqE6qNnXVf0ryAcluDa8T1svshueZ+f5c7d9XP7tK3ql+uqufbdRP
f5WNVNsPJc9S/dVqO0Rtv1KbraXfIX28rhZ6pztr7uNy1a/p/gr19bp+t5Gc
pbKWGk9LyWd1bSl9S8k+Veu9Jc+ser4/U5ujpddVfpTkqxpHovIvNK5DUpfz
e4ae2VbqGMm+anOJyv5XsqI2T0jvIJlpTL/WOM+SvCz1nPxdbdprTKdJ7qa+
L1G9PVX+g+QZesY/1bai+331exuVnyy5h+qdnngvnCP9mcT7a4Xq/k3Xtrp+
rnF8r2ct4xsUrA+RHKl6W+recMln1d9WKmutOldrTEslV2rMI6RfoPI3pB+U
u7+Ves5HanOM2l4n/Z262x6jsR2l78a0dJd8XGUbMrd/M7P+P7p3qPocLb1b
zWXfRp2JWXwD9qH0T3StUv0Dc5edkvtZe6tsZ+k3q/1+es6nNdsB9uAN2ifD
Gn7XEXWXs8fvVp1HpP9J+ijJRO366J2XSh+me8ep/HlskZ65VtcU/d5T8k+q
s0fBfdEna2xfPbussunSj2J9qt7JDe/LNWGLXpVcl7lf2tD2A/W/p/q5UPrt
dT+bMfxQ9JgY21TJdbpuUvkXkp8zx9LXsjdzr9OTmAc97wmVjZa8SXKcyv+C
/dDvpySnSX6oZ2yH/ZEcn8Va1/W6fu+Q+Nv11TU1sV09Qfqdie3Mx7r2KttG
NTXuLir/Y9n7FJvXRmOYIP1q7IfkdNaHyufpXb+VPpk51/rsWfX+OlbyGo3r
ZpW/LHms+vqZ9J6S18a7T+Rddd0mfZJkr6hzvOSf9Zyi9HtLnnfm/2Y95+ro
8y7JefSrZy2QnKzvMqPmNck8jFfdB6R/rHsjVecTyevjWTMll+s6SeVF9T9Y
egvGL3kHNlfyEclheue+modd1V+ma7Tq7KM+/6m+r5HewLaUvcbfVNlfYz1t
rnEcKf0hlS/U/U6qN0r6tpLr9ft96f/S/dekPy59ScX+4JCq/cPrKn9C5fNV
frb6ekt9XlWzPTw1tZ3cSr/7qvznNc/5Lfg11f9GbVeq7WUqH6Yxvyq9VdP2
CFuBzVhddvk4fHTZtnqF7n+dehwb9PvnetbvpW/FXsxt87H9r0qmqved6rxQ
9vpZqPLvVZbpuk+/l5f9LJ65UmP7TOWreLdoO0b3FpW9DvEZ/cI34aP217yf
rPI2Gufi+C58nwvVfqL0/6j+ItXdUf3crd/XVDyWOZLrNM7PVe9tve9OTduH
7dXPolgzrJ2vJLup7Qe69wvVfUO//yjZUNtTpB8uvR++I7Wf2l96D/Ya76jr
QexE1fa7a/i1zqkxyAnqI9W96dLbS85V/b7SE+lfFlx/mOStqneo9D9J/nfB
+gjJ+1XvUunb6ru8qLYnq+xHyTMKnuPpTfvbo3S1V9l2KmsreR/vrmuC9F3C
X+GfLtLvj/SMj6V/LDlDdT6RvlF1btB1GNiAOdDzeuh7jNX9R3V1UrvTVLa2
4H7wcRtUfp/kHqrfVnpn6Y9L9lS9BwPvHazxLdH9KWAcXdeq6Y4NfzO+XRvd
20X6ftIflFyh35+q/3Y1z+Eo/X5G7Y6QfEBtF6jOOVW/F+/XOXAX+Iu5ZE6Z
/+EF66/p3qiCv3EJjKJ+t1e9M9THJ3VjK3DfYPwoGKDmcuoMUfmw1G1ZG8/q
dy/6Br9U7F9bq11V+nvSd5T+W9XZQfKv2BmN6S2VH6DfRZWPTdy2na7T1e89
fGfuST9MclXdvhUfu13Te2eQ9Olho7CLT+tZ5zL/GmdVe+NK6atVvjDWP35q
ovo6T/oWqjNC7Qfo95Pq7ytdl6rs6MBjYDkw3Q25MeSNufdOQXoX2qjfTnrU
WMktKsbNO/E99LsHtqLo71JR/SMlL6saE4INsW8bVf9g9ouugvSq5MkVY8uV
mptD9L4jpN/Dd2gaw4BlTtO7fA520e+XVX+w+rxXbRdj+1RelP696p2r+wdJ
dlDbIdK/1fgPTD2f3+v3U+Blyb9VPM/M/wvSX6n7/ue593ZJ9btJHqJ7H6v/
vaTfU7aPZj0zNtbmlZIPlz1m9j7f6FrJQU1jjM0Df/wr7MHspvcbewZct63q
fhD7cXtdrxX8XpdWvY/YT9tVbU+Z/176PUvt3tAzd5b+YeyXzTTuThrzLbnn
c13gSeb5i1hvV+g6KLUdw+98GvZncIyH/Uv/nxWM7Veq7u26Dsan5p4T5qa9
vsUK5h//2vA7ttD8rakb4xA/3VF0vFbSevxL03tpP8lJugZW7GvAQeChxZnX
xSvhU/4bOy95heSQktf20JJt7I3xDSeGf91Ncr3kgWo7TfJXTcdQxFLj1Gag
yseXjJkZ7zcV2yxs12PSX888J9MKxp3gz8Nq9nF36jqh4G+3WFcPvddTmWO3
7gXb9oviO04O3wGWebbpbzNaYxiYeu+cpHv/p7lqqbGMl/yo4G96bO79QWx4
NP4j9zx0lxwKbsSOY7/Yh3rOg+rzn2rfIA5q2D4TKxEzfac6L9NPbl86WtfX
ie0Ccwjuwq4foTqXqfjfufFY29xYG8wNHseeYldZ/6yR13Wdjr3DP+MzpL8r
+Y6ufaUfVbGPxlcT6+Fvv1LZc+prabTdITeWAGscWtoEs5NuYDb1cRp2nmFK
P0f6U9I3S22jsc+9cvvufsSOat+SfRq4pl/B2KgzOBCbX/L6Xa7rdwXHm+dK
tpDslznOIca5r+q1sXXNPqIRPnesvt1YlXWXPD6wEDglrxpnEueCb3gmuOxb
vrH0X+X2cdjaeyveT4NjbZyVGSO9KP2tijEb2G2m6u+j8gdUNkTfco7KB9Vd
d1DUf7diSVzZKjeG/H3dfh98dIb6qOfGAI+pfEDgE3DKlSWvu6tKxlPgKuZx
O9XrKbm+bowBN9I7OBX6uUP32hKDhj/iG00E8xFzqc3vJPtqvMul3616neFv
JPfOvMdWp+ZYLk/sO/GhF1WNBbBpzBc8BGuPmAA8BC6akzm+Jc7dUPecUpd9
dFnmuIu1Bc5kDvvVHUez31eVjSOJqbfOHVMRW32p514X8TVx9ha5v91Zatsl
sAHfHSwFppoMnxFxMWsFnEF7cEdHlQ1Q2anY0/Ajv5a8JvgQeJGWRX/vFg1j
4ydVp3/d/X0X8fX2kjPV37UFY0ywBGsdjIkvm8x6rhgzg517qp/eKj9TclrY
pHGJfSc+9HrVnRPxP3HHrMz2ijb4NnwcMcO3EQcRD4EFsBVgl9ewMwXbQLAo
3/9R/JGeNzcx/pzV9HviX8ArxxeMX9DHp8ZB8C5X8B5qc3zu/deU/CE3T/Kj
5DbMger/AZ9TMYb/Rv3+u+KY/qaKOYNbC+YcrgqcDF7evelyYvwlTWPQnSVn
FmwH4A2/0r2nE6+lLDgB4txWmbE6z2UO7wo8MF/tB6nvfZvmjpar7FPNOYTl
j6n3UmtwVGYODm6PmJp4j7XDGgJPwpfAS8BPFFinYdf+nDv+3Vi3Xdms6Hjq
Oz1vQs3rpWVwUZThQ7di/Ukvlxx7EoPCFcBlDZV8LLAfceo1WmdHarxfNYzz
wUtjyo7Jic3pC3wxV9eefO+GYwH2/o4lv1dryclqe57kP2rGg7wHseEuTe/j
E9Quyx3j4IfhNy7U/XWSj4B7M/8eXjdHBJ7EL42M9YDPJ978WuM6X/f+Qayj
dxtAzFl13AHfybqaTVxVs+1nPZweXCWcJTwOvC7YaoTG+7T0kZJnqv4S6cMl
90ptW/CXZbXpgz2Eg2p4Hg7LXT5B9/cmtlKb/6jtFXBaDcsvm17TrG34uKeD
v4XHvU7XfPau5IbcfvZJYm6Nrahx9SyalwMnwPWCG9iP61RvZuZ3wYceg/9K
vT66xfc6vOwL/QjJ3g3b0t1z2xA4O+zIwprbwa+wjvAdrWr2/ezr1bnXGjwn
32Nj+H54b/gJ+J/OcApqs7/m7xbJebo/N3W8MUDPPSUzF8qcrJd+fsM4D7w3
omGejfelLe+M3qFkTHiYxr5A8hOwoPqcFePHtmKXhwXHCNfYPTAPsQZ2ExvJ
njiiYU6+a+41BsYD68GnwKvAjcCXPsT+qpifWxIc3bZ1c2VgrdkqmxTY4vLA
k+DKm3VVde+Wnzh8lS9Wf99EvICdhTdj308gNiLGy9wPfPWlgf8eVZv1eqcr
4Wf03OHELKq/QuWHqO972FN6n/mqXys5VgYf0Has+t9N8gu1SzPHTdiNFzPb
F2JW4lr2LH4RTpuybXP7jesCIxEHYf/InyxTH0tT73d8FT4LP0Tc11rlIyV/
E/kU8io9iO8L5s4eTf27Iv2Cijmo/6jPDZqf01Q+gZhU73O42t2LPaubhwSL
MnfM4XjVeS64RzjIboH3dig6fsCmzlPfRWx0ZnwIZwhWqeW2MzeofrvcvgLu
A94jq9rOv1JxXgGuCT7ti8zc12PY5aa5A3jUq9R+F7W/MvfeW5sat5MfIefz
neqd2TRPQbyJH9hddU6vOZ7EFy8J/gEM/oz0m2LNsHYeg79T+SzwYGb+BGy9
tOL5XlN13gEcsUplLVRns8x+kRwE6xwufZne/dKS8zJ3l+zTJ5bMVYHXiCfB
eOTEnm4a/4EDwajkLchfwMuBccA/xNL4TPgguMVPq14Dr6rOUj3jwpLtB7wW
6wP+cEzJ8fUdJecywJ/vqHxLbG1mfAb2Zo3Ac7dtOiZ+pGmuFj72uLJxPxjt
PN0bX7SffJbvXjdewndgU8EN4BLsPTo4ZD0YPDMf1Dtw6W1hE8BU4Pe2kUOZ
Bt8Q+aldi94P7ItLcueT4CqJDclbwV0tahoDE3OBmwc2bEfJcUwte88Oq/p9
ee7ciLGJteGb4ETgbeBvlqifwZn5jo+kP5b5u4NjiTvAio+wV1LHs+zFhzLv
R3zQVOlHNjxuxv+g5H6p56JXYJnXAs88jK3KzGWM1BimqvyHimMBvvuJ6mdS
yWO7p2SMDFY+T/WXZZ5T7CP8GvM6pe46l0cOo1+MH/t1otZER9WdWbF/Zq7g
Hr5NHceNT7zH2GvwMANrjgWIlweUrJ9Tco6QNbhdbl6amLK/5HLJN9inibE0
sTeYs1/N5exr/CT49frE/urxmFt8AL4A2wWnBbdLrMVeXB59vhH6jILxCrjl
7ro5cca8KVeV+rms+4MyY1/GMDzwA7ke5oy5I0dDPAQ/ASaGq1ga+rLgLqhD
O9bUXrnrvhp18F9898MbnvNFEb8cFDwV2LVPw9zv2bnb0S/fCzxDX8R3+H4w
ABgVPPBy5vd6KbOOX0S+Ejq5UnD12rCxxO9TEsfrrD1i9tuKzl9vIDdUdJ79
R8kH9P3eY+zSp1c9TuJZ8M8YtZ8Ejg1eBX4Fm8aaB3P/Vm1OkTygaEyH359Z
dew4KeLHSRFLEuPDLY0JfgmfB2aGB3gGjCU5tW57wPegr7H4mdQ8yVPs88Tj
YX88HHwHeBVe5wzJN+rOa5Ef25TnSs0dtNUebiH5isZ5YHB3B5UdjxGXEefD
bRIjX1+2P8QvFhL7/kkx/kbD+6HZMHdCXhO7/IuG+bH39dyT9IxjVNahaPtK
ffbO8KpzBOQK4I3BYlfoWSfXbbPhK7Ah4CLmYnbZePVKtbs/vhHfanbuWOav
ufO692gchyTO2WNb7i865iWPmmtcz6TOpe6YOD8J38U37tpwW845UPZglJNf
YS2xpuBXWV/kNLsFBl5JLJ7blvC+F5Udt5EfXxV4F6xL/ANexe/AK8zIzH2A
halzQeI8JN+Jb9Q1uFA4Ub7bpvKCOTns6nO55Z1hY+eEnyL+I27Dx4yNOJa9
mNaM56hP7AzPxlpijTGHrL3nc/eBD8D+Hxd+jXwj+Tm+y9Xqrws2N3O+G1+x
ZfjH5wsu3yvxHJO3Zp7hSehnofqfnbqcvDVxCPHI1bltPnEs3AS2Fu5sfOwl
9tTPSrbHH4X/gpeeEOuiGevwvtznF/jW5OenNc0jEPuQb+yTOSZiP50YdmZp
2Ct0YlW+TUX9XZKac2etTonngnXgy9j7+1XNwf8mcy5vUOjYXuKGU8Mmg0V5
x1MT23k4O3KSjKV3YPWOwat3kmxVN25cqrH017W6YN6PczW7ZsbKm/LMmbHF
uNApB6NSBz6hvebtYN3PSx47z8E+b4p3w3ezt9nj5EJ2yp0bhcti3a0O/8ve
75QZH3+Wmyc5O+Jg9i+4gZwKfMqkqnHBjtE/vEdXcEvDOHZAZiz7eepYcmj4
916Z8WgjYi5iL3wSz4KH7ZK5n87hN6dF+YAYD+ParejcfaHk/B+cLPgPO3Rs
Zl6uY924AB6eMdEnZ5zAAMSicMKTyubc/gtuqWouqqj3G1o2l8LZEjgFxgTH
8ELqdc+aJ6bsEuMEq/XPjH37B3Z7McrBvWC6VhG3vh1jBbOypuFpzs7M1VD/
rGhLTudiPX9B0zF+n1g/+PxqrD3yKcRJt5f9fofGeMi546s503F23dzsYM3b
u+qrVPNZsplN87PksueDOTWX1zaMj/oFtuf8FTjk2MQxGmeKyC0Sq70YOmXo
4FHsyZywD8eprxcyc2L4TMrxm6xzuNl9gqsA4xH/EI9j07Hn5FzgV8lb7NCw
PrFu/LlvZvzGORO4EdY099vHd8evMAfkN8mHgSVpy9poH32SByc/PKJprm5e
9MPZq4WBtchFPJE5FlodOniR3OyTmXMNxFjkSIizNqTGcvCQxHnYNGI9zoiw
h4fn7mevzPiG+Iq+OQNAfh8/dF7De5r9/9O+XxD7HX6FZw1L/N6MmfxTnjnm
/8lXo4M9wEHMP1hoz4r3Lti/Q/joFiXjYrAa+6RDxd/hybL3b6tYk9g5bB/r
bVHUZ37YywfEPGBrWJtgQzAFnC8+e5WesZnkQj1zn8ilPl70uTTWDXz12Ch/
tOjziQeEfeDcI/sRnv/xps+fkY++PMZGjMw44VhfV72tq36P8yM3RF8PwUXn
PmeCzrmygbo/r+ncLXbr6aL3136ZeTR8AvlpcgHEx21D/ya3zbir7tx1u/Dp
xIasYbg1xt4h5oR9BubGnpwV59zSkMQ98G3wOPgibCnlB8Y94ldsH3Yvz42Z
wc5gecrB85wleF/t3mw6dodPJ09AbAUnxjv3qHtdrsmd64UDxu+zNrPwuchi
rBNwBHiC55H/hNsFq8LTpLGupodOObwG/Aa5+/GBkyeUvAbzqE88jg4/cKHG
82TB/rZb3fsHrgJ82D51TEoufojkO03neeEP4Nc567Jr6u/H2UrOfPCtl+W2
T8Qd5LUZN/lbziWSY8PujYpvxze8Iuw89p6zpdg42s8Je8d5CLAe/XOehH1U
jL28MeII4omf7AJx18W5c3jE42BL+l0s/cu69y68F/zZ5mEzsYfEErwb5zyw
KXxLzgXR3wzJ1g3bIGJY7A05TtYVdohybBG8+VbBT06J82OcIwPvgHuIgTnD
SR5hTcV8E7wTZyrSks+AcRbs2pJxzaiSYw/a4j/IR3RMjcOJR/Dl+HHsEN8O
WwSvDScEz43Nh/P5Mvd5UIKIJRr/Z1VzRHBFnEeCV6Scui3CL/CtmmHHGjFX
cIasR/ITrEls5+p4d7hwnk3u/A+RQyeXznrCHvcIHozYmrW2KLAI8dQp0S+Y
uXvqnDTlnCHaJb57XX0tkH5Z0dwgcRJ50al6xxPLPn8Hz4XPnxz5Gs6/3N/0
mTPwFedg4PbJlZDL4Bzr0REDkpvHX5ErfC+37eoY+OT91PEDWKxHxGLYWLAw
+I6zKt1jzLfnXpOcqZ4ZcShn7eYXfX67jeSnFfPgnNXpGvwkeekFVfO0CyVf
KtpW/6roc6ucX/1l0WdG4cDJQZCrgLfhTAu5fDAy4zkhzq5zhp1cM/t7bdWc
Gtwa5884N4yv5fwM3Bw2jjMzi7lSn5HiPANnmcfBFeTmeeCi4GeZB/i4t3LH
T7vXzWniKziDDZcPhgA/ELPw+5Xc5xXhUPC/zP0eMf+cJ+Z7gLHAHbQlF8B5
MNYX/FAW7wVnAK8Fvgfbv1T12lhUdS4JP0B+m1iHmIc4CF4V/8E5jbfrjoE4
wztX73Zu1TxtKTde6BmxEf3Dm3GOCNyyDXFl7n12cN2xI3Em779C5ecTRxCX
5R4XPNutuiZovB82HG+2TR2T4t/wc3wzMB5YChzFWTjiJM5cPN80VuB8NWd3
wAScB+kTbanHvmJ/Uc65HfoHP3O+gj45swFWaR/7kPgOG4L97ETeln1ed46B
XANnd/sEBgAjDKibhySvDfYg1sI2bax5bl/Knb+CeydWR54WOmft0Dkbz5k0
MDxYnvl/IdpylpPzLsTH+GtwDGvortycHjl/zrtyrmx67vNE+Cw41uM1vnaS
7eLMJGfjyEmAR8AiYJIBoYNJODNJPnCNxrC+5th+fm6u5pnQ8RtDU+fExwTf
+3DRPoVc68i68+2c62Be8KHEqfwX4MSI+4j/2sXYKiXzBcT9xP/gOXDdiKrz
U/gOfAvnyojDyTNwZu/dgs9U9y35/wWnlJwbIn8MboDHwvfDWd0V5TwDHurh
8E3wN/A4cBRgBOqDAeAuKIfb6RVzzvrm7C84BX//RNh2/Cp2G24U283ZBXgC
zqGwBsGZrGHOYnBev3XivCQxALECNn5s2EZsBWd3+N8HZwLxh62qPkO4aR/U
jOPAfOxh7DBxwiZOK/eZMDgfcBkxL9iM/cjZIP7PUqj4+fBAveLbwdljv/vF
/oJfoH9wIzEV5WCRP1Z8n3waOAGeHR6A81MDw6/BgXdI/e2In8AN8O6ciX0x
8XkZYo4N4eewu3+LNYKdBgsyv7fF/2JGl/y/F/bUDeQuI/9CHoYc4DfxrZl7
nts7fDH/zeDcCPYKfhw8uTbsPOcxWGdfx3efFv2wv16OMTBvcCSMAZ7k/wEg
wtVq
         "]], Polygon3DBox[CompressedData["
1:eJxFmge0FFW2hqu6u7qqu7pBxzBmRMQEBkRmRIcroiTFBI4CBlAwgYI6Ksk3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         "]], Polygon3DBox[CompressedData["
1:eJwl1Flo1UcUBvCpyU1yb9YXS6uiWOu+xKiFqnHBQq0kPijihloQlwc1qag1
al/UuMQFVGqa1iqIoiLaxrVUQRDBDY1IlCJuVCi0Kor6UJCi/Q3z8HHnfOc7
3zkzc+fffW795LoOIYRxkIHdJSG8yA+hTNAm8SYXwp6iEBZaf4tbAW8LQ+hG
15AXwsBsCA/lR5eGsJO2h1xP8c8fhNC7OITpdJ9bH8Uvph1PV0o3Qq8rdFdh
JG4S3XV+s2haaT/F1cpNLpCD7Twmiofi6/1W0NXSj+DVJ5f6LcYvgiqantDO
Zw3da7p5/HuYp1Lfojg/XV+aj9ROwN0Ut0E1bixk1OXDAbkqdYNxM+SnFyWP
PHXH8NXWU5zXc/hej3L8GNwXZh4HP0WO7jDumvi23hXiIfzqeM3W44b5+uJ6
4R7KZ/Gn4n54tebSDFfUXpLL0bWqWeUeGjLpXs7gX9PdtC7NpPuL97gRN1Fc
GyG3S+0/cJ//L9DI92/xx/ou4vGvHo9wq9R9A3et5+KfQG+aFtqZfB7wPw27
9OiD/0u+hN8ZMzeoy9L9R9eo73pooavHn5ZvotsMn6mbALvtpRlu6bWE5ju1
F+k2m2Ue3RrxVKjAPdOnK26auFBtf/ERuutyc3B1UWt9Eb8BOtP8mUv3dUiP
H+JexFvobtB14rUSmsQltKPlL/BroS/A1eCOZ1Nt9Lindqe9nLT3+/npLOKZ
bIdGPhlYwLcscnSDeA0sSOcYz7NZ/i6vmZn0n/uR7qyeb/iszqQ7jXe7j3YA
/kR8M3Sj4rsyy6+F6X3EdzIc1x/6QZNe1frs9VtZnOYfRTtIvwHxjK07mut3
fWro7vDoom42XWe5/dCd7mBpOqPxNF9CI782uqD2Hv4lv1f838b3YIZ34qUw
LNbRVpi/HGqUdFK3DTeYTyVcxs2PZ48bJh4KR3CTcFtxQ8RV8BtuBm6tHgt5
PzXreWe9TtxMV8K/OJPeXRndV3ovp1kBj3GrcR1p/zBvO79TuA/FO9Sey6Zv
V/yG3RavxH+txwvcJ/b4NJd0y+WXwXu5vLIQNuFrzLAHyunaxf8DmTmiqA==

         "]], 
        Polygon3DBox[{{2706, 1828, 1957, 3362, 2602, 2603}, {3177, 1375, 1374,
          2430, 2431, 3178}}]}]}, {}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1m3nAVeP2x897znn3eHbGBkNokDKUMhTyM4/JLSQXiWiikEzX1aDMqVBc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         "]], Polygon3DBox[CompressedData["
1:eJw1m2f4FUXSxed/w8ydcFFAAQMqYsIcAbMi5ogKqKAoCmJGwbCugIIRBTEr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         "]], Polygon3DBox[CompressedData["
1:eJwt1nuUVlUZBvDDMMzM9zEfCqIichXlMopABMNFQiQUEVEREIHQLKBcIo4D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         "]], 
        Polygon3DBox[{{3201, 1053, 1134, 1933, 1934, 3357}, {2611, 2610, 3396,
          2372, 2374, 3397}, {3208, 1106, 1071, 2471, 2195, 2964}, {2966, 
         2196, 2471, 1071, 1240, 2967}}]}]}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0bsvnmEch/GfvkIcIhJLB0ljNDgr5XV+nc+0JltrMjCYDCox+Q8stCZh
MrFZRCISEuKQ2IytQ5CKxCDxkQ5Xrut753mSO89T9H16dCotImaQTES89+aH
iExxnxWRb2/bz/qT3tGvulQf5kTs2Y36SB/ofn2ij/W4vtCXujg7YtK+0g16
Vj/olF7UL7pXL+mEe6zxP+/m6S39pAv0ni7UP91vwj61P/Kc/YNvMyLOnM3b
d/pcl3Ap/uZGlHE5rnUFV+JGV3E1bvVnXuUarsVv/YXr8EvXcxIruoEfuZGX
uYmb0YJW7Dtr4xTa0YEnZ53chW70YMNZ7/vdfds+3rX7eQCDGMIwRjCKr/iG
dc+N8UJ6xJ9M3zLt/398A3X8O0o=
       "]], Line3DBox[CompressedData["
1:eJwt01tMz2Ecx/GHCOMOOfwzkhlFTrOonNKordlq05hT0j/HymFjzqdbh2uz
ScK9O2vuYnNBTRqVkTObUcqhCxdez9j+770/3+/veZ7f7/k9/19GVX153ZAQ
wnNUpoYwlCu4dlgIv8eEsIYn4yZmYz/mDA/hAP9BKX4Zl8VfRoVwkH+qyzgH
h7AQD/WWmpeHfBRgQG8J52KxMRvQr5fLN3gT93Eeb0avnM9b8E0u4G34Ki/n
Jt7OK+PzylVciFvyDl6N23I1F8U17POZ/fam/tt/H3fyd+7ifh5At3zOS/oh
v5BbUkI4r07Yb1Ju8vzJ+B4wGN8b9qHDva5wI/biLPZgivGf+TSu4wy6rXWP
r+Eynpq7m9ON/cSr4jnICUzCJfUuTJQ/8gpUYoI6De3mn1K/xwe8wzJsxTzX
T/B4PslvMVN+wxdxx9wGnq63k4+jBuPUr/kYHhgzVp2DI+qjOIwu+7jAPWiL
Z84bMd+4LGSjNZ57/F/IC/BKnsuP9V/G57HGIl4f18Mj/c743ChHs7ojviNk
Yx3u6rVxK2bgqrqE76MFmah3ftqhlkdzo/sUu2+xaxloV6/laXgiT+WRxtUY
n8QIuZr9QoPrhebWxfOM34bcozeL0+Pe5QSn/P+u/gK9q2+k
       "]], 
      Line3DBox[{1635, 4, 2462, 1341, 2526, 1342, 1343, 2512, 1344, 1345, 
       1347, 1054, 5, 1635}], 
      Line3DBox[{1642, 9, 2464, 1348, 2528, 1349, 1350, 2529, 1351, 1353, 
       1058, 10, 1642}], Line3DBox[CompressedData["
1:eJwl1FdsVlUAB/ADlNnSAo/EgASwPJQEEuMLBh6IL7RCZRVRZG9tWdUWKoot
LW1ZLXQARWXvJZUqtQU0bE0EAobRMg24gQQZCeN3w8Ov//85597vu/eefrfL
uIzB6U1CCCn+dI8Joa0+oHkIyaTwNifjQhgoB5HKKeN35GCGMJTT5obJ4aTx
g/EI+S4jOd86hPdknfn35Sg+YDRjOGZ+rBzHeCYwkXrzk+RkbvqMKXIq05jO
h/zqmI9kOhnMYCazmM0czjgmU37MJ2SRzVzmkcOnzOczPmcBX7DFubkyj4Xk
U8AiCimimMUsYSnLWE4Jh5xfKlewklvuo0yWU0Elq1jNGqpYy5fsce5X8mvW
sZ6NvGWvrtirV5q5Jnv3oEUIDcb/y0b5UF6Vj+Q1ebula3ZcdtMQrhv3l/nG
WTKnTQhnzfXTs81lyp+MM/Tx1qr1KnObZG2s69TL9YN6pV6g1+hlepZerZfq
fZw71XiZnqiP1Iv1jnqyXqDH62/qO52zwLinvlHP0Tvp56wnuI6+7jPBOMn9
/Ozeu3sGv8gM1pDMHc+qh2xirSl/6H9y23yq7ElL8634S99u/m85lN7Emo/j
d/P/Gd9lOK+TYL5dtHfW7hnfJ403aG/+iPkO0f+V8Q29UtZG32+vK+T3HKSY
77jumBpZzrd0ce4BWcQOa9XR/rKfMvbwI1et7ZWL2M1v7GIF2zhMo2O2y3y2
cpYtlLCeauv1cgN5nKZb9LuWicR7zteMT+hdo9+/zGU1ddF1OX+AfI1NnGEz
C6mK7sf6ITmIpOh+uMBOCljLAccckUPoxT4u8w0XrRXKzr77VRKJ59/o/RTt
q2f6j94g2xhnRtekX5IpXmAX9Dl662gv9ZV6c73W57aI3kXGMbIZpfrzaH+s
hehdoj/jKct5TI21J/IoxzkW8/Jd+QK8V7uu
       "]], Line3DBox[CompressedData["
1:eJwl0Ekyg1EUgNGbSCNERN+LaIPNKAswsADWpMoQExagikWYqCIh+r4X3aky
OPW9d+8b/PWXl1cXVxIRscROMqLgsqDruYjjdESVGiecUueMw3zEuV5wyRXX
3HDLhv2d3vPAI08888Irm9686TsffNLgiyO7b/3hl8hEJEiybdekKdJkyHLg
m5s1x5o3LdpKzTmvbRRop8i+eYd20kU3PfSyZ9en/QwwyBB182EdYZQSY+ya
l3WcCSaZYst8WmeoMMsc8zRS///8D1mFMok=
       "]], Line3DBox[CompressedData["
1:eJwl0ElOQkEUBdBnCAMStqCJ+2ANDFwCC9CFuAwjoqhgryiNig3Y94iiM3UZ
ngqDk3t/Xv2qX3+6NDczOxERRSYzEfMeCnIhF7GYjSizRIVlXvIRK7LKKmus
U+PVrC432GSLbXZ4M9uVe6nbe18e8KMPzBr6r34oj/jTm/JDtmSbDseccEo3
nePdM3nOBZf06DM0u5LX3HDLHfc88Jj2t+ZJPqe7pTuk72PAO3XzYVrHJyO+
+GYqO/5n/7eoPR4=
       "]], Line3DBox[{2510, 1627, 1101, 1332, 2541, 1331, 1333, 2510}], 
      Line3DBox[{2515, 1625, 1626, 1334, 2540, 1623, 1624, 2515}], 
      Line3DBox[{1631, 1267, 1269, 1114, 1631}], 
      Line3DBox[{1268, 1630, 1629, 1628, 1268}]}, {
      Line3DBox[{2543, 2769, 2866, 2476, 3240}], 
      Line3DBox[{2550, 3014, 2772, 2869, 2902, 2903, 3515, 2849, 3134, 2773, 
       3016, 3266}], 
      Line3DBox[{2557, 3018, 2776, 2872, 2906, 3490, 3369, 2851, 2777, 3403, 
       3491, 3241}], Line3DBox[{2574, 3222, 3301}], 
      Line3DBox[{2586, 3223, 3300}], Line3DBox[{3265, 2599}], 
      Line3DBox[{2601, 3031, 3032, 2884, 2909, 3513, 2705, 2855, 2810, 3417, 
       2706, 2603, 3229}], 
      Line3DBox[{2619, 3038, 3039, 2883, 2951, 3512, 3379, 2618, 3036, 3101, 
       3037, 2994, 3534, 3363, 2617, 2812, 3160, 3399, 3569, 3161, 2616, 2970,
        3262}], 
      Line3DBox[{2620, 3040, 3041, 2887, 2910, 3335, 3516, 2858, 2814, 3423, 
       2718, 2621, 3230}], 
      Line3DBox[{2627, 753, 2890, 486, 3517, 2861, 2819, 1845, 2628, 3231}], 
      Line3DBox[{2634, 3052, 2821, 2893, 2911, 3498, 3372, 2863, 2822, 3340, 
       3499, 2635, 3232}], 
      Line3DBox[{771, 349, 2050, 428, 350, 3500, 2641, 3210, 3308}], 
      Line3DBox[{668, 254, 1999, 356, 347, 2077, 468, 355, 2052, 430, 353, 
       2051, 429, 1418}], 
      Line3DBox[{2659, 2927, 2767, 3058, 2766, 3057, 3544, 2658, 2838, 2837, 
       3502, 2657, 2836, 2005, 2656, 2835, 3083, 3550, 3365, 3172, 3084, 3085,
        2977, 3263}], 
      Line3DBox[{629, 524, 786, 628, 2330, 866, 865, 3087, 1040, 3579, 2670, 
       3191, 3477, 3401, 2669, 2841, 3156, 3567, 3366, 2668, 626, 2288, 785, 
       1433}], Line3DBox[{2684, 2929, 2930, 2842, 3168, 2423, 2683, 3193, 
       3196, 3194, 3179, 3572, 3400, 2682, 3485, 3353, 2681, 2846, 3484, 3368,
        2680, 2928, 2121, 2899, 3247}], Line3DBox[{2771, 2695, 3304}], 
      Line3DBox[{2844, 2958, 2959, 2898, 2960, 3529, 3381, 2671, 2843, 3478, 
       3367, 2672, 3213, 3305}], Line3DBox[{3303, 2980}], 
      Line3DBox[{2988, 3220, 3242}], 
      Line3DBox[{2996, 2717, 2997, 2886, 2952, 3527, 3380, 3066, 2716, 3102, 
       3065, 2995, 3422, 3364, 3153, 2715, 3154, 2857, 3378, 3526, 2950, 3064,
        2714, 3079, 2975, 2813, 2504, 3280}], 
      Line3DBox[{2999, 2728, 3000, 2889, 2954, 2953, 3545, 3068, 2727, 3067, 
       2888, 3051, 3542, 3390, 3103, 2726, 3104, 3050, 2998, 3428, 3049, 3048,
        2818, 2725, 3047, 2860, 3587, 3216, 3281}], 
      Line3DBox[{3002, 665, 759, 510, 3497, 2820, 890, 3001, 823, 2400, 976, 
       975, 1009, 2426, 974, 2862, 488, 2892, 3433, 755, 949, 1404}], 
      Line3DBox[{3003, 3005, 3004, 3055, 2764, 2956, 2116, 2828, 2916, 3054, 
       2915, 3155, 2827, 3546, 3392, 2865, 2736, 2826, 3509, 2864, 2914, 2913,
        2895, 3438, 3355, 2926, 2825, 3224, 3239}], 
      Line3DBox[{3020, 3135, 2783, 2873, 2784, 3521, 3376, 2563, 2785, 2786, 
       3492, 3204, 3316}], 
      Line3DBox[{3021, 3136, 2793, 2878, 2794, 2935, 3505, 3071, 3070, 3169, 
       2795, 3069, 2796, 3580, 3195, 2575, 3226, 3271}], 
      Line3DBox[{3025, 3140, 3141, 2880, 2940, 2939, 3507, 2587, 2806, 3151, 
       3451, 3361, 2588, 3228}], 
      Line3DBox[{3030, 3142, 3143, 2882, 2947, 3525, 3377, 2600, 2809, 3457, 
       3362, 2602, 3209, 3313}], 
      Line3DBox[{3059, 3150, 2829, 2896, 2830, 2957, 3510, 2648, 2831, 2832, 
       3501, 2649, 3211, 3307}], 
      Line3DBox[{3060, 961, 2897, 574, 3511, 2660, 2839, 2011, 2661, 3212, 
       3306}], Line3DBox[{3243, 3218, 2968, 3217, 3289}], 
      Line3DBox[{3252, 2961, 3292}], Line3DBox[{3253, 2850, 3294}], 
      Line3DBox[{3254, 2852, 3295}], Line3DBox[{3255, 2962, 2694, 3273}], 
      Line3DBox[{3257, 2963, 3274}], Line3DBox[{3259, 2965, 3275}], 
      Line3DBox[{3260, 2573, 3387, 3404}], 
      Line3DBox[{3261, 2198, 2969, 2584, 3388, 3494, 2802, 3221, 2803, 3024, 
       2585, 3297}], 
      Line3DBox[{3270, 3205, 3177, 3178, 3571, 3176, 3125, 2597, 2382, 3139, 
       2853, 2938, 2937, 2598, 3524, 2945, 2946, 3215, 3298}]}, {
      Line3DBox[{2512, 1635}], Line3DBox[{2529, 1642}], 
      Line3DBox[CompressedData["
1:eJwVzz0ohAEcx/H/KXdHTDYDLiyu1OlWq4nUWc7iLSZCucFbyUteymS3yCBZ
pEjcYFDsdqtylMGgJJ9n+Pb7/X/fp+fuyU0tlOZTETGBWjpiMhNxmo1oxAH2
8dwc8cqVuaI7gz3c2HflCzfM9en12ME1ty2fuAGuoNdhC5uo2vvtvfq5Z//0
dX0NV1zRXbXn3b/6qlzBGZd333M97h+9IpdwzN3aO23d7m85J2fxaD/iW21d
7i85k/yWfTr5Tq7FltM/5bi85NINEWP6Bt9k79A/5AM3qpexzGVt7fqJvaaP
6CUscin3nb3N/a4PycHk/3r3BQ5tb/gHW1Mymw==
       "]], 
      Line3DBox[{1773, 1890, 2018, 3478, 1760, 1881, 2011, 1749, 1872, 3501, 
       2001, 1737, 1863, 3500, 1992, 1726, 1854, 3499, 1983, 1716, 1845, 1976,
        1705, 3423, 1836, 1969, 1694, 3417, 1828, 1957, 3457, 1683, 1819, 
       1953, 3451, 1673, 1043, 2459, 3580, 1045, 1664, 1805, 3492, 1943, 2470,
        2477, 3491, 1941, 2516}], 
      Line3DBox[{1781, 1898, 2059, 1930, 2121, 1769, 2102, 2101, 2056, 1928, 
       2288, 2209, 2327, 2099, 2532}], 
      Line3DBox[{1782, 2022, 2060, 2021, 3484, 1770, 2014, 2057, 2013, 3567, 
       2402, 2403, 2434, 2004, 2427, 2003, 3550, 2326, 2325, 2401, 1996, 2051,
        1995, 2208, 2076, 2112, 3438, 1925, 1985, 1924, 2111, 2075, 2275, 
       3433, 1974, 2480, 1973, 2304, 2203, 2042, 2490, 3587, 2303, 1921, 2479,
        1920, 2261, 2501, 1964, 2504, 2386, 1956, 2478, 1955, 2531}], 
      Line3DBox[{1783, 1899, 3485, 1771, 2454, 2453, 3477, 1758, 2006, 2054, 
       2005, 1746, 1998, 2052, 1997, 1735, 1987, 3509, 2047, 1986, 2398, 2399,
        2426, 1980, 2425, 1979, 2322, 2222, 2267, 3428, 1966, 2388, 1965, 
       2301, 2268, 2039, 3526, 2158, 2397, 1963, 2038, 1962, 2412, 3569, 2411,
        2370, 2371, 2369, 3571, 2431, 2430, 2199, 2509, 2198, 2517}], 
      Line3DBox[{1784, 2421, 2420, 3572, 2435, 2015, 2455, 2457, 3579, 2456, 
       2329, 2008, 3502, 2007, 1747, 1990, 2077, 2176, 2175, 2049, 2308, 2309,
        3546, 2048, 1988, 2223, 2306, 2400, 2307, 2045, 2205, 2323, 2204, 
       2073, 3542, 2269, 2349, 2270, 1975, 2272, 2271, 2221, 3422, 1968, 2396,
        1967, 3534, 2220, 1952, 2381, 2383, 2382, 2032, 2296, 2297, 2200, 
       3494, 2254, 2253, 2537}], 
      Line3DBox[{2023, 1931, 2422, 2424, 2423, 2017, 2291, 2452, 2292, 2016, 
       2211, 2330, 2210, 2010, 2119, 2120, 2009, 2287, 3544, 2286, 2000, 2284,
        2285, 1999, 2118, 2117, 1991, 2115, 2116, 1989, 2114, 2113, 1982, 
       2109, 3497, 2110, 1981, 2108, 2107, 2074, 2167, 3545, 2305, 2168, 2043,
        2166, 2321, 2165, 2072, 3527, 2161, 2302, 2162, 2040, 2160, 2320, 
       2159, 3512, 2071, 2153, 2348, 2154, 2036, 2152, 3524, 2151, 2538}], 
      Line3DBox[{2526, 2462}], Line3DBox[{2528, 2464}], 
      Line3DBox[{2510, 2445, 2444, 2541}], 
      Line3DBox[{2518, 2248, 2247, 2533}], 
      Line3DBox[{2524, 2250, 2249, 2525}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJztnXk01t/2+JWkDCFkSJQpUplSVJwmTZQypESDMVIkESFJKFLRnCQhSYnM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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{367.54069510122025`, 230.41388520053397`},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{1.6647685620973713`, 2.6286262664267124`, 1.329988566155325},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.604330100426984*^9, 3.6129774049661064`*^9, 
  3.6239961421081343`*^9, 
  3.624019986973486*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
},
WindowSize->{1920, 1178},
WindowMargins->{{Automatic, 1912}, {Automatic, -65}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 614, 16, 52, "Input"],
Cell[CellGroupData[{
Cell[1196, 40, 487, 13, 52, "Input"],
Cell[1686, 55, 310, 8, 31, "Output"]
}, Open  ]],
Cell[2011, 66, 1587, 41, 52, "Input"],
Cell[3601, 109, 235, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[3861, 117, 441, 13, 31, "Input"],
Cell[4305, 132, 523, 12, 31, "Output"]
}, Open  ]],
Cell[4843, 147, 1683, 40, 52, "Input"],
Cell[6529, 189, 1100, 30, 52, "Input"],
Cell[7632, 221, 1192, 31, 72, "Input"],
Cell[8827, 254, 9501, 217, 392, "Input"],
Cell[CellGroupData[{
Cell[18353, 475, 1606, 37, 72, "Input"],
Cell[19962, 514, 2375, 45, 344, "Output"]
}, Open  ]],
Cell[22352, 562, 4297, 99, 372, "Input"],
Cell[CellGroupData[{
Cell[26674, 665, 843, 22, 52, "Input"],
Cell[27520, 689, 158210, 2557, 208, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185767, 3251, 997, 23, 52, "Input"],
Cell[186767, 3276, 6986, 121, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193790, 3402, 2031, 46, 92, "Input"],
Cell[195824, 3450, 193, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[196054, 3459, 1011, 28, 52, "Input"],
Cell[197068, 3489, 276, 5, 31, "Output"]
}, Open  ]],
Cell[197359, 3497, 272, 6, 31, "Input"],
Cell[CellGroupData[{
Cell[197656, 3507, 673, 17, 52, "Input"],
Cell[198332, 3526, 6651, 118, 253, "Output"]
}, Open  ]],
Cell[204998, 3647, 729, 12, 72, "Input"],
Cell[CellGroupData[{
Cell[205752, 3663, 1045, 29, 31, "Input"],
Cell[206800, 3694, 299, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[207136, 3706, 1381, 28, 52, "Input"],
Cell[208520, 3736, 560, 17, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209117, 3758, 896, 23, 52, "Input"],
Cell[210016, 3783, 332, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210385, 3796, 825, 19, 72, "Input"],
Cell[211213, 3817, 832, 19, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212082, 3841, 1651, 39, 72, "Input"],
Cell[213736, 3882, 254812, 4129, 149, 235393, 3809, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[468585, 8016, 1378, 31, 52, "Input"],
Cell[469966, 8049, 229399, 3730, 258, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[699402, 11784, 1023, 26, 52, "Input"],
Cell[700428, 11812, 210674, 3432, 260, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[911139, 15249, 546, 11, 52, "Input"],
Cell[911688, 15262, 617, 18, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[912342, 15285, 353, 8, 52, "Input"],
Cell[912698, 15295, 449, 14, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[913184, 15314, 603, 11, 52, "Input"],
Cell[913790, 15327, 832, 19, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[914659, 15351, 1819, 40, 72, "Input"],
Cell[916481, 15393, 133162, 2201, 245, 105232, 1741, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
