(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1041412,      17842]
NotebookOptionsPosition[   1037037,      17699]
NotebookOutlinePosition[   1037387,      17714]
CellTagsIndexPosition[   1037344,      17711]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Helper", " ", "functions"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SphVec", "[", 
    RowBox[{"theta_", ",", " ", "phi_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "phi", "]"}], " ", 
      RowBox[{"Sin", "[", "theta", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{"Sin", "[", "phi", "]"}], 
      RowBox[{"Sin", "[", "theta", "]"}]}], ",", " ", 
     RowBox[{"Cos", "[", "theta", "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6043271954978313`*^9, 3.604327220929286*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"linear", " ", "interpolation"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Lerp", "[", 
    RowBox[{"A_", ",", " ", "B_", ",", " ", "X_"}], "]"}], " ", "=", 
   RowBox[{"A", " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"B", "-", "A"}], ")"}], "*", "X"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6043199648572626`*^9, 3.604319965387293*^9}, {
  3.6129746928149805`*^9, 3.6129746974232435`*^9}}],

Cell[BoxData[
 RowBox[{"A", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "A"}], "+", "B"}], ")"}], " ", "X"}]}]], "Output",
 CellChangeTimes->{
  3.604349087961071*^9, 3.604386874260832*^9, {3.612974679993247*^9, 
   3.6129746982162895`*^9}, 3.6239958739677973`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"spherical", " ", "lerp"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Slerp", "[", 
    RowBox[{"A_", ",", " ", "B_", ",", " ", "X_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"angle", " ", "=", " ", 
       RowBox[{"ArcCos", "[", 
        RowBox[{"Dot", "[", 
         RowBox[{"A", ",", "B"}], "]"}], "]"}]}], ";", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"angle", " ", "\[Equal]", " ", "\[Pi]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "X"}], ")"}], "*", "angle"}], "]"}], " ", 
            "/", " ", 
            RowBox[{"Sin", "[", "angle", "]"}]}], ")"}], "*", "A"}], " ", "+",
          " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"X", " ", "*", " ", "angle"}], "]"}], " ", "/", " ", 
            RowBox[{"Sin", "[", "angle", "]"}]}], ")"}], "*", "B"}]}]}], " ", 
       "]"}]}], "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6043863974191647`*^9, 3.6043866168294716`*^9}, {
  3.604386724099622*^9, 3.60438672989963*^9}, {3.604386850550799*^9, 
  3.604386856150807*^9}, {3.6043869035308733`*^9, 3.604386926260905*^9}, {
  3.6129746862316036`*^9, 3.61297469053585*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"BRDF", " ", "functions"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.604327210520691*^9, 3.604327219737218*^9}, {
   3.604386866990822*^9, 3.604386877700837*^9}, 3.6129747003984137`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", 
   RowBox[{"F0_", ",", " ", "Cos\[Theta]H_"}], "]"}], "=", 
  RowBox[{"F0", " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", "F0"}], ")"}], " ", "*", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "Cos\[Theta]H"}], ")"}], "^", "5"}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.604172611123061*^9, 3.6041726120291133`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "Cos\[Theta]H"}], ")"}], "5"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "F0"}], ")"}]}], "+", "F0"}]], "Output",
 CellChangeTimes->{
  3.6041726159453373`*^9, 3.604269102527836*^9, 3.604293083268638*^9, 
   3.604315921033969*^9, 3.60431997372577*^9, 3.6043204289738083`*^9, {
   3.604320799397996*^9, 3.6043208270055747`*^9}, 3.6043490905572195`*^9, 
   3.6043869489609365`*^9, 3.6239958762709293`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"GSmithGGX1", "[", 
   RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", ":=", " ", 
  RowBox[{"2", " ", "/", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"Roughness", "^", "2"}], "*", 
        RowBox[{
         RowBox[{"Tan", "[", 
          RowBox[{"ArcCos", "[", "Cos\[Theta]V", "]"}], "]"}], "^", "2"}]}]}],
       "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.6129747184154444`*^9, 3.6129747303591275`*^9}, 
   3.623996267087283*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "GSmithCorrelated", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"LambdaSmithGGX", "[", 
     RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"Roughness", "^", "2"}], "*", 
          RowBox[{
           RowBox[{"Tan", "[", 
            RowBox[{"ArcCos", "[", "Cos\[Theta]V", "]"}], "]"}], "^", 
           "2"}]}]}], "]"}]}], ")"}], " ", "/", " ", "2"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GSmithGGX2Correlated", "[", 
     RowBox[{
     "Cos\[Theta]N_", ",", " ", "Cos\[Theta]V_", ",", " ", "Roughness_"}], 
     "]"}], " ", ":=", " ", 
    RowBox[{"1", " ", "/", " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"LambdaSmithGGX", "[", 
        RowBox[{"Cos\[Theta]N", ",", " ", "Roughness"}], "]"}], " ", "+", " ", 
       RowBox[{"LambdaSmithGGX", "[", 
        RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}]}], 
      ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.623995976624669*^9, 3.6239959812549343`*^9}, {
  3.6239960789425216`*^9, 3.6239960921822786`*^9}, {3.623996146630393*^9, 
  3.623996276110799*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GGXNDF", "[", 
   RowBox[{"n_", ",", " ", "L_", ",", " ", "V_", ",", " ", "Roughness_"}], 
   "]"}], "  ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", " ", "=", " ", 
      RowBox[{"Normalize", "[", 
       RowBox[{"L", " ", "+", " ", "V"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"Roughness", "^", "2"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n", ".", 
         RowBox[{"H", "^", "4"}]}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Roughness", "^", "2"}], "+", 
           RowBox[{
            RowBox[{"Tan", "[", 
             RowBox[{"ArcCos", "[", 
              RowBox[{"n", ".", "H"}], "]"}], "]"}], "^", "2"}]}], ")"}], "^",
          "2"}]}], ")"}]}]}], "}"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.604320111038624*^9, 3.60432014961983*^9}, {
  3.604320180467595*^9, 3.6043201842758126`*^9}, {3.604326462761922*^9, 
  3.6043264938567*^9}, {3.6129747222876663`*^9, 3.612974725918874*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FrGGX", "[", 
   RowBox[{
   "n_", ",", " ", "L_", ",", " ", "V_", ",", " ", "Roughness_", ",", " ", 
    "F0_"}], "]"}], "  ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", " ", "=", " ", 
      RowBox[{"Normalize", "[", 
       RowBox[{"L", " ", "+", " ", "V"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"F0", ",", "  ", 
        RowBox[{"H", ".", "V"}]}], "]"}], " ", "*", " ", 
      RowBox[{"GGXNDF", "[", 
       RowBox[{"n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness"}], 
       "]"}], "*", " ", 
      RowBox[{"GSmithGGX1", "[", 
       RowBox[{
        RowBox[{"n", ".", "L"}], ",", " ", "Roughness"}], "]"}], " ", "*", 
      " ", 
      RowBox[{
       RowBox[{"GSmithGGX1", "[", 
        RowBox[{
         RowBox[{"n", ".", "V"}], ",", "Roughness"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", " ", "*", " ", 
         RowBox[{"n", ".", "L"}], "*", 
         RowBox[{"n", ".", "V"}]}], " ", ")"}]}]}]}], "}"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6041734992668605`*^9, 3.6041735102004857`*^9}, {
   3.604173550254777*^9, 3.6041735991535735`*^9}, {3.604173640368931*^9, 
   3.6041736753239303`*^9}, {3.6041737731845274`*^9, 
   3.6041738104386587`*^9}, {3.604173840776394*^9, 3.604174114814068*^9}, {
   3.6041742095524864`*^9, 3.604174305319964*^9}, {3.6041745011811666`*^9, 
   3.60417450211622*^9}, {3.604174718669606*^9, 3.604174720612717*^9}, {
   3.6041747577658424`*^9, 3.60417476174407*^9}, {3.6041756424034405`*^9, 
   3.6041756462616615`*^9}, {3.6043199061819067`*^9, 3.6043199255350137`*^9}, 
   3.6043199805981627`*^9, {3.604320011740944*^9, 3.6043200545643935`*^9}, {
   3.6043201665247974`*^9, 3.604320168579915*^9}, {3.604320220228869*^9, 
   3.6043202258201885`*^9}, 3.604326503332242*^9, {3.6239962708795*^9, 
   3.6239962721195707`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FrGGXCorrelated", "[", 
    RowBox[{
    "n_", ",", " ", "L_", ",", " ", "V_", ",", " ", "Roughness_", ",", " ", 
     "F0_"}], "]"}], "  ", ":=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H", " ", "=", " ", 
       RowBox[{"Normalize", "[", 
        RowBox[{"L", " ", "+", " ", "V"}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"F0", ",", "  ", 
         RowBox[{"H", ".", "V"}]}], "]"}], " ", "*", " ", 
       RowBox[{"GGXNDF", "[", 
        RowBox[{"n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness"}], 
        "]"}], "*", " ", 
       RowBox[{
        RowBox[{"GSmithGGX2Correlated", "[", 
         RowBox[{
          RowBox[{"n", ".", "L"}], ",", " ", 
          RowBox[{"n", ".", "V"}], ",", " ", "Roughness"}], "]"}], " ", "/", 
        RowBox[{"(", 
         RowBox[{"4", " ", "*", " ", 
          RowBox[{"n", ".", "L"}], "*", 
          RowBox[{"n", ".", "V"}]}], " ", ")"}]}]}]}], "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.623996288119486*^9, 3.6239963453987617`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "function", " ", "perform", " ", "a", " ", "numerical", " ", 
    "integration", " ", "of", " ", "the", " ", "GGX", " ", "BRDF", " ", "and",
     " ", "keep", " ", "the", " ", "peak", " ", 
    RowBox[{"intensity", ".", " ", "Then"}], " ", "deduced", " ", "a", " ", 
    "factor", " ", "to", " ", "reconstruct", " ", "the", " ", "offspecular", 
    " ", "peak", " ", "from", " ", "the", " ", "normal", " ", "and", " ", 
    RowBox[{"R", ".", " ", "The"}], " ", "factor", " ", "to", " ", "recover", 
    " ", "the", " ", "vector", " ", "should", " ", "be", " ", "use", " ", 
    "with", " ", 
    RowBox[{"Slerp", ".", " ", "However"}], " ", "for", " ", "performance", 
    " ", "we", " ", "can", " ", "use", " ", 
    RowBox[{"Normalize", "[", 
     RowBox[{"Lerp", "[", "]"}], "]"}], " ", 
    RowBox[{"instead", ".", " ", "In"}], " ", "the", " ", "shader", " ", 
    "code", " ", "this", " ", "will", " ", "allow", " ", "to", " ", "use", 
    " ", "directly", " ", 
    RowBox[{"Lerp", "[", "]"}], " ", "without", " ", "the", " ", "normalize", 
    " ", "as", " ", "cubemap", " ", 
    RowBox[{"don", "'"}], "t", " ", "require", " ", "the", " ", "vector", " ",
     "to", " ", "be", " ", 
    RowBox[{"normalized", ".", " ", "This"}], " ", "is", " ", "an", " ", 
    "approximation", " ", "of", " ", "slerp", " ", "Ok", " ", "for", " ", 
    "our", " ", "case"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FrGGXTest", "[", 
     RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_", ",", " ", "F0_"}], 
     "]"}], "  ", ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"dangle", " ", "=", " ", "0.01"}], ";", 
       RowBox[{"n", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"V", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"1", " ", "-", " ", 
             RowBox[{"Cos\[Theta]V", " ", "*", " ", "Cos\[Theta]V"}]}], 
            "]"}]}], ",", " ", "0", ",", " ", "Cos\[Theta]V"}], "}"}]}], ";", 
       " ", "\[IndentingNewLine]", 
       RowBox[{"MaxTheta", " ", "=", " ", 
        RowBox[{"-", "1"}]}], ";", " ", 
       RowBox[{"MaxPhi", " ", "=", " ", 
        RowBox[{"-", "1"}]}], ";", " ", 
       RowBox[{"MaxVal", " ", "=", " ", 
        RowBox[{"-", "1"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"R", " ", "=", " ", 
        RowBox[{
         RowBox[{"2", " ", "*", " ", 
          RowBox[{"Dot", "[", 
           RowBox[{"n", ",", " ", "V"}], "]"}], " ", "*", " ", "n"}], " ", 
         "-", " ", "V"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Retrieve", " ", "the", " ", "peak", " ", "intensity", " ", "of", " ",
          "the", " ", "GGX", " ", "BRDF"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"For", " ", "[", " ", 
        RowBox[{
         RowBox[{"angle", " ", "=", " ", "0.0001"}], ",", 
         RowBox[{"angle", " ", "\[LessEqual]", " ", 
          RowBox[{"\[Pi]", "-", "0.0001"}]}], ",", 
         RowBox[{
          RowBox[{"angle", " ", "+=", " ", "dangle"}], " ", ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"theta", " ", "=", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"angle", "<", " ", 
              RowBox[{"\[Pi]", "/", "2"}]}], ",", 
             RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], " ", "-", " ", "angle"}], ",", " ", 
             RowBox[{"angle", " ", "-", " ", 
              RowBox[{"\[Pi]", "/", "2"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", " ", 
          RowBox[{"phi", " ", "=", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"angle", "<", " ", 
              RowBox[{"\[Pi]", "/", "2"}]}], ",", "\[Pi]", ",", " ", "0"}], 
            "]"}]}], ";", "  ", 
          RowBox[{"L", " ", "=", "  ", 
           RowBox[{"SphVec", "[", 
            RowBox[{"theta", ",", "phi"}], "]"}]}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"val", "=", " ", 
           RowBox[{
            RowBox[{"FrGGX", "[", 
             RowBox[{
             "n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness", ",", 
              " ", "F0"}], "]"}], " ", "*", 
            RowBox[{"L", ".", "n"}]}]}], " ", ";", " ", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"val", " ", "\[GreaterEqual]", " ", "MaxVal"}], ",", 
            RowBox[{
             RowBox[{"MaxVal", "=", "val"}], ";", 
             RowBox[{"MaxTheta", "=", "theta"}], ";", 
             RowBox[{"MaxPhi", "=", "phi"}]}], ",", "0"}], "]"}]}]}], "]"}], 
       ";", " ", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Compare", " ", "the", " ", "off", " ", "specular", " ", "peak", " ", 
         "with", " ", "the", " ", "reflection", " ", "vector", " ", "and", 
         " ", "deduced", " ", "a", " ", "slerp", " ", "factor", " ", "to", 
         " ", "reconstruct", " ", "the", " ", "vector", " ", "from", " ", 
         "normal", " ", "and", " ", "R"}], " ", "*)"}], 
       RowBox[{"slerpfactor", " ", "=", " ", 
        RowBox[{
         RowBox[{"VectorAngle", "[", 
          RowBox[{"n", ",", " ", 
           RowBox[{"SphVec", "[", 
            RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}]}], "]"}], " ", "/", 
         " ", 
         RowBox[{"VectorAngle", "[", 
          RowBox[{"n", ",", " ", "R"}], "]"}]}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"newMax", " ", "=", " ", 
        RowBox[{"Slerp", "[", 
         RowBox[{"n", ",", " ", "R", ",", " ", "slerpfactor"}], "]"}]}], ";", 
       " ", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Dispplay", " ", "to", " ", "oberseve", " ", "the", " ", "behavior"}],
         " ", "*)"}], 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Pink", ",", " ", 
           RowBox[{"Arrow", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"n", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
                RowBox[{"n", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",",
            " ", "Blue", ",", 
           RowBox[{"Arrow", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"V", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
                RowBox[{"V", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",",
            "Red", ",", 
           RowBox[{"Arrow", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"R", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
                RowBox[{"R", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",",
            "Green", ",", 
           RowBox[{"Arrow", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"SphVec", "[", 
                  RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
                RowBox[{
                 RowBox[{"SphVec", "[", 
                  RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}], "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",",
            "Orange", ",", 
           RowBox[{"Arrow", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"newMax", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
                RowBox[{"newMax", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}]}], 
          "}"}], ",", "   ", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", " ", "1"}], "}"}]}], "}"}]}]}], 
        "]"}]}], ",", "slerpfactor", ",", " ", "newMax"}], "}"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6043204779836116`*^9, 3.6043205221581383`*^9}, 
   3.604320638487792*^9, {3.6043265742172966`*^9, 3.6043265877970734`*^9}, {
   3.604326924056306*^9, 3.604326934598909*^9}, 3.6043428130977907`*^9, 
   3.6043428537121134`*^9, {3.604343013201236*^9, 3.6043430137202654`*^9}, {
   3.6043431596146097`*^9, 3.6043431886582713`*^9}, {3.604343228905573*^9, 
   3.6043432291855893`*^9}, 3.604343286609874*^9, {3.6043435156889763`*^9, 
   3.604343534945078*^9}, 3.6043870066610174`*^9, {3.6043870940411396`*^9, 
   3.604387097691145*^9}, {3.6043871329511943`*^9, 3.6043871399912043`*^9}, {
   3.6129755248605704`*^9, 3.6129755523241415`*^9}, {3.6129758607327814`*^9, 
   3.612975891866562*^9}, {3.6129759408843656`*^9, 3.6129759622465878`*^9}, 
   3.6129760139425445`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Manipulation", " ", "test", " ", "function", " ", "to", " ", "see", " ", 
    "how", " ", "the", " ", "peak", " ", "behave", " ", "depends", " ", "on", 
    " ", 
    RowBox[{"parameters", ".", " ", "Two"}], " ", "test", " ", "to", " ", 
    "do", " ", "with", " ", "F0", " ", "set", " ", "to", " ", "0.04", " ", 
    "and", " ", "with", " ", "F0", " ", "set", " ", "to", " ", "1", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"for", " ", "metal"}], ")"}], ".", " ", "With"}], " ", "F0", 
    " ", "set", " ", "to", " ", "0.04", " ", "we", " ", "notice", " ", "a", 
    " ", "discontinuity"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"FrGGXTest", "[", 
      RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "F0"}], "]"}], 
     ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Roughness", ",", " ", "0.1", ",", " ", "\"\<Roughness\>\""}],
         "}"}], ",", "0.01", ",", " ", "1.0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "Cos\[Theta]V", ",", "0.9999", ",", " ", "\"\<Cos\[Theta]V\>\""}], 
        "}"}], ",", "0", ",", "0.9999"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"F0", ",", " ", "1", ",", " ", "\"\<F0\>\""}], "}"}], ",", 
       "0", ",", " ", "1.0"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.604326589542173*^9, 3.604326635042775*^9}, {
  3.6043266666505833`*^9, 3.6043266705858088`*^9}, {3.6129759447445865`*^9, 
  3.6129759994637165`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`Cos\[Theta]V$$ = 0.396, $CellContext`F0$$ = 
    1, $CellContext`Roughness$$ = 0.9520000000000001, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`Roughness$$], 0.1, "Roughness"}, 0.01, 1.}, {{
       Hold[$CellContext`Cos\[Theta]V$$], 0.9999, "Cos\[Theta]V"}, 0, 
      0.9999}, {{
       Hold[$CellContext`F0$$], 1, "F0"}, 0, 1.}}, Typeset`size$$ = {
    472., {88., 92.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`Roughness$18165$$ = 
    0, $CellContext`Cos\[Theta]V$18166$$ = 0, $CellContext`F0$18167$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`Cos\[Theta]V$$ = 0.9999, $CellContext`F0$$ = 
        1, $CellContext`Roughness$$ = 0.1}, "ControllerVariables" :> {
        Hold[$CellContext`Roughness$$, $CellContext`Roughness$18165$$, 0], 
        Hold[$CellContext`Cos\[Theta]V$$, $CellContext`Cos\[Theta]V$18166$$, 
         0], 
        Hold[$CellContext`F0$$, $CellContext`F0$18167$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`FrGGXTest[$CellContext`Cos\[Theta]V$$, \
$CellContext`Roughness$$, $CellContext`F0$$], 
      "Specifications" :> {{{$CellContext`Roughness$$, 0.1, "Roughness"}, 
         0.01, 1.}, {{$CellContext`Cos\[Theta]V$$, 0.9999, "Cos\[Theta]V"}, 0,
          0.9999}, {{$CellContext`F0$$, 1, "F0"}, 0, 1.}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{523., {161., 166.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.604342822254314*^9, 3.604387038651062*^9, 
  3.6129753547428403`*^9, 3.612975906366391*^9, 3.612976016223675*^9}]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{{3.6042717414098988`*^9, 3.6042717479599075`*^9}, {
   3.604272512379981*^9, 3.6042725582440453`*^9}, {3.6042726290091443`*^9, 
   3.604272635660154*^9}, {3.6042729899426513`*^9, 3.6042729912126527`*^9}, {
   3.604273714969669*^9, 3.6042737260306845`*^9}, {3.604273853969864*^9, 
   3.6042738552598658`*^9}, {3.604320376622814*^9, 3.6043203928937445`*^9}, 
   3.6043271613498783`*^9, {3.6043272555882683`*^9, 3.604327277883544*^9}, {
   3.6043273120754995`*^9, 3.6043273509617233`*^9}, 3.6043273902709723`*^9, 
   3.6043275801968355`*^9, {3.6129760313345394`*^9, 3.612976058165074*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "fiting", " ", "function", " ", "representing", 
    " ", "the", " ", "slerp", " ", "factor", " ", "to", " ", "apply", " ", 
    "between", " ", "normal", " ", "and", " ", "reflection", " ", "vector", 
    " ", "for", " ", "off", " ", "specular", " ", "peak", " ", 
    "reconstruction"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Same", " ", "function", " ", "as", " ", "above"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"GetLerpFactorFrGGX", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_", ",", " ", "F0_"}], "]"}],
    "  ", ":=", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dangle", " ", "=", " ", "0.01"}], ";", "\[IndentingNewLine]", 
      RowBox[{"n", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"V", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"Cos\[Theta]V", " ", "*", " ", "Cos\[Theta]V"}]}], 
           "]"}]}], ",", " ", "0", ",", " ", "Cos\[Theta]V"}], "}"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"MaxTheta", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", 
      RowBox[{"MaxPhi", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", 
      RowBox[{"MaxVal", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"R", " ", "=", " ", 
       RowBox[{
        RowBox[{"2", " ", "*", " ", 
         RowBox[{"Dot", "[", 
          RowBox[{"n", ",", " ", "V"}], "]"}], " ", "*", " ", "n"}], " ", "-",
         " ", "V"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", " ", "[", " ", 
       RowBox[{
        RowBox[{"angle", " ", "=", " ", "0.001"}], ",", 
        RowBox[{"angle", " ", "\[LessEqual]", " ", 
         RowBox[{"\[Pi]", "-", "0.001"}]}], ",", 
        RowBox[{
         RowBox[{"angle", " ", "+=", " ", "dangle"}], " ", ";", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"theta", " ", "=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"angle", "<", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "-", " ", "angle"}], ",", " ", 
            RowBox[{"angle", " ", "-", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}]}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"phi", " ", "=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"angle", "<", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}], ",", "\[Pi]", ",", " ", "0"}], 
           "]"}]}], ";", "  ", "\[IndentingNewLine]", 
         RowBox[{"L", " ", "=", "  ", 
          RowBox[{"SphVec", "[", 
           RowBox[{"theta", ",", "phi"}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"val", "=", " ", 
          RowBox[{
           RowBox[{"FrGGX", "[", 
            RowBox[{
            "n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness", ",", 
             " ", "F0"}], "]"}], "*", 
           RowBox[{"L", ".", "n"}]}]}], " ", ";", " ", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"val", " ", "\[GreaterEqual]", " ", "MaxVal"}], ",", 
           RowBox[{
            RowBox[{"MaxVal", "=", "val"}], ";", 
            RowBox[{"MaxTheta", "=", "theta"}], ";", 
            RowBox[{"MaxPhi", "=", "phi"}]}], ",", "0"}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"slerpfactor", " ", "=", " ", 
       RowBox[{
        RowBox[{"VectorAngle", "[", 
         RowBox[{"n", ",", " ", 
          RowBox[{"SphVec", "[", 
           RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}]}], "]"}], " ", "/", " ", 
        RowBox[{"VectorAngle", "[", 
         RowBox[{"n", ",", " ", "R"}], "]"}]}]}]}], "\[IndentingNewLine]", 
     " ", "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6042717414098988`*^9, 3.6042717479599075`*^9}, {
   3.604272512379981*^9, 3.6042725582440453`*^9}, {3.6042726290091443`*^9, 
   3.604272635660154*^9}, {3.6042729899426513`*^9, 3.6042729912126527`*^9}, {
   3.604273714969669*^9, 3.6042737260306845`*^9}, {3.604273853969864*^9, 
   3.6042738552598658`*^9}, {3.604320376622814*^9, 3.6043203928937445`*^9}, 
   3.6043271613498783`*^9, {3.6043272555882683`*^9, 3.604327277883544*^9}, {
   3.6043273120754995`*^9, 3.6043273509617233`*^9}, 3.6043273902709723`*^9, 
   3.6043275801968355`*^9, {3.604328037037965*^9, 3.604328096500366*^9}, {
   3.6129760596091566`*^9, 3.612976227193742*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Display", " ", "the", " ", "slerp", " ", "factor", " ", "function", " ", 
     "for", " ", "F0"}], " ", "=", " ", 
    RowBox[{
    "1", " ", "and", " ", "compare", " ", "it", " ", "with", " ", "a", " ", 
     "linear", " ", "function"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GetLerpFactorFrGGX", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "1"}], "]"}], 
      ",", " ", 
      RowBox[{"1", "-", "Roughness"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.604273867679883*^9, 3.6042738973419247`*^9}, {
   3.604274025820105*^9, 3.604274035171118*^9}, {3.604274174731011*^9, 
   3.6042741865186853`*^9}, {3.604274268918579*^9, 3.60427427660959*^9}, {
   3.604274334662671*^9, 3.6042743605537076`*^9}, {3.604274628680084*^9, 
   3.6042746324100895`*^9}, {3.604274662642132*^9, 3.604274690694171*^9}, {
   3.6042747440462456`*^9, 3.604274744386246*^9}, {3.6042761688972454`*^9, 
   3.6042761739572525`*^9}, {3.6042762193393164`*^9, 3.604276219869317*^9}, {
   3.6042775860702343`*^9, 3.6042775904702406`*^9}, 3.604327404724799*^9, {
   3.604327441827921*^9, 3.604327459098909*^9}, {3.604328068698776*^9, 
   3.60432808084247*^9}, {3.6129762053354917`*^9, 3.612976297479762*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJysvQdQFMv3v41ZMWHOWcGEAQOKYVQMGDArmLMo5oA5B0TFgKgYMGdRTIiK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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtm3nAFlMbxmfe53nGO9MzRUQIIVmjhVBoI/u+l5KUJSkqUalUUra0KqSI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         "]], Polygon3DBox[CompressedData["
1:eJw1m3f8ltP/x+/7c3/O5b6uz/0hsyIjZURaKKNUWvYuVKSoZJZQEglpUCpS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         "]], Polygon3DBox[CompressedData["
1:eJwt13m8jdUex/HNuedkn+xmcrv3VqSkQUVU0iFDpUylJKFoVCFDg8xDGZqE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         "]], 
        Polygon3DBox[{{2491, 1435, 1748, 3225, 2357, 2358}, {2454, 1364, 1691,
          1012, 1011, 3047}, {2493, 1437, 1712, 3220, 2361, 2362}, {2362, 
         2361, 3213, 1648, 1649, 3214}, {2698, 1699, 1231, 1232, 1700, 
         2699}, {2475, 1390, 2207, 828, 835, 3050}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmXW8VdUWhS8HvPuw1zlLCUEJfYQiYIPyFBRRbFTKoAQJKRGkJBUFpEVJ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         "]], Polygon3DBox[CompressedData["
1:eJwtmnWcHcUWhJcb2B52Zje4u7u7u7sT3CXwcHu4uwb34O4Pd3d3DyG4hwAh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         "]], Polygon3DBox[CompressedData["
1:eJwt13fcVuMfB/Bbqe6ep6WIFjJ/qfhFRWloIUo7NJSUaCshStHStvmhoamk
IkVFJaOBFq2HFm2lIU3p9/6+7vuPz+vV9933Ouc+51znOtdTsl33xt2yJRKJ
FZJDZmYmEkdyJRIXSQf/cTgjkdicJ5G4K5lIPM1Wsdp6lksV1pp9zG5XT5Pf
1RfKA+w3YzcZe6e+p9hKVkfPDvYQG812sJbsQ/lDnUfasP3GrmBV9T3EPmFV
1N/J7awVm8Mqq5fIzawJm8r+q/5EEqwk683OO96fztubTWGnWC89v7JmbDDb
zJqyb6Uya8lms0rqxVKONWZT2E3qvcZ2ZiPZKLkmXyLxF+vHPlKf1/esvr9Z
fzabXZA9kejLNsqD7Fm2Wt8D6l36OrA32D7Wjn0jlVgLNovdpv5aKrL72QxW
Xr3H2I7sLXaAdWCH2VNsKjvNnmQfyVF1QXmUHXFfPmD71LmlFdvDdhv7qLFv
sv2svZ7trHUyda1xza+53i3sPva8up+MSFt91k3dXQqzqWxP/Fsec7zfnWMD
q55M9UTvC/p2sjZsjHqnvlbO+5WUZ83YB+xm9Qw5oM6Uh9g+xztq7LP63mXv
yY2Ot1TfLaypepq+curpsl+dIa3ZXmOzjG2grz9bx+rpWSYVWHM2nd2i3iQt
2HNsDXtQvVNeYBPZ36y/eq5cwK5iT8ULpl7nHNemryN+y1VsPbsufY64tqsz
U/elGmvD2sazch3v86x4jjndb32b/ebxbHOck9VjG9m7cR62l93J1rI32Cp2
nFVlK9hY9hP7g93N1rM32ffsBKvGVrIJbAs7yeqzTex1tpIdY1XYcvYW+yHe
K1adrWJvsx/ZGXYH+569HPOX7WG3smXslZjnMefZbezrmJPuwUFWPOYQ+4O9
Gu9mzG99ldg37LVYE9hBVpl9y95ha9luVoetYRPZL+wsa8C2sEnx/rNzrCHL
Yj87763ufUe+kFWM+8SuT79vMQ+uYV9IWXYfm8jKqN+L5xnvi+PdxdY53u/G
ttf3ejwT9oieRVKG1Wfvs9LqhVKa1WMT2A2xRhh7B+vBlrGqbIHcwO5l41kp
9edSit3DxrH/xH039kpWg9WMuW4OnWAD2Bx1NutQP32/sbbsZfabsa1jHWd7
1ZfK42yX6/iQHVZfIT3ZITZO78/qQ663LvuJzdD3J7tcnmAH2Wx9p9RFpAs7
wabrO6QuIT3YATYl3qX4bdKc7WCT43sR66Y0Y9vZ1Pjd6uxyP9vJ5rDT6qLS
lZ1kX7IbXVsDNomVjTngvA3ZALae1Wcfyxl1sViH2Cljl+q7SN/N7JaYI3kT
iW3sfjZUnaWvmXGz5Ji6kHRkR439ntXS1559xmrE+yI1WDs2j1WP+eJ4S2Od
c/9qxveSTWRbWd5499mvMSd5E2OfZMtZo1hb/J4xbEl8qz3LEWymsX+pL5ZL
Yh7qmcS2+Xc+edjYXxxvH+tq7Fh2mHUydj67kJVnQ9gFbDLbrs4v7djWWDfY
CvVRv/lIvF/m1X7Wzdhx/Ii+zvHtde7RbDEr4PcNZ+f0jWCL4vrY0PimSE/2
WqwJxvZQb5Mn2KvxDrPu8V5JI9aTfcsapK/3eHx35er4jX7LVtZc3xD1Fn1N
9J1no9iXcS3OOyzWSKnHurKv9N2b/p53Saa+HfEN+Z/j/ctGsi/iHhr7kr4p
bJc6h+SM98a1fs5y6quofsnxsuvLzl+P77kUNHZkrDfyuHq4vm36HlPPMzZ7
MjXPYr495rxz2b/xDYvvor5/3PtP2Xn1TfIiO8f+YcONXcgWxJpg7Gk2mM1T
J533Rec4y4ayz2ItYINizrMhbD7LzQay4+x5Nosl2HNsAtuQK/W847lvdV0n
2UB9c+Me6BsQ32PWnY2P+eH3dWGfyWWsEhvJCsc+T18PNiG+Iaxr7EvY3+pr
5Wl2zLVt5Z30jWDb2ePq2fpOqq+XPuy4vlnshPo6eYb9xdbqvdfYLmwpuyfW
EenD3mF/smdin2jsOXVZGcDOGvsx+0ddRvqz0+wUG2TspyyX633B2DnsrLq0
PK/vTEbqWWZLpuZjzMtj7tUavfewzuol+uqqV0td1oktZnfHmi112KPxLFkt
9XLHK5pe28eyS9kKViz9DYj1vggbz9aoz3s+jdkPGanntjE9R2OuNjQ35ust
YGw59WB9+TNTa13BZOo7Ed+LLvqyeDs2UL1RX9tYO+URNohtYg+rlxibn1Vn
r7K88T1mRVhd9h67LL7b7FJ2V7xX7OLY17FCrBZ7gxWIPRe7mNVmb7KL2CH2
JJvMTrInYl6xHKwCG8qyxR5HarJH2Hx2R6y7+oqnv6vxvSyamdqHxH7klVhj
JFve1Hs0zL9n6PtQKrkHm/W2ZH3Va/W3SL/7u9Pra6yzLfQdYU/rm6Y+o693
7HHYJawOe4sVjD0OK8zuZG+zQpmpPXWrZGrvHHvo4o63gOVit6qH6bsw9gcs
g1Vmo1hu9qkkWSnWl+VUH9TXi01iJ1jP2L9IY9aLfccaxj3Qd3l6/xJ7kOKx
Z2LXpPfK8XdUSbaGXZ3+2yr+7rky9nlSm3Vgn7Oa6f1GSdYo5ll8R13HanZV
+m+myfqu0LdBmrLebAVrrB6nb7X6X3O3Efsx3iOeW98NvB/LpR4dcybWW30V
2FJ9i4zN1Hc7H82SsTdjeVgVNoZlZKa+W8vjvTf2sGR55sdYX30z49z6+ujb
Ig+zF9kG1ka9WF8+Vo29wvKw99mmWAvkQfZz+u+P55Kp+RPzaKx78AO7Ir0H
iX1iiZinrER6/xd7vWLsS5aXVWUvs0w2Jt4H9S6/tyL7yjn+D3G7NtI=
         "]]}]}, {}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1lVtsVVUQhtfu2d3snp7NRS2kBUpBK9IWmiCtoEaNGG49tFBUJNHEKGqB
UhLDg9eICI0ISmK8giCBYqEFw02lQqJG66sPJhp9EBAxRiM+KAEBL9+fGZKu
/v+aM2vW2rNm/jX+oVXtXSUhhEFGjjExCmEe4zz8uTiEjfA1YDljBrYCeBXj
cexXg8V8CK+Cwwsh9KYhXI/PDrAE+03Yx2PfzXwU9q3gfaUhJPA9/LYUPhLe
r30Y3cTcBHZgr8J+CD6SsQr7KPAiB6zFfgl8LzU+gH0xAe/G515wO/OX4e+C
1zH64bVgY2Q+/7CmjfkK+AIwx5o/sR0h3qNwjhsOY9/hcT5hr2LOcjMlZ3Fl
1+9PetynwAl5i10K/uD+k/m3hG8ZAu/Dp4c9+Av74C+x0Wj4GQx7idHFOMd8
dN5yXwdOYtyAvQrciH8d9rP4P836D7A/A24q2L1cwL6Z8y/H3gFWs+YS9kgx
8navlWBH3tYuA/vATt/3GOvb4e2snRbb2iZwHH4X4a3geuYb8OkGH+a7KrDv
hT8AL4cfhFfp/vAZozOm9i0JMU+Ri1+w/5yzGFMYlxUXrItsj5q82XLgWMbf
8AZwLesn4dMAjmF+AXtL3u5Gd6E7V7x2jxn8zDr7NRl+nCPOLI/KZ1PecqGc
bC7Y+c577ocxH0G8P8rtbnRH28tCmJm3mpf9IPa58FmsO5laDW/B59SVOof/
6vXZA8+IWUHMs6ythJfB92Pvht9DjP6hdk7VfS/2EZn1xm54NT4T8X+E/b8h
ZgP8I/B7xlT4x2AhszvQOdPMekznSVg7D5/f2Xcy66dHls/j+LSx73qdJbMa
1ZnXMV+Cfy04OzYdmAPezpgPvwP8r8zyr3tYmVhN7kytjlZ6LUkzGr3XViSW
w22p1Zvq/K9gddul39h/GHFXYx8Obo3N5x3wMGva4K2J9af6NE5Mc9ZFVgMn
vK5UX4OR9bX8VC86s2pogLUL4QtZ+5trlHJbL42KrNcOYS9K+/CZzt718Bng
cf+25dhbmDfBi+AXvleVapnfGrF9i+/R1Gp6fmI5v1XaULC97oJfC/8QnxZ8
5iamp+rfLDab6lP5Fe53/gq/HVCtxtYrB7xfbvQ+neZ6NujnUf76/C7WsMee
yPLW6XblXz21L7LaL/X6V782ecxm8I3E4klPVKursaXgLK8N1chtXhuqkcHU
8qB8LOV7J8DH4l/D+E46R53H3uM1rkXPKtfqQddP6eiLuntibgCHJHaHqvkF
id2j7vO12PLzOjiAPeUROwqeoQ70njXkTH+lw0V/Ly6Dn4I/5sz/QfCc+0iz
pcmPESPLrBfU38cy095OeAX8S9Y/wZ5TE3vv/mXdZ+CJ1PTwberqpNfkaTDv
96v3M1b82PpudmIaIi2RdstHmvBTam/fNvhQ7wv1xxbvC/VHq9+33rES13np
/WnfVz1RTKwOVY9r8TsCfwGsju2NGBfbvet9fF7vJ2NRZHqkN0Z9LS3axZ0t
LrXvqnRtl8a/yWiGv+V39L7iJ9bveq+Vr5tj05xb/J3VvnqjGlzP5X9nbD04
U+8F+W3B1sy3fKW88B29qvnEtFrnlG5JE6QN0iL1rPznJNY/6q262M5TH9ub
rjPrXj/PrB+uaL7qX7rawzfeX2o5X+Z9or7/mpGo92J7Q9X70lLpnt4C6dei
xN4dvZ//A/KVDu4=
         "]], Polygon3DBox[CompressedData["
1:eJwtlmvQlVMUx5/T2e/TOed93xCVSleDdKNMEcO4jHTT5a0UilRMupL7ZUjl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         "]], Polygon3DBox[CompressedData["
1:eJwlkt8vlmEYx6+Xm/eHHtOiQqso4fWaHJQOOKI2P7Y208JyEvGWXxs61EJ1
gK2tjlQcNIQXo5iZNgf+ENlyUosDBzGZPteug+/z3N/v/b2v676+z5P1uLu2
K05ECkECGEoUWfSJhJ1IPojAX58Ruc/7W0AkiubgvpBIMeuboAD/ZfhtUI1v
Ad8htU6DIuPgEYU/oSWh/dQ9EGbdibcLjFIvwtkjtDLqlYJC+C4+tqQVTxsY
hoxR7yH1xthDkm3eeyCTdTtCBxjB9xktlTrnQI/Peg2AGOvraNdAGF4dsru+
h78DNfAcztezXqbGPTyv4F+CducA+qbW9iyXNngrWET77llemlsemKfXIDxM
zb+cvYtWoXmFLC/N7Q68BMTBF+gRdNZDe2lO2jfKvF+dzaizrrO+wfokXuQf
mEabwNeEb9lZZprdOLgIvwC6fZaP51mWUXg6+jEfZQ+kOctLc0vD44AfniHW
X+d9S+GXnHXgAD2dO3+kbwP7c3pvtB0ek2jNaLNo59F+oW15lrfmng1aOPsE
5OosYFW/J/srvK/Cr4Bn3DFe/zvWt5jzkrN76/+gfj2X4+ybJqBt0KOAdyNa
g7PvtoYvopk7+6/97AfQe+F1rB+AN/B9MjiLlgL68JVztynmaGGOmGbIHL+p
9QdfFbwS5OLLw/cBXz2+GTQ/vh8By2iG/Sxn8+hcT/EWob2A9+ss8FiyyBJ7
z7Wvs7v8B3uNYds=
         "]]}]}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt1HmQj3UcwPHvrtadY+QoTcYwazK2NTSiLFGOtdaxzpaMKCJHESFHSNZ9
tbtSuli3latS+UNMuUK7rGtJMylXDWoa4w/T6zuZ8fL+PN/v8/x+z+/Z3279
IWOzxiSEEIYn/C/Onf13W0vLh1BNf9d6elOf0LuapuUqhNBVa+kATdZGjDS3
1cmarjnaW/N1sK7T0bpbp+oBrVExhNre9zLFjos1mQ5JIZx03FFPaSctifeo
p+Pr6xntomc1Q89pV83kvLmblmp3vaA99KL21F80Sy9pg7IhPOw9Z/FrvFet
w0xy3WeRtUHmh0h3vzN0v7VqOsX+LnO29XzHBeZ+5lxznrmPeYV5rrmXeZl5
UrwX82JzmutHOF5obmDONs+P72XOMOeYk8ytzZmumeM4JX5u82zzY+Z79v/V
EsdVdfUDIawv4zOzgZeZRhZNK4fwtB7mCLv5klTrfbU9xznBVyRY/1oH0pki
ikmx/o1+y4t04SSnaGLvO93LIDIoobr10zqCxua3NZ/zvldTNJc8xvE+jztn
hU5mGedYzhsk2luqu1jCJBaymkb2FulYFrCT+UzkPT4k2TlzdTRz2Mq7vMk7
VLD/gc7kNdZRSgGtqBK/R57zmnj/rGUkU1lJQ9f31JbMYguzGcV0KtpfpX1o
Rw47mMcYZlDJOR/pADqxmOGUs/66nmUPr8afp2e4T5Me9HtlHmb+mTPmt/SQ
HtN6rn1FDzr+Qn/iKBPiWvxc9g/pZn7kB8azn8r2DuinfM5nPIW3DHU9i4/N
n9CDR53bQjeyibqOe+uzFLKNR6xla0e+Z3v8/rivIZrOS3TgXqUQXtC28Ttm
v47r2sR7Mj+pd+131+bxubqXQvfiVyKssp9o7ma9lmuaaS9qmtO0P0XOeV77
xedlfk5bU9aHOuH4mXhv2lTveJ9MTY3P2esXeG3/wkr7t6zd5m/+4bf4bP1d
qZ0Ywh/mK1zlGte5wZ/xHNf+pTc5Zh6qia67df9v839gBbgB
       "]], 
      Line3DBox[{812, 2, 1007, 2252, 994, 864, 2251, 992, 995, 991, 993, 998, 
       997, 812}], Line3DBox[{814, 3, 1013, 990, 813, 844, 814}], 
      Line3DBox[{1192, 6, 2201, 1014, 1015, 3092, 1016, 2255, 1017, 2238, 
       3068, 1018, 1019, 2240, 1020, 1021, 2241, 1022, 1023, 3069, 1024, 1025,
        3065, 1027, 817, 1196, 8, 1194, 7, 1192}], 
      Line3DBox[{1201, 11, 2204, 1028, 1029, 3095, 1030, 2259, 1031, 3332, 
       2239, 1032, 1033, 3097, 1034, 1035, 1036, 1037, 2247, 1038, 1039, 1040,
        1041, 3087, 1042, 1043, 1044, 1045, 3085, 1046, 1047, 1048, 3067, 
       1049, 1050, 1052, 821, 1203, 12, 1201}], Line3DBox[CompressedData["
1:eJwl0EdOAkAUgOFnwISFC6MncGFiQuJhsDdQ7AWwo4IVe2/Y496D6I3c+yUu
vvyT92YxmbZ8KVNsiIgsXw6/WtDPVEQmGdFFNz300kc/7U0RAzrIEMOMkCVH
wn5Ux8gzzgSTTDFN0p0ZnWWOeRYo0GFX1BKLLLHMCim7VV1jnTIb/Hjzpm4R
7lS0Stp5W3fYZY99Ws0PtMYhRxxzQovdqZ5xzgWXdJpf6TU33HJHs/m9PvBI
nScazZ/1hVfeeOeD78T/n/8Bh5csjQ==
       "]], 
      Line3DBox[{452, 282, 1686, 468, 1053, 1054, 1055, 1056, 1057, 3101, 
       1058, 1059, 1060, 1061, 1062, 1063, 3102, 1064, 1065, 1066, 1067, 1068,
        2262, 1069, 3071, 1070, 2263, 1071, 2245, 1072, 1073, 2265, 3104, 
       1074, 2266, 1075, 1076, 1077, 1078, 3105, 1079, 1080, 1081, 1082, 1083,
        3106, 1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091, 3107, 1092, 
       1093, 1094, 1095, 1096, 1097, 1098, 3078, 1099, 1100, 1101, 1102, 1103,
        1104, 984, 452}], Line3DBox[{1185, 958, 960, 863, 1185}], 
      Line3DBox[{959, 1184, 1183, 1182, 959}]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0r1PU1EYwOEXCv0UBIyiUTEkaEFGS0H8wI+4a8Muyt4admBgpasM+Bfo
piK0Cq46OGuMk2JVNJIQbYxh8GkcfnnOzc3JOffNHbxbKZXbImJJw4mIc+0R
Qzysl9mIa57f8BY/cIbfWeFfLjCTi6jyKB8wz0csss4bfM1pvuMsv3COTX7m
MeedVafOaECPUxFJPmGKT5nmGjN8xizXmeMGD7DGurqsn7ObL3iQm+zhFntb
38g+3k9HHOeoDimvU6q6WwcX+dtd77HBO3zLEl/xOmss8CFPc5VHuMwU5/nH
zMr8xtt8z5v85H2/c0Z0tbWfJ7WfjLjSmjWnWvt5mU1e4i9e5B4vcJc/NWn9
g+e5wwl+5TgbLHKbY/zIAlfM4ETi/3/wD7ReQLc=
       "]]}, {
      Line3DBox[{2268, 2544, 2692, 2718, 1363, 3063, 2690, 2744, 3544, 2454, 
       3047, 3746, 2455, 2269, 3335, 2456, 2270, 3064}], 
      Line3DBox[{2278, 2691, 3122, 3527, 2728, 2727, 1375, 2279, 3342, 2465, 
       2280, 3343, 2466, 2281, 3344, 2467, 3048, 3749, 3334}], 
      Line3DBox[{2288, 3125, 3424, 2287, 3126, 3425, 2289, 3350, 2472, 2290, 
       3351, 2473, 2291, 3352, 2474, 2292, 3353, 2475, 3050, 3750, 2476, 3051,
        3751, 3127, 3426, 2293, 3128, 3427, 2294, 3129, 3428, 2295, 3354, 
       3070}], Line3DBox[{2298, 3130, 3429, 2297, 3131, 3430, 2299, 3132, 
       3431, 2300, 3133, 3432, 2301, 3356, 2478, 2302, 3357, 2479, 2303, 3358,
        2480, 2304, 3359, 3134, 3433, 2305, 3135, 3434, 2306, 3136, 3435, 
       2307, 2545, 3752, 3198, 3052, 3502, 2546, 3059, 2547, 2653, 2308, 2663,
        3333}], Line3DBox[{2309, 3061, 3117}], 
      Line3DBox[{2311, 3137, 3436, 2310, 3138, 3437, 2312, 3139, 3438, 2313, 
       3140, 3439, 2314, 3141, 3440, 2315, 3360, 2481, 2316, 3361, 2482, 2317,
        3532, 2698, 2699, 3531, 2318, 2729, 2730, 3542, 2319, 3142, 3441, 
       2320, 3143, 3442, 2321, 3199, 3511, 2593, 2548, 2322, 3503, 2549, 2639,
        2550, 2654, 2323, 3113}], Line3DBox[{2324, 3062, 3116}], 
      Line3DBox[{2326, 3144, 3443, 2325, 3145, 3444, 2327, 3146, 3445, 2328, 
       3147, 3446, 2329, 3148, 3447, 2330, 3149, 3448, 2331, 3533, 2701, 2702,
        2332, 3534, 2703, 2704, 2700, 2720, 2719, 3530, 2333, 2732, 2733, 
       2731, 3449, 3218, 2334, 3150, 3450, 2335, 2707, 3451, 3219, 2336, 3200,
        3521, 2656, 2706, 2705, 2337, 3201, 3520, 2655, 2659, 2658, 2338, 
       3517, 2616, 2617, 3057, 3114}], Line3DBox[{3089, 2339}], 
      Line3DBox[{2343, 3362, 2483, 2341, 3363, 2484, 2345, 3364, 2485, 2347, 
       3365, 2486, 2349, 3366, 2487, 2351, 3367, 2488, 2353, 3368, 2489, 2355,
        3529, 2694, 3369, 2490, 2735, 2734, 3370, 2491, 2358, 3371, 2492, 
       2360, 2709, 2710, 3535, 2493, 2362, 3214, 3372, 2494, 2666, 2722, 3538,
        3222, 2596, 2675, 2495, 2676, 3208, 3518, 2619, 2597, 2641, 2496, 
       2640}], Line3DBox[{2365, 2667, 2668, 2595, 2618, 3512, 3207, 2364, 
       2629, 2683, 2630, 2582, 3217, 3510, 2714, 2674, 2363, 2681, 2682, 2657,
        3522, 3213, 2361, 3220, 3461, 2708, 2359, 3460, 3158, 2357, 3225, 
       3459, 2745, 2747, 2746, 2356, 3226, 3543, 2736, 2695, 2693, 3528, 2354,
        3458, 3157, 2352, 3457, 3156, 2350, 3456, 3155, 2348, 3455, 3154, 
       2346, 3454, 3153, 2344, 3453, 3152, 2340, 3452, 3151, 2342}], 
      Line3DBox[{2367, 3373, 2497, 2366, 3374, 2498, 2368, 3375, 2499, 2369, 
       3376, 2500, 2370, 3377, 2501, 2371, 3378, 2502, 2372, 3379, 2503, 2373,
        3380, 1446, 2374, 3381, 2504, 2375, 2711, 3382, 2505, 2712, 2551, 
       2697, 3537, 2721, 2506, 2642, 2677, 2678, 3383, 2583, 2631, 2685, 2507,
        2598, 2713, 3536, 3221, 2669, 2679, 2508, 2680, 3209, 3519, 2620, 
       2599, 2644, 2509, 2643}], 
      Line3DBox[{2377, 3159, 3462, 2376, 3384, 2510, 2378, 3385, 2511, 2379, 
       3386, 2512, 2380, 3387, 2513, 2381, 3388, 2514, 2382, 3389, 2515, 2383,
        3390, 3160, 3463, 2384, 1458, 2385, 3391, 2516, 2386, 2696, 3392, 
       2517, 2715, 2738, 2739, 3393, 2737, 2748, 2518, 2684, 2716, 2717, 3394,
        2584, 2632, 2686, 2519, 2670, 3525, 2606, 2607, 2568, 2646, 2520, 
       2645}], Line3DBox[{2388, 3161, 3464, 2387, 3162, 3465, 2389, 3395, 
       2521, 2390, 3396, 2522, 2391, 3397, 2523, 2392, 3398, 2524, 2393, 3399,
        2525, 2394, 3400, 3163, 3466, 2395, 3164, 3467, 2396, 3401, 2526, 
       2397, 3402, 2527, 2398, 3224, 3403, 2528, 2725, 3540, 2567, 2529, 2569,
        3202, 3513, 2552, 2671, 2648, 2649, 2647}], 
      Line3DBox[{2400, 3165, 3468, 2399, 3166, 3469, 2401, 3167, 3470, 2402, 
       3404, 2530, 2403, 3405, 2531, 2404, 3406, 2532, 2405, 3407, 2533, 2406,
        3408, 3168, 3471, 2407, 3169, 3472, 2408, 3170, 3473, 2409, 3409, 
       2534, 2410, 3410, 2535, 2411, 3505, 2570, 2536, 2571, 3203, 3514, 2553,
        2672, 2651, 2652, 2650}], 
      Line3DBox[{2413, 3171, 3474, 2412, 3172, 3475, 2414, 3173, 3476, 2415, 
       3174, 3477, 2416, 3411, 2537, 2417, 3412, 2538, 2418, 3413, 2539, 2419,
        3414, 3175, 3478, 2420, 3176, 3479, 2421, 3177, 3480, 2422, 3178, 
       3481, 2423, 3415, 2540, 2424, 3506, 2572, 2573, 2425, 3216, 3504, 2554,
        2673, 2555, 2608, 2426}], 
      Line3DBox[{2428, 3179, 3482, 2427, 3180, 3483, 2429, 3181, 3484, 2430, 
       3182, 3485, 2431, 3183, 3486, 2432, 3416, 2541, 2433, 3417, 2542, 2434,
        3418, 3184, 3487, 2435, 3185, 3488, 2436, 3186, 3489, 2437, 3187, 
       3490, 2438, 3227, 3491, 2740, 2439, 2741, 3507, 2574, 2687, 2575, 2688,
        2689, 3526, 2609, 2556, 2621, 2557, 2622, 2610, 2633}], 
      Line3DBox[{2453, 2611, 2612, 2576, 2724, 2723, 3539, 2452, 2742, 2749, 
       2743, 2726, 3541, 3223, 2451, 3501, 3197, 2450, 3500, 3196, 2449, 3499,
        3195, 2448, 3498, 3194, 2447, 3497, 3193, 3420, 2446, 2543, 3419, 
       2445, 3496, 3192, 2444, 3495, 3191, 2443, 3494, 3190, 2442, 3493, 3189,
        2441, 3492, 3188, 2440, 3508, 2578, 2577, 2579}], 
      Line3DBox[{2558, 2464, 3120}], Line3DBox[{3119, 2634}], 
      Line3DBox[{2637, 3060, 3073}], 
      Line3DBox[{2751, 3042, 3228, 3545, 2750, 3647, 2958, 2752, 3648, 2959, 
       2753, 3649, 2960, 2754, 3650, 2961, 2755, 3651, 2962, 2756, 3652, 2963,
        2757, 3653, 3229, 3546, 2758, 3654, 2964, 2759, 3655, 2965, 2760, 
       3656, 2966, 2761, 3657, 2967, 2762, 3658, 2968, 2763, 3330, 3744, 2969,
        3043}], 
      Line3DBox[{2765, 3230, 3547, 2764, 3231, 3548, 2766, 3659, 2970, 2767, 
       3660, 2971, 2768, 3661, 2972, 2769, 3662, 2973, 2770, 3663, 2974, 2771,
        3664, 3232, 3549, 2772, 3233, 3550, 2773, 3665, 2975, 2774, 3666, 
       2976, 2775, 3667, 2977, 2776, 3668, 2978, 2777, 3669, 2979, 2778}], 
      Line3DBox[{2780, 3234, 3551, 2779, 3235, 3552, 2781, 3236, 3553, 2782, 
       3670, 2980, 2783, 3671, 2981, 2784, 3672, 2982, 2785, 3673, 2983, 2786,
        3674, 3237, 3554, 2787, 3238, 3555, 2788, 3239, 3556, 2789, 3675, 
       2984, 2790, 3676, 2985, 2791, 3677, 2986, 2792, 3678, 2987, 2793}], 
      Line3DBox[{2795, 3240, 3557, 2794, 3241, 3558, 2796, 3242, 3559, 2797, 
       3243, 3560, 2798, 3679, 2988, 2799, 3680, 2989, 2800, 3681, 2990, 2801,
        3682, 3244, 3561, 2802, 3245, 3562, 2803, 3246, 3563, 2804, 3247, 
       3564, 2805, 3683, 2991, 2806, 3684, 2992, 2807, 3685, 2993, 2808}], 
      Line3DBox[{2810, 3248, 3565, 2809, 3249, 3566, 2811, 3250, 3567, 2812, 
       3251, 3568, 2813, 3252, 3569, 2814, 3686, 2994, 2815, 3687, 2995, 2816,
        3688, 3253, 3570, 2817, 3254, 3571, 2818, 3255, 3572, 2819, 3256, 
       3573, 2820, 3257, 3574, 2821, 3689, 2996, 2822, 3690, 2997, 2823}], 
      Line3DBox[{2825, 3258, 3575, 2824, 3259, 3576, 2826, 3260, 3577, 2827, 
       3261, 3578, 2828, 3262, 3579, 2829, 3263, 3580, 2830, 3691, 2998, 2831,
        3692, 3264, 3581, 2832, 3265, 3582, 2833, 3266, 3583, 2834, 3267, 
       3584, 2835, 3268, 3585, 2836, 3269, 3586, 2837, 3693, 2999, 2838}], 
      Line3DBox[{668, 1865, 669, 1866, 670, 1867, 671, 1868, 672, 1869, 673, 
       1870, 674, 1871, 675}], 
      Line3DBox[{2840, 3270, 3587, 2839, 3271, 3588, 2841, 3272, 3589, 2842, 
       3273, 3590, 2843, 3274, 3591, 2844, 3275, 3592, 2845, 3276, 3593, 2846,
        3694, 3277, 3594, 2847, 3278, 3595, 2848, 3279, 3596, 2849, 3280, 
       3597, 2850, 3281, 3598, 2851, 3282, 3599, 2852, 3283, 3600, 2853}], 
      Line3DBox[{2855, 2088, 2854, 3695, 3000, 2856, 3696, 3001, 2857, 3697, 
       3002, 2858, 3698, 3003, 2859, 3699, 3004, 2860, 3700, 3005, 2861, 3701,
        2096, 2862, 3702, 3006, 2863, 3703, 3007, 2864, 3704, 3008, 2865, 
       3705, 3009, 2866, 3706, 3010, 2867, 3707, 3011, 2868}], 
      Line3DBox[{682, 1879, 681, 1878, 680, 1877, 679, 1876, 678, 1875, 677, 
       1874, 676, 1873, 1872}], 
      Line3DBox[{2870, 3284, 3601, 2869, 2104, 2871, 3708, 3012, 2872, 3709, 
       3013, 2873, 3710, 3014, 2874, 3711, 3015, 2875, 3712, 3016, 2876, 3713,
        3285, 3602, 2877, 3286, 3603, 2878, 3714, 3017, 2879, 3715, 3018, 
       2880, 3716, 3019, 2881, 3717, 3020, 2882, 3718, 3021, 2883}], 
      Line3DBox[{2885, 3287, 3604, 2884, 3288, 3605, 2886, 2120, 2887, 3719, 
       3022, 2888, 3720, 3023, 2889, 3721, 3024, 2890, 3722, 3025, 2891, 3723,
        3289, 3606, 2892, 3290, 3607, 2893, 3291, 3608, 2894, 3724, 3026, 
       2895, 3725, 3027, 2896, 3726, 3028, 2897, 3727, 3029, 2898}], 
      Line3DBox[{2900, 3292, 3609, 2899, 3293, 3610, 2901, 3294, 3611, 2902, 
       2136, 2903, 3728, 3030, 2904, 3729, 3031, 2905, 3730, 3032, 2906, 3731,
        3295, 3612, 2907, 3296, 3613, 2908, 3297, 3614, 2909, 3298, 3615, 
       2910, 3732, 3033, 2911, 3733, 3034, 2912, 3734, 3035, 2913}], 
      Line3DBox[{2915, 3299, 3616, 2914, 3300, 3617, 2916, 3301, 3618, 2917, 
       3302, 3619, 2918, 2152, 2919, 3735, 3036, 2920, 3736, 3037, 2921, 3737,
        3303, 3620, 2922, 3304, 3621, 2923, 3305, 3622, 2924, 3306, 3623, 
       2925, 3307, 3624, 2926, 3738, 3038, 2927, 3739, 3039, 2928}], 
      Line3DBox[{2930, 3308, 3625, 2929, 3309, 3626, 2931, 3310, 3627, 2932, 
       3311, 3628, 2933, 3312, 3629, 2934, 2168, 2935, 3740, 3040, 2936, 3741,
        3313, 3630, 2937, 3314, 3631, 2938, 3315, 3632, 2939, 3316, 3633, 
       2940, 3317, 3634, 2941, 3318, 3635, 2942, 3742, 3041, 2943}], 
      Line3DBox[{2957, 3046, 3745, 3331, 2956, 3646, 3329, 2955, 3645, 3328, 
       2954, 3644, 3327, 2953, 3643, 3326, 2952, 3642, 3325, 2951, 3641, 3324,
        3743, 2950, 2184, 2949, 3640, 3323, 2948, 3639, 3322, 2947, 3638, 
       3321, 2946, 3637, 3320, 2945, 3636, 3319, 2944, 2195, 3044, 3045}], 
      Line3DBox[{3066, 2275, 2460, 3339, 2274, 3421, 3121, 3094}], 
      Line3DBox[{3074, 3058, 2628, 2615, 3079}], 
      Line3DBox[{3081, 2623, 3108}], Line3DBox[{3082, 2580, 3110}], 
      Line3DBox[{3083, 2581, 3111}], Line3DBox[{3084, 2624, 2463, 3100}], 
      Line3DBox[{3086, 2625, 3099}], 
      Line3DBox[{3093, 3123, 3422, 2284, 3124, 3423, 2285, 3347, 2470, 3049, 
       3096}], Line3DBox[{3098, 2626, 2662, 3524, 3056, 3103}]}, {
      Line3DBox[{1189, 1366, 3335, 1190, 1377, 3343, 1207, 1388, 3351, 1216, 
       3432, 1397, 1227, 3439, 1409, 1239, 3446, 1420, 1250, 3455, 1430, 3365,
        1261, 1441, 3376, 1274, 1452, 3386, 1286, 1464, 3396, 1298, 1476, 
       3404, 1312, 3477, 1489, 1326, 3485, 1502, 1339, 3494, 1514, 1352}], 
      Line3DBox[{1198, 1371, 3339, 1199, 3423, 1382, 1211, 3427, 1392, 1222, 
       3434, 1403, 1233, 1747, 3542, 1414, 1244, 3449, 1692, 1424, 1255, 3459,
        1748, 1435, 3370, 1267, 1447, 3381, 1280, 1458, 1292, 3467, 1470, 
       1304, 3472, 1482, 1318, 3479, 1495, 1332, 3488, 1508, 1345, 3498, 1520,
        1358}], 
      Line3DBox[{1349, 1511, 3508, 1570, 1336, 1499, 3482, 1323, 1486, 3474, 
       1309, 1473, 3468, 1295, 1461, 3464, 1283, 1449, 3462, 1271, 3373, 1438,
        1258, 3362, 1427, 3452, 1247, 1417, 3443, 1236, 1406, 3436, 1224, 
       1394, 3429, 1213, 1385, 3424, 1204, 1374, 3527, 1744, 1746, 1745, 1186,
        1363, 1722, 2237, 2253}], 
      Line3DBox[{1350, 1512, 3492, 1337, 1500, 3483, 1324, 1487, 3475, 1310, 
       1474, 3469, 1296, 1462, 3465, 1284, 3384, 1450, 1272, 3374, 1439, 1259,
        3363, 1428, 3453, 1248, 1418, 3444, 1237, 1407, 3437, 1225, 1395, 
       3430, 1214, 1386, 3425, 1205, 1375, 1743, 1187, 3544, 1364, 1691, 
       1741}], Line3DBox[{1351, 1513, 3493, 1338, 1501, 3484, 1325, 1488, 
       3476, 1311, 1475, 3470, 1297, 3395, 1463, 1285, 3385, 1451, 1273, 3375,
        1440, 1260, 3364, 1429, 3454, 1249, 1419, 3445, 1238, 1408, 3438, 
       1226, 1396, 3431, 1215, 3350, 1387, 1206, 3342, 1376, 1188, 3746, 1365,
        2200}], 
      Line3DBox[{1353, 1515, 3495, 1340, 1503, 3486, 1327, 3411, 1490, 1313, 
       3405, 1477, 1299, 3397, 1465, 1287, 3387, 1453, 1275, 3377, 1442, 1262,
        3366, 1431, 3456, 1251, 1421, 3447, 1240, 1410, 3440, 1228, 3356, 
       1398, 1217, 3352, 1389, 1208, 3344, 1378, 2242}], 
      Line3DBox[{1354, 1516, 3496, 1341, 3416, 1504, 1328, 3412, 1491, 1314, 
       3406, 1478, 1300, 3398, 1466, 1288, 3388, 1454, 1276, 3378, 1443, 1263,
        3367, 1432, 3457, 1252, 1422, 3448, 1241, 3360, 1411, 1229, 3357, 
       1399, 1218, 3353, 1390, 2207, 3749, 2256}], 
      Line3DBox[{1355, 3419, 1517, 1342, 3417, 1505, 1329, 3413, 1492, 1315, 
       3407, 1479, 1301, 3399, 1467, 1289, 3389, 1455, 1277, 3379, 1444, 1264,
        3368, 1433, 3458, 1253, 1704, 3533, 1703, 1242, 3361, 1412, 1230, 
       3358, 1400, 1219, 3750, 2257}], 
      Line3DBox[{1357, 1519, 3497, 1344, 1507, 3487, 1331, 1494, 3478, 1317, 
       1481, 3471, 1303, 1469, 3466, 1291, 1457, 3463, 1279, 1446, 1266, 3369,
        1434, 1749, 1751, 1750, 3543, 1254, 1423, 1725, 1695, 1724, 3530, 
       1723, 1243, 1413, 3531, 1700, 1232, 1402, 3433, 1221, 1391, 3426, 1210,
        1381, 3422, 1197, 1370, 3421, 2202}], 
      Line3DBox[{1359, 1521, 3499, 1346, 1509, 3489, 1333, 1496, 3480, 1319, 
       1483, 3473, 1305, 3401, 1471, 1293, 3391, 1459, 1281, 3382, 1448, 1714,
        1713, 1268, 3371, 1436, 3460, 1256, 1425, 3450, 1245, 1415, 3441, 
       1234, 1404, 3435, 1223, 1393, 3428, 1212, 3347, 1383, 2243}], 
      Line3DBox[{1360, 1522, 3500, 1347, 1510, 3490, 1334, 1497, 3481, 1320, 
       3409, 1484, 1306, 3402, 1472, 1294, 3392, 1460, 1717, 1697, 1728, 1282,
        1727, 3537, 1726, 1653, 1536, 1269, 3535, 1437, 1712, 3461, 1257, 
       1426, 1709, 1708, 3451, 1246, 1416, 3442, 1235, 1405, 1655, 1524, 3752,
        2211, 3354, 2216, 2209, 2260}], 
      Line3DBox[{1361, 1523, 3501, 1348, 1757, 1756, 3491, 1335, 3415, 1498, 
       1321, 3410, 1485, 1307, 3403, 1738, 1737, 1752, 1753, 3393, 1760, 1549,
        1754, 1548, 1736, 1718, 1575, 1684, 3383, 1547, 1654, 1546, 1270, 
       3372, 1649, 1648, 3522, 1662, 1711, 1533, 1710, 1532, 3521, 1661, 1528,
        1527, 3511, 1584, 1657, 1526, 1656, 3502, 1525, 2261}], 
      Line3DBox[{1362, 1732, 1731, 3541, 1742, 1567, 1758, 3507, 1566, 1759, 
       1689, 1563, 3506, 1562, 1322, 1560, 3505, 1559, 1308, 1556, 3540, 1739,
        1555, 1740, 1577, 1719, 3394, 1553, 1687, 1552, 1671, 3536, 1715, 
       1551, 1590, 1550, 1632, 1588, 3538, 1729, 1545, 1730, 1544, 1682, 1680,
        3510, 1573, 1663, 1681, 1535, 1660, 1534, 3520, 1659, 1698, 1530, 
       1658, 3503, 1529, 1652, 1670, 2219, 2250}], Line3DBox[{2254, 1538}], 
      Line3DBox[{1571, 1537, 1733, 1735, 3539, 1734, 1569, 1677, 1755, 1678, 
       1568, 1605, 3526, 1690, 1604, 1565, 1675, 1676, 1564, 3504, 1674, 1673,
        1716, 1602, 1603, 3514, 1561, 1601, 1600, 1637, 1598, 1599, 3513, 
       1558, 1597, 1596, 1557, 1594, 3525, 1672, 1595, 1554, 1593, 1688, 1592,
        1591, 3519, 1635, 1685, 1636, 1576, 1634, 1651, 1633, 1589, 3518, 
       1630, 1683, 1631, 1574, 1629, 1650, 1628, 3512, 1587, 1626, 1627, 1572,
        1625, 3517, 1624, 2267}], 
      Line3DBox[{1762, 1985, 3647, 1763, 3548, 1999, 1791, 3552, 2014, 1806, 
       3558, 2029, 1821, 3566, 2044, 1836, 3576, 2059, 1851, 3588, 2074, 1866,
        2089, 3695, 1881, 2104, 1896, 3605, 2119, 1911, 3610, 2134, 1926, 
       3617, 2149, 1941, 3626, 2164, 1956, 3636, 2179, 1971}], 
      Line3DBox[{1764, 1986, 3648, 1765, 2000, 3659, 1792, 3553, 2015, 1807, 
       3559, 2030, 1822, 3567, 2045, 1837, 3577, 2060, 1852, 3589, 2075, 1867,
        2090, 3696, 1882, 2105, 3708, 1897, 2120, 1912, 3611, 2135, 1927, 
       3618, 2150, 1942, 3627, 2165, 1957, 3637, 2180, 1972}], 
      Line3DBox[{1766, 1987, 3649, 1767, 2001, 3660, 1793, 2016, 3670, 1808, 
       3560, 2031, 1823, 3568, 2046, 1838, 3578, 2061, 1853, 3590, 2076, 1868,
        2091, 3697, 1883, 2106, 3709, 1898, 2121, 3719, 1913, 2136, 1928, 
       3619, 2151, 1943, 3628, 2166, 1958, 3638, 2181, 1973}], 
      Line3DBox[{1768, 1988, 3650, 1769, 2002, 3661, 1794, 2017, 3671, 1809, 
       2032, 3679, 1824, 3569, 2047, 1839, 3579, 2062, 1854, 3591, 2077, 1869,
        2092, 3698, 1884, 2107, 3710, 1899, 2122, 3720, 1914, 2137, 3728, 
       1929, 2152, 1944, 3629, 2167, 1959, 3639, 2182, 1974}], 
      Line3DBox[{1770, 1989, 3651, 1771, 2003, 3662, 1795, 2018, 3672, 1810, 
       2033, 3680, 1825, 2048, 3686, 1840, 3580, 2063, 1855, 3592, 2078, 1870,
        2093, 3699, 1885, 2108, 3711, 1900, 2123, 3721, 1915, 2138, 3729, 
       1930, 2153, 3735, 1945, 2168, 1960, 3640, 2183, 1975}], 
      Line3DBox[{1772, 1990, 3652, 1773, 2004, 3663, 1796, 2019, 3673, 1811, 
       2034, 3681, 1826, 2049, 3687, 1841, 2064, 3691, 1856, 3593, 2079, 1871,
        2094, 3700, 1886, 2109, 3712, 1901, 2124, 3722, 1916, 2139, 3730, 
       1931, 2154, 3736, 1946, 2169, 3740, 1961, 2184, 1976}], 
      Line3DBox[{1774, 1991, 3653, 1776, 2005, 3664, 1797, 2020, 3674, 1812, 
       2035, 3682, 1827, 2050, 3688, 1842, 2065, 3692, 1857, 2080, 3694, 1872,
        2095, 3701, 1887, 2110, 3713, 1902, 2125, 3723, 1917, 2140, 3731, 
       1932, 2155, 3737, 1947, 2170, 3741, 1962, 2185, 3743, 1977}], 
      Line3DBox[{1778, 1993, 3654, 1779, 3550, 2007, 1799, 3555, 2022, 1814, 
       3562, 2037, 1829, 3571, 2052, 1844, 3582, 2067, 1859, 3595, 2082, 1874,
        2097, 3702, 1889, 3603, 2112, 1904, 3607, 2127, 1919, 3613, 2142, 
       1934, 3621, 2157, 1949, 3631, 2172, 1964, 3642, 2187, 1979}], 
      Line3DBox[{1780, 1994, 3655, 1781, 2008, 3665, 1800, 3556, 2023, 1815, 
       3563, 2038, 1830, 3572, 2053, 1845, 3583, 2068, 1860, 3596, 2083, 1875,
        2098, 3703, 1890, 2113, 3714, 1905, 3608, 2128, 1920, 3614, 2143, 
       1935, 3622, 2158, 1950, 3632, 2173, 1965, 3643, 2188, 1980}], 
      Line3DBox[{1782, 1995, 3656, 1783, 2009, 3666, 1801, 2024, 3675, 1816, 
       3564, 2039, 1831, 3573, 2054, 1846, 3584, 2069, 1861, 3597, 2084, 1876,
        2099, 3704, 1891, 2114, 3715, 1906, 2129, 3724, 1921, 3615, 2144, 
       1936, 3623, 2159, 1951, 3633, 2174, 1966, 3644, 2189, 1981}], 
      Line3DBox[{1784, 1996, 3657, 1785, 2010, 3667, 1802, 2025, 3676, 1817, 
       2040, 3683, 1832, 3574, 2055, 1847, 3585, 2070, 1862, 3598, 2085, 1877,
        2100, 3705, 1892, 2115, 3716, 1907, 2130, 3725, 1922, 2145, 3732, 
       1937, 3624, 2160, 1952, 3634, 2175, 1967, 3645, 2190, 1982}], 
      Line3DBox[{1786, 1997, 3658, 1787, 2011, 3668, 1803, 2026, 3677, 1818, 
       2041, 3684, 1833, 2056, 3689, 1848, 3586, 2071, 1863, 3599, 2086, 1878,
        2101, 3706, 1893, 2116, 3717, 1908, 2131, 3726, 1923, 2146, 3733, 
       1938, 2161, 3738, 1953, 3635, 2176, 1968, 3646, 2191, 1983}], 
      Line3DBox[{1788, 2193, 2194, 3744, 1789, 2012, 3669, 1804, 2027, 3678, 
       1819, 2042, 3685, 1834, 2057, 3690, 1849, 2072, 3693, 1864, 3600, 2087,
        1879, 2102, 3707, 1894, 2117, 3718, 1909, 2132, 3727, 1924, 2147, 
       3734, 1939, 2162, 3739, 1954, 2177, 3742, 1969, 3745, 2196, 2197, 
       2198}], Line3DBox[{1970, 2178, 2195, 1955, 2163, 3625, 1940, 2148, 
       3616, 1925, 2133, 3609, 1910, 2118, 3604, 1895, 2103, 3601, 1880, 2088,
        1865, 2073, 3587, 1850, 2058, 3575, 1835, 2043, 3565, 1820, 2028, 
       3557, 1805, 2013, 3551, 1790, 1998, 3547, 1761, 1984, 3545, 2192, 
       2199}], Line3DBox[{1978, 2186, 3641, 1963, 2171, 3630, 1948, 2156, 
       3620, 1933, 2141, 3612, 1918, 2126, 3606, 1903, 2111, 3602, 1888, 2096,
        1873, 2081, 3594, 1858, 2066, 3581, 1843, 2051, 3570, 1828, 2036, 
       3561, 1813, 2021, 3554, 1798, 2006, 3549, 1777, 1992, 3546, 1775}], 
      Line3DBox[{2244, 2218, 1669, 2264}], 
      Line3DBox[{2248, 3524, 2217, 1668, 2249}], 
      Line3DBox[{2258, 3751, 1220, 1401, 3359, 1231, 1699, 3532, 1701, 1702, 
       1706, 3534, 1707, 1705, 1531, 1696, 1693, 3528, 3529, 1694, 1265, 1445,
        3380, 1278, 1456, 3390, 1290, 1468, 3400, 1302, 1480, 3408, 1316, 
       1493, 3414, 1330, 1506, 3418, 1343, 1518, 3420, 
       1356}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXk0lt/6x/+UigzNCmlChVLSRKUrkiFTiVIoyZDQgJQUUiIhGgyFDCmS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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{364.33400497460514`, 175.4984815636671},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{1.3028358028874827`, 3.058794643387869, 0.6295984436895339},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.6043281823532763`*^9, 3.612976323078226*^9, 
  3.6239959565085187`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Fit", " ", "the", " ", "two", " ", "extremun", " ", "curves", " ", 
     "from", " ", "the", " ", "previous", " ", "function", " ", "for", " ", 
     "Cos\[Theta]V"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"0", " ", "and", " ", "Cos\[Theta]V"}], " ", "=", " ", 
     RowBox[{
     "1", " ", "then", " ", "interpolate", " ", "in", " ", "between", " ", 
      "to", " ", "recover", " ", "the", " ", "final", " ", "2", "D", " ", 
      RowBox[{"function", ".", " ", "Fit"}], " ", "function", " ", "have", 
      " ", "been", " ", "chose", " ", "base", " ", "on", " ", "the", " ", 
      "shape", " ", "of", " ", "the", " ", 
      RowBox[{"curve", ".", " ", "We"}], " ", "perform", " ", "two", " ", 
      RowBox[{"fitting", ".", " ", "One"}], " ", "simple", " ", "and", " ", 
      "one", " ", "complex", " ", "more", " ", "accurate"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FitFrGGXSimple1", "[", "Roughness_", "]"}], "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "Roughness"}], ")"}], "^", "a"}], " ", "/.", " ", 
    RowBox[{"FindFit", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", " ", 
          RowBox[{"GetLerpFactorFrGGX", "[", 
           RowBox[{"0.9", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0.001", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
      ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "xx"}], ")"}], "^", "a"}], " ", ",", 
      RowBox[{"{", "a", "}"}], ",", "xx"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.604293185520808*^9, 3.604293234124894*^9}, {
   3.604293722409746*^9, 3.604293792118869*^9}, {3.6042938276659284`*^9, 
   3.6042938733820086`*^9}, {3.6042940312442837`*^9, 
   3.6042940670123434`*^9}, {3.6042942053245797`*^9, 
   3.6042942482956553`*^9}, {3.604294520094108*^9, 3.604294553435166*^9}, {
   3.604294655655332*^9, 3.6042946669493494`*^9}, {3.604295095478054*^9, 
   3.6042951075610733`*^9}, {3.6043273019159184`*^9, 
   3.6043273093303423`*^9}, {3.604327340601131*^9, 3.6043273419052057`*^9}, {
   3.604327477042935*^9, 3.604327574705521*^9}, {3.6043276363640475`*^9, 
   3.604327651907937*^9}, {3.6043277855875826`*^9, 3.604327810628015*^9}, 
   3.6043281780850325`*^9, 3.604328245022861*^9, {3.6043283103075953`*^9, 
   3.60432831057061*^9}, {3.6043287309476547`*^9, 3.604328746626551*^9}, {
   3.604328963764971*^9, 3.6043289720104427`*^9}, {3.612976348704692*^9, 
   3.612976434814617*^9}, {3.612976471806733*^9, 3.6129765239587154`*^9}, {
   3.6129765556545286`*^9, 3.6129766009351187`*^9}, {3.6129767331126785`*^9, 
   3.612976768719715*^9}}],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   RowBox[{"1", "-", "Roughness"}], ")"}], "0.2891837804614315`"]], "Output",
 CellChangeTimes->{
  3.604294249975658*^9, {3.6042945463151526`*^9, 3.6042945558461695`*^9}, {
   3.604294659368337*^9, 3.604294668729352*^9}, {3.604295098411059*^9, 
   3.6042951121870813`*^9}, 3.604315958314101*^9, {3.6043276299506807`*^9, 
   3.6043276547480993`*^9}, {3.604327793423031*^9, 3.6043278126801324`*^9}, {
   3.6043283012180753`*^9, 3.6043283143708277`*^9}, 3.6043287517728453`*^9, 
   3.604328976027672*^9, 3.6129765441058683`*^9, 3.612976604074298*^9, 
   3.61297677789124*^9, 3.62399595933068*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FitFrGGXComplex1", "[", "Roughness_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"a", "*", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"b", "*", "Roughness"}], "+", "c"}], "]"}]}], " ", "/.", " ", 
   RowBox[{"FindFit", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", " ", 
         RowBox[{"GetLerpFactorFrGGX", "[", 
          RowBox[{"0.91", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.001", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
     ",", 
     RowBox[{"a", "*", 
      RowBox[{"Log", "[", 
       RowBox[{
        RowBox[{"b", "*", "xx"}], "+", "c"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", " ", "b", ",", " ", "c"}], "}"}], ",", "xx"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.604344802092554*^9, 3.604344844420975*^9}, {
  3.60434491635709*^9, 3.6043449353641768`*^9}, {3.612976765431527*^9, 
  3.612976767007617*^9}}],

Cell[BoxData[
 RowBox[{"0.29847502436794354`", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"39.41149727672321`", "\[VeryThinSpace]", "-", 
    RowBox[{"39.00289316713873`", " ", "Roughness"}]}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.604344852228422*^9, {3.604344920405321*^9, 3.60434493839435*^9}, 
   3.6129765468440247`*^9, 3.6129767806063952`*^9, 3.623995962037835*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Check", " ", "the", " ", "accuracy", " ", "of", " ", "the", " ", 
   "fitting"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6129766110396967`*^9, 3.6129766134708357`*^9}, {
  3.612976779590337*^9, 3.612976785446672*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FitFrGGXSimple1", "[", "x", "]"}], ",", " ", 
     RowBox[{"FitFrGGXComplex1", "[", "x", "]"}], ",", " ", 
     RowBox[{"GetLerpFactorFrGGX", "[", 
      RowBox[{"0.999", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6042942547926655`*^9, 3.604294290300729*^9}, {
   3.6042943324948025`*^9, 3.60429437699988*^9}, {3.6042944507169967`*^9, 
   3.6042944682250276`*^9}, {3.6042945706631923`*^9, 3.60429458304921*^9}, {
   3.6043276165619154`*^9, 3.6043276172979574`*^9}, {3.604327660114406*^9, 
   3.604327668346877*^9}, {3.604328287618297*^9, 3.6043282924425735`*^9}, {
   3.604328325105441*^9, 3.604328325345455*^9}, 3.604344857740737*^9, 
   3.6129767736879997`*^9, {3.612976863984164*^9, 3.6129768659832783`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnk81P0WxylkqWfarys9iXgSJeEm0aciFSVZoj2GLIXIUkKSJ7SqiyxF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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwtlIlXzAkAxycxSmoYg4SELVI9bLFk7LeQkIdS2xZqdSoyFBW1s3QNRWKj
Ih1WeSt0kFt3DUOMZpqmZprR3dTvoCjaZI+3n/c+7/MffOb78Fz8xzEYjD3/
+G+rv5rY2ba9BeM/3oM95spM4TbgjTTqSDhJw8Q8OYmXIcH8Ky6Xcq7TSHV1
J0haivlqYnjAk8Yb7QOn3ZfKMDPjgr4Vh8atWxl2wtNN8LMNvsWspbCjmW2z
oF6OWVXvT1ZHUkj7dt0+1qIFJXraKo+FFNabCZfExiqwacON7OhXJO6LbXYc
rFHCJ3EP60IkiVdHnpzzNlGB42+hu9KIxJ+ZZ/W4/mrMNs1NLykjcLQ9oljh
/A42m4adBHsJBIatCM4cewfpVRMjh8/9WFtnWNmQ3YZQr4Ac4fl+dF7UMT2z
rR2efYv3Zc/tR5l/xRBnpB07x3t3Deb1IXr4asC0yx3QZzRHvVzWBz3mqY5U
x06ovQrkBgUa/CpLG0vSdEKsmtiGRRosuMETuJzqwjNOnllFVi/SP+6cm2nT
jZ6YrnuRWr0Y0PZy3tXYDYIVzdTy78HclCMXrsb2oE6/+woKu2GpKjrsZtYL
pz80Ar/PXQixLC1T1vbiZ11aJVzZhRPDtYY9oRpc0Ok0bHLuRHjc6JRATh+s
iy6e1wR0YG0yZgRX9yHKxEBJO7Xjh/Qtp7m8fqhmzjKYxW7DdL+oy3EsAmpN
V26NQI1VHh/r1rAJ1C5ZvzQrSg3PbSGDAxwCFWLHrzyeGjmrvLfuNSKgKblo
PfqTGkv014+tNSUwdMKaLjVVw+7+JJ9hWwKGvJqUvEoVDuhcNg8OIKA1Wpi2
eLAVNbcePtz+jECch3TORFslqFU3n8jLCfRpJx5PtFTCsPZK2d4qAqV8udP4
eUqEtPJrwoQEsl70sBXaSswwcBCnvSXAXvqtcFq9AkG8tz3qLgLWloMF1/co
YPB934xDBiSU9QlLFOEtcH8w+2iKNwn7SGemKF6OGN+a0sk+JIZ6UzRPjspx
hxUydMqPRMn2kXU5/nKM31cWcTKIRODgwVE4yFFkuPd4aBgJXi7xRa4th87x
/N9cBSQOW5g07uI34TF3eaJhIYmaqIoPRKAMXb3NotRiEgOTDriNuskw5WKM
3tR7JCyvzRCPrJchgJSc0X1EQqiYklgzTwZ2Vvi5kSoSjk2DxwSyRuz/9iRV
KSORP6fE7bZdI+ZUbczOGSMR9Gh/aBhTCtuchYSLFoWEyn2f/d5L4MFnrJ4w
nsLC2EUabosEl2wfNwTpUhj0y52dfVsC1l0rpjWHwjKqY5LZTgnGXeeE1JpT
CGru9pqQ0YDe+HbbPlcKi9609rIM3oLpVy7IdKcw4m+ltfmjGKbrMqXbPCn0
fMmf790ihs+Y28G73hRWG00eNckXQxH+Ijc6mELglXSH92vEeB1YpMM6QWGS
pbt9VcVr3N3Ml1kXUKhd7jKQxH4JeZnky4PbFHKHgqcVy0UYszafyy2iEMpx
ZfOzRNhiLPXdUEqhvG7FAT1zEdoHzD+4llMIexkvkq5+AXZmo164hEKEs/E6
o81CrJpqsXSkkULSp+mTrXWF8Eo44cKXU9hZ+OrHd8/rcPOQRUZCKwW+at93
AxvrYO9w0iyth8I37m8rRWtrcYiytH/4F4UVkSUN7ZxqXPKN8eOOUUh2n1ce
X1+Fp/ImQQWDxp283b7X4qugUx3z+vkEGkMRAondx0pkp8l3NbNoHB+orGoS
VeC1XVz4yEIanlJVSev9p7D6XVHA3UpDO883ikUV49JuxiO97TQ2hHc8n25c
DIaZaV2LM42zz+r71U5FkD48+C7SncZzg1Tj2fa3Ea3Sml7qQ+PTFOrpHY98
iMwX862O0WBSnb8EGCfDZnBr0mgUjcsRoxWnNicg6+nh9Jd8Gufach23lkYj
Wt/JThhL//9vBuNv+mD1Mg==
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxFyX1Q0gccx3HSLNLUBsbhUzOaOTfEWro4Dvtp3sy5ZqY0vfVMM5vTSFOW
yzonWrDKnOgRhMOzhnbabEuFnoxE01uaZYk4mE9pior2YHWpw9U/3+8fn3vf
6z4r+YLYRDsSiZT0bu/ruY+m2cePIQp09Ivd+gmCqjpu+8PnBHiA7awXe5SA
TbFeQrXgd3COn0sqX14Drpwnyhxba8EenTvSswOv43+1Ivg85za4P6RqjSWh
EawpLz/WuLgZ7O26Njxd3AJuPficyyL+Bi8wRNboWtrADht0xsLwDrC6Leh8
/cwDMMXGW1TI7QT7+BecEsgfgYt58RPWqcfgDvsUSXygAVxdLQ9tkXSDY3oo
QYx2I1g2fzFM9Ok/4PDVLZ+IRCZw/YOgmINNZnBbxo2zu316wZeUZ5y4iX3g
zMEf/zRt7QcnHQ5OVtrQIXfpdzpVA+ChErLv6ehBcEOi7rXbDDr7Tel+quIJ
2GmR+EnxpiHwMYPMdsqCZlQITsaKh8HnpuO8lUFPwV/MJWhm89Av7Hdt3d6F
rksRZBL96CNdOfJV4+jKwPxys/UpcW0HNTJYOUz0SCRVJc/QjkNnaqNfojkb
im4tfo1WvlB0ZM2i/1NfGBgnjYBzj9z1r6WhyVGWtGwmmmJl2TknoL0LM4pK
ReiPNJTct4/RzN4radtWj4JTmXUN5mZ0zptm+ki6BTwbMuBWoUcL8+aWJbmN
gUcjvu70C0V/u+Q36egPaGlyxHTrz+i2e5O8SzL0y277vYkKtMcQPXVl6Rgh
fuVp9LWYibBnAVn/qtAH5jbmy8vR9W6ppR9UohcGyOokl9FlO8eHs7TokAKC
lqxHc6jNW+Lcx8Hrz0VJuAL08u+OKvJcJ8ApZIV/8n50U7VWu+UW+nvBw5G+
YbTLZ2O0Qy5WMLvB5P52mZUgb2KENq5rJ/hR7V65VPRpQ8OHTjS0hn+FUUxH
Lz0q/Vjtjd4jFbK0DPSSJi7HzET/NW0XQVqPXvjN2Z2RX6HjNZ6ZhbvR17lr
f6HXoL0aI1RlNvRo/iBnjDcJvvrlccO6KjRF2eUkfIQ+NMkM086ibxq7T+pI
U2CyPvd+qwOaxTY+30xG8y4HLH/oiP6JIWJvc54iVliLFnhUpBMqmXF7jyv6
8xSWxeKOvh+aJ5xZhbZZAn/1ZKMDpKYq7mb0AV1GzAo1+oLV+dX8PPp/nPo6
cg==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0.001, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.604294409080926*^9, 3.6042945007930746`*^9, {3.6042945922752233`*^9, 
   3.6042945973122306`*^9}, 3.6042946765773664`*^9, 3.604295116950089*^9, 
   3.604315959947195*^9, {3.6043276633365903`*^9, 3.6043276712380424`*^9}, {
   3.6043277952901373`*^9, 3.6043278149662633`*^9}, 3.6043283291266713`*^9, 
   3.604328757347164*^9, 3.604328981188967*^9, 3.6043448616979637`*^9, 
   3.6129766558112574`*^9, 3.612976783437557*^9, 3.6129768700155087`*^9, 
   3.623995964833995*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnH+0VWWZx7f3nnPuD7gCWkplRr/MMtNpKVyZUWmojKLUpU7MaAWieGmp
WeEaR5dKPwAzjBtYgpfAnyCJAoNepDAwTMRxZDQI9VoEKwdbiqyR1GFyzZ3z
ed732fvd5757n733ua01fyTe82Pvs7/Pr+/zvM/77vecz0+Z0XXxZVNmTJ86
ZdQZ35hyRdf0qd8c9emvfaN6qPmQIDikKwiCV0cFvO6vvrQP/dX/+6fzwBH/
63Z5GhL0Tgvkv7HdfXKkv783mFb912tQYuc75Uhr6jXVc81ysjmY1ttvT/cH
J8tjS+qlTXKkOejv6w7GTuuVd5051awKtdcMrXNNX9A9NtCLODamRlT1uqCv
jkeajTPb5Kkc9HPOat47bWzQ3ddvP+I/NzrlXEnelYK+qprGgt6gu7sv7ZKy
x4FjsqpmrUUcgUuT4zNJ1RyjOoiDjddKKVhNcQ+qeIlX9eORk/3nRqecU3f0
dXeHwUv7fFNMdRPkJsvliEPK5cHVNXQpZBMXQTrjojSXJtsRutQ43S/Od250
yrmQYaGa/amfb7Yk5r2cM8zszKBaxHuTcvVUK6lqNj8535niOR/GX5CMFauK
8r4ekUrh56tq23zuzKCXeDiIFbbsxAtruHlukHiDWQ0jt2suR/lRv4pawsbG
h/TPu+zLVEKdkqvMKlgK28PIR+NM2XOs03NMB43QXHPc91El5MDR1v+5PlsS
3SI/UHQ5Vj11UBkdqqXnxBs+q+yImqWFSXot/ONFMFn6oWC4kWObI8PZQzMe
62jg2r/K8H/OUKWyf+mCCRvXrrhc/55e2XPRvttnn1viTc0lhip/jeT/Mxk2
kv2L5p4aHqv+de1Y/atbNs+9t+S5JCWS4zIe+0TGz9myU6td08wnlzz0F1Lt
u4lqDHDS8g0z75j0woancmoij5/0Q25beeHcE195/g8KefqpixqF3L90wtXD
Dx54ozhk2YUc+fq+1/beeeZ1OqI1ijfuxaf6Nq69/EeDhafMHSy8eY/NX33F
Mz/dVBdP4JJQ1vXOWPSZPY/v1Pak9eDBt9781PjFJmT5tdKgKt6ovXtf2/XF
85blwAuzChzwyo1DQV0oPAhQGsdBgNIQDgKUxnEQoDSExaGagQrzsdIYDlZh
XaM4OBqH18WpzRe5Wktqo1poHW0UhyC1vnXwz4rTuWP7S1umd60uoo9zTfO4
bU+9uPFrl6/NiyOeHQScyc/2bh0MnGP37/6jizPp4Q0vLP/WzA2ZcMabEyRB
WNtazLHJ63qfXTpn9qY8OJ0vbf/9YODA4Mw4EYvt1avWX72k9uor7v3pM/MW
zH8sjxbkdBynaebSJU+21Ln67y3fX9u7b9ey874jCK3mGBqgSSYtLA65SE66
OPgBf+TB0RLs4qy65ur1Z23+5a48OJrXLg68hb+ZcEznWdIxj3dgWShKBKUi
D9RZu375DEGvgdr/uQlLhx84cDAPVNhrWChLn1izYAlg12jqLOTblfxybCW/
3wC4bCuF9TIuOVY2VXKu1e7mJJNN7112A6HCNW2O3b17/84vnb+iRnrWlWIR
XQ7z8zQj0A1XrcDPbH18z7orZ/TWCMy6jlrPVje8taJjBSbdVt9CZFMd0TtX
nD8nrNUx0VJVWlNDm7Z0l2jz6fFCFNPSnaGUPUVF7S/Vcjxhdcw3AXOVCHuS
OkrEKkm9Smuxw86+DjZEhtCZsE8wJ27Z/PO5urYSDDWLKo/86/LL/txzzed5
rmosx3Yt6zmvVl5snpJRHjiTXti5YdyLe54Khspj1XcPr9228srrzTvzOPL1
P+0LAUqeZG3NLm/Ua/+1V94NNcdiSWJXUhklGC0axY5lQXvI/rYCiEM89B7i
obKrbdQrpCDGuGqPbZt64coT+55/pbD9Fod5NvNt17cMLoxVPAdFPGFxwnmI
Iy/WLTeATbe6dNPs5S5215rVO265ae7mRrFj+euLYBFsc410tvhEZhBDPbFs
ANvnk1ij0F4c2+eT2AyhCHZrsk9inWkD2OHaj5PzMX83gL1ldVc3MwzXJ/R3
5I5zLEuma3tTrURUJFfbWBswpIC2FnvO1oUPXLXtrg0uNtlC1hTGto0HkaPm
kfG6zrz37DPvHLlv3+uNYse6s6GeKjK0ODa44LvYMeYVwbajLb7AJ8Jqn08a
wCaOxDPRJx3FsdGZMczFjlW/Itil5FjGRptDi2P7YhnLnSLYtpeNjek2lrHO
0MVOz3SLGOtprLaxfmlYAW2bomwMV6k6PKxuADvWi1i9qXkwWyI4vDg2Y4BU
EAc7tk6SDbsSw67+Kes6IsIxg5VEHFEMUifHHR4ts0GWXcgwL3wqHpYfL5y7
+/SzeHYUS1ku8O3dS5zcGS1KqkWazw+3CmTf8JZValpYIqn59omVYvvE+t31
g+MjLk/7zYZNbgQxlFyW9Z63haJz7KdKnME6GbRjRde33TjH6vTbUg327UWq
J/KPdyw4c/2D1853E5RGioZK3r09NbK+fTv1RB5cPOeMz+5+epsrMta/qcgB
CwO+vTCJPPqYOcHa5p+WfH+C5JGVFptVHFEnFw0jStoP7bl70TlgDfGQ4shs
UFpwleIWihV1VtblXT2oj5oKQW2lu6TfDquFnfPEVulHZsOjr6a/5l2I1xaZ
Spwk4d9RB+84eVmhl6an1pOKaSFjA25GSHcR04WU2icz/Xc5QNHIbVglaxsz
n/zVEv6Cw+Sx+aHenuu3rJ73z/KuyRxj10ttbxnrx95VR10rb+mmh2avWr/6
akEdYbDnbtmw8OXbv3nhDVs33ho0m2OTn93eGwJov+l6/Kjs8kKsEXps9vLw
XpCzIoD7sSl4dwHs4epPe2efd5bJsc6kCPYwq2M152CPhNu3InB0UWzZW+LM
eVkPll7nPQUQ7Y4btERb6dGsl+n/YIyUh1EFsDs8nrDYLNsTQbmV8d7i2LGZ
h65pVPVFb1nLfF8BbJ3BVPMfdohPHGz0lnr//gLYOi+v1jyKgcxsfNgfSKsD
PsTYfKPVg/jBAtraaMW6bB/2MQWw2zxe9mF/qAC2s5ITetmHfWxx7HAfAO+c
m1EwT7A/XABbb7W4K2f2GJghqz9SANuOA6zp4BPxt3NXCWyp1ccVwC5H/ibT
ZQXbuW0UVqiPFseOrfhZW+YsWrg1nE8fXwDbtntu56Dy0Bfsq+6+a1twQgHs
Zk/uODtp4KD0xidmznQ7KYitWlhExgFGWxkR/yaTti0x7H6zNSocAywuLQma
yhjw8Uy4FReXzAOTXq8UJSC3SoAOTsoEWVZICEaxkKGkFE8MuVF/cia8kuIp
qSwUsQ5zbHT2mG9e873rpUexcyfyCM7DT3g0JhtU3z03Xrx407Kb3WCTmvTo
PAen1MExU6xWBsQn7//xZRoEpTIq4f2xBsaOczm+9pY4O5LJrPQlUaygIpQU
kv+dFZn/S2KJcySzbtDidgB3/KJ31gMLb745jOGpodi837NJFGva0opborF0
36xrL7n3tp6Fp4cS837xqGYzgGnMWlQOcSOGmHb/g/fNlNiensk839d1Es0z
3WurilX66SxegxtJzvoNl0TuGEPL1Ml71l9/J7M+iCpjUZOnCp5mRSfOsN1v
kSTaafrHEpR9dMlXe7CROWcpWWBi1pk0Kq1ZddVtL18z8SaSnmiVC0C1R/Vj
9w/Ovem5mf+0EB63FIAybUqJ3P/u0p4n3pjzyZnz13Y/2FYAyogvwYHdF5x7
566ef7jhC797dEd7ASjjlDK0ojbcf+M1D2xf8ZUb5bbVkAJ4Jr4VxgBIw99X
H79vK0MOQ8/QOpDReHuISTdGZtIM5VCSroBBQnYyd+RT8H+NrQSTSSXrjeFi
WBMtx7B8eG+Z1IRbiqcTVdRDTdQdng/1f+SxDVRGZEWVdq16hlYOb0rrNSIf
9H8bB7jQPEsv4fQyYcd4WD74V82xzpf+czsLI7Lxo2weJ77w3BO3/WTRPXsv
mfp9nnmvW0Pu/Vn3gs1rrps1cfdzW4LDzbF1vffNyCJyXyRSv1kUmK8SlTev
Xnbprp4fTnnze9dN4pn3uvtl85pll+6/bdY5fffc/OXg7eYYIsM1mvoi0VMu
FPYYx0JWmMDNjtCx2hXZfe6ymeKL9eBbXXiSiRxwqWCLGUVacyuYVA9VgrFt
+U8uIS3DVsCU6ZJSlt6YjvMfk9FeiepP3xWXdu+fN+t8clMnL1VmsowoDD2/
Nrnt3l+SkO4OV2HbRU88tgl7rTIoQBOBQrSqFyQrY2+5U5bVSVR8vY2qjrQO
g9c0rHKn+8vJqGYVsUwPi7N0yJUsbPYwwB4DlihL/fxKMvyeKBPxAkrTgktT
WRnIADfxcQvumZyM/nuDri7Bx7hE1nbMMFRx0V2lL0xG/a25EhfgChof1y3t
EcW2rrq9y1U1mJqM2jcwddBZ5k22vt/6yJLFB5Z8+2xx6sXJUM8ZKNoGYqbp
Illo2wt14t0P/+jHbIebloz2m8iJLBGiGK2QhOhQ6wrLUtiOcurUFNRfmyvR
yXUiC5EwdliUQkREWNrkoVuKF562cahOQDX4oUPN50tkFM0k2YVHfIR2JYgA
s7BSIVA6eOiUmfCPiAoS7pDZVzmf5v8WJ5jGEGlINaNRiQKKBOoUNauST4hZ
t5aGx3WPhNXcAixRTJnPUydwT2s+CXbPPlVbiYMpmETYD48qHM0upjDotucT
YpasK7CT1MZPFHTlkZ1WEwXuMyEIgUPyCdkUhZwqBVH54zXHjogCAllhFMzq
yCfk4UgI2YoVWsOx7sgocTUmDKXD8gn5mV8IFYc4jYzyAlppTEYkC7EFJefP
zXinP+vSdTN3smR4JoyEkyQ7PEW3/L/g4tPrgXS93mngoBVlyqWZvbWcpFze
30LxKbcmXTlzf6tE+41iFGkceESqXll/YUSOycLAyigLSYpaLd4dz0KmGFBs
ZGPeqfnBDp93zHbGCmOAzkxIXHIq0ktCp7qRvNJEvrM4rzw/h+FTzq6iU+YZ
qqm+7O9iMCGU0qUcHWkI2WMaHpWiYcL2f/8vVPiUu8soRw2lltKUsT2WkV8L
uL2tF1OOqiFbk47OV5duH0ggxgvGDVpPcyOurLnPBqhQ0qh8kszqdIVxDvRa
SpjbcmUcjAQkIVGm2e/LJ+nWyIW4DNfhQsZAXCrxNXfqylR14qpFTYrHB/KJ
u8WIo7/BGHUhtIJe0rEbyJJ+YVUblA/lk7RgoGEQlx6O4Dk33iTlGRN1PfvD
+SSZLQ4t5K/PJmHhMRE3qL9EDFfKSvxx+cSZ75m2wEKX9GRkaNixUcSoY4ij
qgoVj68jTqTdIAdktQQbXBIq3YmV8ZR850pDRRUXZpyQz6xZcWYQJ+JF3EIi
fiTyouYybYbMXT+eT9y3Ii9Sx9SLSg9pwO3OGIJEsDShpa6dlE/ctcafWKHb
WNWf1Hz1p5FY0VrP5Adi8ppjo/MJ/RdzjBTQIAZN8nW/cG+ZuPVjA9mCvTKD
OyWfyCuNna5IbNT5mEbyhIF2KncI7t/mE/r1iKw4EodqEqpQ4mxu7JUxa4CZ
p+WTeJlfIoSFSTCKPDScrGASpmEipqqZ4/IJnZ5N6ElRTnKXnb3DmCtrhOPz
Sbw4m8STI/7ocERayv39T2epNq/KF+qa5z22cX4o+6Jktb5kjiGa2MpON8tr
jbdUwTERy9AFndANb5DTa5MlmOW0VqoA1QBjMRrjoTTUhsanRK7WAoHLZSNJ
bzL6ufIoi8aM8HqXmG/0UX8of7hbBg5zt7HCtA29iSZ2kDVQ6KFkKWfFSw56
a/AY3ZHKkGXuLVbcrGDaphz9ebKAiUYAIOokUo5AUF40DOYuYgWPm62P531H
k4Dx6BfJAs4wfsICPA798A9+wl/qJ1k8NAlcgYM68aJyMkxQrx9JljI+2QzY
BMnhwbjIDF1F4g9hCHg0WYBRrY0SRCBSzfhEPNxqBj2DrIYlSzFcbAMFNCUV
gxoVmIioKdbkistbjTm2PJEsxaR6Gyig4SAchcN0VwKOlD7OSGmBRdCVzHhz
8fgrlb7SjPx7bSkw+znaNLdhrTqLZ5yn2Rd8yghAZb3TRH5gEvkuXch/JNty
3MC4aBpqoqOCeOyMiF66AKuTRLqP7clSjolInBYX2Qs7wUgBUVMFjsE3eLcz
WYqZe7TXSiHZdbnajY0R1EII3NDgQc2Y4PlkaUdll0YR+5yRRonBFJyng28Y
p98mSzsykqblkgKmSVorbeJA22AFNYfQScu9O1maWbhsh4AQjex0bdPSiSbk
2hfSbZMp2R+SpXVE0nwcJL8oSmrbmXHGk0oDbHspWZpZG20DTZPLlRbj4tnm
CoJDnYDpcFFZzzGMe9lIq9kNk+GXmX07GszieTsM1XKst5O1WmpWcv6cyPdY
jxe0wOAd6Xj2W/1KVkj4Q59pv/Np1hrauU75DcvIV51qwQsiRuTMeN6CvNqo
wAlpMA/U0yNxJUnWrszdQlnFAN6NQPBGPWjfUpm8u6CIUtmu9Ll1wJV1f2tU
rjDtnnnt+THR4JD/A2LcWZ8=\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FitFrGGXSimple0", "[", "Roughness_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "Roughness"}], ")"}], "^", "a"}], " ", "/.", " ", 
   RowBox[{"FindFit", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", " ", 
         RowBox[{"GetLerpFactorFrGGX", "[", 
          RowBox[{"0.001", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.001", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
     ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "xx"}], ")"}], "^", "a"}], " ", ",", 
     RowBox[{"{", "a", "}"}], ",", "xx"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.60429470406641*^9, 3.6042947196064377`*^9}, {
   3.604294768587522*^9, 3.604294769437523*^9}, {3.6042950844360356`*^9, 
   3.6042950846660357`*^9}, {3.604295120641096*^9, 3.604295125985115*^9}, {
   3.604327561586771*^9, 3.6043275969227915`*^9}, {3.604327678099435*^9, 
   3.6043276856668673`*^9}, {3.6043277546198115`*^9, 3.604327770650728*^9}, 
   3.604328182607291*^9, 3.604328246706957*^9, {3.6043283659067755`*^9, 
   3.604328366138788*^9}, {3.604329009931611*^9, 3.6043290323068914`*^9}, {
   3.612976789647912*^9, 3.612976790424957*^9}}],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   RowBox[{"1", "-", "Roughness"}], ")"}], "0.4759528917771724`"]], "Output",
 CellChangeTimes->{{3.6042947170204334`*^9, 3.6042947216514416`*^9}, 
   3.6042947713305264`*^9, 3.6042951294681196`*^9, 3.6043159613422747`*^9, 
   3.604327687947998*^9, 3.604327774631956*^9, 3.6043278208546*^9, {
   3.604328353512066*^9, 3.604328369281968*^9}, {3.6043290253724947`*^9, 
   3.604329035283061*^9}, 3.612976799455473*^9, 3.623995967460145*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FitFrGGXComplex0", "[", "Roughness_", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"b", "*", "Roughness"}], "+", "c"}], "]"}]}], "/.", " ", 
    RowBox[{"FindFit", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", " ", 
          RowBox[{"GetLerpFactorFrGGX", "[", 
           RowBox[{"0.001", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0.001", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
      ",", 
      RowBox[{"a", "*", 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"b", "*", "xx"}], "+", "c"}], "]"}]}], " ", ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", " ", "b", ",", " ", "c"}], "}"}], ",", "xx"}], 
     "]"}]}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.6043445921515465`*^9, 3.60434466355663*^9}, {
  3.6043448140532384`*^9, 3.604344834452405*^9}, {3.612976793760147*^9, 
  3.612976794905213*^9}}],

Cell[BoxData[
 RowBox[{"0.3858974159270268`", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"13.130032430768706`", "\[VeryThinSpace]", "-", 
    RowBox[{"12.257428196651462`", " ", "Roughness"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.604344671735098*^9, 3.6043448397577085`*^9, 
  3.6129768021986303`*^9, 3.623995970107297*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Check", " ", "the", " ", "accuracy", " ", "of", " ", "the", " ", 
    "fitting"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FitFrGGXSimple0", "[", "x", "]"}], ",", " ", 
      RowBox[{"FitFrGGXComplex0", "[", "x", "]"}], ",", " ", 
      RowBox[{"GetLerpFactorFrGGX", "[", 
       RowBox[{"0.01", ",", " ", "x", ",", " ", "1"}], "]"}]}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6042947350844655`*^9, 3.6042947409854755`*^9}, {
   3.6042947737605295`*^9, 3.6042947745905304`*^9}, {3.604327610586573*^9, 
   3.604327610865589*^9}, {3.6043276942263575`*^9, 3.604327696874509*^9}, 
   3.6043282493941107`*^9, 3.6043282839000845`*^9, {3.604328374122245*^9, 
   3.6043283743382573`*^9}, {3.604344677500428*^9, 3.6043446802835875`*^9}, 
   3.604344745043291*^9, {3.6129768047187743`*^9, 3.6129768197916365`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlXs41HkDxUkkl3dsaFO0SKlWSkZ6LR3l3dqNCmFKWnItkW6kF61QkQ3J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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwthwk01AkAh0eObBLP2RLZvGhEh6Msw48nXUrjSqRsxtHaEDVSSV6jYpOs
RMRq29bdJveRK8cg4Y1rHE+OwRgz//8qy1KNbd/b773vfe/7zifE2W8dhUKh
f/W/ajLUKhg+dBQu7jCTbCfR6v7lVGSAGz6/rr2m2UYi7BhvNfmCJxK6XV+a
sElMa3hsZVj6oHT45jSjhYSVlD4j2f4CVjJYt5saSYT/dI75yTACS78pJt2s
JqGcFSX+U+cOOjamvxUUkJgwl2+K1XiEDY5ee+8nkBhx3hKeHfIHDj04GCg6
TiJaf1OQT9pLmGQtx59VJJG7hqcb2kqx9kVeqZ9DQIPjFRa5uxrpzQUuxQkE
cktyzJ5Y1GOeQnVrPE5g3Kpgz9ypN7BT33p4QJpAxbNnN96sb0F8CV0/vVYE
LYW9dmGxbATyHEJLIkRoC16g7UIHjrI/rrcxFEFi4PDLBnYnmnp8GndOCSFt
3cBNtOvGOe0q3lCaENmdpk/KV3swxNR54XJYCCWxq0wijYMZ3SI6fXUeOtSE
eyFpvQhYNI+M+X0eya7uQhHZB/mG/AWhwzy6JS/Eue8egFpdJ+PLsgCFhWk2
7LhB8Kxnbb3SBaAPKZlue8eFBOVEj6+NAKlrz21ZO4ehVraSLxqZg50e24DF
GoHDyp521fA5lPeY0oObR5Gs7DYgrTKHzss1D7x1xsAftzbVy+YjL+O+HM3v
PfLMtRPWLPlgTl55NeI0jp9rJZw8e2YRcMksMEM8jkN+rAl791lYtW5u5GRN
QMnBPvSviRnwHsluj3ecxFKx40L2mRnU+TUsqaxOQo7ufYk6MI3I5Ux/5fQp
KO26YurqPA05mdip5EM85OfU+I6+5uHGQKr43hwPvzhQQnMMeNiWE3LXOXYa
RePXcsOSp/B40UUrw3QG9zZ97FrkT+KD5Fmn0/0zsPIY3q5hMwmtxMtJmaxZ
9PREb7SNmoDhWFGomx4fCovpWoO14wgyLKsbbeHjvm7eKWPBe0Qvt2yeDZtD
4c7gyrfqYwiP+awYoCKAjKuOt7rdKKwSoBbYJIB9l7tOypZh7H98NI4WMg+W
QLBf4d0gVH2vp8coCCHZEc8NDu5Hc2Fl5YlaIaT48nL+Dzlwr9BkJnqLcKfK
MU5Rrxtb3hzMeioW4ebpoGwasw0WT3WFzhIEotWrkjVOtsEjivK9tBSBXkWD
Qd6+NqRYVHN+/IbA38a/Llr9w4ZCiZGMiQoBg+t2nWtX2Vj3XCWohUpgs+qr
rQVXW8G/PWkhcCXgYgmF9+ebUXIkasCkgMDD0PYk7lo9uHW9KxUvCPT5zy1P
VNdDbELVohURuM1aUath1uOodh/jQBkBG+Ujl0YEdZj8QF1wrScQEZWq/o5T
C6WMfrnwXgJVxknVZmk1uEgY2lZ+ItAkpdIuKy5HCuOWL01MgJk56nmtuByv
uYN3GygkNOt7l175l0O26VZXmzSJQsOa2dCuMmSlck8PKZAo4pZWGjwpRZdN
TPiq7tc3+iHXiFoMo4cjBbRjJKzHqswDqflI8aJUyZ0gkaSkv280OA8Uve2t
w04kKjZeDMgsyUVfZfB4hDsJT4MQHVnLHESOSaiW+ZCo+ZZq7GH7HB3UHVFG
V0mcjPxUecYtA+cbLtO1s0nEBOFD3El/cOLSzohySXz2VXVj0pwRNxtDG8kn
QfmffwHMcYAc
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxN13c4Fe77B3BFSIhDZvZI+FCyEh4JZc+IVHZG2VkhoUEJUcnICaGMsrP3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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0.001, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{{3.604294743745479*^9, 3.6042947848225465`*^9}, 
   3.6042951431331406`*^9, 3.6043159702617846`*^9, {3.604327690104121*^9, 
   3.6043277073101053`*^9}, 3.6043277885127497`*^9, 3.6043278332733107`*^9, 
   3.6043283958974905`*^9, 3.6043290585553923`*^9, 3.6043447031248937`*^9, 
   3.604344766605524*^9, {3.6129768317513204`*^9, 3.612976852744521*^9}, 
   3.6239959911495*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Final", " ", "2", "D", " ", "function", " ", "from", " ", "interpolated", 
    " ", "fitted", " ", "curve"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FitFrGGXSimple", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", "=", " ", 
   RowBox[{"Lerp", "[", 
    RowBox[{
     RowBox[{"FitFrGGXSimple0", "[", "Roughness", "]"}], ",", " ", 
     RowBox[{"FitFrGGXSimple1", "[", "Roughness", "]"}], ",", " ", 
     "Cos\[Theta]V"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6042947825925436`*^9, 3.604294799474571*^9}, {
   3.6042948490496554`*^9, 3.60429488118571*^9}, {3.6042950135049267`*^9, 
   3.6042950153049293`*^9}, {3.6043277099622574`*^9, 
   3.6043277174976883`*^9}, {3.6043278338183413`*^9, 3.6043278497382517`*^9}, 
   3.6043278989300656`*^9, 3.6043281880826044`*^9, {3.6043282630898943`*^9, 
   3.6043282659700594`*^9}, {3.61297689730307*^9, 3.6129769553763914`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos\[Theta]V", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "Roughness"}], ")"}], "0.2891837804614315`"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "Roughness"}], ")"}], "0.4759528917771724`"]}], 
    ")"}]}], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "-", "Roughness"}], ")"}], 
   "0.4759528917771724`"]}]], "Output",
 CellChangeTimes->{3.6129769561314344`*^9, 3.6239959911695013`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FitFrGGXComplex", "[", 
     RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", "=", " ", 
    RowBox[{"Lerp", "[", 
     RowBox[{
      RowBox[{"FitFrGGXComplex0", "[", "Roughness", "]"}], ",", " ", 
      RowBox[{"FitFrGGXComplex1", "[", "Roughness", "]"}], ",", " ", 
      "Cos\[Theta]V"}], "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.604344974286403*^9, 3.604344993339493*^9}, {
  3.6043450256993437`*^9, 3.6043450647315764`*^9}, {3.612976934808215*^9, 
  3.61297696706406*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos\[Theta]V", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"0.29847502436794354`", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"39.41149727672321`", "\[VeryThinSpace]", "-", 
        RowBox[{"39.00289316713873`", " ", "Roughness"}]}], "]"}]}], "-", 
     RowBox[{"0.3858974159270268`", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"13.130032430768706`", "\[VeryThinSpace]", "-", 
        RowBox[{"12.257428196651462`", " ", "Roughness"}]}], "]"}]}]}], 
    ")"}]}], "+", 
  RowBox[{"0.3858974159270268`", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"13.130032430768706`", "\[VeryThinSpace]", "-", 
     RowBox[{"12.257428196651462`", " ", "Roughness"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.6043449812968044`*^9, 3.604344995127595*^9}, 
   3.604345035512905*^9, 3.6043450683547835`*^9, {3.6129769454808254`*^9, 
   3.6129769699472246`*^9}, 3.623995991237505*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "compare", " ", "the", " ", "fitting", " ", "result", " ", "with", " ", 
    "original", " ", "curve"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GetLerpFactorFrGGX", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "1"}], "]"}], 
      ",", " ", 
      RowBox[{"FitFrGGXComplex", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}]}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6042949117477655`*^9, 3.604294930346796*^9}, {
   3.6043278767787986`*^9, 3.6043279040663595`*^9}, {3.6043282522342734`*^9, 
   3.6043282693382516`*^9}, {3.6043284138825192`*^9, 3.60432841424254*^9}, 
   3.604345002974044*^9, 3.604345043428358*^9, {3.6129769787197266`*^9, 
   3.612977003375137*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyUnXlUTd/7+EuoCJmLUKiEDJESOciQIXMylDKkTElkCkmppKQZJZkSkSlJ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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1m3X8FFXbxmd2mV129reLIiIIImnQpQgioJKCdHfbSIOAIKWInagYqKiP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         "]], Polygon3DBox[CompressedData["
1:eJw1mwe0FUXWhbvf5da1u997BkBFJYuKIEnFgGQMoOQkOaMgUQRMKKhgFjEi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         "]], Polygon3DBox[CompressedData["
1:eJwt13ecVcUZxvEDyy5y8S6KKIpEpKsgqFTp3cLK0ovsAlIUpIsBC81eY1di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         "]], 
        Polygon3DBox[{{2659, 1506, 1833, 1086, 1085, 3246}, {2680, 1532, 2337,
          834, 841, 3249}, {2567, 2566, 3433, 1790, 1791, 3434}, {2903, 1841, 
         1373, 1374, 1842, 2904}, {2696, 1577, 1890, 3445, 2562, 2563}, {2698,
          1579, 1854, 3440, 2566, 2567}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmXW8VsUahT/gHNiHvZlRRMC6kioYiN3dgd16FRv0WrQFgq2UdEgISisi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         "]], Polygon3DBox[CompressedData["
1:eJwtmnegFcUZxS/3vcfO8+7eawHEFgtgwQKWEGtibCkmGlt6sRs1iTGKICgg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         "]], Polygon3DBox[CompressedData["
1:eJwt13eQVeUZB+BLk13ZpYkRTBBQEluMaIgtMSbORMUxJtF0kwkwIwo6giK9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         "]], Polygon3DBox[{{3457, 2157, 2368, 1269, 2403, 3771}}]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwlj1kOAUEQhotpZtrYxTq2EbENV+ANiQfiCJ4sCfdxAW7J16mHyvf1312V
6vjyOj/TIhJRHpUyIgHShB8rModHGFIl8n0g4uN18jfMUUXyHXmA+/gGn3Kf
wX+UJS/ALXmSEanhI+4PnCuezl9wruIxLFv1E0w4R/jY6JwuvEEDQ/KOy10P
PjC6Tw/erfa43pXR/fvwYXXPBn6FE9jnzQym3Sy85eYY3W1o9L9ZfM2+X3xp
dDfPvSNvu79SeTyCfw5fD+k=
         "]], Polygon3DBox[CompressedData["
1:eJwlkctOQkEMhiszcE4Pd1igkIC44ZYQHoHrQjcaH8GVSqLvQxRlgfCUxK/p
4s/8XzvT9vT0Xz6fP3Ii0kYR7VXkBpMFkWUq8g4ncAXO8H/oFq7DD+Sf4AZ+
TOyMf1TPZfAJv0MXuIAS/BdqkUvhOe+/4WtY4QU8xY/weTSIHrO7V9Hvzjin
cAdN8G/ECpxlWPH33K/iU2JH+Ae18UViK3JDfDd4D+t1h5rBa1rtV/VFJFYD
v+FNyeYhdlCv2cPXgvfaqveynkX1nVhOo+9qnXrvCP+qf7PVth62C5vJdh2i
z2o7t13kov8Le9OJPoPV+geDWxtd
         "]], 
        Polygon3DBox[{{2119, 781, 1030, 1053, 2314}, {2110, 798, 1062, 1045, 
         2311}, {2111, 774, 1022, 1046, 2312}, {2384, 1068, 1069, 795, 
         2320}, {2383, 1065, 1057, 786, 2123}, {2120, 782, 1031, 1054, 
         2315}, {2118, 2117, 2465, 1052, 2313}}]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3mQVEUSxqvt193T0z3zwFsUDXYRUFFD5VZBPMAbHJD7FhGFGQIcDxRF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         "]], Polygon3DBox[CompressedData["
1:eJw1l3mQVcUVxu/jdd7cd9+bGXCNEDRJgRCNMRqHYVAJrgiyDaACIhhUmBIG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         "]], Polygon3DBox[CompressedData["
1:eJwl1EtsVkUYxvGRHgu09gM2IJpITASMLhAJhYIKGgIsVKDcKS20QMUirS0V
pXJR5KJRufUrQkK8ADEklCoXESHAisDCqIluSOhGQk0kGgERWiXxN5nFk3Pm
P8/7zMyZOfNoTUN5fa8QwlS6n5qLQnjCszyjviH8URLCygdCaOwTwie9Q6hk
PlIcwhB9NTzV1HBfCN2FIdxRe0ftdmwb3dV+Xuj4ghBqtZfz/c3XJfN2YWov
wX+S3yZzouwSuTn6medB7K68Tp4rNFh7irxh2BTtyfQ472NU5b2SmmT+K7sU
q9N+leqwndgA8+/w3oytotPYK+bYJbOUdIcj6pZjv2mPJcsOHVi1+RxV8zU9
pd2WC6GfgsPy6rGVdEreGH2vx2+Spb7WOIb1LRX0Af80a/zCOmqxJdhW7GXs
c6xM7Wp1b2Rpnm1qi4y7I47HV8F3mG+F+V03twkkJhzT34Td1C6jQdgprBG7
oT2GBmLfxrUpWGbcD+VNl7c/5hkjp73LeLf4utStxar41uMb6KT1rvGcquaW
/cyZ4wvyKuTN4duk7zl9rfIuYpP07cYWYu1YJTaP7/3eaZ/jfi/DarDN2EvY
Z9glbLLaQ1g8mGexBdhsvo3Ys9gubD42C3sHewbbibWY98wsnd14hi/IuY49
6VtuxN6lH7Xr6Hff5BH9ysJRz6XyquW9J+9FeZ/qmIfNwFqwcdh2bF8u7XPc
79doJHaPb7/3UXJ+0bfYtyvFRxj3En6RRhenf+sf406kh417hn+O2mnGWG2M
scb4mO9paszSOYrnKS9zLt90vrf4yvi2xbx+vPrP852jGuOe4Mt7b6Xhxr9t
zIXYXLVb1E5Qm1f7A/42T0uWvk/8TuvUL+bL883n21eczn2n8Ucb5xjvZVnd
vN3mv1V7C/Vor+Gb2SedlXhm+ptbPW8Ttke7Sl6HvAZsFbYXW4R9VZz2Ke5X
/G//i/eCrJN8FbIXULP59ecrkfmmuhvO31/0EVZAl9WM6Jvuiu+L0neN3zfe
ST3x/5OXt2/feT8o70CW9ugbYyzK0t0R75A/sSs0Q/uhkPYq3n/xvzhkDiuy
dKfEuyWut9w61prPOjouv1PeWf2/8l8tTPsR/834j8Z7L955tSXp3on3TxO1
x7WprzXva/Fc8OsO7Z5DrfdLfT3W2l2Q/qP/AeL6vjY=
         "]], 
        Polygon3DBox[{{3452, 2143, 1939, 1013, 2415, 3865}, {3340, 1037, 2369,
          1908, 567, 2956}, {3339, 1039, 2371, 1915, 585, 2971}, {3337, 1043, 
         2373, 1959, 621, 3004}}]}]}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt1HmQz3Ucx/HPspujFX80yMg1DX9pphxp7UrKFZEkZ2JphCIVkRzr3BAh
VhTlviVnrkgzchTt2tNeNDFjRrPYyT9Nenwmfzx/z9f7c3w/3+/79/v+mqaP
f3VcQghhVML/xNzNxx3eViOEOryPG/NxfpLPcBpf5p78Bw/mu1yJMXJyzRCm
cF3O5KacxS15M6fwAe7OP3M513Pun8hR53DzmJOcE8/iXM7lPM7jfM7nAi7g
Qi7kIi7iKxG5mIu5hEu4lEu5jMvi2VzOex8K4TFnzsJV9TCujwyku79sY0Pl
R1H34RBm8Gljdbir+f1yC+NZ6k3yE/IKeaXcTF4uz5ebyEvlyfLj8mK5pv2j
1YvkCj0cJC+I9yH3kDPlbDlVbmDPXHVLuZ48W24kn3eNv2Nv1LX5RmIIu6r6
frAbYzAbA1C9Vggd+RJ+x1EcQzXjQ7gbcpGH49HJIZzgdPRCAQqRZP1JPoUR
eAVFuIJEcz/xaYxEHxTjumuV8HhUsSaDv8ZCzzeT1+ArTMZqJFjzJc9AFsqx
Ch8h37VW8hGswHQswwbcN7ecJ2IpfsDn+ASL8C3+teYz/iCej31YgI8xD6Xm
1/F8TMBOXMMOPIdH9HmNPm+Tr2I73sMsrMU/9vfnDsjE9/gU72MOysx/w4PR
FYtxGEvwIebG57VmPQ/Hy/gC78ZeGp8Ur4EfMQ5v6OEZLtGz/vI7sUfxbHka
D+HLfM/esfFc9UHOQTam4rf4mzF/kffiV1zAFJyNz2nuHG/GVmxBGhwZ3tKL
jfImvI5Ka1N5D77DXfUg7oL9OIA7xoZxT/yCQ/G53dfb3Buj0CPeo3VvcufY
O/MV6hfjOXIKX1T342fhVQip3mtToWH8n3Jfrxn/y5p2PBC35Bd4aPy+rHkp
9g8ZcnfuFHvroWaqn5f7cdvYD/v6chs4IrTykRjfS/PthVSkoQNuxh5X855W
CeEp9dNohdZog7Z4BtPsbccpmC6Pjr9V/0e3H/w3/wf3eMdy
       "]], 
      Line3DBox[{818, 2, 1081, 2399, 1000, 870, 2398, 998, 1001, 997, 999, 
       1004, 1003, 818}], Line3DBox[{820, 3, 1087, 996, 819, 850, 820}], 
      Line3DBox[{1334, 6, 2331, 1088, 1089, 3308, 1090, 2431, 1091, 2385, 
       3281, 1092, 1093, 2387, 1094, 1095, 2388, 1096, 1097, 3282, 1098, 1099,
        3278, 1101, 823, 1338, 8, 1336, 7, 1334}], 
      Line3DBox[{1343, 11, 2334, 1102, 1103, 3311, 1104, 2435, 1105, 3548, 
       2386, 1106, 1107, 3313, 1108, 1109, 1110, 1111, 2394, 1112, 1113, 1114,
        1115, 3300, 1116, 1117, 1118, 1119, 3298, 1120, 1121, 1122, 3280, 
       1123, 1124, 1126, 827, 1345, 12, 1343}], Line3DBox[CompressedData["
1:eJwl0EdOA0EQQNFCRkhI5g5wJXZsWLAHLkTONjnnHEzOOWe4AEskv5YXT380
XdMqu6ahubapLCLqyXn400atroxoKY9opY12Ouiki/9sRLf20Esf/QyQ49Z5
XgcZYpgRRhljnDszEzrJFNPMMEtURczpPAssssQyT75b0VXWWGeDOjtv6hZX
ZrZ1h4y7CrrLHvsc8GvmUI845oRTzvhxdq4XXKb7uKbCXTfp96X9ueeBL/OP
aTeeeeE1nXv/pu988Jlm+U47ZEr/eRFtNkhj
       "]], 
      Line3DBox[{452, 282, 1828, 468, 1127, 1128, 1129, 1130, 1131, 3317, 
       1132, 1133, 1134, 1135, 1136, 1137, 3318, 1138, 1139, 1140, 1141, 1142,
        2438, 1143, 3284, 1144, 2439, 1145, 2392, 1146, 1147, 2441, 3320, 
       1148, 2442, 1149, 1150, 1151, 1152, 3321, 1153, 1154, 1155, 1156, 1157,
        3322, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165, 3323, 1166, 
       1167, 1168, 1169, 1170, 1171, 1172, 3291, 1173, 1174, 1175, 1176, 1177,
        1178, 990, 452}], Line3DBox[{1327, 964, 966, 869, 1327}], 
      Line3DBox[{965, 1326, 1325, 1324, 965}]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0slKlXEcx+GfHs1ZMzM7ag6Zpkm0CHEf3YBegUPZThc2O9xASosKFwpC
CUKuXNamrYK4LQhdOhy1tHJO85EWH57v/+VM78up7epr702LiEk1JyLupkc0
sFSv8iLuOY+xjVPs4Cz7+IXDXOQolzjBTc7wmJ+Zmx8xzyS/sZGrbOUep5n0
fbeVmRlxQVnKVo5y9SgnIo/5GrcL2M9CFumxfZHFemJfYome2pdZqmf2FZbp
uX2V75lkuT7YFazUlH2NL1jFar20a1irAfs663RDg871bNBNNapJt3Qng+6t
Wu3uNYP3ueveW7hy/sz5lWWcYzY/8dAz/MgUx/mdI1zgENd89rpGfH+KG963
wVHnTfZwiz/0U6+dt7lcEPHQ3rF/6YH9m3/Ube/yDfeY8pn7fOt8wEO9s4/Y
xWP+Pf8dXnfCMddO2cl/DM+gw05juhKqd73YtcrE///dGdPbTzQ=
       "]], Line3DBox[CompressedData["
1:eJwl0EsrhGEYBuDHGGl83ziXlYVsLCzHacY4/APZWCprZsYkSZQkyUJYiO2U
tV/gJ2Gcz+Uqi6frvp/3ra/3G1qpLlZaImLJ1NojCpmIbFvEcDbirjUi4VUu
4l5O5Uv5QV5lXk/zEU390VzYPXGNnc6e5YrcJSfuvehV/ZXnfGO3szP5Xe6R
T+UOdz/0mtxr9yl/mRP9m+vss8+596PX9X79V75NfNMbbrjMBhd4nUYMOB81
8/oIB82xN8/pR5zlIWd4wDL3Oc09lrjLHVOUtznFLU5ykxPc4DjrHMv8/9c/
wbMq9w==
       "]], Line3DBox[CompressedData["
1:eJwl0MsuA2EcxuF/TaedqVMRx1IqgiqNK0CdtTs7Wys04X6kdVg4XCWexOKX
5/3yfYvJNG6frh8LEXGjgyyilEQcsswjZuww5zErPOEoTznGM55r3L7gBC85
yStW2eUUe5xmNY+osa0ZtdKI9WLEvlra0J529e3tDhtq6su5wjV92jlX9WFn
7LPOsh7sFZZ0by/znSlrerOLXNKrnXBRL/YIFzS0C5zXwA7ecY4/vv3ZnrU3
ta22tvTrLlVT9eT///4BSEUXeQ==
       "]]}, {
      Line3DBox[{2473, 2749, 2897, 2923, 1505, 3262, 2895, 2949, 3761, 2659, 
       3246, 3947, 2660, 2474, 3552, 2661, 2475, 3277}], 
      Line3DBox[{2483, 2896, 3342, 3744, 2933, 2932, 1517, 2484, 3559, 2670, 
       2485, 3560, 2671, 2486, 3561, 2672, 3247, 3950, 3551}], 
      Line3DBox[{2493, 3345, 3641, 2492, 3346, 3642, 2494, 3567, 2677, 2495, 
       3568, 2678, 2496, 3569, 2679, 2497, 3570, 2680, 3249, 3951, 2681, 3250,
        3952, 3347, 3643, 2498, 3348, 3644, 2499, 3349, 3645, 2500, 3571, 
       3283}], Line3DBox[{2503, 3350, 3646, 2502, 3351, 3647, 2504, 3352, 
       3648, 2505, 3353, 3649, 2506, 3573, 2683, 2507, 3574, 2684, 2508, 3575,
        2685, 2509, 3576, 3354, 3650, 2510, 3355, 3651, 2511, 3356, 3652, 
       2512, 2750, 3953, 3418, 3251, 3719, 2751, 3258, 2752, 2858, 2513, 2868,
        3549}], Line3DBox[{2514, 3260, 3333}], 
      Line3DBox[{2516, 3357, 3653, 2515, 3358, 3654, 2517, 3359, 3655, 2518, 
       3360, 3656, 2519, 3361, 3657, 2520, 3577, 2686, 2521, 3578, 2687, 2522,
        3749, 2903, 2904, 3748, 2523, 2934, 2935, 3759, 2524, 3362, 3658, 
       2525, 3363, 3659, 2526, 3419, 3728, 2798, 2753, 2527, 3720, 2754, 2844,
        2755, 2859, 2528, 3329}], Line3DBox[{2529, 3261, 3332}], 
      Line3DBox[{2531, 3364, 3660, 2530, 3365, 3661, 2532, 3366, 3662, 2533, 
       3367, 3663, 2534, 3368, 3664, 2535, 3369, 3665, 2536, 3750, 2906, 2907,
        2537, 3751, 2908, 2909, 2905, 2925, 2924, 3747, 2538, 2937, 2938, 
       2936, 3666, 3438, 2539, 3370, 3667, 2540, 2912, 3668, 3439, 2541, 3420,
        3738, 2861, 2911, 2910, 2542, 3421, 3737, 2860, 2864, 2863, 2543, 
       3734, 2821, 2822, 3256, 3330}], Line3DBox[{3302, 2544}], 
      Line3DBox[{2548, 3579, 2688, 2546, 3580, 2689, 2550, 3581, 2690, 2552, 
       3582, 2691, 2554, 3583, 2692, 2556, 3584, 2693, 2558, 3585, 2694, 2560,
        3746, 2899, 3586, 2695, 2940, 2939, 3587, 2696, 2563, 3588, 2697, 
       2565, 2914, 2915, 3752, 2698, 2567, 3434, 3589, 2699, 2871, 2927, 3755,
        3442, 2801, 2880, 2700, 2881, 3428, 3735, 2824, 2802, 2846, 2701, 
       2845}], Line3DBox[{2570, 2872, 2873, 2800, 2823, 3729, 3427, 2569, 
       2834, 2888, 2835, 2787, 3437, 3727, 2919, 2879, 2568, 2886, 2887, 2862,
        3739, 3433, 2566, 3440, 3678, 2913, 2564, 3677, 3378, 2562, 3445, 
       3676, 2950, 2952, 2951, 2561, 3446, 3760, 2941, 2900, 2898, 3745, 2559,
        3675, 3377, 2557, 3674, 3376, 2555, 3673, 3375, 2553, 3672, 3374, 
       2551, 3671, 3373, 2549, 3670, 3372, 2545, 3669, 3371, 2547}], 
      Line3DBox[{2572, 3590, 2702, 2571, 3591, 2703, 2573, 3592, 2704, 2574, 
       3593, 2705, 2575, 3594, 2706, 2576, 3595, 2707, 2577, 3596, 2708, 2578,
        3597, 1588, 2579, 3598, 2709, 2580, 2916, 3599, 2710, 2917, 2756, 
       2902, 3754, 2926, 2711, 2847, 2882, 2883, 3600, 2788, 2836, 2890, 2712,
        2803, 2918, 3753, 3441, 2874, 2884, 2713, 2885, 3429, 3736, 2825, 
       2804, 2849, 2714, 2848}], 
      Line3DBox[{2582, 3379, 3679, 2581, 3601, 2715, 2583, 3602, 2716, 2584, 
       3603, 2717, 2585, 3604, 2718, 2586, 3605, 2719, 2587, 3606, 2720, 2588,
        3607, 3380, 3680, 2589, 1600, 2590, 3608, 2721, 2591, 2901, 3609, 
       2722, 2920, 2943, 2944, 3610, 2942, 2953, 2723, 2889, 2921, 2922, 3611,
        2789, 2837, 2891, 2724, 2875, 3742, 2811, 2812, 2773, 2851, 2725, 
       2850}], 
      Line3DBox[{2593, 3381, 3681, 2592, 3382, 3682, 2594, 3612, 2726, 2595, 
       3613, 2727, 2596, 3614, 2728, 2597, 3615, 2729, 2598, 3616, 2730, 2599,
        3617, 3383, 3683, 2600, 3384, 3684, 2601, 3618, 2731, 2602, 3619, 
       2732, 2603, 3444, 3620, 2733, 2930, 3757, 2772, 2734, 2774, 3422, 3730,
        2757, 2876, 2853, 2854, 2852}], 
      Line3DBox[{2605, 3385, 3685, 2604, 3386, 3686, 2606, 3387, 3687, 2607, 
       3621, 2735, 2608, 3622, 2736, 2609, 3623, 2737, 2610, 3624, 2738, 2611,
        3625, 3388, 3688, 2612, 3389, 3689, 2613, 3390, 3690, 2614, 3626, 
       2739, 2615, 3627, 2740, 2616, 3722, 2775, 2741, 2776, 3423, 3731, 2758,
        2877, 2856, 2857, 2855}], 
      Line3DBox[{2618, 3391, 3691, 2617, 3392, 3692, 2619, 3393, 3693, 2620, 
       3394, 3694, 2621, 3628, 2742, 2622, 3629, 2743, 2623, 3630, 2744, 2624,
        3631, 3395, 3695, 2625, 3396, 3696, 2626, 3397, 3697, 2627, 3398, 
       3698, 2628, 3632, 2745, 2629, 3723, 2777, 2778, 2630, 3436, 3721, 2759,
        2878, 2760, 2813, 2631}], 
      Line3DBox[{2633, 3399, 3699, 2632, 3400, 3700, 2634, 3401, 3701, 2635, 
       3402, 3702, 2636, 3403, 3703, 2637, 3633, 2746, 2638, 3634, 2747, 2639,
        3635, 3404, 3704, 2640, 3405, 3705, 2641, 3406, 3706, 2642, 3407, 
       3707, 2643, 3447, 3708, 2945, 2644, 2946, 3724, 2779, 2892, 2780, 2893,
        2894, 3743, 2814, 2761, 2826, 2762, 2827, 2815, 2838}], 
      Line3DBox[{2658, 2816, 2817, 2781, 2929, 2928, 3756, 2657, 2947, 2954, 
       2948, 2931, 3758, 3443, 2656, 3718, 3417, 2655, 3717, 3416, 2654, 3716,
        3415, 2653, 3715, 3414, 2652, 3714, 3413, 3637, 2651, 2748, 3636, 
       2650, 3713, 3412, 2649, 3712, 3411, 2648, 3711, 3410, 2647, 3710, 3409,
        2646, 3709, 3408, 2645, 3725, 2783, 2782, 2784}], 
      Line3DBox[{2763, 2669, 3336}], Line3DBox[{3335, 2839}], 
      Line3DBox[{2842, 3259, 3286}], 
      Line3DBox[{2955, 3236, 3448, 3762, 3263, 3967, 3155, 3264, 3968, 3156, 
       3265, 3969, 3157, 3305}], 
      Line3DBox[{2967, 3450, 3764, 2966, 3451, 3765, 2968, 3862, 3167, 2969, 
       3863, 3168, 2970, 3864, 3169, 3266, 3970, 3170, 3267, 3971, 3171, 
       3306}], Line3DBox[{2980, 3454, 3768, 2979, 3455, 3769, 2981, 3456, 
       3770, 2982, 3871, 3177, 2983, 3872, 3178, 2984, 3873, 3179, 2985, 3874,
        3180, 2986, 3875, 3457, 3771, 3268, 3458, 3772, 3269, 3459, 3773, 
       3550}], Line3DBox[{2993, 3460, 3774, 2992, 3461, 3775, 2994, 3462, 
       3776, 2995, 3463, 3777, 2996, 3880, 3184, 2997, 3881, 3185, 2998, 3882,
        3186, 2999, 3883, 3464, 3778, 3000, 3465, 3779, 3001, 3466, 3780, 
       3002, 3467, 3781, 3003, 3884, 3187, 3270, 3972, 3188, 3307}], 
      Line3DBox[{3007, 3468, 3782, 3006, 3469, 3783, 3008, 3470, 3784, 3009, 
       3471, 3785, 3010, 3472, 3786, 3011, 3886, 3189, 3012, 3887, 3190, 3013,
        3888, 3473, 3787, 3014, 3474, 3788, 3015, 3475, 3789, 3016, 3476, 
       3790, 3017, 3477, 3791, 3018, 3889, 3191, 3019, 3890, 3192, 3020}], 
      Line3DBox[{3022, 3478, 3792, 3021, 3479, 3793, 3023, 3480, 3794, 3024, 
       3481, 3795, 3025, 3482, 3796, 3026, 3483, 3797, 3027, 3891, 3193, 3028,
        3892, 3484, 3798, 3029, 3485, 3799, 3030, 3486, 3800, 3031, 3487, 
       3801, 3032, 3488, 3802, 3033, 3489, 3803, 3034, 3893, 3194, 3035}], 
      Line3DBox[{668, 2006, 669, 2007, 670, 2008, 671, 2009, 672, 2010, 673, 
       2011, 674, 2012, 675}], 
      Line3DBox[{3037, 3490, 3804, 3036, 3491, 3805, 3038, 3492, 3806, 3039, 
       3493, 3807, 3040, 3494, 3808, 3041, 3495, 3809, 3042, 3496, 3810, 3043,
        3894, 3497, 3811, 3044, 3498, 3812, 3045, 3499, 3813, 3046, 3500, 
       3814, 3047, 3501, 3815, 3048, 3502, 3816, 3049, 3503, 3817, 3050}], 
      Line3DBox[{3052, 2222, 3051, 3895, 3195, 3053, 3896, 3196, 3054, 3897, 
       3197, 3055, 3898, 3198, 3056, 3899, 3199, 3057, 3900, 3200, 3058, 3901,
        2230, 3059, 3902, 3201, 3060, 3903, 3202, 3061, 3904, 3203, 3062, 
       3905, 3204, 3063, 3906, 3205, 3064, 3907, 3206, 3065}], 
      Line3DBox[{682, 2020, 681, 2019, 680, 2018, 679, 2017, 678, 2016, 677, 
       2015, 676, 2014, 2013}], 
      Line3DBox[{3067, 3504, 3818, 3066, 2238, 3068, 3908, 3207, 3069, 3909, 
       3208, 3070, 3910, 3209, 3071, 3911, 3210, 3072, 3912, 3211, 3073, 3913,
        3505, 3819, 3074, 3506, 3820, 3075, 3914, 3212, 3076, 3915, 3213, 
       3077, 3916, 3214, 3078, 3917, 3215, 3079, 3918, 3216, 3080}], 
      Line3DBox[{3082, 3507, 3821, 3081, 3508, 3822, 3083, 2254, 3084, 3919, 
       3217, 3085, 3920, 3218, 3086, 3921, 3219, 3087, 3922, 3220, 3088, 3923,
        3509, 3823, 3089, 3510, 3824, 3090, 3511, 3825, 3091, 3924, 3221, 
       3092, 3925, 3222, 3093, 3926, 3223, 3094, 3927, 3224, 3095}], 
      Line3DBox[{3097, 3512, 3826, 3096, 3513, 3827, 3098, 3514, 3828, 3099, 
       2270, 3100, 3928, 3225, 3101, 3929, 3226, 3102, 3930, 3227, 3103, 3931,
        3515, 3829, 3104, 3516, 3830, 3105, 3517, 3831, 3106, 3518, 3832, 
       3107, 3932, 3228, 3108, 3933, 3229, 3109, 3934, 3230, 3110}], 
      Line3DBox[{3112, 3519, 3833, 3111, 3520, 3834, 3113, 3521, 3835, 3114, 
       3522, 3836, 3115, 2286, 3116, 3935, 3231, 3117, 3936, 3232, 3118, 3937,
        3523, 3837, 3119, 3524, 3838, 3120, 3525, 3839, 3121, 3526, 3840, 
       3122, 3527, 3841, 3123, 3938, 3233, 3124, 3939, 3234, 3125}], 
      Line3DBox[{3127, 3528, 3842, 3126, 3529, 3843, 3128, 3530, 3844, 3129, 
       3531, 3845, 3130, 3532, 3846, 3131, 2302, 3132, 3940, 3235, 3133, 3941,
        3533, 3847, 3134, 3534, 3848, 3135, 3535, 3849, 3136, 3536, 3850, 
       3137, 3537, 3851, 3138, 3538, 3852, 3139, 3942, 3242, 3243, 3140}], 
      Line3DBox[{3154, 3240, 3244, 3245, 3946, 3541, 3153, 3241, 3945, 3540, 
       3152, 3966, 3547, 3151, 3965, 3546, 3150, 3964, 3276, 3149, 3963, 3275,
        3148, 3962, 3274, 3943, 3147, 2379, 3146, 3961, 3545, 3145, 3960, 
       3544, 3144, 3959, 3543, 3143, 3958, 3542, 3142, 3957, 3273, 3141, 2319,
        3238, 3239}], 
      Line3DBox[{3279, 2480, 2665, 3556, 2479, 3638, 3341, 3310}], 
      Line3DBox[{3287, 3257, 2833, 2820, 3292}], 
      Line3DBox[{3294, 2828, 3324}], Line3DBox[{3295, 2785, 3326}], 
      Line3DBox[{3296, 2786, 3327}], Line3DBox[{3297, 2829, 2668, 3316}], 
      Line3DBox[{3299, 2830, 3315}], 
      Line3DBox[{3309, 3343, 3639, 2489, 3344, 3640, 2490, 3564, 2675, 3248, 
       3312}], Line3DBox[{3314, 2831, 2867, 3741, 3255, 3319}]}, {
      Line3DBox[{1331, 1508, 3552, 1332, 1519, 3560, 1349, 1530, 3568, 1358, 
       3649, 1539, 1369, 3656, 1551, 1381, 3663, 1562, 1392, 3672, 1572, 3582,
        1403, 1583, 3593, 1416, 1594, 3603, 1428, 1606, 3613, 1440, 1618, 
       3621, 1454, 3694, 1631, 1468, 3702, 1644, 1481, 3711, 1656, 1494}], 
      Line3DBox[{1340, 1513, 3556, 1341, 3640, 1524, 1353, 3644, 1534, 1364, 
       3651, 1545, 1375, 1889, 3759, 1556, 1386, 3666, 1834, 1566, 1397, 3676,
        1890, 1577, 3587, 1409, 1589, 3598, 1422, 1600, 1434, 3684, 1612, 
       1446, 3689, 1624, 1460, 3696, 1637, 1474, 3705, 1650, 1487, 3715, 1662,
        1500}], 
      Line3DBox[{1491, 1653, 3725, 1712, 1478, 1641, 3699, 1465, 1628, 3691, 
       1451, 1615, 3685, 1437, 1603, 3681, 1425, 1591, 3679, 1413, 3590, 1580,
        1400, 3579, 1569, 3669, 1389, 1559, 3660, 1378, 1548, 3653, 1366, 
       1536, 3646, 1355, 1527, 3641, 1346, 1516, 3744, 1886, 1888, 1887, 1328,
        1505, 1864, 2367, 2429}], 
      Line3DBox[{1492, 1654, 3709, 1479, 1642, 3700, 1466, 1629, 3692, 1452, 
       1616, 3686, 1438, 1604, 3682, 1426, 3601, 1592, 1414, 3591, 1581, 1401,
        3580, 1570, 3670, 1390, 1560, 3661, 1379, 1549, 3654, 1367, 1537, 
       3647, 1356, 1528, 3642, 1347, 1517, 1885, 1329, 3761, 1506, 1833, 
       1883}], Line3DBox[{1493, 1655, 3710, 1480, 1643, 3701, 1467, 1630, 
       3693, 1453, 1617, 3687, 1439, 3612, 1605, 1427, 3602, 1593, 1415, 3592,
        1582, 1402, 3581, 1571, 3671, 1391, 1561, 3662, 1380, 1550, 3655, 
       1368, 1538, 3648, 1357, 3567, 1529, 1348, 3559, 1518, 1330, 3947, 1507,
        2330}], 
      Line3DBox[{1495, 1657, 3712, 1482, 1645, 3703, 1469, 3628, 1632, 1455, 
       3622, 1619, 1441, 3614, 1607, 1429, 3604, 1595, 1417, 3594, 1584, 1404,
        3583, 1573, 3673, 1393, 1563, 3664, 1382, 1552, 3657, 1370, 3573, 
       1540, 1359, 3569, 1531, 1350, 3561, 1520, 2389}], 
      Line3DBox[{1496, 1658, 3713, 1483, 3633, 1646, 1470, 3629, 1633, 1456, 
       3623, 1620, 1442, 3615, 1608, 1430, 3605, 1596, 1418, 3595, 1585, 1405,
        3584, 1574, 3674, 1394, 1564, 3665, 1383, 3577, 1553, 1371, 3574, 
       1541, 1360, 3570, 1532, 2337, 3950, 2432}], 
      Line3DBox[{1497, 3636, 1659, 1484, 3634, 1647, 1471, 3630, 1634, 1457, 
       3624, 1621, 1443, 3616, 1609, 1431, 3606, 1597, 1419, 3596, 1586, 1406,
        3585, 1575, 3675, 1395, 1846, 3750, 1845, 1384, 3578, 1554, 1372, 
       3575, 1542, 1361, 3951, 2433}], 
      Line3DBox[{1499, 1661, 3714, 1486, 1649, 3704, 1473, 1636, 3695, 1459, 
       1623, 3688, 1445, 1611, 3683, 1433, 1599, 3680, 1421, 1588, 1408, 3586,
        1576, 1891, 1893, 1892, 3760, 1396, 1565, 1867, 1837, 1866, 3747, 
       1865, 1385, 1555, 3748, 1842, 1374, 1544, 3650, 1363, 1533, 3643, 1352,
        1523, 3639, 1339, 1512, 3638, 2332}], 
      Line3DBox[{1501, 1663, 3716, 1488, 1651, 3706, 1475, 1638, 3697, 1461, 
       1625, 3690, 1447, 3618, 1613, 1435, 3608, 1601, 1423, 3599, 1590, 1856,
        1855, 1410, 3588, 1578, 3677, 1398, 1567, 3667, 1387, 1557, 3658, 
       1376, 1546, 3652, 1365, 1535, 3645, 1354, 3564, 1525, 2390}], 
      Line3DBox[{1502, 1664, 3717, 1489, 1652, 3707, 1476, 1639, 3698, 1462, 
       3626, 1626, 1448, 3619, 1614, 1436, 3609, 1602, 1859, 1839, 1870, 1424,
        1869, 3754, 1868, 1795, 1678, 1411, 3752, 1579, 1854, 3678, 1399, 
       1568, 1851, 1850, 3668, 1388, 1558, 3659, 1377, 1547, 1797, 1666, 3953,
        2341, 3571, 2346, 2339, 2436}], 
      Line3DBox[{1503, 1665, 3718, 1490, 1899, 1898, 3708, 1477, 3632, 1640, 
       1463, 3627, 1627, 1449, 3620, 1880, 1879, 1894, 1895, 3610, 1902, 1691,
        1896, 1690, 1878, 1860, 1717, 1826, 3600, 1689, 1796, 1688, 1412, 
       3589, 1791, 1790, 3739, 1804, 1853, 1675, 1852, 1674, 3738, 1803, 1670,
        1669, 3728, 1726, 1799, 1668, 1798, 3719, 1667, 2437}], 
      Line3DBox[{1504, 1874, 1873, 3758, 1884, 1709, 1900, 3724, 1708, 1901, 
       1831, 1705, 3723, 1704, 1464, 1702, 3722, 1701, 1450, 1698, 3757, 1881,
        1697, 1882, 1719, 1861, 3611, 1695, 1829, 1694, 1813, 3753, 1857, 
       1693, 1732, 1692, 1774, 1730, 3755, 1871, 1687, 1872, 1686, 1824, 1822,
        3727, 1715, 1805, 1823, 1677, 1802, 1676, 3737, 1801, 1840, 1672, 
       1800, 3720, 1671, 1794, 1812, 2349, 2397}], Line3DBox[{2430, 1680}], 
      Line3DBox[{1713, 1679, 1875, 1877, 3756, 1876, 1711, 1819, 1897, 1820, 
       1710, 1747, 3743, 1832, 1746, 1707, 1817, 1818, 1706, 3721, 1816, 1815,
        1858, 1744, 1745, 3731, 1703, 1743, 1742, 1779, 1740, 1741, 3730, 
       1700, 1739, 1738, 1699, 1736, 3742, 1814, 1737, 1696, 1735, 1830, 1734,
        1733, 3736, 1777, 1827, 1778, 1718, 1776, 1793, 1775, 1731, 3735, 
       1772, 1825, 1773, 1716, 1771, 1792, 1770, 3729, 1729, 1768, 1769, 1714,
        1767, 3734, 1766, 2443}], 
      Line3DBox[{2321, 2316, 3762, 2124, 1903, 3764, 2137, 1932, 3768, 2150, 
       1946, 3774, 2164, 1961, 3782, 2177, 1976, 3792, 2192, 1991, 3804, 2207,
        2006, 2222, 2021, 3818, 2237, 2036, 3821, 2252, 2051, 3826, 2267, 
       2066, 3833, 2282, 2081, 3842, 2297, 2096, 2319, 2407}], 
      Line3DBox[{2391, 2348, 1811, 2440}], 
      Line3DBox[{2395, 3741, 2347, 1810, 2396}], 
      Line3DBox[{2400, 2125, 3967, 1905, 3765, 2138, 1933, 3769, 2151, 1947, 
       3775, 2165, 1962, 3783, 2178, 1977, 3793, 2193, 1992, 3805, 2208, 2007,
        2223, 3895, 2022, 2238, 2037, 3822, 2253, 2052, 3827, 2268, 2067, 
       3834, 2283, 2082, 3843, 2298, 2097, 3957, 2459}], 
      Line3DBox[{2401, 2126, 3968, 1907, 2139, 3862, 1934, 3770, 2152, 1948, 
       3776, 2166, 1963, 3784, 2179, 1978, 3794, 2194, 1993, 3806, 2209, 2008,
        2224, 3896, 2023, 2239, 3908, 2038, 2254, 2053, 3828, 2269, 2068, 
       3835, 2284, 2083, 3844, 2299, 2098, 3958, 2375, 2419}], 
      Line3DBox[{2402, 2141, 3864, 1936, 2154, 3872, 1950, 2168, 3880, 1965, 
       3786, 2181, 1980, 3796, 2196, 1995, 3808, 2211, 2010, 2226, 3898, 2025,
        2241, 3910, 2040, 2256, 3920, 2055, 2271, 3928, 2070, 2286, 2085, 
       3846, 2301, 2100, 3960, 2377, 2421}], 
      Line3DBox[{2403, 3771, 2158, 1954, 3778, 2172, 1969, 3787, 2185, 1984, 
       3798, 2200, 1999, 3811, 2215, 2014, 2230, 2029, 3819, 2245, 2044, 3823,
        2260, 2059, 3829, 2275, 2074, 3837, 2290, 2089, 3847, 2305, 2104, 
       3962, 2466}], 
      Line3DBox[{2404, 3772, 2159, 1955, 3779, 2173, 1970, 3788, 2186, 1985, 
       3799, 2201, 2000, 3812, 2216, 2015, 2231, 3902, 2030, 3820, 2246, 2045,
        3824, 2261, 2060, 3830, 2276, 2075, 3838, 2291, 2090, 3848, 2306, 
       2105, 3963, 2467}], 
      Line3DBox[{2405, 3773, 2160, 1956, 3780, 2174, 1971, 3789, 2187, 1986, 
       3800, 2202, 2001, 3813, 2217, 2016, 2232, 3903, 2031, 2247, 3914, 2046,
        3825, 2262, 2061, 3831, 2277, 2076, 3839, 2292, 2091, 3849, 2307, 
       2106, 3964, 2468}], 
      Line3DBox[{2406, 2176, 3884, 1973, 3791, 2189, 1988, 3802, 2204, 2003, 
       3815, 2219, 2018, 2234, 3905, 2033, 2249, 3916, 2048, 2264, 3925, 2063,
        2279, 3932, 2078, 3841, 2294, 2093, 3851, 2309, 2108, 3966, 2382, 
       2426}], Line3DBox[{2420, 2376, 3959, 2099, 2300, 3845, 2084, 2285, 
       3836, 2069, 2270, 2054, 3919, 2255, 2039, 3909, 2240, 2024, 3897, 2225,
        2009, 2210, 3807, 1994, 2195, 3795, 1979, 2180, 3785, 1964, 2167, 
       3777, 1949, 3871, 2153, 1935, 3863, 2140, 1909, 3969, 2455}], 
      Line3DBox[{2422, 2378, 3961, 2101, 2302, 2086, 3935, 2287, 2071, 3929, 
       2272, 2056, 3921, 2257, 2041, 3911, 2242, 2026, 3899, 2227, 2011, 2212,
        3809, 1996, 2197, 3797, 1981, 3886, 2182, 1966, 3881, 2169, 1951, 
       3873, 2155, 1937, 3970, 2453}], 
      Line3DBox[{2423, 2379, 2102, 3940, 2303, 2087, 3936, 2288, 2072, 3930, 
       2273, 2057, 3922, 2258, 2042, 3912, 2243, 2027, 3900, 2228, 2012, 2213,
        3810, 1997, 3891, 2198, 1982, 3887, 2183, 1967, 3882, 2170, 1952, 
       3874, 2156, 1938, 3971, 2452}], 
      Line3DBox[{2424, 3943, 2380, 2103, 3941, 2304, 2088, 3937, 2289, 2073, 
       3931, 2274, 2058, 3923, 2259, 2043, 3913, 2244, 2028, 3901, 2229, 2013,
        3894, 2214, 1998, 3892, 2199, 1983, 3888, 2184, 1968, 3883, 2171, 
       1953, 3875, 2157, 2368, 2451}], 
      Line3DBox[{2425, 2381, 3965, 2107, 2308, 3850, 2092, 2293, 3840, 2077, 
       2278, 3832, 2062, 3924, 2263, 2047, 3915, 2248, 2032, 3904, 2233, 2017,
        2218, 3814, 2002, 2203, 3801, 1987, 2188, 3790, 1972, 2175, 3781, 
       1957, 2447}], 
      Line3DBox[{2427, 2322, 3945, 2109, 2310, 3852, 2094, 3938, 2295, 2079, 
       3933, 2280, 2064, 3926, 2265, 2049, 3917, 2250, 2034, 3906, 2235, 2019,
        2220, 3816, 2004, 2205, 3803, 1989, 3889, 2190, 1974, 3972, 2445}], 
      Line3DBox[{2428, 2324, 2323, 2329, 2328, 3946, 2327, 2326, 3942, 2325, 
       2095, 3939, 2296, 2080, 3934, 2281, 2065, 3927, 2266, 2050, 3918, 2251,
        2035, 3907, 2236, 2020, 2221, 3817, 2005, 3893, 2206, 1990, 3890, 
       2191, 1975, 2444}], 
      Line3DBox[{2434, 3952, 1362, 1543, 3576, 1373, 1841, 3749, 1843, 1844, 
       1848, 3751, 1849, 1847, 1673, 1838, 1835, 3745, 3746, 1836, 1407, 1587,
        3597, 1420, 1598, 3607, 1432, 1610, 3617, 1444, 1622, 3625, 1458, 
       1635, 3631, 1472, 1648, 3635, 1485, 1660, 3637, 
       1498}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXk0l92/+E0UhWZjmkyhMpSKSu/KnKEipZAIqaRCZMiUIUKkDBkKiQbz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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{366.5320715098225, 281.2831189860293},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{1.4431636567362705`, 2.465144077022358, 1.8139303568211318`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.604345138701807*^9, 3.6129770554551153`*^9, 
  3.6239960586953635`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Simplify", " ", "the", " ", "complex", " ", "expression"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"FitFrGGXComplex", "[", 
    RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.604295223691265*^9, 3.604295225112269*^9}, {
   3.6043160081469517`*^9, 3.604316011387137*^9}, {3.604327937746286*^9, 
   3.6043279520181017`*^9}, 3.604328257042548*^9, 3.604345089901016*^9, {
   3.6129770107105565`*^9, 3.6129770262554455`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.29847502436794354`", " ", "Cos\[Theta]V", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"39.41149727672321`", "\[VeryThinSpace]", "-", 
     RowBox[{"39.00289316713873`", " ", "Roughness"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"0.3858974159270268`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.3858974159270268`", " ", "Cos\[Theta]V"}]}], ")"}], " ", 
   RowBox[{"Log", "[", 
    RowBox[{"13.130032430768706`", "\[VeryThinSpace]", "-", 
     RowBox[{"12.257428196651462`", " ", "Roughness"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.604316004643751*^9, 3.60431602665701*^9}, 
   3.604327965676883*^9, 3.604328489141824*^9, 3.6043292402297835`*^9, 
   3.6043451853914776`*^9, 3.6129771244430614`*^9, 3.623996058717365*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Test", " ", "with", " ", "F0"}], " ", "-", " ", 
    RowBox[{
    "Note", " ", "the", " ", "discontinuity", " ", "of", " ", "the", " ", 
     RowBox[{"function", ".", " ", "Discontinuity"}], " ", "is", " ", 
     "expected", " ", "for", " ", "all", " ", "dieletric", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.02", " ", "-", " ", 
        RowBox[{"0.2", " ", "but", " ", "not", " ", "for", " ", "metal"}]}], 
       " ", ">", " ", 
       RowBox[{
        RowBox[{"0.5", ".", " ", "We"}], " ", "chose", " ", "to", " ", "not", 
        " ", "consider", " ", "rough", " ", "dieletric", " ", "in", " ", 
        "our", " ", "approximation", " ", "and", " ", "focus", " ", "on", " ",
         "metal", " ", "because", " ", "it", " ", "will", " ", "be", " ", 
        "barely", " ", "noticeable", " ", "for", " ", "rough", " ", 
        "dieltric", " ", "anyway"}]}], " "}]}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"GetLerpFactorFrGGX", "[", 
     RowBox[{"Cos\[Theta]V", ",", " ", "Roughness", ",", " ", "0.04"}], "]"}],
     ",", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6043298660745797`*^9, 3.6043298871387844`*^9}, {
  3.612977184151477*^9, 3.6129771930309844`*^9}, {3.612977233095276*^9, 
  3.6129773999588203`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJytnWdQVU3TrlFE9DHniDlHDIgJl4oKBswRE4qKOYuYFXlQEREQMyZMmFER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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mgf8j+X6x5/v+H2f5zuM5mlRyEknREu0tE6DJkWE9pB2NLWkQWlQISVU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         "]], Polygon3DBox[CompressedData["
1:eJwtmnngVdPax/c5Z+/2PufsIve93WuOSoZKlCY3QqYm4iIl81jhklKGFCnD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         "]], Polygon3DBox[CompressedData["
1:eJwt1HtMV3UYx/FDBXHVqNUmuDSRjbakxNJ0itMuq1DWzMCybHkjRaWLuLQL
hcq0ttaWJZYTgxDKEs0Csrkuy0urDUJzGYoGq63bRoK3zOr13Y8/PjvneX8/
z/N8b+dcN7dsxrJLoiiaRfG0NiGKdiRGUY+gmxpSoig5OYq+wMfTszy1SVE0
LzWKXuXLuTyKsuKi6ALPl1TlfQWWSrfzZFOzvHG0Um613BzsM/FUWodtxXLl
XvQ+Q94YdeP0fRy/GxshzqI58qZTEc/TtE6vtjAXmsCXyTOUHubpxI5jp/SY
w1uIJanZbLF38nRgxdgJzz51xlnrWKoTF+HtYZyvk/91tf4UZ3v2Xhab06fm
+556NeItNBGbb/xB/F7eR/Xdjc0WV1C1HlV4Lt2j/na5dfJqqYDvybBW/LS4
n3r5zojLzWHwpeaDtdHP4kX4Sc9uqjf2hlqRHq165tJS4ZvqDcLv4omnNVia
+D+8hWcULcE2hTmrl2fto6kcPyvu1z/D2lOwZCoVX49/bvw2Wi+3Ru4d+q7k
22puFfSuHr/hXeaVI06x7jyeWrl/mMcxtTrpLb6bsaNqzaWP1ftE3pVYtfgK
mhTuJXYL9qN4HjVjrVh7cmzPf9HnOX0a1buJ7zueYtpmbCffEKxePIJmY8ux
DGybOIsewp7CRmMd4lnUgDVhv1KP2t30r3V8lBxbX1jn27Qq3CXsKrmb5KVT
vtxieXnYIfED1Ijtwq7GtoiH0DRsIZaCvSKOo2HYSPUnYD3iMtqPHeB7B5+o
52JK1XePvtvpW+cyOZwD/n7YE740e7LcXhfQI2oNpg1qJdGN6t3HP4o32zmM
pI3hByAvRa2/vQ7FMimJb4rcPnmVCbHvKXxX47Fu8TLah+3DJmG/i1fRYawD
uxX7KdxH+grbj+WHeyB+hr7HDmFjw/cqnk8t2J5wHubSal4J5hFPGdg1fDU8
GTSdbwG2EGuxzlY6gR0Pd8ja6rwX8U1RZ6b4Br6DYd9po7FGvkX4Oed6kucb
up+nCl9Lw7038b7g+ZK9KZHzgx5H6WXxIPw144nhmzM2U04lvUjDjO3AKzyn
UaHae+VVOJcVcpdg58V/hX+V3PJwHtjXYV1UjTVga2g1XWvsA/x5z8fCXoXv
iNr42o2XhHsvbk+MrXuBHjutbbO1rdf7CDWJS/nO8fRSIV+J3KnhW1d7NXVh
x7DFWLq5doV/gjg9zVlj/8g7TQf4Dg78r7LVTgvrcFab9S3DLorP0BG+wwP1
zibGvv/h2GS+XeZTaX5PhPtLBTxL6QJPfzjP8I8d+DedN57pfYz57E2J3f3w
DZS68/lUj/UlxfZ8d2rs/MI5nkqK7duHqbFzCefzP3AY6js=
         "]], 
        Polygon3DBox[{{2827, 2119, 1899, 1290, 1289, 2826}, {2548, 1711, 3252,
          3000, 1490, 2973}}]}]}, {}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFm3n8llP6x5/l+9zPvT1E27e9LKUaClEzSioqO5VCRaWUrc2+EyOULaoR
kYZkD8NYw4xlUvKzZB8GSaKQLUb8Pu8+5/f6/XG+1/Wc+7rPOfc517n2b7sx
kwZNLBUKhd51hUJZcFVeKHwTFQpfq7VOC4Vu6huZFApHiuhz4TuonRcXCi1F
fK7g46IZr3c/zAqF7mp/1PMxot9f+O7CRwhvK5rNGu9njb2X8ObVQuED4TsI
LwhvXSsUJmu8zZpjrbq2U//vov9VNL/r+Rfq+69+L9J8WxULhWbqu02/D1d/
S8E/q3+D8JL6+2qMr4UPVlugZ4cJthAcof5vhB+htk5zHSq4THBo4jV/K/iW
6OYLHyS4r8baT3P1EzxO31fV+2ME9xBcI5rt1c7UvD/p97GCT2usdup7TvB5
vX+B8J6C7fUtRY3xi77lYM2xo/q/Evynnp0vfC/BF9QuFN5L8ATRdtK8fxDs
ovaj+hPBp/RssvDdBK/UfB01zxWCh2msndS/XvBwtY7CNwgOUusk/GvBY7Tu
Oq1zpOBgtc0af5Dg5dGW7S/8WCkUrhKuIyv8Jnyg3mkifLXgyZqjrLlOFJwu
mneF76b+AWqNRfOp4HiNfbxaRePuKviZ+htxZhp8teBPeq+/6LYV/h/B6zXW
XhpnlmAjvbNe/f3V5oluH8FtBdeoPSl8vOBnak8IP16wufbzZ8FN2s9hwg/S
HN8J/1B998Jvgv9Wu0f4cMFIc/wmvCa6kaIfIvix6EfpY2+Ej8V7R+XeK/Zs
QO7v4vuaiX5X4f1Ee2nmfWa/m6Y+633U92vV391I8FrN10H9FcEjNU4L4QeK
vl702wl/XnDfzDSHqn8X4aO1hlxr6C98D/hT/fdlPkfOs4Xe+UXj/Vfj3Zt5
D9nLljq/IzXvVoIjNfco4SMEh2hfz9AZTNbvD/Te3aI/WvBqvTNG+AEa7zzu
rtoi0fVU21a0++pZQWv5Eh4Q/dGJv72T5rxQ/euE/6r+hqL9Svh+ajNFMxqZ
oLV9pfGOEb5c8CKN2V503+v3hcI7CP9B+J0aZ5ye3xFbvrysvqmCLbWmPdlz
zfWBaE9Va632gujaiP4CwQ6C3xb8DYv1zijBHQUv4fyFR4J3RV5Pe8E71Y5l
bfCRxmqjtlG/d9Vc9aL9TWuerrU1VdtTz1aJ7mb2XPAl7ob6FwleJthDz6+D
pxPjG7Wej9RfH97trbXdXzT+nvq2Cd+8m/rvKhq/S2O1V/8Zgr3Uf5P69ih6
jHMEu6odpLVN1TybNM8H6m+otov6F2u9O0GvtS1U3+/CT1Rrov1qKriP3jtR
/UW1VL+v1O8ZglMFb48s89oK7qp5u6o117NZmmMcZyKaHuq7t+i5mPPMomXQ
IXp2mmh+Ee05wluqbwB3SDKit+iOENxP8Pqin/2gcf4l+reQr2oH09R/j775
EMFc8Bn4WzTHZuZP7vU4wdVqy4RPFtyAnBF+vuDbifnk6yAHwKcItgnnsglZ
nxpO1pmuU9/zan2KPve2amP1rE3s725btR5oVvS+3FE13k5j3qFxZgk/l/1T
mwkvCi4O/MM4t1T8vbcKnpd4jE6iuVb4ccLnCK/oO4cJnyi4Sr93LPrerdAc
M7m/yHmtvxzO6zQ9ywVnCh4Rm//Hal1/C3x/uWCd9utO3hHcrur70U7w0dh3
raPwzlXfs1jwMNFdxHq1rulqr2icsvZnWtX3oE5wkN6dpHfH8K6edypb3/TR
OlqpbzNysep7XBW8TvO3Vuutd6LEe56q/019z03IRsHZGrOPxrlB8En9nsSd
E3xF7SruOGeuNlF4V8G5ousv+jmCK5FT6h8o2FdrGCh8kua5JNwDePIs9W8j
+Jrg64JXF/37OP2uK1ofNdaaNEThB53Rq0WfY03tr5pjqMaKBY9MrRe6Cq4R
HTbQJq3jP/pdLVpHN61aF4wWHKv+qGideHrq8f4lOKdsmwTdcKZ+NxbeU/D6
1LptlOjv1nxbC99aizpD/Q1Yd2pbCNn7J8FJWgCGGHQnlXx/4YnJwq8q+p2b
I8vdJoJn650m6ttbsI9oriv697GJZWk7ZGrqtS3W/Ov1zjvYboL9tOb5vIsc
SH2egwS/q1oW9cH+0TunCR+nvj0jywFskubi6UuELxFcpnmni2YFd1XzDsW2
0Thn1rn/bc2zrOo7hfxBtt9Q9D0Zpmf3CT+7aD0EzRBsjtDHfBurlpP7wDsa
945wR/6t/gXcX/X/UPW3HCj8Gj1bFPb2qnDPe+k7rg/3gvtxTbg73KG9wz5c
q2fXBT6H3xfq7tTpGz4RXFOyrGGPzgnyeprovguyGpnNuXF+3bHD+P6S96ES
dBM6ao9wFpzJ40XTc9aPi/dOEf6EYHOtdYrwZrF5ln74bPcgH5AT6JnpQe+g
m9Abh6q/Q2x90h1dEbv/d8GBQW4jv79VO1XrGYptHvQ033yn5j5X+GLBfcve
21uRuaJfqL4fRf9z6u8+Svh+orlW9AvY0/T/ZTB6kDWhK/dNLW/XoF8Cz8P7
+4tmofD70ROifS/o+9u4gCXrNWywJvqOM3LfxROKtkexMycUfSexd8agb4W/
m5gHG2bmkxO05g3CJwv+VTRT0FMaa1uNebrg7GBXY183zSwD6wXnBtsbG7yq
Mf8gHughGOnZv4vWlfAvfAwP3V8yDj+PFvxa7X3hH+r99UXbputKxh8o+PnG
QLMDPFL0HsLP4Pga8Dw2Cec4Q3uVqE3FTk2s39eov6HwVaL/R7BphwofIbg2
8j6chrwVzdNBvtX0HUuF3y14Z9G2IXcVHX1o0XT9NMd9Gr+v4BGZaSZqjK1i
05yoMZ9Lrcdb6flhevfhon8PDDyDvzSrZN5A/26TWEYv1Tq3TiyLn6j6no7W
mazXOJ1KPkfOk32DN46NbMtuOePUe4VO71/0uTB2U8ErUtsXQwUP0BoeDDSN
MsufKeqfnlrODdK5XxXbNm6jsXsH+YkcfVn70kX9Zwl+WjAOO56scbqWbLd/
G/ncLorsr+xdss/SMzZer/6zBI8p+c4PDTbSMMGyaAYL9sKvKnvMhtiyJZ/L
ysTft0O4U03DNzbBn8vsU72gNYwrGce3mqJx9hLer2DZhIziHvYIOHcQ2Yi+
7lW1HGsd+pHzzYTvJrgs9t3aVDEPsgb2cEXZNgy2zGrNPRyblv3O7EuforX9
Wc/2h4/17oXqPx1ezUyPH36yaNZXTLNB8OPUMYFvEvv7w0r2h6vBR8NXQx8e
XbI/ksSON2Cv49P3K9mvxw/oX7Iv8CfNt0p4c8FM9EeVHDvYVvgEbHHBGYH/
uQfsOb7gq7llyfjgt47JvZ/EOvBl6UfONAz+HX5ek6B/D49tu50Y7Le1qdf5
ZeK1Dw/r5w7Bb9y1YxL7d+j6Uuxzw88aLPy1ksfErl8ZZOCwovUr9/kNwTdL
nvv0zL+x+V8vGad/p9R79GlqnY3ufhlZEplPsece1vc/LvqH6uzDvR7eRefS
j959WXB5yb5ll9h3B/75UvPuxTfIV71PZ3m6aO4XfFhtqvC/VWyLgWOPIQNm
BX7mPjIu8nl0mIPxnw/yAl4/ruzvhQ8eEFxSsn8yu+jf4OfgO5b8nbsRbxL+
Smq5yFkkRevF+qAX0bfQYJv9VjXv4UtPzBzHeRl7LfJZEaMhrrNbybGdZcS+
SrbxsCGwJcqi6Zcb3pPbRmJt+J7I1cUlnznCY2E4x79GtmvaCB5VsX14tOBi
ncFs0fxaNt/2EL5VZDlGP/oiCT46798TWc90DHYUuge9OSvYT/iB8A/zxoI/
6d23Rf+O4Aua6wj1Xy74vX4/rv5VguM1b9+C/fo92fuS431T9axYNo+OCzTQ
sjc/h/1BLoHvJPhM0f7q//mP4NgZD+qdTchSfM/M43fNrN8+CjbMzvr9S8lx
BmAf7pzoe5btJ2PTYK/2LdtO2zv0XZoap284fJXZ33yWmIlg67LjLNdBo/ar
xp4T+Q7mYT3EG7ugK/T8v8hD6BP7eUs1/hPar7fR33r+dNG+Pb5847LlODK8
XrBp2fEd5Dr9xL/6atxGwj9J/Jt3GgX+qg/0cyPb6jV0R5B1yDzGgwZ+JPZE
HGa2aCrqq1MboN87lx2Xw0c6PzO+Z2YZj6xHJ7xWtq0+pc53gj2fFsZizDSy
PYndhl7grIhntis4VrEu8CH6Hj3/UGrdsibokZvC3eEOocc3lqzLo8h3jpgt
9iDjc9bY8pzpxaw59n5nxGx0l9qWHSueFpsHR4fYD/19w5lxdsSRLwk00B6k
te0omh1T6+H2Zcs79BR4R/VfFPvuIwMuC7IXGXxOYn1ySGY/e6cQY+oWfGHs
+6WR19tbcFBm/PDMcZQuQUdiT8PvP2u81pqjXt95c4g3dA00XULspT707Rrw
QzPPyxqIlREzgscIxu+gNohvSR3/+T61v9Iv8H2rwOfEx7GbsK2xwfCXielw
H1+KTHtAZNud869LfQ49w1nwrd2C7w/cI+ADyh4TW537x7zoA+ws5BS8gawC
x2YYFHzJzYLvRH7vmMhr7xb28/Bgj2GX/U9kP2OI4JKi/Qr0xYJgU/KMOO1B
ZceL/hPZVj0h8toGhu8FDgj0M2LfD+LV3L9/ivd3J/bMfS07Hs3ZsPfYgcdl
viMVreeB2M+JW2PbYuNiN2D/bolnBZ2MrsK+nCd4fNmx2sUhN0GOAn9/Qrmw
JbjOXZ4Y7vt5meOf5BomC38Y26vmGA620yOx5dCksu8G9hF2EjkRbBNsPuKw
6C9oTgkyDBrsqG6Z+WaPzL4D+pLYDvqBeC86YmFknm8dWT6zNvIXEzJ/y/jM
tMSI8YuQyZeVLZfH5V5j25p9hSvLtsM6B9mNLEdnzQjvvhJ7XSuIX2m+9pxn
7HXNCLr8mtDP8xWBfrng2Nxx4vNzj3le0IVvxI65VInxBh2KLmVfbyw7jk/s
/RNiGYK3h5gzsWfenVt2/gj9NiXoOL57bjjHDbHzQetEs3+dfbYDBWdovvc4
R53d17Hl7ldV5w7WCp6X+y62CnrnANE1F/xc8NiK4xKjKr6nh4Q71SbYBkNi
70Vato2LLoMGvwadBu/B9yfp/ZV6/+SKY9DY+h0FH9P8rwhPiUHq2WvCxwo2
CDxPzmBynW3+J7GFQ67vAf35qGx5T/5qUmx5MwUejmxf7xSFMcI4UwINubZh
wcc5khhGbL/opNhnlQQeaB34DV6/ILP+Gq11flex/iQ3dGrFNtNpFcdeiP0Q
e35ec7ylMZqRl6lzbHeg4Adl57DIZd0muhfxD7T/cZ1t2f7YuVX7m/idT2nc
2/FzBcdXHEeaINgNGST8VuRq6j28RfCPam8IXyD4dNU+LL7sc1X73fjfZwef
Ed/xmYr9gWcrjr0Tc7hF3zFcv98UPkJwm6rjk8QgNla8l600zk2J84BF3ksc
H85S22rYbDMF70kcX90qdcydPce/nJDazl+kuT6t2v5bLbg4te3/TW5ZCe+Q
95qZO4/YXvDKxDmU7YVfnjhXsp3wpyPHjfcW/JvaFOG7C16qZw+Hvs/Vlqv/
VOLxiWP4xOaXJbYt98odcyYf1C53Pow7Qb74zMQ52ZbqPyNxHraF8Pkhh9dd
8O3IOYKRgi8S1xO+v+BHak8Jn0C8OXe+dne+KXGei3zCWYnzwq3U3yHkgybH
joeTM+2QOxeAX0Y8YHPF9/T12DlrbI6BmXPT8HN3waax47D1yMnEOcqmGqdV
5LmOV3/D2HHbRrHjdSdjPwku0PgXCL+t4ngcfgl+91rNk6p/ArHScNbY6eSL
yWW/Lnij1lHP3mrOecKbCV+TOKdIbnFtyK2TszuQXGTFNOfEzqHj472a2r7E
ziTvPit3vrmT4M+ib6r+l0X/bcUy4Uc9W5U4j9NbNLfkzsX2ZL8T52j2CTUC
xN4uFNxctr1IjuvozLndzqJ5Vc9uEc3gyH4pfhsxhDdS+1PYZugRdAh216l6
Ly77+5GH/YKv1y91zoI8y+G57chpqWOtbbX2ovTRvZF9xM6RbSrefTO1LYPt
gQ2CLMf/xPcckXlt9+ub3knMz8Sa0O/43vihKxLz24gQtxwQ7I29g+2EH8L3
wp+LEucx4NtHkW9l8+SbZdvA2L+cfbPM8j7Wmg/LnWs7UeM/kzpXtb/g1bHz
hrOq1lHFoPc5Y866DTEE9fUq+feK1M9bpeZX+Hb71PqoRbAP5+bOr+wieG5i
vXO7aFamfj4qN6/AM+QOlqe2O/DXmpVti/Cb/PvnBcdw5oZ46Hmp/SRk0XeB
dzlDbPL5If5AHII9JzfURXP9IbN/gw2zKbJPWY7sP+Er4TOhdxoEm+3F1H34
m/hG+FG8/1WILxFn2hBw4lK3h9zkHcj+xLmnXGO0F/4GOhVZlrhOoGFq+xg7
mbwV+VZ82muIHSXOYf2YOC+Iv01O46rE9Rg/EYdMnM/6QfCRxHUIjUR7TWL5
icy8L3FtSQP135E4z1UTflPVtu/N5DGqtq1vEbwt2KALybuJ7i/EYHL7a/OI
F+e22caXbXv2Dn4KNRVb8l9Fx9DJYRFDb6D+exPnuLdOfWac3WCN0y2ybU49
yfzEtSjl1PUV2LzEWS+LHBtFPnBe8MDmqu17bBlqKZYmrtlojN4MegGZTBz1
FK3zpMyxaWJaxHeXh9wuumNI8AXIA6ax643Ojh23x2/+S+Y7jhwgh/lZ1XEf
4uL7h7szRLQ3J669KQXeg59bivYG/HnRzBasix2ffCi273mx4Hu5c67EVIiB
U1OE/zUd+RK7TmJC7DjhpYLvhzwCefM5VeeY7hZ+Q9W5JO4v9/iExLZzfe64
BroDW/nR1DVFC/RdZ+auxUkF2+v3U+LfdzPHHbhXj+n3FZFlNTK7T2bbaW7m
fWF/iDM0ijwX9RLUk1CjtU3uOhPiHwfgvyKv1D8tc4zr7xrv9cy5HvTUN4J3
V5xTvEdwidqfhD9YcV4YH4K6g2/LrpGgVqJFkBXIjP65a2HOzV1rAe+RUz0k
8fpruX1+/BvqeMilv1N0jorcN7HcobFlI3u5Jncuj/ja1VXnUMmb3SWaztwp
reviqnMGC8PdIcdHzv7aqnOEC8L9Ikc4P9yfTpH5Hxp0Cme4Lnee49Bw78in
kFs5QvihueXxh7n9oOMKzvmPqjqOvLXW00m/D0bfV51DJV/IvYXX4XnyVNhm
5JLIKVG3gz7aVHX9QbPwjY9Erhkgp0/9Bnuex87/Eh9vUXUdw5Z6htg28NtF
12ZMCflZ8rTUM5BfQ85/gp1Uta17du56L+yHPiFORbyKXDU5609E86lonq3a
Bl6nZwfqu0bkzmmS32zHHcm9VupV8CvR39yps7AvI9stxAHQi+T5L1H/Q5Fl
ZqOaY0DYWjfnrtlCbsBT+DQlPS/XLB/J3XxedQ0bvlazEPMn9o9/i5+BPzk1
+FHg29XsW+a567jQFeic4fq9j75lbWZ/mVjnJMEf1P+lxnpMtNfmrs9DX3Du
2A7EYMiBElv5JXVujFgv9RgXi2ZJZPlP3QKxhSHq76E1NIltB1IHgp1DfgR5
jdyGh2fkrpNA3l6ZuzYC2bWY+kj0h+CNuWss0FO1mmOyu2e2M7Bh2N+7ctc7
Ype2DDod3Y4NhC1EfuTu3HWTyKIXgp2N/fzHzHbXlMz5DvJM8DM2FrbWYPXP
zl2/gu6Yk7ueA13GfpJj+Z3aErUHI+vKeblrqtCDB6bWg+jDuUF2fZw490r+
gpxGT/wC/CLBbvrGxonrechF7kIcg/dqjpki0/rq+T/E42fErtGZGXy3E/T7
CtG/FDvu165s+U4tFDUVX+AzZc65NBbcuma/t0fmGDv2KLnQ4YnjHudmzq1A
z3vIbWID3+eOKz1f5/vTWePMjOzvd6o5XoCt/kbu2gts6ZGZ42jHCC7JXa+G
n7Kz6B+P7AN2DvFo5p2lvtll+yb4zPjOJ6j/gdw1cPhQjwTew88iZtKj4BgO
9Yq8++cQNyOGNi92/WFz7NjMNsSNVdsU6B1iv8SGiami9xprXW/mrsfC5o+4
h3q3Ue7a4HXB9rw/d70dfhzxvX3DN6ILsOvIXX6WOjdKPQCxr9MCvx0QdFMD
0XbRfMsj+7nE8YhxzxS8LndNLfbStKC/uNfUYWIbdkCX5fYP8R+vi/yN+EFv
xY4LvR1b9xFb2r7muNC80P8C8bSKffYX9fvywD+PBZ+X+kZiWeQSVsau5/ws
2KQda7aNqGt9JXcdG/7vx1XHKIhDEa/evmy74dbcuhxd/2Du+jNskl00zj8i
+/7dQzyfuP676JrY9vnfg/zEZx8T7sVA4Y+Ge4f/fkfuOlrOiBwn+XtynuTJ
yIV9mbpmg/wccdqP+fY6xxCwObH3Dq46vzI/+DrYpfg91ET/JXV+hDxJfc3x
btZADQrxKHyd5jXHnTsH/sJPoj4F3oLHqJum/oU6GGpmOodaVmpax8SOaW7Z
58gx/YnCF1Wdg6EO7cbUvh41jGNDvGtcxfkz8mhjY/tU+FYbU+eXqfui/gub
HtuemmryUuQ8lsSO//xdfd1rzkmSm1xQcG3dU0XXyTSouQYa2UXsiNocasGo
z2IN1LjkiWNHz2isLHF86cmqY0rkRalfGxHiQiMF79SzpUXX7OFPMdecYM9S
v4i92ybg7PvOiWsJqCnAZ6TWlFwVOQNw6pz47oYhB/d/OTnqWuBJHcmW4jhy
QU1DPoh45ks65z0T+xrUZREPx895v+g6Q+xibAnqXhalrnuk/nGF+OZjvXsr
dzmcI+c5MdRAniK4Vc1ymfwUOpb4KnFWdDpxjC9i50nR3ehwbHVy5tSUUUcH
n+DP9kqdP6XOjjvxezhr4oPECf+p8b6oOga8PnZNHP3UeeArlErO15MjJd5I
npT6N/yv31LHH+k/XfDJ3LEwYmXklonvkV9+NsT6nqtYnxCPpTaLnCd8xZ6T
J6KeEr1JXJS8HTyc1ZyDRNZtW7Ocom7/pNS2InYFuUxiC9y7BblryrGZybXh
8+OD7FizbqDOv1Bz3Ri22XMh5oKPT00JMSXuPjlrakepISWuWy27ppSaFvJ2
2J+rc9eDohP5nw5iU9hCK3PH+4j/UMM2MciQFjXnb/DlqYXbUksGvd5fXbZf
06bmnAp+39LcsTziTv+q2uZ/qeqaNPJe3NOmNefbOgSbhHWil8mNEoPAH9wj
5Diwf+DD94M/fnKIjZ9CXVFueYFve1JiPw4bD5uS2jhszA257x4+4/8ClBwP
LA==
         "]], Polygon3DBox[CompressedData["
1:eJw1m3f8FcXVxveW3Xt39/4s9Cpio9kLGLEEFbAhiIhdAUXBQhOlCPZYKCJE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         "]], Polygon3DBox[CompressedData["
1:eJwt1nmQV8UVBeA3zPpbMANhUEENGBhFLRVxZRHQCstA2CtqBEUiQYwFaFKS
IqAGNCwOi6CisimKooFSg4hGJG6AiGKKcjdqiMsMUwpoRZC45bvV88ep1/f0
ubdv9+u+3R3HTR4xqUWWZUugHL7OZdljFVm2sZhlc7TnQl57Lu4wwTcwlX0I
/zfcJu167fnwcj7LWpZk2VM0m2AHuxxmiduX9q7KLLuNPYiWW7aH/R+4mHGi
/hNgSlWWVZZm2SPaQ2i7iFdZlmVlsLqQZSP4tufbwK8RLuF7EPc4/ZPa87Rv
hVfEWSjOjqqUc+Telv9ukz2S9li+fSNfeIndE24Udw3ffbCYvZtvO9zw5jWY
gzsoziFYxR4JD4pTCf+lmy7WKNxD7Cr4GjcQdzJuO986WIj7tTzOFXOAOTWZ
X9+YI7ua7k6aIhwv9zq6Bfyr9Y8z5hWwkH0S3TaagTAAFrMn0P6Wz0NyXgNX
4r7w3YIbZ5xK894rp3v5P+dbarxW4p7HXgn12n/Cb4IV7NH8BxmvDqpps5bW
HrdM//KIQz87dPq66b7JWH+GK2jG4M7EzWLfDOMiF9xtcp3GPlrfMPa7cn5e
fh3Zh+RXyz4fnpPvu/jZ9NXGPYf/h9qjYQzsKKb82kUsGCzHJn5tcA38XoA8
3Rr2L+XYjb2AbrG8h+LOpp3I3g5z9M1g98R/xmcCXAW72D/qz8nlQZgjvxPZ
1eK9pr8/LJD3evPoiRsqhyHxf6zLVHYRXqTpATfQPUC3yjh7StM/iX8z3Rjd
6c6K5aVrJ78e7M9988ZrpNsO+2lraZ+lOR96QT27ibatviPiPBm3G/sE/Bb9
veGmWGdjDsAdF/+NdlTsB1x9PvlcLeeJMJ+9G3oZt4ZvCX0tu5G2t/7WfFvB
pWKtxE3GTYJbxZhHdwCWaN+PWw372T+BV8XqB/Plsk6ep/H/J3sUrMSNFutU
3OvskTAClrLHwm9iH8O5ctolVk2c/9hPcptmHn9g3wMbtd+Her4n2y+ltM9o
d416YowVxu0PzKyGb1voL/6nuHnIjr5P8L9brCP47sT9ItaY/q+xv2nfbt57
sQeXFVNNiNrQaK4NsJ5vZ777cLfIcXbsy0Kqn1FHjy+mGjXT9w66NXLoyP4V
/e3sacVUC7+3hv+Sy6OFdP6jDsyMcwWnsj/PJ58OtB1wX7D35NJZOSNqN/1S
umuhSvs4/Aa6KYVUo6NWdzLWBvzNvgX+L2h3hxni3q+/H3DNttj3/4B1fAc1
5xK16XvokE//bVdzDYpa9Dy7P/4YcygXY5sc72OfE3sB94g8Mlwndht4k89w
WIHeSP9Z1O6ofbn0T+PfnkF/tP8/pSydxTiTLY2ziK4cavkOoZ9Ju4jPq/p3
Ri1i/9sYF/HNsY8Sp2vs57ir+P1Qnu6guIuepq31HRr/Frch6l3cbeKNKEv/
JO6q39E9Kta32qeLe02cLZiBK1SkOjiQfTms174Md7e+sZGLmH+J+6MirW2s
8ev5tLcLND/GvNkVtI/hxhvjFViL+ybWQ3+XOJNyGYw7UvL34trDUPGuyqV7
YWtzfYg6sSXqJO1m/RPjzPEfw/4pvMEeBsv1PcH3KNr72McEH/q4++lWG+9D
foPhInYL+DvN6TCZbjldDe4D9qWwLvZN/A/cQe07+N0Jw4uphm2OfRprBc+w
u5nvePOfACUW5iz2FHyNGG1z6W4cGXsKt5ZPZ7hc3Km5VLMb2L+H66KesNvH
/avdCS6ju57uAO6U2NP+5QclaU0X5dJaPmncjTCepktVqvNfymM3fBX/BT8t
3gr2S5/yVP928j+b7gf8/+IfsPfSPsVnTLxVWqT3SZm5rNXupa+UfWEx3VH3
8GkN2+griqm+vNVc+6IGbo0aUZHusLjLNpelu3GrcbqK951YbaBf1AzzaEPz
Es3jvncV0vmPOvBiWerrG++NqNnyuLYq1YXz2N0hr/2z2Btxl7L7iLkvagG8
Y/3eEv9Y3MNx1mAs7o+5tN9i3zXx76S9lmah7wKok2dnazvId1XsP7m2yKW3
4Zn59D6Ld9rPi+kNOcu3GP7aZRXpHMd53k/TZM33lqc3X7z9DjS/N+K8HY47
M5/eBx8139txf69g5+CwOB9n6dx1cS+U0D6tfRpMwi8TqyGX7o3GOMO4Onbv
eK/gpsPbuDdxPXCfxH0CL+N24KpwF/hez7e1sfoIcHU+vfuWmPPtMIymFSyt
SHd83PX9CumuiTvnvdJU806S3/8BFpplAQ==
         "]], 
        Polygon3DBox[{{2993, 973, 2439, 3105, 1712, 3201}, {2968, 945, 1023, 
         1809, 1810, 3141}, {2744, 2027, 2286, 963, 1127, 2745}, {2976, 996, 
         963, 2286, 2026, 2742}}]}]}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0bsuw2EYwOG3rarT4A7EDUhcgITBZhKDxCAkDAYGXTAycAWMJjFJE5ow
o051bNX5zAVYTIinMfz6vN+X79/vn7Z1eKJ3PBERI/o2VOeij5S66yOarXvY
wj62sZ8dHGUPsxzgLOc0Zl7iFJc5z1UuMscVbjHPAnc41BAx6M7PZESp+g5c
sJ6qjShbT/OSM6zwqy5iO+1ZfTdG7LKgH/Me9/VrPuChsk0Rne46MuftF3ms
DfMJT7VuPuO5ks5fcNNeiWXV2LtkRV2+K219Zc45c80b3Spj/473etCkdbvz
j+YnPWvNMy981Zve9VF955TfPOP+xP//8QfUL0M4
       "]], Line3DBox[CompressedData["
1:eJwt07lPVGEUhvEPhxlmBO1dGowhMVJJYrS1cO2w1mIstFBwXxK3zvXvcE1E
BJXNFQVRRFAEZjAihgzEaJRRFkXF3yUWT573nPPdc4d7L6Xp6sqqghBCL8bj
IczjHE/HQjhWGMJzHMVPdaokhBv8SP0Y61IhJPWG9O5FfWSKQ2iJ5vIoEuZt
vI+XO/9J7sAd5z7zC8TMXnKtXhd/RYHeK/6GIHdzHrPOvOEyuxrl73IvmuQf
/BbN8gT3oUWe4gH0W3U8IfMJzvBJPoWsnPYg8h7AafWgOq9e61ls8vdswWas
xFIsRD1G7T/C/fav8Jsm+Yz6Kc7iInLOXOAFuIZnuI4SPDD745qr8mEU4zKu
4Lf+fJ7hDbwRa9yjnA/hIA5gxI4l/Mu5/fyax9EuX0IKe9GMnuhd8GLcRNa1
HVyLOtxCEutRho/mhVyEGMrdfxFXY9iskZvwxd4GPofz+GDWqReXq7AHbRjS
382r7Wk3H8Mu9Xv9ndyqHkGXeoc6jfvqYXTqbVdvQ4O6Rv2Ot6orcTf6VhJz
n0v4670Zh7Gk3WaDZrexzH2zXI9SuY4dCVPOT6JInojPrQk5gwHXzkbfJp7I
Fa5pjZ6depWc4YfRe4x+J2qi7/n//9I/GomD/A==
       "]], 
      Line3DBox[{1524, 4, 2277, 1231, 1232, 1233, 1234, 1235, 2352, 1236, 
       1237, 2336, 1238, 1239, 1241, 946, 5, 1524}], 
      Line3DBox[{1531, 9, 2279, 1242, 2356, 1243, 1244, 2357, 1245, 1247, 950,
        10, 1531}], Line3DBox[CompressedData["
1:eJwl1GlM1nUAB/A/iCjgASKopQgiAhqg4AWelW2tNLQok9goJzRrq80Xznnl
0eYrnbd2aocv061VTvPAskU4F1aulpzhmWVKlOX9+c0XH77f3/F/Hp7/8/s/
WfNff/q1mCiKZvtzoFsU9dbb4qKond/o4ExSFJ2V5zhPk/EFeZFL/E6zucvy
D/6k0fiK/Iur5CRE0TV5ynyn/Jsu/uFffjJ/Xf7H/9zgJrf4xdpteYcJXueu
jLpHUQyfWouV3YijO/H0oCcd1hNkIkn0ojd96EsyKfQjlf6kkc4R1w6QAxnE
A+R6/wflYIaQwVAyyWIY2Qwnh3NeY0S4jjzyGckoTlt7SBZQSBGjKfUeY2Qx
h+0pkWMZx3gmMJGy8BnciwW+uxs9vFas78atqTFeHe870dfIFrlWtso3ZZus
tv9l+wpd027cpddSYNzq/X8wd9W4ijxzXxtX6MetfaY/Y26PbE6Mojn6dr1J
L9fX6b/qs/Ql+s/6E2GPaxcaP66v0iv1Gfoi/Ul9ur5An6w3uqbUuED/Vi/R
M/RiPcn/0Wjc1/gr9+AF92A/VeFckEeLs3zTvTsktxpvYynLwtky32G+jreN
32E5deZXhDNu/hve13eFM2l+lVwdzrv5ej7UP+K6tTVyLZfNN/Cx/qP5PTI+
nHE9Rz7GNJ9vuHyUGQzkkfAs2POwzA572Md0BnDM2lT5KlMYRilz6LRWJtOY
SG14RsikhHKu2TNWplLMS4whgwLqrc+ShaRQyRfM40ufp4/buth9nmv8Oc+T
TC4zwzPu+mb7DlJk/CKj6Uc+31l/KvyeWD/KOL2G8fRnJA32zA6/MdaPM0l/
hcnhN8VauvyEvRzmA95gN1Pd05WySL4nY8NnCWdNLurlPOgx+ruU6VlyJ997
3bfC88MOtjOUzZy0tkVWs4mNDGE9J6xtkBU8x7Nx93877wFJeKPx
       "]], Line3DBox[CompressedData["
1:eJwl0DdKhFEUgNHrMIJhFdbuxgVY2NloaY5jzjlnHXNOY85gb6GLsBEEYTqP
WBy+9+59zf8XlVWWVORERCnliYgCl4R+5kVU5UZUU0MtddTTwFdhRKM20UwL
raRo48m+XTvopItueuilj2dv+nWAQYYYZoRvu1EdY5wJJpni1W5aZ5hljnmK
8yMWdJGMN0u6zI/ziq6yRpp1Psw3dJMtttlhl3e7Pd3ngEOOyJof6wmnnHHO
m3lGL7jkimtezG/0ljvueeDx75uT///8F6A2Png=
       "]], Line3DBox[CompressedData["
1:eJwl0ElOAgEQQNHSaALxFG5JPEErOA+ogDiAooLgiAIqeiD3XEOWnkMxegYf
cfHyq1PdqaRnm71ydyIiCrxNRrQ9fOgoFZFMR8yzQJYcnzMRi7rEMiusssaX
3bpusMkWebYZ2e3oLpm0e1okMX/blca3zHtaHt807+ucHughR1SocswJQ9/W
9JQzzqnT4MfuQpu0uOSKa2645dc7d9rmngc6dOnxbv+oTzzT54VXBlP//+wP
wQgkMA==
       "]], Line3DBox[{2335, 1515, 992, 1228, 2372, 1227, 1229, 2335}], 
      Line3DBox[{2339, 1513, 1514, 1230, 2371, 1511, 1512, 2339}], 
      Line3DBox[{1519, 1156, 1158, 1006, 1519}], 
      Line3DBox[{1157, 1518, 1517, 1516, 1157}]}, {
      Line3DBox[{2373, 2582, 2853, 2922, 1669, 2983, 2977, 2990}], 
      Line3DBox[{2380, 2852, 3083, 3338, 2938, 2879, 3178, 3345, 3187}], 
      Line3DBox[{2388, 3086, 3233, 2387, 3087, 3234, 2971, 3079}], 
      Line3DBox[{2392, 3090, 3235, 2391, 3091, 3236, 2393, 2992}], 
      Line3DBox[{2404, 2986, 3064}], 
      Line3DBox[{2406, 3093, 3238, 2405, 3094, 3239, 2407, 3179, 3077}], 
      Line3DBox[{2418, 2987, 3063}], 
      Line3DBox[{2420, 3097, 3244, 2419, 3098, 3245, 2421, 3180, 3376, 3076}],
       Line3DBox[{3027, 2432}], 
      Line3DBox[{2436, 3198, 2546, 2434, 3199, 2547, 2438, 3200, 2548, 2973, 
       3074}], Line3DBox[{2454, 2807, 2808, 2685, 2733, 3305, 3158, 2453, 
       2805, 2875, 2806, 2774, 2935, 2953, 3366, 2955, 2954, 2452, 2936, 2937,
        2844, 2730, 2665, 3157, 3301, 2823, 2729, 2451, 2749, 2843, 3032}], 
      Line3DBox[{2456, 3109, 3258, 2455, 3208, 2559, 2457, 3209, 2560, 2458, 
       2995}], Line3DBox[{2464, 3112, 3260, 2463, 3113, 3261, 2465, 3215, 
       2570, 2466, 2996}], 
      Line3DBox[{2472, 3116, 3263, 2471, 3117, 3264, 2473, 1738, 2474, 2997}],
       Line3DBox[{2480, 3120, 3266, 2479, 3121, 3267, 2481, 3122, 3268, 2482, 
       2298, 3188}], 
      Line3DBox[{595, 251, 1867, 331, 330, 3295, 2487, 329, 1909, 389, 327, 
       1908, 388, 1907, 250, 1310}], 
      Line3DBox[{2489, 3124, 3270, 2488, 3125, 3271, 2490, 3126, 3272, 2491, 
       3181, 3377, 3070}], 
      Line3DBox[{2500, 2714, 2607, 2818, 2606, 2817, 3333, 2499, 2651, 2650, 
       3296, 2498, 2957, 2965, 3368, 3177, 2966, 2497, 2963, 2649, 2846, 3337,
        3148, 2934, 2847, 2848, 2754, 3140, 3332, 2816, 2605, 3045}], 
      Line3DBox[{2502, 3128, 3274, 2501, 3129, 3275, 2503, 3130, 3276, 2504, 
       3182, 3378, 3069}], 
      Line3DBox[{552, 458, 494, 457, 2142, 752, 751, 2849, 931, 3367, 2513, 
       2956, 3280, 3176, 2512, 2654, 2918, 3357, 3149, 2511, 670, 2203, 849, 
       611, 3029}], 
      Line3DBox[{2527, 2715, 2716, 2655, 2931, 2234, 2526, 2958, 2964, 2959, 
       2944, 3361, 3174, 2525, 3288, 3138, 2524, 3287, 3137, 2523, 3150, 3286,
        2791, 2851, 2850, 2522, 2755, 3319, 3162, 3005}], 
      Line3DBox[{2610, 2538, 3067}], 
      Line3DBox[{2657, 2656, 1883, 2514, 3133, 3281, 2515, 3134, 3282, 2516, 
       3183, 3379, 3068}], Line3DBox[{3066, 2759}], 
      Line3DBox[{2768, 2984, 3008}], 
      Line3DBox[{2775, 2558, 2776, 2689, 2734, 3314, 3159, 2825, 2557, 2824, 
       2688, 3207, 3146, 2687, 2556, 2811, 3171, 3353, 2903, 2904, 2555, 2704,
        2686, 3206, 2994}], 
      Line3DBox[{2778, 2569, 2779, 2691, 2736, 2735, 3335, 2834, 2568, 2833, 
       2812, 2832, 3334, 3167, 2876, 2567, 2877, 2831, 2777, 3214, 2830, 2829,
        2916, 2566, 2828, 2668, 3213, 2827, 2826, 3043}], 
      Line3DBox[{2780, 592, 654, 449, 2094, 653, 540, 2670, 487, 3303, 2669, 
       710, 2694, 3220, 709, 859, 431, 2693, 3219, 649, 832, 1297}], 
      Line3DBox[{2781, 2783, 2782, 2815, 2604, 1968, 2645, 2961, 2960, 2962, 
       2640, 2947, 3364, 3175, 2917, 2578, 2644, 3304, 2672, 2577, 2696, 3224,
        3147, 2737, 2671, 2752, 3006}], 
      Line3DBox[{3000, 3252, 3104, 2437, 3251, 3103, 2433, 3250, 3102, 2435}],
       Line3DBox[{3009, 2981, 2746, 2980, 3052}], 
      Line3DBox[{3016, 2739, 3055}], Line3DBox[{3017, 2661, 3057}], 
      Line3DBox[{3018, 2662, 3058}], Line3DBox[{3019, 2740, 2537, 3035}], 
      Line3DBox[{3021, 2741, 3036}], Line3DBox[{3023, 2743, 3037}], 
      Line3DBox[{3024, 2403, 3165, 3186}], 
      Line3DBox[{3025, 2029, 2747, 2416, 3166, 3293, 2629, 2985, 2630, 2798, 
       2417, 3060}], 
      Line3DBox[{3028, 2972, 3145, 3318, 2748, 2952, 2951, 2430, 2112, 2821, 
       2663, 2723, 2722, 2431, 3313, 2731, 2732, 2979, 3061}]}, {
      Line3DBox[{2336, 1524}], Line3DBox[{2357, 1531}], 
      Line3DBox[{1657, 1770, 1883, 1645, 1761, 3274, 1634, 1753, 3270, 1623, 
       1745, 3266, 1612, 1736, 3263, 1602, 1727, 3260, 1591, 1718, 3258, 1580,
        3198, 1709, 3250, 1570, 1701, 3244, 1561, 1694, 3238, 1552, 1688, 
       3235, 1544, 1683, 3233, 1537, 1678, 3338, 2242, 2244, 2243, 1520, 1669,
        2222, 2328, 1781, 1808}], 
      Line3DBox[{1658, 1771, 3281, 1646, 1762, 3275, 1635, 1754, 3271, 1624, 
       1746, 3267, 1613, 1737, 3264, 1603, 1728, 3261, 1592, 3208, 1719, 1581,
        3199, 1710, 3251, 1571, 1702, 3245, 1562, 1695, 3239, 1553, 1689, 
       3236, 1545, 1684, 3234, 2284, 2295, 3345, 2353}], 
      Line3DBox[{1659, 1772, 3282, 1647, 1763, 3276, 1636, 1755, 3272, 1625, 
       1747, 3268, 1614, 1738, 1604, 3215, 1729, 1593, 3209, 1720, 1582, 3200,
        1711, 3252, 2289, 2297, 3376, 2288, 2296, 2369}], 
      Line3DBox[{1665, 1778, 1886, 3286, 1654, 1769, 1911, 1806, 2203, 2103, 
       1643, 2101, 2102, 2100, 1910, 1804, 3332, 2097, 2039, 1632, 1952, 2096,
        1951, 1907, 1803, 2313, 2343}], 
      Line3DBox[{1666, 1779, 3287, 1655, 1879, 1912, 1878, 3357, 2209, 2210, 
       1871, 2237, 1870, 3337, 2140, 2139, 2208, 1862, 1908, 1861, 2038, 1932,
        2011, 3224, 1855, 1905, 1854, 2010, 1930, 2090, 3219, 1846, 1848, 
       1845, 2122, 2036, 1899, 2119, 3213, 2121, 1841, 2330, 1840, 2312, 1925,
        3206, 1828, 2302, 1827, 2359}], 
      Line3DBox[{1667, 1780, 3288, 1656, 2268, 2267, 3280, 1644, 2273, 2274, 
       2272, 3368, 2276, 2275, 1864, 1909, 1863, 1622, 1857, 3304, 1906, 1856,
        1931, 2128, 3220, 1850, 1902, 1849, 2137, 2053, 2120, 3214, 1844, 
       1898, 1843, 2193, 2136, 2086, 3353, 2192, 1832, 1837, 1831, 2016, 1995,
        3301, 1894, 2085, 2117, 1830, 2061, 1829, 3318, 2032, 2030, 2334, 
       2029, 2341}], 
      Line3DBox[{1668, 2232, 2231, 3361, 2248, 1880, 2269, 2271, 3367, 2270, 
       2141, 1873, 3296, 1872, 1633, 1866, 3295, 1865, 2255, 2256, 2257, 3364,
        2205, 2207, 2206, 1904, 2008, 3303, 2009, 1903, 2093, 2092, 2091, 
       3334, 2123, 2164, 2124, 1900, 2126, 2236, 2125, 1927, 3207, 1838, 1926,
        2240, 2241, 2239, 3366, 2265, 2264, 2219, 2221, 2220, 2238, 2084, 
       2113, 2112, 1891, 2110, 2111, 2031, 3293, 2083, 2082, 2366}], 
      Line3DBox[{1887, 1807, 2233, 2235, 2234, 1882, 2106, 2266, 2107, 1881, 
       1974, 2142, 1973, 1875, 2104, 2105, 1874, 2099, 3333, 2098, 2200, 1971,
        1972, 1867, 1970, 1969, 2012, 1967, 1968, 1858, 1966, 1965, 1852, 
       1963, 2094, 1964, 1851, 1962, 2138, 1961, 1929, 2006, 3335, 2127, 2007,
        1901, 2005, 2033, 2004, 1928, 3314, 2002, 2118, 2003, 1896, 2001, 
       2135, 2000, 3305, 1924, 1998, 2163, 1999, 1895, 1997, 3313, 1996, 
       2367}], Line3DBox[{2042, 1956, 2015, 1955, 1913, 2304, 2331, 2041, 
       3319, 1653, 2361}], Line3DBox[{2277, 2165, 2352}], 
      Line3DBox[{2356, 2279}], 
      Line3DBox[{2294, 2301, 3379, 2293, 2300, 3378, 2292, 2299, 3377, 2291, 
       2298, 2368}], Line3DBox[{2335, 2261, 2260, 2372}], 
      Line3DBox[{2344, 2076, 2075, 2362}], 
      Line3DBox[{2350, 2078, 2077, 2351}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJztvXk01dH+/09ChpSpzJWMqZApKrtUIkRCRUmJJqUoomQoQwOKjEkyRZFZ
GSKZM8/zPJ5zDFFEil+fdf28ztf9ve/9nrv0SfeXf6z1WHu9zms/33ver733
ulOmmkZLyMjIti4nI6P4+b/5ct4r4c0dmWT/+LOrnJF/IDuDR2T/n3+fMHmV
tpgxHnXN2Wn7pK1A9xCHeLYV6ztIdM9xg880t1Qq+km2j8UT2Xj2N7Li5uyz
7yrkWtvahZwf+Q7feIyf47eO10o+rOgg2T7FhyORhRVDc3aO4rnoeGUrkPvq
U/LKMcNz3CW+MdhhIAt9fKVNmJkBPulCc3Wp6BYUwJory1HYPscf7BVWcpAn
oOqpVMHzyaD/V/sk2ifhpOv/p/OF0plPPEqE9z7ovLWK5pX6aQLyXf9CY+Q+
6Czw4sGb0A9/df5Pdd4pdOK7oCrobJr90nb8LgHx84mw7lQBnR+OqaQGDeDR
1xTyuCiTzjmePCJC3Sv836v/Qum8aUXetDA96Ly/yNn6SgwBfQkS+nZtDej8
YSCZ0X0ZAb2J/Rg1hkBn8cyTAhuU/+r873Q2XbtPpC2rbY4XnaxlOVRAQLKi
AdfWfwb9Nxy+JW3KR0CrcJyU+sKg86Mvn1WLjvzV+d/pfCSGf6/9edBZ2K2a
m7uDgFw5LBP25YHOL/fx7kA7CajWaPWNpCko5y94Mi7RXv/zdXZVX+067DI4
l68hWzv2/uf1yKC6x2UoD3R2vL/sIpdTBYqiFL08/BL0NN7h+2TQ6AOmzhTU
4o9kmUBn+fT2npJJArJ4cnSkwxd0Ll0RJvxDj4BuKVbtDu0GnSXzdWpfOOMx
x3W/Wp+F4nUcBc1hRqCziBk+zVWpAZ1a+9DzYgzo3O1ogFYIVSKdlbQBsuGg
555N2TfberB1Pnqd/hx1Suscv3MhJsmQaQCZ0xWxTtmDzo1XvBKrzxFQ9nlJ
Fmqi8d7mmdedzT/He1wnd9G5CIHOfeKmtt7P/xyd++LO2l1FoPMu61O++l8b
UGF5j9AOL9DZwYY87lFNJeIX9Dfifg563taSpO8wycbUOS7KRWrVA9D5jHzQ
eAjPAGpNML82ch50nrGKHQu3JKAq49d51oGg8yH1dZ/Mk/Eo4GuFxdhK0LlB
KkWBL2Hx6XwinGLNdAVhzs/wgzM8o8/aEN0ECmTCDczxG31Pnr0ybUKjo9fE
p8+Azp+/RVNJjFahion1kXZeoGfLkefr7njkYLcbexLl8Pqgc0zC2dLmDQNI
L/fWo2vbQeejF7jd5TwJ6MbLGu5cJ9B5Rk9HcVkeHjkwqJ/aMgn9o3ZepHRi
zuLTOXyLgkJhC8wTrc0/he091YGW0K+fdFICnTnQpr31wy1oGXJdTbUMdG5q
b+KdYK9FjhKaqX0WoGcULr0j42A+ps7J11Jvd1CAzlZLdl6Q2T2AmgW0+Cn4
QeeE7rETU0E/+8G3EUM9l0BnHIuur18NHp1bfs9evgN0rseFLFOsXXw6F136
PiLKCPP0p5pv4pd0dyFut3RHui+gv7T69NXXqAOVySPpsVPQnigaWjbSazeg
y24Sm/mUQc+kidh3hd0fMXXO2rIrY2ltC7Qzmx3fHlEfQBET6iEXl4POG99Q
1ye9/vN1VnSPbvC/2jPnJ6HvoGHduz70UsIkO3Z3/xxfzpOelN3cjbwtvZiW
vYZ2xryyA/kxtKM9hMztM5FQzkOlNHgDVSsxddYR8R4ceAE6b+jYl3pFD1vn
/dvOsrXogM6W9F8eCfbg0crbPK7shaBzce6ekw19v0/nXM4eazb9+jl/KqWk
9n33HkQ7qF/a8tg1wfjhijP/hp4BdI55mDG3CvKbJzjZMSBDQJEbdE7x5cN3
GW+bvLPVrA9N6rB8PrMF2pn46OV6LQqtSPtjp4kUkc5GEiI0DJYPUFRs13J/
K9BZ5vNuSYczA6hw7aHRcwQY74V+yYk7l05ATnYh51/Kg85pofb9cV/wyLUk
XCE7FnT2HtDvvjj5+3SOs/Bnc+6QnvPH9uS+tp/lDBXRBNmvTEVznP7Bqqz/
4U9XJ0Z07lCC/v0568X/4XeW6H6w5dSZ41XUu1dP/+Q3udCqOGrTOX7+u/OX
Tz85ls4GkUXVVqagmwzfEzvZmj9/3vGX/xuuOpOzpRfKQwdfZNsRtUTM9Pdp
b1kf6oD0fElZ9hS8yeiGwdiSC0HQr7FnJS9JzuxABIEtq7/WQnoK9hvBx3xS
kOj+++lW+/rmOIOOkm/Zlx40slUgRTuPyB+/fW7qmhmY/py97mPw7TmU20cl
x7v5EvGol35z2OQlsBPspuVi9S0fWVjXP0jrhfbHvFPoppNVE2b5j6E/MMpI
BZxaYdDWk42w+L4jBsfqvxabn/+tXNsr8vLQftCf/wGf9ansjwuWnlRuqh+8
y6IByv852lp5trgmFLNFuMVHAsY/p+4WiioL1qD165mcJPiBS1jShRZer0GG
VV1SMzjw80tEuTvb+/hFp39No9mKEEsYV5f5hEXt+FKPlklnVTHvBv+fjhyr
TtAqIjlft3s05FLjQM8NO1TYdbWaMdPTVW65f4oK9GSJFDdp5a1FSv58immX
wc5k0sStEe0WJD+tviFJDvwZuvxOTXigCNHXWX2R6gfeM6rO33grgWR9Ngfk
KHvOwHhYZX9XwJkfrZjpLxbdS7hUCXqqUdU78EvVITWc8mNKHvDne/dwz7mm
EjQVgRt1e0KkZ881yXtT2chhx3mXpG+gg3VWBvvUsnJ0gm7mKqEL0m8dkln+
ZFMSyfliq2iXa6+DfOFaV5pJ3W/DTO9x9c4p2nOQr43s1m7vtzag79/eGoU4
gz8Ndq7+V5tzUW3nln16rcCPqVRxntn0hmQ/jZyLuGxLod88HRsoUW7Vgcai
aCj5iOaPV+/ypzL+nD9ej+DPMnkP5SQsc/CdLVszYjnzlL7uJejZ6CcZOq5Y
ieijpo0tToGf591tRg9PFaB8MbFGzUrg1z2MJL5Npy5YveuVV3jhmwzzL9uY
JI71Wt3I7N3MFYdW2B83Mxl1FVPo/zlvvbXUhhH8Z3faaKvQW4PEn1EEbF4F
fl5wsBecOlaK2a+F2GR6iUQC9zHxTFDy/rBg+cILNEvuTIL1tAh/rXIKaRxK
8XNuHmOF7zIivDdp/FUr6mbZpZ+4FvKlZVDyfPJRDab/rQ+EGozaIf0Nxtxj
YmXlKFMgqF/yPayf6H6jijBZOYA5D12o/J6xcgyneVA0Z59Jwt+bducw2tx1
dcZuo/scx8+EL1v+c36Bd2nq5Y2Tm+P6YderZv7FvGPmjbfp8yrHOT5mqNjj
8jP9QvmPtV+zUHyh/Fmofh+rv8baT8GyQ2p6LK76MKlzSBPa1a/mDhb9gQ3I
5fAZhvIAqC+np4TTrSOaSd6nyBG7NUW3CuyP0ahVdr5uRLsD9QuXOIOdDY0T
U9TiVYhLkFGChZmoPTTv+xDiXopoP9ybHrsI/UV8k+Fx7hvtKOjp6xC6QPBz
9zrzDteQZvTW7/wYnyS028ZbGQ1X63eiHx8dDZo/gJ3I7BGu8eo2pMq+hlcm
EOY7HcMj2419ejB1c6NJWKLsDesVNu7rB43p8ZjtwPuDLGRLagoh/dosoSuH
F64e/ekca1yHNR424m9luJUG5UdccE1+Uk0F5niM1HEjqeM3C7aammtC4Ofq
yR9fK860ooPijK5Gr6D8dxUv01v6rQ7Tzs7Ma4dPHofyuc0A5+3t3b7ovtdC
cVOhg5YDPKDP9QPU3PQujQtmf8vZ5xbKQUT9vuMyN29/7PE/Fn/RmV3G7Qbj
vWarG2etFLow0z96bdssNwjlZ53nPYeOg3HoU393u0Yx0XjpDY6PNTkduZGr
qc3YvJ3jy4ztGU0ah5Ebb9Qz62Box65NxnAEpncgsQMqK3kPwLpHwrPvNnn4
P2c9UHGpb29bAejwMskojib8HTq5x2Pb8lzgpYetqLtfZKCPMRvuVrwnqr/W
WTPpaZmowb2DqjWZqJ4GMbx8uxK739+pPVB+0wH0XOuEt1cZ6EAMFO98f8SC
nVznISba9CwUueFuXH8w8Ls4JXXcjmzEPHFce2QUOBN11RKrnijESra0hYYe
+De1M4pq5GXo3bJ9FB86gb891aJ0OSAJxa+PZTJzJdoPnarrytTKReS9yb0i
HPB9ySNWUfTT/TnrWr+LT4h3aD6yAz3XZjOt2mGT98t/14VjpZduGbRjOXG3
943uqUP8XZo5vNehn+IyUnsc51aFOnjrfG+WgZ+iminhGRVpC8ax/OzfrBGm
Q9T+HHt7V/1mYjomp9P4ZC5TCv4Phr3UfKpZgfI3DR1U+Aj9VHIEzxb2tDbE
LbT3xSVd4LXNAt5mT7D7L1LrLxbvbFoWbexPtL4hwHU1gy0HMz3WfKcs+tDp
ngbgnT86mp9HvsW081nvGjXhZepcegGbvCOXqrDnUws1r8GaR5BaTrC+O6n9
C1Y8Hlb638VJjRtcbHaw1oGx7GCldwhd4nBBHNorL/27nkgae9yFFR+IlT5S
cnzvOzpIb7FK4FV4UyMK5+a7X28O+XovE7T8gmc+5vwRyz6p/KbEyq2XFGAc
aNZsy1tH1YpaPTyq35YAj7zFnVLW0YToFVjO4Y6BP5Wp04YD5wpRh5iV51It
4NneH8/yriZ9HeCNXKaGfwa0k5YHhUSKu9pQVzrhifNzAtF3IV/DzNeOzo4R
6EWVgI+G32Q5ltKOLrZff28+AeOZFU9b7hRuxT5XcpKzSqm/AdLjKPlKFM5i
p98WZSJnsRHWCQs7ql5Hfu3GXB/bai9nmikO899otl1jP6Sx17uy49YdNvOt
nEsfkhDo4hU4hHqj2D/vVJea410mgV3/ap2q0CBSmel14ByX1tvprPn918+v
F9v+3WLz53f5uVD2sdb9SLWPlf6CD/ubzd+A4/Z7BpfsD0Et60qC2seg/by3
0sUq5EYtyXaw0qepTBdaTwKfwJspOpmEYqZ/w1hu/Pwr8AGJ7U8M1r/ATG+E
H1jR+gW4duD5maHXLxddOSSVk9oPYun81F9JLHQCONnDp9Ga8WGomrP2vNE4
8L78zgt9BRGY9t3WbRO8TAX7HTiqNPrhVBzyLEhyzvvYAOP20ZT1GsqDi07P
P52/LaGW3bwSvpdBWrxNaEYpJv9d/pA6L8Y692EW75Sj1AblX2l5zteI0doF
8//UoZR7l6zBT44LERs4KPMx2zcsO7SjiSL8q8D/jcU3eQKLa0i2Qyrfv4z1
aRoLjCfTSrRVrsW2osehr4eeyoM/bYqsXPi+ajRspvkxTxz8oU9kb+K/V4yy
3NU4PjVC+sCRlYc4v5Zjxs9jxYkt1H49FseKN/vE3q0/3AhcXsvQVegQ9jz6
Zpn0kTIcrK+e21C+zCivE9k4m6vI74Dx50HV61M7u7vR9YcdBd6OYH9Xduv9
e3R5mPFsTxvqYhuI5rkBm2q1OB6mo61rKH0jNvZC/14hZqPG1IdWJ2dcSDgF
fDV1aWpHSy+6TZ93iHYD8LzTmWcrWPqQs3SH7Mk0aIddAn4wbRXHIYox45y4
c/C7PLJ3Vm89W4A0g1bVB9rC9z2r4c9ZdqKKZP2x6vVC7YculD+ktpO/Os4K
i2O1b1jreFjzaywdsNo3rP1crPTr7VbU77wI7cxjvzHv84YtmPkS3qvnUfMV
0reyWpziEm9Cu9ynz6o/gfx+I+NB9Mr1mHFTRVrvHwg5A4+JoRTTmm5GZb1H
FcuPgQ5dPfjsVqlqxDnCvoH9APC3Xr1cVq7V6OsjNjv+UeDUEvsdfPaXo32h
R5dnfgduwtUidG60DCmfFuvKNgEdlsZnjIYJFWCe28JaZzg2HWNCbgD5zdj3
xCLtVAPCn8tQ4eOG3zWuo5+qDavBbIef7y2+QCsD83EOy9UqEjULt0+HNY+2
tG8L+aqaPsfdbnDkFZZgz3NJPQ+7UP7/ao61foVVT7HskBpHYdes5/ouA37X
VWNG3dCvDvNcJ5Yd3iNx63WJ4pEeL3k+Kfa6Ff1Qf1dzlmh+EXri2IpLofXo
9LnsmxtFgD/f0WNCrtmIqt1o4tYbgf9Ksh2HVXMLMOP6sNa1sPzEmveVe0w8
2PMU1pGCOX+MXMrpIHne5xRUn5U8Af0+9di1lKy4TlRzbCyUtRL6/QIJwtTd
Ld1oMsTijaoNcNGDX3dR+nWjXXysyikmoA+Dh074fcEGdENes2DzfeCnfaUs
eHzq0cDGmhXXb0M52XFpLMlhXxXJ8Vp7b3NexW2pgv4r3539jdMQ+hQudTS4
C9a1dN9cxzN6DiGXzaaXzorDuvqxEeQr9AOP7iXYPZVRBN6mPvKyafjP2c/9
0/nv2jfEan+w/NFTyLeJCybaj6MYXaFqU4nZz27V031V2QJxSneon8Xk1mOf
q/rciLYPskH6pTymk2yn/5bDv/x/lx/9Sq5OJw/jH7Klm/DxEgsXN7vYOFb8
ANb5CCw7WONwrPWQX50vLB7v6GC2DgfjZ+rcN8xTatjx//+t3FkkhtmEKG4h
4oSrq/S/iFv41dxqlWrUSn1Yx6AVHOLbZoVDR38csf2cCH4qT2elaypnoXN1
9/J5DwAnv8pZI+RM+vkpUvtfrLjlput7K3qJ1lWyb2dV0uhXYc43tbs+m1GT
gR0BHhtpVoYm1JrvIXRwM6Tft/kA1aG9Ncj1nhwH+17gbgeW9yh8qEZnX68M
k44n6n/XJHOLsVair9b2ZN2jML49SnGLtzalE/G5aQT2ZgIP3Hj0SfJMJ/rx
jO6CYR6sL204LTrgZ92LbA7Sk29bB/HJx5RNfrBy92Lqc0T39efQfRCXcuZD
d/Db6l+/H4q1noO1nrxvC7cTRzjRfSzH8tODjSuRSv+ja7IeMB6efsAn5Zjx
3zsOwdJNQnPokUkCnN9fYaEXXKFCQE1dEs4vauH8/kuKF7p5hn3oOtvQWRQC
80ovcwqdFDfS412xOFb8/51lRl7a1OC/YbrLORXVMkRTTlvUJgDztUd0/GvY
p7sRZcEJvFgf2NmT5sM4HlCOvJiVRTOowE7eIT/zV9plmOXntf5TLwp/4AFs
O2KuJFeiYkXcVXmic8dd7i/HgxLxKO6QiKmeDfBlBobaosWLr1xhtWOGW865
TH0APR0eDQ7R7u1GVe/jvjjJwHcvuxiplCmKfU6QVP7tLo2FeSuRP+tup1u2
lCOjOk9nRQ+i9brhrDN5/ZXIjVPMM59ontKz5VZsys3KBfMH61wAqXZeVLpL
Vt8BP7dsUnfrlq/C5FjtFVa5xSrnHjW1d4aloN/R8z19iI23Ea3XXbf14XNo
578XcfGme/agtq8hIhtdob9wbE+aSNndhcxWV+kq9sA4qtOE+vwbvTZ07+SO
r5yywOn68qMaK9pRe6Ke43oC2BG6Yn3KPacT1RXz+Q/chXJ1xZhgMHm3G7W8
ef9J4Qlw+tfc7WLXupEaU1ztICJaF0rgPMPsVoSUWnce5R6E/N4cDboRcrkc
0VtlfNr5FX5XWXewqyChEz3fcU3h4VVYR1LdNvi8kqwTXS/ffHnDRvi+1VyO
lCy6rSi28EXUQXHI16Vd0eOmrb/+fITYoJ0y23E4F7mpwstPJmbh7g0O9fPu
u0QL+bK6orHCjov0+4FdArKkahtAf4bbzrRcM+UoyyUxvTIMvldBGutg0KcP
KDlxQ6IsUfyt9NHD+Oz1Waiq2XzD1wHgPtHfGr5ejiPZH6zfXSj7pP6uullE
szUBeBKvytW3nKSfiyfVzkL97l/+eznhleKOeqL1OqMidS2Tsx/QRKz5RA9R
XEGg+MGjzIzBmHacRVl39xLtX7x/pBzAJYkdf7tQv7tQdrA4qXZ+1+/+5QvL
+w/FjgfFw7jakMWiiCcSe1yN1f7H1TLIihKd3zwe+OLunbEiTL5Q/n9dEnDy
JVGcXkSrnaT1utBFpzOp/DtqZNDPhXHFxDsBauniNsz+kVJFJ/HWG+Ah2Xi3
pdPvF116LL5QumHx4xVhbX3DML7anunr8FivHNOfX52eVK55/E6PN9E4pINv
lcPRFdjjEFL7C6z0WJxU/bHGq1icVH9Itf/Xn4X151fzCjrqw/1EcZLqorsC
nSix79P7XZxU/X91elL9x2rHsOanWPxXl0+sdmyhxpNYOvwu/f9bf/cv/9cc
a7yNVc6x1iuw0mN9d6z9PlLtk5qe1PH8nzL+J7X9xLITybTsHlM3pH9BxbSV
PbF8wTip7SqWHVLzi8VJ9YfUeehC2edZISfUehx4W9jMxaWHC0m2/6v7td/F
sfTB4outfyG1H1xs3wtL59/lz5/OHfYoGm32gn2uvimn7Pa8Zsz1Yaz0WPbD
H+d2Gb+HeM7lXe6V/EM4xNvjxvYsEzi5lrJy8k+uEdwl9qoHeNuTtTk0VThk
dPC86pkvwDf/CKTZVoBDl9hT+F/jgPO1KZSyl+NQc0BLKddhiCO6b7+/zeEW
DsWac4br+AGX4zFsSFfBoW5JwfsjtLC/9pZxZyH7aD/J73UavGunIFOF9EO7
9hL2vetHape81pidgX3MlqusdD3x3Zjvddq69YdHnQMuWVaTc82M9Hc8sfb1
Rj+xJB24Cf3UVITOnmdXq9CgSz6rexRwnXFKzXPbKknmf+3/Z/azRUoqthRA
vXPe5Jtz41zdL+dylHu6PP2Af7n0SdfmYD36nOrwcsUR4CfWztw86dyA9h/Y
0H9RAXhVcdnAZ1wDZnosjnWOZtNTuTBTduDkZYIvVgVhc6x4jM9prunry4Cf
4jY89rmpCT0UfkCRWws8QNv+tVp6E6K8IJo7VAr82r21pqXNTUi8rcvHMg34
URaG5qyNzej8m0i/PFfglhtWUsh1N6NEx94uVSfgrF+jryeStyDpAPeqqStE
/sSdxrEebEG3I20YIuyBG3zucBthbkH38tZyqh4BvktgbPPnhBZUPrTfc1qP
KL+KTtyVYS1IbWztIx2id5qC2mzE3D+1oCcCtGHGcsCPt1IzT/O1Ip6PqcPm
G4A3NW6RMzVoRS/5b8veJOJdRvE3NX5yDqFUtc1cwHmt2sd4vVpRTapKeRgV
cPnTTkUfu1pRZ3VpX98KIjtbna6wf2hF7eLfWqLGoV36RL674gZ3G9LlEyfn
6AYeov6osOtEG3K+mn1Dkei+7nUjE2Jarm1IfeJDe2kBcH7HxN5N79tQ2o/m
yaNE99s4sz1giOrG5rw/jLbpmABXqjOjqrBpR7ovwz5KE937KqfK6KR3sx2R
S5rfOKlOFPeyo6LGN7odTZaJJ3ylA37ggNpqZo4OVKnjRvmiHdrtpSFuNbXH
O9BlDr5CpV2Q3vXRCnHfnHZk6NmebqMJ3GF/Pc42oh0diZC/b5AJegprsssV
cjWjq5kv7N+3AB8wZLMSe9aE8rdeTkjKAP70bnjb7TXN6Jrkgw8uxUT3Uo4U
vHrT24Qitj6n4igH/uCVv8JEXRNKcSiX3NYDXK2Oq7jWtgmVsIbteUwH/VT/
q7XjjIQuNK7NEEuvD/1d0ZaP3z+/60aPTwbh86Ygvsi8tcdFSbQHFTFLS7xt
Avv8ycxN0S+a0LjUhe5nhcCtFF0r3oySzjP0ncSr6qFfbuqz1WTe14/0Yx7l
emRB+pIdgqlFzM3o9AbPbdVVsJ84oVAyNu6BR2IKJTw6a4HHmPYxky8joHpC
QJK1CcRJtszINqRZEFDI+45tsU7wDtGDVd7Ngg0ElEFu93rInMjPNCePO8ot
aH/797wKonuiNjbJqhhQtqIIrfVpdTzAc18wex2+TzqfEWJ/1r4f7gHeYjBC
sNYfRieLTVfycEL6w9dN3Oj8WpHHzRUijPTALz20jl1d3opE89e15eVB+SyU
n1imnI8dP4+1D4iV/i//y//yv/wv/9/hC7U//pf/5X/5X/6X/+X/TRxrHyT/
fnHCahaYVy6NZJB8h+9H8fQ3Ju3ogJv2s9wNH+lHB8yMVwx+gvVnE07BITwV
DnVK+ZPbtAH/EOXYl8uCzdfQye++8BV47Dmy9e/IcUhKbNPTQ2XAyZKOJNxf
h0ObOKdP+RC9S5X7pjAiUwqHujd76snFAJfVlPnyRg6HmO6mFye7At8hdHxH
qhYOWZjKHjsRBvwu7T49IwUc0j9g/kr3OvD65qkOISMceujdXKRoC9zvh8+b
+hM4dE/jHSubAXD3ESGuWEscEtWmZ6HQAx5VpsHuegOHqrTFjPEIeNsnbQW6
hzj0WCmA+4QkcO+TjM/e+uJQf3e1pyIfcHGuyX05oT/tXKfahSd6757nWLbn
xgQcMvJQC48eh30ELfnJDLc8HKqwfHcrtQ341j4e25N1OHSzprHydDDwQzti
8zMo8IiXba86egjcKpWxInElHm093HuiOQB4heM620RqPHpLU2lS7AB8U3SD
924OPGrgoFVRtAJuxzRDvmQdHoXpx35l0weuHl7UsF4Sj55MC5wylAOuM6Pm
TK2GzauOhz/sYQDuRsAPjp/HI6leB5cn32F9I85zN9cly5+/a77E8WoR8JTi
K5s8ffHou87Fu2YfgOu0nmvwCcQj00AeWud84D2+fHYST/Akx2n/ar5Q5/iw
OFa78c607Kq1/5wOZDpbptasTlk4HQ5OdQ8HpM6Vc7IrqfHFFeKL7332mksv
O/K3zq2LknFdW6J+/XDnb/NnWnmac5MJfBde8uds+nWL73wuaxwyixEBP29G
fZouJiOgGEW2RE7+uXpNJmLiZ5Cqt/j8f7XtmOP5H3PrpWSSOoWW5DwEdD37
wTf/CcjXUwOvMX7rxec/FvehDXy+tQLydWP3ZyY7WQLy7XPyj22GfB06JLeC
wvXPyVdgRBuzXSjky0J3/cNBLQJ62RY0IRUD+VqyUkfD8NWfky8szsg5JLDT
EvJbozrxfd9lAnK3n9CMhnshyLYnDDPLZuDRrlgtU2mIZyCzTW4aJR9efO0t
qXzj5kOKscdBh4yL6h/dbAkoTo3qe9050OEb9br7HfV4ZNvZ8lHtGehwk62I
Z4zyzy8PD9LZbrxRBB347FmbNrkS0LtypfBzmqDD2Fn7cMp+PJK4Iiee4gw6
7H7cWpKz6s/R4RntkIsgJ+Q3n7s6Ii2cgKZbw66vkYL8jjY9OvXx289xXf/Z
1HFTyO+FXuGsx4J/Tn4/PNTN+zEzNw4kkzEfjZVnaEIP3O5/mCEDHeRdzLf2
JRHQ0wYGnyPcoIMMe3ZLDw0B9RxpEKA6AjqcLP384vTWxadDlNQ+MkF4P5rs
yIv9E8u7u9B2Gtyq7q9z8RVkO+JNxrsv16J2j4NRU5VtkK9aA+eL2QTkWIkT
9loNOkxszO27t/zP0eGhY6Of9tK5e2zINt+JSTNb1484eySN0sNAH8p1X7i/
8Xahap0HDIdLQIcXG/o06HJ/9gtWgjHnKEGH9GPMkj/YCOiS8ccdfQh0SD2e
ISKp/Pt0+GbevLyQBvIVxG0ocmiwC51KTzN6sbVxji9d7SnfITaIWNIba72f
zd2DR3avirJFm30AXfY/F3IyB/KlyCkRtoeAQwf17g6PBIE+UntMzidVEJCo
3XpfzUGoR8ktVFwrhQiIQqc/208Q7Fjfwo8v0f19+qiuKlPT/7xtzp9KkY1l
//Puz/MWe8try/fM8UvbrJ78D4/+cNJDLU19jm9wVlz6P/yj6d2c7fQGc/wz
Zdvk1E++oZKyWTsUysl+7sJd3vGLr16QyvUUWF+dvAb5mtxRKXOq4tfnq+GE
z9kLEvC7AyPRF9un8Oix25fBCUkoVw6C/H75GgvnT2FbAM0eovpuviS6gYWd
gLRGRTgPU8Dvang3ODSY/XodyO2/BznWQv0aGovmkpUmoFPHhR/e6wM/O8Qv
jsc7/r7ydjtgYLIpEvzc3JtjHXmQgBIo7Ku2pIKfU1x8zatCF1+9+DCssuTV
TfA/+t33JdQXCcjiaNnRgqfg/54SoQBcMh5xXxvZFJUP5eG5tsDezv7FNy8Y
1ZQJEzSEfB0V4JFQu/mzHy9b/tXcFPK1fMxYY0cNHv3olNp5OhbyVToqtCt+
cvHlC8ejsfm6MuTrPj3zcdf7BKRz7/UNhiOQrzpv3vBT3Xh0tyifShfWb8lu
148UPl+5+MrhnTK3XYPckK+S2FYWnjACehiTrWS/E/KlWfTN685nPFJ2DZV/
cR3yFZZ8z8xs3eLLVyOT+V4vKsiXZeuZtqh4Apoxb3vCup5ofFViJrKbioCK
6ZMv5BlAvsathjfu3vL78uWj6abwpB7GP5HLQ0rKs/6c+QLWOB9rfNu3yfrg
GyXwXyneOYx59+/z//mbb2uV4qD8yO4IZV6nRsAclzofKrq97jPRuJRf/+Jl
PgISatFPtRKDfOWvGHPoOvT78nWPTeqhak7OnD9J+Cealp7DqPkrpafojuI5
rq1Jyy8oPYwKRYXlztXVzPF1L6R5xFiGkJFMpojiK/iO+4w7hWeiF1878Jf/
7/D1acv32DyC/ZeQew9oqGs70Jakew+V0+bitMkqKtaSXbLswbTT5f2QxSee
qH/heCPMPYFDVjLcah9tyud4Fz2j8HHC33L438Ln7Z+SnZ/dP8Xi1T1jNoUM
c+eeyGh1b6cwjdWgXU3NDSq0wNckssr7L69FkjHceeunYD0qP6L2lcMJbP6r
88teHRCw+zv8rm4yTYf10VrUOMrUdW0a/L8UStH8oa4M0868963IRGbft5rP
N85yLDs176OSebvAH/ZacbZHrbVo/wNtqVWVwKk3aO8fkK5DSv58immXwf63
pIlbI9otaN88PjXLsX4Xy06uXWvpZDT8bv/2NSrbB+uQ6dVsJTt/4B66R/A/
VOuRtn778dz4uf1xsshoCos6lyzE617vVBINnC7ao3HPKux4VLaKdrl2OB9E
hmtdaSZ1vw2tnscHZvnUV7PqFfvBn8oHXwJP5DegdTcYGB/zA5c80ciXdb4R
6TxcleoaAv6E3ouXGdiYTXL5MXIu4rIthfb2dGygRLlVBzo9jxvPcjMOiucb
4D5tMoWy6lh692ZUwj+doawDnM+lSuVpWgsyOvB+q/JxKId9R7XfUUtUo6V8
HpQCLMDdvz6sC6qrQQfsTYX8nSBfn1zLJtS/5JKcr155hRe+yXPnfchsY5I4
1mt1o+55/PYsX3YoNvf0O9BZhk3ecmNQHfIcOhMX8B3yxX5C4lsyVxNq6Q1k
2KgGfkp45udp+X1EnIVvP8lPQr6yQz693MtSTrL/BIFmyZ0QH0UW5q9VTiGN
Qz3z+KtZTqFwu9REAdZRv1BRF2iHdaGmtiWdg47gz0hvl3W/TBWa2RCwJ4gc
8tt8/KjGNuomxFX+vTo0B8alhyTTt7vkE0j2nzI65PCQcsWcHaaCouemZUOI
LYr+ZcoDizmegefc2j6zcPfwV0SJUQgzwXfZRJ7P4RFI+juzwxPnayqXgG5G
b4KPCkrXovDKvu/WGWD/mgN5C53Qe0yOZZ/xCrnPjybQ394GR11AUYfuHj7D
UB4A5e3MlHC6dUTz/PcayGhn32tYOjLq6pUKvxuzsdjtXdB7ZN80FFoWBvZp
7rM+9GGtn/9+H1nI7Pt9SAbXsiUb+K22vUy7girQqnntVf9se0UeE93xdivY
bzropviMtRElUu1vj3eEdsNj95fYe30d/9TO/L/tySW6qEzKO5BfLZsElwja
FjRJdrhe5TiM9yi2kBV6tfQgVd2bWU/bYJxmmLSzhvY+HvXPqxcvZuvFt3iz
J8HX5s6XkTm4FZscPPbr331YbHz6rZuWC1H5FJl20jkr8P6fxkWXZsdFsZ7T
wrkUkF5KRuZB4J0ypCfideIpUfsWJmSWc5GxHNlHLE81TYP0au47ckKc3iOv
V8NnVOHeRbI334ejOiiykAVbTc01IfhdtskfXyvOtKKynEkVJRsoVyxFLKoO
DfVIPvPa4ZPHoRxuM8B5e3v/+nvO//KF5XUfthFWckA7UJBwp435dieqfjHY
uk4D+q+7CdWqkZ5dJNu3p1BTm7F5O2eH3Nie0aRxGJ0n/z/5slm+UPnC4qJv
S65pwT02ZDuW5Lm9WpuF6LauFutJAP7C8PstibNZaPC4kTkFvE9KdtqTZkz6
Sxaq+bF6TVQc8PorJWvtI7LQ9quFK92jiOyrv1CY2fpzXBpcXmsbDtwpCC9w
p/UDOq9E8+aYH/Do/q+D5Vty0C2WKuakIOCMl+Irb1hmI/UqBvUBeF+bTO6S
oMgmlxwU60Fuz+BKxMlpj4wez0U5P9pYMq2A+2qrUbKw5KNUy67KvDvApzx3
IjaePER+e2sYXQu0J+YXr73J6CtHD0ayYqafAY85krSa333h3sv4yxcnx5pH
uyS9zDN+T1QvStQdjWszSR6PLRTv9vjw2CQduMPR4PHNZ7HTY43TsPju5OCL
R98CfxKXUGnSjZ2eVuOTuUwp1JfRsJeaTzUrEN08/mmWX5vX/7LP9r87MfpZ
rHYD6zti8Yfz2mGq2Xb4d62f/Okca/0Ki2PNj7DSY5U3Uv2cP685OzuvwUqP
5pXD7bPl8JiOY9yBIJi/c9+7EsJt2o1pZ1P8usNmvnPvDpN5JgS6eAUOIbsE
9s871aXmeJdJYNfMAs5D/xSu5381NuMj1LtPm/LjHI7VLTo/sfjGlFLzE3RQ
bst3roxNo/7bbvynfN67e2TGs+/uLRRfLH6eneVY6zxmYi0RNwagXmTFeiRa
Ri9cucKa/9ZpUjX19oM/Xoe69kg/LP+ndZvns+s2WOs5WPMILH96Rpr1dqXD
/CuLNudG+NIudN1/SLJZEtpbcslUiq+D3aib9Xta81mwb2b3KkfLqgBp41/Q
H9AkWjdwwHeMyXxEoq09I6h27h1Psv16LA9unu9F6Xf2OFwPgXjXpK/Sx4Q8
+5DAp+NlpoqQfukPC5oLk73Iek2g78EDc+dYyehGNmYapPWjNZvYys4zw+8a
DnVI8N4rRcEPCrWlFIAXJzj1ep8uQsdirjfvtILvu/cGS6rfQD062BdsYHoQ
9IwK6z753qp60dSjswtcj7D2ubDGsfP7cePZfnylMI+hZSHo6UjFv53asA5z
/6hQ6/0DIWfgMTGUYlrTzWh83jon/ew6J9b6577Qo8szvwO/xtUidG60DJNj
jav7PB9K73AC/6XUOumrXmO/K/27ONZ30S25uVadAP6vb+L7HpFQi4qdGFKN
3gO/GjVKTf2oDnP9wTGoPit5AtqBZWPXUrLiOtGdeZx2luv6ZUQO+8N3HJdb
RT0R04xqqNwrrxWB/qdp9hdsNK5YdHr+5QvLscrn/HpNN1t/twka25jBOXcy
dfzIntS8xRe3+Zf/d/NTdFfDD32GdpJ+yYChzN1azHb1d/mJxSNXCyS9vQr1
Tm/9drN4u3yS7dxN3cXZ+AD20epiOD1Pa2PXx3nvGpPhZ981nvf+O1na7Pvv
Z+bxd7PcaV7/Qj3bv3z/P99/JxOZff99eh4XnuWk5nexcazx3nx+/t+MD4/r
FHdaRMM+6bttbHH3o/78eLbmAWGGdm0on6zLtXjMbXHozVrD9WdPQ7xBlEN6
RlLRELIej950hgD7yOF2W6Kyd/UgLZ+1DaEXYNzCcHdJRci5FiRNmAnXIzpn
p6/jm31jfRfmeHJ+nIn9bDwJ1vea9y42Wcnsu9iP5/HSWT4/ffEsF0jNNjdy
hO97TYX90lAeHtFQ4isH/IjiosP2n7+agkeVWvI9Gu5E54JrXTdcer9w5WHr
ndhxgiborMkxaRHejx2f+bu4oO9WpsvW8B0Vfc7pHrKrmv9uO5n57LvtxvP4
5VlO6u/O32e/iBGXePE/vO8Fq5xglTdu2zLbJX3Qr6kQmHYpfqxF3HdY7/p/
hO948v2TNebGPWhJ94O6hFXQ3r6qkYs6JNiH1vSU6I51wX7uBef7g2+OdCDz
//MddrLu2XfYL8/jn2Y5ZbXIAxkp4LfHluby17ejtctbSk7dB/tNmy9ycLZ1
oLgcsmesOOCmFeqs2RodqH27nRm+A+xEF0xsjzjThvT9PJcyxAPXHbDIf0Hd
js5ebenxGYPxZ4FvIYNePnZ/N3hgmPlAP9T3Nr+iAK7V2OvPC8Vbvskmj6mD
n0PSRhzU8gtXf5d8O4ETnAT7PXkhA2k5OPQlafWdm1XALcgf0R1ox9anMznj
S8NLaJ/f+gnbr5PHIYu7KmRv/YHTPa2heLUfh8yzIorbHwPXejWFE1PHoesT
HW25t4AHmfLnbjPAoThm9pZTR8Gfy6r3Qy/L4NEaX+bkXqLv2BUgsnrdz+9o
ZXDijFcrcNdIEyeZehyqThSwlX8F9vemq2yo2oFDu7fdeqkQBXx1qo/xsh3Y
/tvks8fvdiHyc/MnmaEjOMx4YyzdsPYpsNIvNo7VjmWksgVe6IN6+vHh57Yj
h7DfB/nL/zOeOHbycfc76N9l/UJFnj/Hbh+w1uUWqhxi7SdilRPO2HjrhHSo
R7sVLVhExX79OsCj/TWsGazgZ/Sxl6vqSmsw0xtulo416Ify7J/EKtd8sAON
GGVFBxPtq7rcz0hs8F64dVpSOZY/WLzn0FfBezPQTvr1Cpynfo9DgtffH92q
C3xlY6xEkzTp/Q5Wv3k+TrvgqzToqbze0WmFLvZ9a6S2q0fW0QW4HIf0Q3I/
Ugaftfzy74Vl31BGk7EvC7hw3V6GJRaZSJeW3HR5ApT/Fdn2PmkyODQhbnt/
I9H6GMM9jpTB/2B9bI13/AO9VtCha++4TERAE5oKcOY0qIfzhk35+IvMUqTH
e/9qLlOUKR7hD34eovS6g9NdfH7Kq7qcdDOEdvj5czmHL814NFWzp6+M6Dy7
XvCX1v4bpPvPfdEg3oDovqPVAacLgr7hUd9VgQaJjWB/q2+ZU14AAWW11tYf
1oHyQxXoEPhI9s9fB8DiFB+ORBZWQHt+FM9FxytbgT6+0ibMzEC9m3ShubpU
dAsSSHE81cwAekbnMgbSMROQ34sopZGvcA5i1c6WiZK3BPTqdKzBLRnQ87D0
vcZl6n++nli6PVx9Sl6ZaB/5bnxjsMNAFqae1Rvx1Z/6oBwWh60TOC9CQKmi
F5asiAI9zR/LUDwoJSChpJPjE9ygZwdlqVWwwZ+vpzCtFtepYtBzj8/RoOAT
FUhGmO3bGqJzZKOPuiTlhD9g6mnDZXf76XvQc8qllD1tNwFZPDk60uELvHRF
mPAPPQJSEKv1uXkCdI47vZtKppuAKKjFH8kyAZdPb+8pmSQgq94apmqi+y3f
qz6UnLHCo1uKVbtDu4FL5uvUvnD+87/Lr+au6qtdh11gXWXI1o69/3k9Mqju
cRnKg/LgeH/ZRS6nChRNKXp5GN65IDuzw/fJoBF2eRh4Nu5Rfwe++2WNu2Uc
ZwloV/vIJ/EcuBfL9vWzVq0VA8i4nyOpJQ2+Y1I7R9q3YDzScfWXviZCNP+t
2Ljb+NmvH2+bMYd9TrxMdG+hZ7WU5FUC2uu/4oiWD/jfmI/z8uIcQI1JdetP
EN1PVchVueZhPB4VfjYKbFoF/htRNTV8eP3r/X+grWuNUwP/6xHb+QEXAiri
aFjaYgr+nwgweKosMICW4eWbXhKtu3JvLeKSeP/T/5gtl7mXgP8sSiElazN+
vf9PHHdXvBMD/4toeq5y+xOQ+OnIOFNx8J9nt+t+ZpkBFHELv6vOGvw3Mo72
qSrBI7EvtTfkBqHdvt69qc+25Nf7b9edulLtLdSv9O/upe9T6pA+or26kYuo
3+kQj1gfTkAS7bzL4kZb5viR8FLWvH0DqPZtxFDPJcgXjkXX168Gj84vv2cv
3wH5asCFLFOs/X370TSB9QaXRWF+xC77hb74dCdqEjxOt68IxvPC09mH+whN
iFyrdcJ2PbQbAeWXJ61tSzDbk4gJ9ZCLy0G3jW+o65NeE5D0Lt4Qu4+g25td
0akGmgPITtiZuucs6DacfYfDtgGP9PZ4lUo3gW4+b7dORTUuvn38Trk3HiPL
IX7sbI7tudjhflSgeJIx1B/Wt6+kpAv6hPciwiOWlrFI0H9UYKb/WFwH+nwx
aIslLeimJnfE9GIsATU0BjjVHQJ9VKa/0nP04ZFooPCrFXmgT1Ypmfhy/O/T
5x77+yS/cLiPZYUpgyo59xA6cK8w9vSh+jn+WNwsT9RvENVIb5HkIqpH/ZmT
NwZ/1iOKrkO6OqHQjh0InDaV2I1D7xm1+RC8L0nWpZDubanfgXQ+dppIEZVD
YwkRGgbLB4uunCwUr7ua8flDDPT701cSP5XwVyKDvUv5YqZBB4HjkZ7HdT0W
nf9YHGv8iTVunPdeBln77HsZv8t/LF7HUdAcZgT9yyYzfJqrUgMyXPvQ8yLR
d+x3NEArhCqRzkraAFmic3Yqm7JvtvX88/iNzP8f7S1XJEdlMdF93Ucm75zk
y8Aj613POyLJiMZjHTZsEpm/Tx+nMbJkBi6icwF8cVNPHzeik9esPl4xAx3e
WlR3UcZXoc7LhdbHXCC/osnT3zOKchFvXgyfE1E5v786xpn2sif6jia7LqRB
e1guZcadObL4ysN3P45o7y+wb6j4atPEN742dD4wL+6dB+gzHS3KHWW2cPGi
Kapf9g2NQv2KeRV04SHf4lvv+sv/d7jb4zXrjpVCPfIjGJKnrU9HHSFTkmgM
9ut73StLX0r3oIs8mnVfIojOBReaZXMGfEAWkt/sfNqBh1/FkakZJZPsD9Z4
klQ7f/nv5V0/vgd7bIbvOFjO5/o5qxi5rDmRgTMmKm/vcWdknxcsOv8XiqsO
TsaHFBD1a7t2VrBZL1y8+vp59ziJz97j1O5/8LzbbaL4nJbvFg2yeQv2uyEO
dkm7dSGeremj6nkXpy6kFi0zvr0f/CmhuFxemV2L1E2z1aUugg5KdifClCur
SP5dbT7VU4OrYT5129HSRkigDwXiOvu4rMC+VWl0ip9LFdrWmCG8ZwjmF/Un
r3WPKA0gHRHvwYEXwDd07Eu9ojewYPpgrW9jcW2vyMtD+4HzP+CzPpX9Efu7
r2dykuCH/EpY0oUWXsfeX8bihvL6zaoviPYxNdJWm91qRmkR8tnhlmCfV85y
VfKjKuSkU0jvxQZ+njP+nOUmVYpYcvq0wzRhPPMhOHNcPqIdveQ6HE95F+wz
xcgy/xjHPp/7l/+DG1Z1Sc3gQOcvEeXubO/j0WWMfer584ie2XkEmlbfkCQH
doYuv1MTHijCtI/lz/I6qy9S/ZC+d1Sdv/FWAmZ6davhkwRV8FPWu0VItq0F
iZyeqWPKJFrHHt8ml+SDfS7YWXapZU0KlCtBD9zyE1/aFt33wuLzv9fZBX53
b7FxGrOhoYTvUE4uawWfyqN/ipLUs27rtgK/k6i1/+WmN+hE7JOlPjuBf8x5
W8vkUPTb/J8Q79B8ZAf+sGUzrdphk/dPXGiW/y4/w69qq4dFQT168uBAYvXn
OhTgvKwoWB3agZRY7R1Gd6pRJ2+d780y8F9eMyU8oyLtn/iaWe5RpKq0jOh7
bTOooGtRfvNP7cbSyH+0G3vmnX+8O3v+sVVzPceTJuADl1NYozneIn9NaTaZ
01CvaQpMmvbfx753C6vfxNpfxuJY9klNT6qfx29oxQjrg/0b5XjlrE3VKHaL
cIuPBHDDu4WiyoI1aHTk4+2m4/B9jxskW740aSDZn0N6BFk+PdDZb/iR5T5/
bJ2ZV3MJNPfAvG+QzrN8el8PEgtrKfCyh3XdtqVla4LXL1wc6X/rvG+x5YtN
1yRjSgn82cnaKpPa9xHTz/n1vXt2nLAvY0SB+huUTzPXQ2UWRrWYdrZuDKN7
Mwq8b7TOJ4Q/GjM9Fue+WVMtOwTc6njgirzGWLQ6LDSm4wfwZm71JKTss+jK
AxZns1DpoW+rnfM/T8KLmq5rcNH52b30OhUiuq/JsjSx7Y0U6fc1/Wo+qiOi
R/MY/GwftmM6k5yDqOlUVnoaAs/LbfP73F3wT+vJn1f9Yz1ZmgctN/xMVK62
h3uEG0eR7A/taKII/ypo5zcW3+QJLK5BR9lvM1JLgn2FuohvL08Vk2z/Pu0t
60MdYIcvKcuegjcZTQ+tKOnMhvZcxILmZf/FHqQz7z4Nttn7NHgb+IVDC4E/
u2VjvfPKO5L9SZl3Tk3339wvwdK1NOdIHbQnsWe1uKs46/5p/tI3O3+Zvz+y
e3Z/pKiu4KvBQRhva9psJqiWtqDgJQHvNjsCt9hC+ZydqgWFVe3OJHwEzm1t
1nNisAn5M0b6CFwCf1ryXTRa1jagFfPuo3CZvY9i91HE+40Xvu/xY6brdjvW
IH+JUDsKovtD9l6NP5nwsBTt+f5N0FYD+JVYUbJLuh8Rv6C/Efdz4Le1JOk7
TEi/f3ux8duhSxwuiINu3vp3f1auRsTfpZnDex104zJSexznhr0upFzWYfiM
6F2/aq/YO86DXSg4mMnpjRzEgZfeFVkm2teNKmwnhJhWAK+/qBB4jL0H1Zcd
0iotJLoHnt/MemKkCRkzKdi9KIFxjsm3vWxjrEPo6c7Hdl7O0D4Hr+RFwZ8H
kZx1F//jVthPEUHcctvECajD48eP+xqwHxfAbsooi/sb5/b/Vz7zTOj2HRuo
10cE7YY3Z+WhGubqfTNPoPxrHGVNNY+sRJwj7BvYDxCtG3v1clm5Yt8XdJmL
fyK6EspbmL+Wdrrn3/L2l//f8fp58QlCs/EJ87nILP9dfi42vqNEhk5OGfT5
5ivauaGoARUHFuiJSUP9dVDUN7/MVoO8hgMdlyvDvWS7b2rSErr7FswfQ4ET
ZPtNoB1gueN1WKXuz28HrslSvKztBZ39BBVVNhaRfl9KrnH6tgM2MB5QUNe+
SuHXjSafGb/atAHa59AdV1bmLy9BMfpPvSj84Tt6s+2IuZJciaLn8aBZXmq1
TsnPG/TXHdg5Hpr2+/RPnb66hfoH7JfRqjDTJiuQfp+JaZHcpAdRfsNEM7Xy
4xfu3uyISnfJ6jtgf/Mmdbdu+SoUPo9LzfL59w/kzd4/QFlwAi/WB+n3p/kw
jgeUI6p5HM3y6g3u1XElMJ5s+YLOjw90om35J2i7KmDd7HHNx7MHg9rQiMCH
YL67EH8oGnzYwrSzA4XQ4SY3xEC5ooio8xY83o3aHS6se84DfhZcaZFSrChB
khmHjzYYEcXTuuNFu5MLEM/SEeUvn4n6fQqXqert5Wjv5U3eEiPg52rjbu5N
6Z2IsqUh8po78FeU7dRxO7vQ5OlrT8Svg/+MDv4WNOfbUY72a38PD/DfibKr
7Fz1rz833cDoRctF9C6n0af22up1eFSYdCCH0YvovogljcOnz9Sj6l8c18dW
o/hEuwbqKXsf4fiXR9j1VLZ7I24CD98r0MOkLVgr/p/We90x9nkdZzmW/Tt2
Nbri6eDP9+xsmuxg/D/Fc3LNxnNi7Rf/U3zgo3+sm823s/0/jAtlvxYj2UwF
3/GdrI+l+WVs3U5cWu2e+xbSR7ujqIjP2N9RvK3LxzIN5mVHWRiaszY2ox3T
4Wo0N6A80D66J8thiEPf8la1CnkDZxTgopU4gEOpu+VMxJ4AT3Y8/FJtP+nl
h7l60IpJBuxQdR6LifP+9fGEkVrr0+p4QIe8F8xeh++3IlUZucw+E6jXE/sp
lrbdxF7PFzbe2373C3z38khDK0rmV4hSRSfxFtH7KaHZeLel06Tfv/2reXLi
hkRZoncupI8exmevz0KEV4o76onONxkVqWuZnP2AyV0CsqRqG6BdZbjtTMs1
U475uy+Zlt1j6ob0EVRMW9kTsdNj2R90yWd1jwKuM06peW5bJcoRKanYUkC0
jrTJN+fGOex98MlY84meb0TrcuIHjzIzBiOcteqyQ9Zgx100apdLXz1KPT16
XFkI+qNNj+Iorb6Tfp/MpqdyYabsYJ+8TPDFqqBGku0c91ipGhwBOhiPpDpl
aFdi6oPFSf3dheIWOVzNvGpQH9+E0uGMW7HfDTx3Tz6Zfwvon/Ggr4Z95Nff
50Mqz3JJTK8Mg3L1IY11MOgT9vuDWByr3mGlx6rXWJxUOx7PygNfTwBPlDtH
MRQc9n/dTr6fbSfVzSKarQnAo3lVrr7lxI6TwaqncZmyRavHgGdaBytcPvcS
2cbwSNd9gf6Fl9l7qIgChzql/Mlt2oB/iHLsy2XBITWmSw+39ABPablaIL9y
4fojUW16Fgo9sB9VpsHuegPb/ruk+CwbovOSO+5mBSyLwSFxxlR5M6JzfAff
Tc3o/ItzfBV+PnwaHpC++srMiu0rFm7eNGXs6JmrD+MrqusC7+jbSbefU/fp
hy8F2Dl5v3PJOg4CakzknJxhA/+tjGbW0J8m3X6E49EK1WRYTyYItI0x7Ccg
uv6WlUfy4HefUdEP/HiCbZ9r8ryfBtG9EFkfOAskbxLQ7ouUN7/dBjvHmqLa
m/JJ99M4oY8lhoPofN+Bu+XkLwhoRSPZ616ieyRC9j7TUPm2cN9Rm+dNeVsI
nDdf6cYk215OQMIXTU/b4MEfbtrRoSrhn/nltrxSz0dUrvJ0ovv1fv18fFRT
JkyQSP+jAjwSajdJP2dBzzG2pVcQ7Ei8LtBQeUZAOvde32A4AjrXefOGn+om
PV/X1ixl2pkFet4YPnTfroCA5N3dbm/hBvs+362//qAh3X8/50MnI7XBft1F
j8zJXgLis3m+Oq2W6H6YADNqNmkCcqGf2e4uRfQefYWY7wkN7Hz5duVdKCqB
88WMZpOJ8fQDyHKAwbThOdhndkgMvKdDQG9PKL02mYJ8PeqS6N52Hdt+U6vu
ZdOzYJ8lM19TRWgAbbVbxhNlAPYjr0SP5dsQkPSMF703UT31PCt0p/pf1FMs
brhZV5FSEuyXEGSLxXwJyFmW2fq9A9jnWJEsFVlAun2eJtwRjT1wHjONI79i
X8AgMrq9MUm1CeKiucj3635Rw46Llpz3fnrZv3k/faG40ob7zU+I4syPlRhT
tWfVotPz4mA7ZuNgt78zeTDuB/MmTv77/GTi7YiSPqD+WA6M02rueUnq7e5G
rMNcUUq+cJ63SsJcg2DTj66qOtmkbATdesyqD3M8X3xxGlLz3r36MPvu1fx7
1K1m71E/PG8/ffvsfjqpv3ug+5PKeW7QM3WXP/v4MtLLw9J58XhHZuPxKrwC
X7aOAHeR3/IoTrUcUbPcyTiRCzzQLFmD9tHCnbNYNi9+Y/Ns/AapdrzDNoUx
eEG5GmlJuv/crh9Ziz7j8DYhOh9RXlnEUVuFPCwPhx/4DPXrJYPdmaatPZj3
mmLdY+l17Ky+azRwEaZBsndTOOQ78F5trxnwfbd8lL7w4xFn3OfpL1YwrmNw
/CQ1ZIhDCjdom6zkgfd/W5Wy9hEOZVv6L99HdM/n6tV+06E5pI9L9SvC2vqG
QQfpTF+Hx3rl6Ps6CY1IPbCvcTKlpl4Kj+47bJ3ZTvQ+72nPZ5pU0ovvvOdC
cUbOIYGdltAv1KhOfN93mYDc7Sc0o4nO/25PGGaWzcCjXbFaptKZoJttctMo
+fDv0wfrXeBj897/DZ99/7fZtpsxnGg/y1hvn+eKOjzSv72yjiwM8nWz2YKl
nXzhxnWn5p2L+TR7LgbrPRqlIf1JK1fwJxDHlR/NtHD+zD9PITd7niKfK6jl
7EPwx4hvW8snm4U7L+z0h5+/wOKtt0W9X+6GcnW61F7x1ggeaU4dS7WShe9I
f0DsSqQaHvkzF13KZCXaL1ju6ZvAQEDv2jwJTxgg/QvjB3uEL2B/d3GhWOfs
Aai/15jvKZ4TIqDyUf0E5k9gnyEqqGbQ9tfPU/yTaAR/5II/5u18ay/uJCDL
ygdRkhXgz/QYv0rK41/vj+TDdvuKQPBnXWPD1VNHCCiKjLP7QBT481isukI9
Go/Ix5XG11SA/rm7n7+l7Px97Rup877Hr7WEj6lCepWC/MC6u6TP7w5m/zjq
Kwx2vuDxGmqBBJSwhLndhqic95q7D/iPYNv5IPP10JkVYGcHRa3Dw2gCelKm
lskuDHbGi2MeX1lCQG2fmj3LDUH/H9kbZtaKYdvXsr5zZc8nmA8Wt6oxL00j
oKcNDD5HiOabMuzZLT0/55s9RxoEqI6A/ZOln1+c3optv8PjYNRUJdg/VWvg
fDH757xSR93JmZGovhs8pTrOSEBV1RXH+w6C/aO1e1JebV+4cs5N98a9+BKM
h0WlxeylX3ajs8yHxfWXEMVpcPv59nIQkL7PhrqK7eCPzUaj8cMqC+dPbRM/
Ba1a3Zz9bds4J3NLBlFuUCmZSGwjjKud+hPfsw6i9VujNF/th/IQoHvsbd29
X39fRCCLVrsII8xHaIKCXZ+8xo4fLk+Xu3tJFsYPbuYRd6ooa5BaR/OVeHei
eeLrBoOT9r/+/bX5869/9+7w/HeWR2bfU14373y3xOz5bqz3sH51vhaKF36g
KLqSSfS+TEEYZRDNe2QfsTzVNA24mvuOnBCnhcsX1v3h9iLeThuJ1oWCNm60
OvMv1oX+8n9wrPWf+e91is6eLziXc4D5/iDof/LVHZtzF8sx30/E+l2leXHg
NbNx4JfYO7+8JbpXkHtSRrevZPF9R6x5+mLzE4v/6ndsPefFSe5Z4DhJ5xgH
j9gzYP+E0ubhm4Wk2780Ly4u8t/ExWG9m2M27/0a/Oz7NVTz1nkcZtd5SPXz
d/Gi6s0H7w5BORfeJ4fuFePQnmmnW/1E76Q4XlkTc2AHDlnOew+FfvY9FL+1
dt9SHgGXXrapOujg7xvn/z9B/wRS
    "]],
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.604330100426984*^9, 3.6129774049661064`*^9, 
  3.6239961421081343`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Now", ",", " ", 
    RowBox[{
     RowBox[{
     "redo", " ", "the", " ", "whole", " ", "process", " ", "but", " ", 
      "with", " ", "the", " ", "disney", " ", "rough", " ", "diffuse", " ", 
      RowBox[{"BRDF", ".", " ", "goal"}], " ", "is", " ", "to", " ", "find", 
      " ", "the", " ", "slerp", " ", "factor", " ", "use", " ", "to", " ", 
      "reconstruct", " ", "the", " ", "off"}], "-", 
     RowBox[{
     "retroreflection", " ", "peak", " ", "based", " ", "on", " ", "the", " ",
       "normal", " ", "and", " ", "the", " ", "view", " ", "vector"}]}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DisneyDiffuse", "[", 
    RowBox[{"n_", ",", " ", "L_", ",", " ", "V_", ",", " ", "Roughness_"}], 
    "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H", " ", "=", " ", 
       RowBox[{"Normalize", "[", 
        RowBox[{"L", " ", "+", " ", "V"}], "]"}]}], ";", " ", 
      RowBox[{"fd90", " ", "=", " ", 
       RowBox[{"0.5", " ", "+", " ", 
        RowBox[{"2", " ", "*", 
         RowBox[{"L", ".", "H"}], " ", "*", " ", 
         RowBox[{"L", ".", "H"}], "*", "Roughness"}]}]}], ";", " ", 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"fd90", "-", "1"}], ")"}], "*", 
        RowBox[{"Power", "[", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"n", ".", "L"}]}], ",", "5"}], "]"}], " ", "*", " ", "1"}],
        "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"fd90", "-", "1"}], ")"}], "*", 
        RowBox[{"Power", "[", 
         RowBox[{
          RowBox[{"1", "-", 
           RowBox[{"n", ".", "V"}]}], ",", "5"}], "]"}]}]}]}], "}"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6043485931973934`*^9, 3.6043485989397216`*^9}, {
  3.604348636380863*^9, 3.604348647660508*^9}, {3.604348697326349*^9, 
  3.6043487029486704`*^9}, {3.6129774252962694`*^9, 3.6129774568230724`*^9}, {
  3.6129775642082148`*^9, 3.6129776333431687`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Manipulation", " ", "test", " ", "function", " ", "to", " ", "see", " ", 
    "how", " ", "the", " ", "peak", " ", "behave", " ", "depends", " ", "on", 
    " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DisneyDiffuseTest", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], "  ", ":=", " ",
    "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"dangle", " ", "=", " ", "0.01"}], ";", 
      RowBox[{"n", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"V", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"Cos\[Theta]V", " ", "*", " ", "Cos\[Theta]V"}]}], 
           "]"}]}], ",", " ", "0", ",", " ", "Cos\[Theta]V"}], "}"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"MaxTheta", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", 
      RowBox[{"MaxPhi", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", 
      RowBox[{"MaxVal", " ", "=", " ", 
       RowBox[{"-", "1"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"For", " ", "[", " ", 
       RowBox[{
        RowBox[{"angle", " ", "=", " ", "0"}], ",", 
        RowBox[{"angle", " ", "\[LessEqual]", " ", "\[Pi]"}], ",", 
        RowBox[{
         RowBox[{"angle", " ", "+=", " ", "dangle"}], " ", ";", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"theta", " ", "=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"angle", "<", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}], ",", 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "-", " ", "angle"}], ",", " ", 
            RowBox[{"angle", " ", "-", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}]}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"phi", " ", "=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"angle", "<", " ", 
             RowBox[{"\[Pi]", "/", "2"}]}], ",", "\[Pi]", ",", " ", "0"}], 
           "]"}]}], ";", "  ", "\[IndentingNewLine]", 
         RowBox[{"L", " ", "=", "  ", 
          RowBox[{"SphVec", "[", 
           RowBox[{"theta", ",", "phi"}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"val", "=", " ", 
          RowBox[{
           RowBox[{"DisneyDiffuse", "[", 
            RowBox[{
            "n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness"}], "]"}],
            " ", "*", 
           RowBox[{"L", ".", "n"}]}]}], " ", ";", " ", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"val", " ", "\[GreaterEqual]", " ", "MaxVal"}], ",", 
           RowBox[{
            RowBox[{"MaxVal", "=", "val"}], ";", 
            RowBox[{"MaxTheta", "=", "theta"}], ";", 
            RowBox[{"MaxPhi", "=", "phi"}]}], ",", "0"}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"slerpfactor", " ", "=", " ", 
       RowBox[{
        RowBox[{"VectorAngle", "[", 
         RowBox[{"n", ",", " ", 
          RowBox[{"SphVec", "[", 
           RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}]}], "]"}], " ", "/", " ", 
        RowBox[{"VectorAngle", "[", 
         RowBox[{"n", ",", " ", "V"}], "]"}]}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"newMax", " ", "=", " ", 
       RowBox[{"Slerp", "[", 
        RowBox[{"n", ",", " ", "V", ",", " ", "slerpfactor"}], "]"}]}], ";", 
      " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Pink", ",", " ", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"n", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{"n", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
          " ", "Blue", ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"V", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{"V", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
          "Green", ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"SphVec", "[", 
                 RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{
                RowBox[{"SphVec", "[", 
                 RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}], "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}], ",", 
          "Orange", ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"newMax", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
               RowBox[{"newMax", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}], "]"}]}], 
         "}"}], ",", "   ", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", " ", "1"}], "}"}]}], "}"}]}]}], "]"}]}],
      ",", "slerpfactor"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6042693938254967`*^9, 3.604269444075371*^9}, {
   3.6042695161094913`*^9, 3.6042697059382634`*^9}, {3.604269795052805*^9, 
   3.6042697957438445`*^9}, {3.60426983896944*^9, 3.6042698630004735`*^9}, {
   3.604269964526616*^9, 3.604269968916622*^9}, {3.604270110615821*^9, 
   3.604270175229912*^9}, {3.604270222401978*^9, 3.604270223021979*^9}, {
   3.604270255404024*^9, 3.604270260915032*^9}, {3.6042703718711877`*^9, 
   3.604270401552229*^9}, 3.6042704589563103`*^9, {3.60427055860245*^9, 
   3.6042705642024574`*^9}, {3.6042707193809614`*^9, 3.604270755330018*^9}, {
   3.6042708410913467`*^9, 3.6042708553323665`*^9}, {3.6042708936954203`*^9, 
   3.6042709382084827`*^9}, {3.6042710137128773`*^9, 3.604271134661047*^9}, {
   3.604271168523094*^9, 3.604271270100237*^9}, {3.60427130087228*^9, 
   3.604271498835558*^9}, {3.6042730038036704`*^9, 3.6042730115046816`*^9}, 
   3.604273083167782*^9, {3.604273128770846*^9, 3.6042731438518667`*^9}, {
   3.6042733110131016`*^9, 3.604273383388203*^9}, {3.6042734207402554`*^9, 
   3.604273421150256*^9}, {3.604273507137377*^9, 3.604273512027384*^9}, 
   3.604273551409439*^9, {3.6042736023025103`*^9, 3.604273604762514*^9}, {
   3.604273819136815*^9, 3.6042738335288353`*^9}, 3.604319960954039*^9, {
   3.604320401705249*^9, 3.60432042200841*^9}, {3.6043204836799374`*^9, 
   3.604320494600562*^9}, {3.604326263095501*^9, 3.604326281687565*^9}, {
   3.604326433246233*^9, 3.604326480333926*^9}, {3.604326513927848*^9, 
   3.6043265356470904`*^9}, {3.604327224165471*^9, 3.604327247861827*^9}, {
   3.6043430188085566`*^9, 3.6043430194245915`*^9}, {3.6043482820245953`*^9, 
   3.604348288141945*^9}, {3.6043483482243814`*^9, 3.604348368377534*^9}, {
   3.604348436530432*^9, 3.604348467665213*^9}, {3.604348508193531*^9, 
   3.604348598198679*^9}, {3.6043488844270506`*^9, 3.6043489208801355`*^9}, {
   3.6043873321024733`*^9, 3.6043873358924785`*^9}, {3.6129774702108383`*^9, 
   3.612977526820076*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Note", " ", "this", " ", "time", " ", "this", " ", "is", " ", 
    "retroreflection"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"DisneyDiffuseTest", "[", 
     RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], ",", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Roughness", ",", " ", "0.1", ",", " ", "\"\<Roughness\>\""}], 
       "}"}], ",", "0.01", ",", " ", "1.0"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "Cos\[Theta]V", ",", " ", "0.9999", ",", " ", "\"\<Cos\[Theta]V\>\""}],
        "}"}], ",", "0", ",", " ", "0.9999"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6043261426176105`*^9, 3.604326145048749*^9}, 
   3.6043486701087923`*^9, {3.612977651233192*^9, 3.612977660446719*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`Cos\[Theta]V$$ = 
    0.005, $CellContext`Roughness$$ = 0.9470000000000001, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`Roughness$$], 0.1, "Roughness"}, 0.01, 1.}, {{
       Hold[$CellContext`Cos\[Theta]V$$], 0.9999, "Cos\[Theta]V"}, 0, 
      0.9999}}, Typeset`size$$ = {273., {88., 92.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`Roughness$21616$$ = 
    0, $CellContext`Cos\[Theta]V$21617$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`Cos\[Theta]V$$ = 
        0.9999, $CellContext`Roughness$$ = 0.1}, "ControllerVariables" :> {
        Hold[$CellContext`Roughness$$, $CellContext`Roughness$21616$$, 0], 
        Hold[$CellContext`Cos\[Theta]V$$, $CellContext`Cos\[Theta]V$21617$$, 
         0]}, "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`DisneyDiffuseTest[$CellContext`Cos\[Theta]V$$, \
$CellContext`Roughness$$], 
      "Specifications" :> {{{$CellContext`Roughness$$, 0.1, "Roughness"}, 
         0.01, 1.}, {{$CellContext`Cos\[Theta]V$$, 0.9999, "Cos\[Theta]V"}, 0,
          0.9999}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{324., {148., 153.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604348666005557*^9, 3.6043486707668295`*^9}, {
   3.604349100966815*^9, 3.6043491058030915`*^9}, 3.6129775335284595`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Generate", " ", "a", " ", "fiting", " ", "function", " ", "representing", 
    " ", "the", " ", "slerp", " ", "factor", " ", "to", " ", "apply", " ", 
    "between", " ", "normal", " ", "and", " ", "reflection", " ", "vector", 
    " ", "for", " ", "off", " ", "specular", " ", "peak", " ", 
    "reconstruction"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Same", " ", "function", " ", "as", " ", "above"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
     RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], "  ", ":=", 
    " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"dangle", " ", "=", " ", "0.01"}], ";", 
       RowBox[{"n", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"V", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"1", " ", "-", " ", 
             RowBox[{"Cos\[Theta]V", " ", "*", " ", "Cos\[Theta]V"}]}], 
            "]"}]}], ",", " ", "0", ",", " ", "Cos\[Theta]V"}], "}"}]}], ";", 
       " ", "\[IndentingNewLine]", 
       RowBox[{"MaxTheta", " ", "=", " ", 
        RowBox[{"-", "1"}]}], ";", " ", 
       RowBox[{"MaxPhi", " ", "=", " ", 
        RowBox[{"-", "1"}]}], ";", " ", 
       RowBox[{"MaxVal", " ", "=", " ", 
        RowBox[{"-", "1"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"For", " ", "[", " ", 
        RowBox[{
         RowBox[{"angle", " ", "=", " ", "0"}], ",", 
         RowBox[{"angle", " ", "\[LessEqual]", " ", "\[Pi]"}], ",", 
         RowBox[{
          RowBox[{"angle", " ", "+=", " ", "dangle"}], " ", ";", 
          "\[IndentingNewLine]", 
          RowBox[{"theta", " ", "=", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"angle", "<", " ", 
              RowBox[{"\[Pi]", "/", "2"}]}], ",", 
             RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], " ", "-", " ", "angle"}], ",", " ", 
             RowBox[{"angle", " ", "-", " ", 
              RowBox[{"\[Pi]", "/", "2"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"phi", " ", "=", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"angle", "<", " ", 
              RowBox[{"\[Pi]", "/", "2"}]}], ",", "\[Pi]", ",", " ", "0"}], 
            "]"}]}], ";", "  ", "\[IndentingNewLine]", 
          RowBox[{"L", " ", "=", "  ", 
           RowBox[{"SphVec", "[", 
            RowBox[{"theta", ",", "phi"}], "]"}]}], ";", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"val", "=", " ", 
           RowBox[{
            RowBox[{"DisneyDiffuse", "[", 
             RowBox[{
             "n", ",", " ", "L", ",", " ", "V", ",", " ", "Roughness"}], 
             "]"}], "*", 
            RowBox[{"L", ".", "n"}]}]}], " ", ";", " ", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"val", " ", "\[GreaterEqual]", " ", "MaxVal"}], ",", 
            RowBox[{
             RowBox[{"MaxVal", "=", "val"}], ";", 
             RowBox[{"MaxTheta", "=", "theta"}], ";", 
             RowBox[{"MaxPhi", "=", "phi"}]}], ",", "0"}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"slerpfactor", " ", "=", " ", 
        RowBox[{
         RowBox[{"VectorAngle", "[", 
          RowBox[{"n", ",", " ", 
           RowBox[{"SphVec", "[", 
            RowBox[{"MaxTheta", ",", "MaxPhi"}], "]"}]}], "]"}], " ", "/", 
         " ", 
         RowBox[{"VectorAngle", "[", 
          RowBox[{"n", ",", " ", "V"}], "]"}]}]}]}], " ", 
      "\[IndentingNewLine]", "}"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "See", " ", "the", " ", "look", " ", "of", " ", "the", " ", "function"}], 
    " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.6042717414098988`*^9, 3.6042717479599075`*^9}, {
   3.604272512379981*^9, 3.6042725582440453`*^9}, {3.6042726290091443`*^9, 
   3.604272635660154*^9}, {3.6042729899426513`*^9, 3.6042729912126527`*^9}, {
   3.604273714969669*^9, 3.6042737260306845`*^9}, {3.604273853969864*^9, 
   3.6042738552598658`*^9}, {3.604320376622814*^9, 3.6043203928937445`*^9}, 
   3.6043271613498783`*^9, {3.6043272555882683`*^9, 3.604327277883544*^9}, {
   3.6043273120754995`*^9, 3.6043273509617233`*^9}, 3.6043273902709723`*^9, 
   3.6043275801968355`*^9, {3.6043496527003727`*^9, 3.604349686825324*^9}, {
   3.6129776924665504`*^9, 3.61297774944681*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
     RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.5"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.604273867679883*^9, 3.6042738973419247`*^9}, {
   3.604274025820105*^9, 3.604274035171118*^9}, {3.604274174731011*^9, 
   3.6042741865186853`*^9}, {3.604274268918579*^9, 3.60427427660959*^9}, {
   3.604274334662671*^9, 3.6042743605537076`*^9}, {3.604274628680084*^9, 
   3.6042746324100895`*^9}, {3.604274662642132*^9, 3.604274690694171*^9}, {
   3.6042747440462456`*^9, 3.604274744386246*^9}, {3.6042761688972454`*^9, 
   3.6042761739572525`*^9}, {3.6042762193393164`*^9, 3.604276219869317*^9}, {
   3.6042775860702343`*^9, 3.6042775904702406`*^9}, 3.604327404724799*^9, {
   3.604327441827921*^9, 3.604327459098909*^9}, {3.6043497153449554`*^9, 
   3.60434973815026*^9}, {3.6043498981024084`*^9, 3.6043498994624863`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyNnXlUz9v3/8t4zfM8pTLPXLM6ZMoQyhAyz1KINJBQIbPILKU0IKkoSvOE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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmgf8V9P/x++959yPEJVViQilvYsWLdHek6KSZCQUIinJzJ7ZWVGJsvfM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         "]], Polygon3DBox[CompressedData["
1:eJxNmgW0HUXWhW931324JAQIngBJcHcCJISgwUNwGdwZ3CW4e3B3dye4DW6D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         "]], Polygon3DBox[CompressedData["
1:eJwt1wm8jdUexvF9ztnnSCjSJDJkKGPKUEiRWQMhKhlSKLeo5JYb6QplLkPk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         "]], 
        Polygon3DBox[{{1034, 1033, 1415, 801, 802, 
         1416}}]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0s9L02EcwPFnrS1Xa3rwZKB461IHoVtdOqaYDZ0/ttYP9FBEHYLa9A/I
PyA2EU0QHSGyUx3Eo/oPTEv7XQgi1CGoWxC9Hujw2ev9bPt+n2c/eu8+yj9M
hBCem6ci9qSHYy4nQ+hgkz3c4EXu8Ar3OMBDFvmLv819nTsZQpXnOMvzrPMS
G7zK17zB7Xgvpu07bXatn7DLjJzwmnWBbzjKtxzjPsd5wAm+Y5El817f5AeW
+ZG3+Im3+Zl3+IV9zpyx11dd17P6jJkx3zz3mKfNA2dsxet1WW/Fe+vr+pUu
6VWmU86jazqlx/QzndQFXdEJPayzrr1nndc/7T2hh+K+ul8P6pa+rP9674D1
Bf1HX9PdelP/YNW6nVP8zgqbJqezXDdn9Vrcly/j52Qjfj6uMBN/d7ZxiS/M
Kb3INBfo6GGetg1zdLxQo68zdFoc/f8v/QPPckXq
       "]]}, {
      Line3DBox[{930, 1207, 1210, 610, 1289, 1208, 1308, 1628, 1133, 931, 
       1424, 1134, 932, 1425, 1135, 933, 1422, 1426, 1303, 1136, 934, 1423, 
       1427, 1309, 1137, 935, 1428, 1313, 1501, 936, 1429, 1138, 937, 1430, 
       1139, 938, 1431, 1140, 939, 1432, 1141, 940, 1433, 1142, 941, 1414, 
       1434, 1143, 1238, 1614, 1260, 1261, 1245, 1259, 1144, 1211}], 
      Line3DBox[{942, 1209, 1314, 1603, 1302, 1301, 1315, 1627, 943, 1435, 
       1145, 944, 1304, 1436, 1146, 1305, 1413, 1437, 1300, 1306, 1307, 1299, 
       1626, 1297, 1312, 1147, 945, 1438, 1316, 1502, 946, 1317, 1503, 947, 
       1439, 1148, 948, 1440, 1149, 949, 1441, 1150, 950, 1442, 1151, 951, 
       1604, 1212, 1152, 1239, 1615, 1262, 1213, 1246, 1276, 1277, 1275}], 
      Line3DBox[{953, 1318, 1504, 952, 1319, 1505, 954, 633, 955, 1443, 1153, 
       956, 1625, 1298, 1154, 1311, 1629, 1310, 1155, 957, 1444, 1320, 1506, 
       958, 1321, 1507, 959, 1322, 1508, 960, 1445, 1156, 961, 1446, 1157, 
       962, 1447, 1158, 963, 1605, 1214, 1159, 1240, 1616, 1263, 1215, 1247, 
       1279, 1280, 1278}], 
      Line3DBox[{965, 1323, 1509, 964, 1324, 1510, 966, 1325, 1511, 967, 645, 
       968, 1448, 1160, 969, 1449, 1161, 970, 1450, 1326, 1512, 971, 1327, 
       1513, 972, 1328, 1514, 973, 1329, 1515, 974, 1451, 1162, 975, 1452, 
       1163, 976, 1606, 1216, 1217, 977, 1419, 1607, 1218, 1248, 1219, 1290, 
       978}], Line3DBox[{980, 1330, 1516, 979, 1331, 1517, 981, 1332, 1518, 
       982, 1333, 1519, 983, 1334, 1520, 984, 1453, 1164, 985, 1454, 1335, 
       1521, 986, 1336, 1522, 987, 1337, 1523, 988, 1338, 1524, 989, 1339, 
       1525, 990, 667, 991, 1608, 1220, 1221, 992, 1620, 1264, 1222, 1249, 
       1223, 1291, 993}], 
      Line3DBox[{995, 1340, 1526, 994, 1341, 1527, 996, 1342, 1528, 997, 1343,
        1529, 998, 1344, 1530, 999, 1345, 1531, 1000, 1455, 1346, 1532, 1001, 
       1347, 1533, 1002, 1348, 1534, 1003, 1349, 1535, 1004, 1350, 1536, 1005,
        1351, 1537, 1006, 799, 1224, 1007, 1621, 1265, 1266, 1250, 1293, 1292,
        1008}], 
      Line3DBox[{1012, 1456, 1165, 1010, 1457, 1166, 1014, 1458, 1167, 1016, 
       1459, 1168, 1018, 1460, 1169, 1020, 1461, 1170, 1022, 1462, 688, 1024, 
       1463, 1171, 1026, 1464, 1172, 1028, 1465, 1173, 1030, 1466, 1174, 1032,
        1467, 1175, 1034, 1416, 1468, 1176, 1241, 1421, 1622, 1268, 1252, 
       1282, 1177, 1281}], 
      Line3DBox[{1036, 1294, 1295, 1251, 1267, 1619, 1420, 1035, 1225, 1551, 
       1415, 1033, 1550, 1363, 1031, 1549, 1362, 1029, 1548, 1361, 1027, 1547,
        1360, 1025, 1546, 1359, 1023, 1545, 1544, 1358, 1021, 1543, 1357, 
       1019, 1542, 1356, 1017, 1541, 1355, 1015, 1540, 1354, 1013, 1539, 1353,
        1009, 1538, 1352, 1011}], 
      Line3DBox[{1038, 1364, 1552, 1037, 1469, 1178, 1039, 1470, 1179, 1040, 
       1471, 1180, 1041, 1472, 1181, 1042, 1473, 1182, 1043, 1474, 1365, 1553,
        1044, 1366, 1554, 1045, 1475, 1183, 1046, 1476, 1184, 1047, 1477, 
       1185, 1048, 1478, 1186, 1049, 1417, 1479, 1187, 1242, 1617, 1269, 1270,
        1253, 1284, 1188, 1283}], 
      Line3DBox[{1051, 1367, 1555, 1050, 1368, 1556, 1052, 1480, 1189, 1053, 
       1481, 1190, 1054, 1482, 1191, 1055, 1483, 1192, 1056, 1484, 1369, 1557,
        1057, 1370, 1558, 1058, 716, 1059, 1485, 1193, 1060, 1486, 1194, 1061,
        1487, 1195, 1062, 1609, 1226, 1196, 1243, 1618, 314, 1254, 345, 
       1285}], Line3DBox[{1064, 1371, 1559, 1063, 1372, 1560, 1065, 722, 1066,
        1488, 1197, 1067, 1489, 1198, 1068, 1490, 1199, 1069, 1491, 1373, 
       1561, 1070, 1374, 1562, 1071, 1375, 1563, 1072, 730, 1073, 1492, 1200, 
       1074, 1493, 1201, 1075, 1610, 1227, 1202, 1244, 883, 1228, 1255, 1287, 
       1288, 1286}], 
      Line3DBox[{1077, 1376, 1564, 1076, 1377, 1565, 1078, 1378, 1566, 1079, 
       736, 1080, 1494, 1203, 1081, 1495, 1204, 1082, 1496, 1379, 1567, 1083, 
       1380, 1568, 1084, 1381, 1569, 1085, 1382, 1570, 1086, 744, 1087, 1497, 
       1205, 1088, 1611, 255, 279, 829, 256, 348}], 
      Line3DBox[{1090, 1383, 1571, 1089, 1384, 1572, 1091, 1385, 1573, 1092, 
       1386, 1574, 1093, 750, 1094, 1498, 1206, 1095, 1499, 1387, 1575, 1096, 
       1388, 1576, 1097, 1389, 1577, 1098, 1390, 1578, 1099, 1391, 1579, 1100,
        758, 1101, 1612, 1229, 1230, 1102, 1623, 1271, 1231, 1256, 1232, 1296,
        1103}], 
      Line3DBox[{1105, 1392, 1580, 1104, 1393, 1581, 1106, 1394, 1582, 1107, 
       1395, 1583, 1108, 1396, 1584, 1109, 764, 1110, 1500, 1397, 1585, 1111, 
       1398, 1586, 1112, 1399, 1587, 1113, 1400, 1588, 1114, 1401, 1589, 1115,
        1402, 1590, 1116, 1613, 1233, 1234, 1117, 1624, 321, 1257, 370, 
       1118}], Line3DBox[{1132, 1273, 1274, 1258, 1272, 896, 1131, 1237, 1602,
        1418, 1130, 1601, 1412, 1129, 1600, 1411, 1128, 1599, 1410, 1127, 
       1598, 1409, 1126, 1597, 1408, 1125, 1596, 778, 1124, 1595, 1407, 1123, 
       1594, 1406, 1122, 1593, 1405, 1121, 1592, 1404, 1120, 1591, 1403, 1119,
        815, 1235, 1236}]}, {
      Line3DBox[{406, 785, 611, 1628, 407, 910, 1627, 622, 432, 1505, 632, 
       444, 1510, 643, 458, 1517, 656, 472, 1527, 669, 486, 1539, 682, 1457, 
       500, 695, 1469, 514, 1556, 708, 528, 1560, 721, 542, 1565, 734, 556, 
       1572, 747, 570, 1581, 760, 584, 1591, 773, 598}], 
      Line3DBox[{408, 612, 1424, 409, 623, 1435, 433, 633, 445, 1511, 644, 
       459, 1518, 657, 473, 1528, 670, 487, 1540, 683, 1458, 501, 696, 1470, 
       515, 709, 1480, 529, 722, 543, 1566, 735, 557, 1573, 748, 571, 1582, 
       761, 585, 1592, 774, 599}], 
      Line3DBox[{410, 613, 1425, 411, 389, 1436, 434, 634, 1443, 446, 645, 
       460, 1519, 658, 474, 1529, 671, 488, 1541, 684, 1459, 502, 697, 1471, 
       516, 710, 1481, 530, 723, 1488, 544, 736, 558, 1574, 749, 572, 1583, 
       762, 586, 1593, 775, 600}], 
      Line3DBox[{412, 914, 915, 1426, 916, 918, 786, 917, 787, 1437, 909, 906,
        1625, 907, 447, 646, 1448, 461, 1520, 659, 475, 1530, 672, 489, 1542, 
       685, 1460, 503, 698, 1472, 517, 711, 1482, 531, 724, 1489, 545, 737, 
       1494, 559, 750, 573, 1584, 763, 587, 1594, 776, 601}], 
      Line3DBox[{413, 920, 921, 1427, 922, 923, 924, 908, 1626, 905, 927, 928,
        929, 926, 1629, 925, 448, 647, 1449, 462, 660, 1453, 476, 1531, 673, 
       490, 1543, 686, 1461, 504, 699, 1473, 518, 712, 1483, 532, 725, 1490, 
       546, 738, 1495, 560, 751, 1498, 574, 764, 588, 1595, 777, 602}], 
      Line3DBox[{414, 614, 1428, 416, 624, 1438, 435, 635, 1444, 449, 648, 
       1450, 463, 661, 1454, 477, 674, 1455, 491, 1544, 687, 1462, 505, 700, 
       1474, 519, 713, 1484, 533, 726, 1491, 547, 739, 1496, 561, 752, 1499, 
       575, 765, 1500, 589, 778, 603}], 
      Line3DBox[{418, 616, 1429, 419, 1503, 626, 437, 1507, 637, 451, 1513, 
       650, 465, 1522, 663, 479, 1533, 676, 493, 1546, 689, 1463, 507, 1554, 
       702, 521, 1558, 715, 535, 1562, 728, 549, 1568, 741, 563, 1576, 754, 
       577, 1586, 767, 591, 1597, 780, 605}], 
      Line3DBox[{420, 617, 1430, 421, 627, 1439, 438, 1508, 638, 452, 1514, 
       651, 466, 1523, 664, 480, 1534, 677, 494, 1547, 690, 1464, 508, 703, 
       1475, 522, 716, 536, 1563, 729, 550, 1569, 742, 564, 1577, 755, 578, 
       1587, 768, 592, 1598, 781, 606}], 
      Line3DBox[{422, 618, 1431, 423, 628, 1440, 439, 639, 1445, 453, 1515, 
       652, 467, 1524, 665, 481, 1535, 678, 495, 1548, 691, 1465, 509, 704, 
       1476, 523, 717, 1485, 537, 730, 551, 1570, 743, 565, 1578, 756, 579, 
       1588, 769, 593, 1599, 782, 607}], 
      Line3DBox[{424, 619, 1432, 425, 629, 1441, 440, 640, 1446, 454, 653, 
       1451, 468, 1525, 666, 482, 1536, 679, 496, 1549, 692, 1466, 510, 705, 
       1477, 524, 718, 1486, 538, 731, 1492, 552, 744, 566, 1579, 757, 580, 
       1589, 770, 594, 1600, 783, 608}], 
      Line3DBox[{426, 620, 1433, 427, 630, 1442, 441, 641, 1447, 455, 654, 
       1452, 469, 667, 483, 1537, 680, 497, 1550, 693, 1467, 511, 706, 1478, 
       525, 719, 1487, 539, 732, 1493, 553, 745, 1497, 567, 758, 581, 1590, 
       771, 595, 1601, 784, 609}], 
      Line3DBox[{428, 789, 790, 1434, 429, 791, 1604, 792, 442, 793, 1605, 
       794, 456, 795, 1606, 796, 470, 797, 1608, 798, 484, 799, 800, 498, 
       1551, 801, 802, 1468, 512, 803, 804, 1479, 526, 805, 1609, 806, 540, 
       807, 1610, 808, 554, 809, 1611, 810, 568, 811, 1612, 812, 582, 813, 
       1613, 814, 596, 1602, 816, 817, 818}], Line3DBox[CompressedData["
1:eJwVz1dSAkEUQNG2rHIfrsEsRgwoiGFURIygYgTMWVH40B2wC9fo6Y9Td+q9
Sd1baST1rhBCmT8Xre4Q2vSxwnIPOs0qa/SzHvd2iabZYJMBtuK9dgWdocg2
GbNB3aHELLvxWfM9HeKAfeY4jO+0K+swR1SYj983P9YTRjilSsE8o2ecM8pl
/G/zC13gihopGiR2dV3kmhvGuOOWLPc8MM4Tj+R4juf1/ItO8MYrS7zHs9t9
6CRNPsnzxTdT/PJDh3+D0yZR
       "]], 
      Line3DBox[{597, 772, 815, 583, 759, 1580, 569, 746, 1571, 555, 733, 
       1564, 541, 720, 1559, 527, 707, 1555, 513, 694, 1552, 499, 1456, 681, 
       1538, 485, 668, 1526, 471, 655, 1516, 457, 642, 1509, 443, 631, 1504, 
       431, 621, 1603, 911, 913, 912, 405, 610, 900, 902, 901, 788}], 
      Line3DBox[{604, 779, 1596, 590, 766, 1585, 576, 753, 1575, 562, 740, 
       1567, 548, 727, 1561, 534, 714, 1557, 520, 701, 1553, 506, 688, 1545, 
       492, 675, 1532, 478, 662, 1521, 464, 649, 1512, 450, 636, 1506, 436, 
       625, 1502, 417, 615, 1501, 415}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJztfXs0V1v3/hZJrklSoiiRCklIqk2hQgmVS0QlSaEUqVAkRS6FkmtKRFFR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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{386.1041601147853, 237.44581990084242`},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 0.5}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{-0.8284321747398097, -3.13617775395844, 0.9633738772834508},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.604349982733249*^9, 3.6129777599494104`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Base", " ", "on", " ", "what", " ", "we", " ", "see", " ", "on", " ", 
     "the", " ", "curve"}], ",", " ", 
    RowBox[{
    "we", " ", "fit", " ", "only", " ", "one", " ", "of", " ", "the", " ", 
     "extremun", " ", "and", " ", "use", " ", "0", " ", "for", " ", "the", 
     " ", "other"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FitDisneyDiffuseComplex0", "[", "Roughness_", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"b", "*", "Roughness"}], "+", "c"}], "]"}]}], "/.", " ", 
    RowBox[{"FindFit", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", " ", 
          RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
           RowBox[{"0", ",", " ", "x"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0.001", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
      ",", 
      RowBox[{"a", "*", 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"b", "*", "xx"}], "+", "c"}], "]"}]}], " ", ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", " ", "b", ",", " ", "c"}], "}"}], ",", "xx"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6043500601036744`*^9, 3.6043500852501125`*^9}, {
   3.604350146599622*^9, 3.6043501880399923`*^9}, 3.604350379587948*^9, {
   3.612977763207597*^9, 3.6129777706640234`*^9}, {3.61297782200696*^9, 
   3.6129778651024246`*^9}, {3.6129779852642975`*^9, 3.6129779862803555`*^9}}],

Cell[BoxData[
 RowBox[{"0.08630177573518154`", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"0.7896915070171395`", "\[VeryThinSpace]", "+", 
    RowBox[{"28.04254269803164`", " ", "Roughness"}]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.604350158822321*^9, 3.604350190181114*^9}, 
   3.604350494788537*^9, 3.6129777874229813`*^9, 3.6129779907626123`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "the", " ", "fitting"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FitDisneyDiffuseComplex0", "[", "x", "]"}], ",", " ", 
      RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
       RowBox[{"0", ",", " ", "x"}], "]"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.60435020828615*^9, 3.6043502168296385`*^9}, 
   3.6043504077525587`*^9, {3.612977791007187*^9, 3.612977796399495*^9}, 
   3.612977990974624*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtzgs01AkbBnBlZTcVK1rrGmFZIbcvn/D0bZ1ilSRyb6nQRsht21wit5ks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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxF0Wc8FXwfBnCzVMo4SFYoFDpmqOgvlJQkhCSVnYwyU4hOQiUkhbjtkb3J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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0.001, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.604350224123056*^9, 3.604350500279851*^9, 
  3.6129778037079134`*^9, 3.6129779981330338`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Lerp", " ", "with", " ", "0", " ", "at", " ", "0.5"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FitDisneyDiffuseComplex", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", "=", " ", 
   RowBox[{"Lerp", "[", 
    RowBox[{
     RowBox[{"FitDisneyDiffuseComplex0", "[", "Roughness", "]"}], ",", " ", 
     "0", ",", " ", 
     RowBox[{"2", " ", "*", " ", "Cos\[Theta]V"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6043504060514617`*^9, 3.6043504828728557`*^9}, {
  3.604350568058728*^9, 3.6043505778902903`*^9}, {3.6043507110469065`*^9, 
  3.6043507139340715`*^9}, {3.604350808985508*^9, 3.6043508554521656`*^9}, {
  3.6043509628863106`*^9, 3.6043509651944427`*^9}, {3.612977868894642*^9, 
  3.6129778800002766`*^9}, {3.6129779969109635`*^9, 3.6129780002961574`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.08630177573518154`", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"0.7896915070171395`", "\[VeryThinSpace]", "+", 
     RowBox[{"28.04254269803164`", " ", "Roughness"}]}], "]"}]}], "-", 
  RowBox[{"0.17260355147036308`", " ", "Cos\[Theta]V", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"0.7896915070171395`", "\[VeryThinSpace]", "+", 
     RowBox[{"28.04254269803164`", " ", "Roughness"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.6043508558321877`*^9, 3.6043509661874995`*^9, 
  3.612977886929673*^9, 3.612978001354218*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "the", " ", "final", " ", "fitting"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], ",", " ", 
      RowBox[{"FitDisneyDiffuseComplex", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}]}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.5"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.604350600275571*^9, 3.6043506246759663`*^9}, {
   3.612977890510878*^9, 3.6129778960631957`*^9}, 3.6129780069445376`*^9}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJycnXdcj9///5O9Ze8RMt5kRfZlC4W87b33ysgspFKEopS90pISSdqloUFD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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mge0FMXTxXvZGXb27QBKzghKkqxIUhQEVFBBQAFBJZhRgopZ/4oZI2LO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         "]], Polygon3DBox[CompressedData["
1:eJxFmnXcVcXXxe/lmeHM5XkkBQnpDgkVRFQkFDEwMDEQsbtbUVTs7u4WW+zA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         "]], Polygon3DBox[CompressedData["
1:eJwt13n81cMex/FT5/z6fatTIUspNxVFaUGFXMoVriwhOwm5dsqVNXtucgnX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         "]], Polygon3DBox[{{2083, 2082, 2846, 1329, 1330, 2847}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmHewVdUZxe+7z3fOnPv2oZjMRKpRRwGViKD0OtIsdJVeNYICYklAaQo8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         "]], Polygon3DBox[CompressedData["
1:eJwtmXewVdUVxi/3+M6dcy5gSWaigBo7dkUFLKCMCmpsgI0iKDZUsGEDrPCw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         "]], Polygon3DBox[CompressedData["
1:eJwt1VlQV2UYB+CDZI6i0DZTSlrWpGk1KZalksoopdUUYjOlYqDOKK4olhtW
I4tZ7hOupZlWataVCC5XBYjWRSUgdpOymFcKiF0l0vON/4t38H3+v/cs33fO
ceDsvMwl3aIoylHd1daEKBrSI4qW3RtFC/2Q2CuKtrGhLJ8tYklsC3uaLWUL
WB+2mQ1meWw+680OsFw2Qq1gH7N17GF9ttx7rLNnFA3iJfox/EhcFM1kL/v3
J37fGR9FO9QH+u1yOf5mxnLb9Jscb5B+iflc+QSWwgr11W7quFweK2J95Wbx
6XJ3nGMEK9KflSuTWypXzPrJzeYz5LrkngquH8UPy2WxErlk/RyeFRZRZhhb
oy9zvFK2mk1QF1hvFbHjZgvlHjGbw6ax2yyf3dZPDOvA/mbTzbbrn1EDWR1L
Zh+FezB/iJXox5n9irU4b53rWyU3ln3JmlktW8leYXtZE7vAPmRp5s+wf9k1
tpelyu1hjexPtoK9xU6wTtbKStnbrJzdYW3sC5bBKlgXa2c72BR2Mty/usl2
skx2Sh+nOtguNpWd1ndTt9huVur6ytznXPf7gtolk+/vHs/EbvWN35brh8it
N3fGeY+ZzTE7in3N/mLn2Vo2T7bczGdmN6gU/fPhmZY7J1chtyCsH/uJXWOX
2Eb2knNvYnWsks1li9h19mLYJ8f9gy1j/+knqNHsMpvBqmLPQZfZg2w569Sn
q1S5K2wV6+maprDJ7AZbzG7oR6pn2e8sh53X36/uYUdYNjunv0/Fs8PsfVaj
Twrryr4P7xbbrK93H1WuJTc8a6ySJYT9ZIfYSLZRXyv3C5vHBliXlY5TaO3W
qUP6LLlquT6xZ/xbuZnsrD4x7DH7js1nl/WD1aPsZ9bXfEH4FvS4u5dF4T1S
W9l55z3pvAvDNbP97BI7xwrCM8Ra2AD1oNmz4Vljzfr+6gFWzV5l9bE1COtS
zl5jF2NrFdavgk1iDbE17c5OhmeSXdU/ph5iNSyLdeifU0+yi2F/2c2wP+oJ
Vs+msTb9UPU4q2X92Nrw3rvfg6y4193vXfiejWXj1G7rlMGbwjqF65GrCnup
jsqNl0kL70D43qgE/54q94Zcq8xq1it8J9nr7DorYL3ZO+xN1saGh++7/ldr
espxF4V3mjWy5LA2cpXhvOb22+t96gDL1k90vMMyrWavmC2Rm2i2NvYchD0v
C+ss90N47+Wa5T5lKXLb2W/sNFsc3i22jzWwGrYm7IfZY+H7wFrYhrCX7Chr
Z01sPUtnR1gba2TFbI7jxbnOMTzFtVwNexT7Zm5xH5tVqn6hXH9/35XL8Fu8
Pl3VxZ7d8M6cMJvLkuQmszR2i81iXeH/BTWMNbPZLJIbzYazlvDNYYlsEhvP
OsK3mP2o/8c1N7jmz9n/VgP1dw==
         "]]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmGe0FdUZhg9zODN3zp1ZUcpFTZSOBYQgRSkqXppS1BiKJmqkKiRSBKIk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         "]], Polygon3DBox[CompressedData["
1:eJwtmHfQldURxm/hnsN934+MUkRjRJpobCBNBRX8ALEglgBiIkaqiTKABUsS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         "]], Polygon3DBox[CompressedData["
1:eJwt1VdwVVUUBuADITfhJjoqzTJDt4AYRMECihhQigEVsQNCKApoorTIjIro
CIioQwBrQKwPKgQFW+g+MbQgLyrVJ4VEcCxAANu35uRhzT3ru/8+dZ99OpSW
Dy9rmiRJhcpVQ7NJciCTJG1UgT82Nk+SErZf31pl2QY2jB3Un68K2SZ2A/tI
/5Md7W6SJM+zPuxDdojVsudYL/Y6+45tZtPYNewNtodtYdPZaNbArlKXOcY+
Nr0gSfJykuSU/ga+uTBJHmHN2Al2HlvLehr7mu3d9rfJ/qYa+xA7xa5WXWT3
szJjM8Y26It4jbG95T6wfdDYXcbOkRvDTrOeqqvsATaKndT3UJeyvWxGXpL0
tb96fa2aqR8hd1imY9xXtk3ubnZE3ynuIdvOxrOMfD92LatjE1geu5ldx+rZ
RJbPitn17Fd2D6vTd1YXsB3sUdZZbjS7l2X1613TYdtnO8cn/fby/338V5lL
1EVsl7H3snr9xepCtpN1ZS/qZxmzyn0pZZNYK/3tfKDc6TgX93SjPqMa5KrY
B3EM/7d13Gq/lfq75TbI5KqTcm/L9WTz9Duc5+8xr+TuZ1tYc3VG7h25yby1
497BBsmdYffJbdbnq9Nyy+M62CZ9njrFlrGrjV2qr3WMjewJtkCuo/1N5uPs
L0+mxv9V/j/LOReqN/3/uNwJmb4xF+R+MHYEW69vpo6zdTHn1fK89P7GfX5M
Xy53XObGmIPs+8b53FRmSJwz+zKb3oN/4/nHu+Yc5piT42TaOYejbLUar79N
bnXcY5kjzvNl+5vCfmHdYy7IbWU3s3f1R+R+lHuazWVt7WMi/1turePOjPeI
lbD+7Be569l/TdNnEc/kBedSwXLlhsoN4Ifl+rP39fUy+xxjNitm77E6tpc9
w55i58Sci2dp7BeOO45X+38Av0W9LfO0Otf2/XJ3yh2XWcyK2Ez2OGth7Eus
E5vCxrN89ixryUayEazB2HmsHXuYjWHNYi6zDmwSK2UZNp+1Z4+wsSyXPcPO
Yw+w4eyE/c1mLdiD7C52Mt5ftdp1DOKD1bKCdG409dz+inHuwwr3bzL7OZOu
N7HufO0YlewKY2aw8ljHsum69oO+fbwf7Bu2iHWTm87+YWuy6Rr2VyZdD2Nd
/IotYd3lKtgTrCWbwXJi3rBi9rPzfY31YLPYNNY63g12ZcxbNpW1irmrL3Id
3dR8dmusU3KJ/o9Y+1zbQtc2mK3KpNca17ze2NvUPtYq3uGwWNfkdjV+U8JW
xv1jOxtz+ezTWOtYbeP3KL49q9g7bFisOXEfWBv7L2GfxfU7bp1n8IrcUPZ5
vFesnr3KirLp9yW+MyUxPuaf3A65lrFO2N8ncg+z3Y3ft/gOVrPLZRfot+Sm
8zXmbTzL3Jz0+cRz+tI9KGXbbbeINZB/LNfB2DmZ9L2N93exvp2azSry0m/F
smx6/5rY35/xXjnOUvsr8//lrIuay4tjfsn+2HiMOOcaxxhibHXMlVjjnd9C
1pstZvvYNlbGxsY8yEnXqlizVham5xPnNcG++6u3ZEr9fsh+UxfKj9XPjW+j
fqTtgaqqIF0jKjPpHIi5sDGbzo0VmfQa4lo2sHnZdH+jYr1Ty2WGsL2N9z6e
+bpYN9i3sS4Ze8w5v9t4ztsy6fc9vvM12XQNa56TriOxnuxxHX3YEtv7jd1u
bLmxjznWm7Z7y/ZRVXnpe5TNSde+WAMPGNuLzbe909h18d3KputVfk66Nsca
vVWuH19r+5jcIblKx7iJrWFH2UG2iP0PIis2rQ==
         "]], 
        Polygon3DBox[{{2592, 1664, 1904, 817, 748, 2724}, {2865, 1662, 1469, 
         746, 783, 2669}}]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0l1Lk2EYwPGrMm0vpsceJELSkYIQEZIHeZgjYoTIFhGhtVm+EeiWx9G+
QPoJGiUaBTMipZOCzterlqtOInr5AtJBvweCXfv97437ebZ767s6l589EBH3
zJJIetLTD251RHTzNXvZ5CBbHOEf5viXRWaPRHSaaX2CVZ5kjWe5yvOss8hN
TvMV21PGfW+bN9aL7DFTbRFvra/xHa/zPUv8wDI/JtfhDm9wlzc5Yz7pWX7m
HPc4zxYX+IWjhyNS7vVVP9Q1nTHL5pvXbjFt7visTesrekm/1Jd1STf0iO9w
yfq+HtYFvaJP6wl9V5/S47qSnI2+qPvtL1vndUoX9AW971zHkjPTv/QZPWRP
znpAD+pz+pj+ad9vVq27OJXsYYUvDkUcTX4fva079XNm+YwZPmWaDbpsPOFj
47LxiG4fG2znOh1TrNERxgN6RN3TQR735vf//6d/RWJGag==
       "]]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl08lvTWEYgPG3t9pq1TxViyox1VAzNevKEht7EhtD0VvD2lJiUamZkuiG
haqWtjqwMkTEPyBinqpiLlX8TiyePM/73nNOzndvbsmWyk27MiLiDu6lImoN
FzMjxmMeJmAMxqEtJ6KAn7puGE/FUrTaL+Fn9sN5GsrRYr+Mn9uP4Om4ZLeC
l+OF/Ug+bzeDV2ElXtoP4jr7ybwQC/DKvskuXw/Ga/M5c31exFDzO/MfdJk/
8V906s8cPu/QX3SGbtdfdUrf1N90ZnJG/V0PSM6lf+is5Cy6V2frG/qnztHX
9S89UDfrPp2rm/Rvnaev6X6dzo6o5Grezft4D+/nvXyAq/ggp3mDs9Xwg+Qe
3EUdCjxvW/Js3sx9uRHruZvL+TGX8kMuSr4PzucG7vf7XuAeruEnfIgfcZpv
c7XnHnF9o67Sh/V9bHWWSShDCcaiCI3es5A/umY0z8ZcXLWfwz32o3gmZqHB
vpQ/2BfzFfNE7jbP58vmtVyBdXhvv5rr7dfwFCzGIrz12Vn7IfqNbs+KOOO9
2/g0N9u16lP6lm7RJ/VO93SZT+gdulMf19t1hz6mN+qjqf//i3/mUmgk
       "]], Line3DBox[CompressedData["
1:eJwl0ssunGEAx+EXCUF6BzYSO3fgDrrtamIpqXGaGQyGGoc6nw3VltZ5Jup8
jErsdNOFDVfAFXAFxDOx+OX5f28ykzdfvsq6xKd4QQhhUpHSEHIeZgtDqLUv
7Cj/sYv3HOUjl/jMLF95zg9+d8MK3rGaD6zhEz/yhRGmykLI8FZR/de6YsUh
NDDORibYxFY2s40tbGeMScY5XRLC5yL38L/1jOrMbmCjTu0mNuvEbmFMx3ac
CR3ZrWzTod3OpA7sDnZq3+5iSnt2N3u0a39hr/7YafZpx+7ngAa1Ve69uutX
e0jDynke4ajGNK5LZxOc1JSmNaO/zmc5p3lldOVsgYv6pqX8HZx95w/91LJW
8vdx/ou/tao1refv5XyDm/mtbWVVpWvvN134/n28Aag/T48=
       "]], 
      Line3DBox[{696, 413, 1917, 835, 836, 1964, 837, 838, 839, 840, 841, 
       1965, 842, 843, 844, 845, 846, 1966, 847, 848, 849, 1955, 850, 851, 
       852, 1960, 853, 854, 855, 856, 857, 1961, 858, 859, 860, 861, 862, 
       1954, 863, 864, 865, 866, 868, 752, 419, 710, 668, 1476, 418, 707, 
       1475, 417, 705, 1474, 416, 1472, 415, 1912, 730, 414, 1897, 696}]}, {
      Line3DBox[{1979, 2278, 2281, 1138, 2368, 2279, 2387, 3197, 2182, 1980, 
       2978, 2183, 1981, 2979, 2184, 1982, 2861, 2980, 2383, 2185, 1983, 2863,
        2981, 2388, 2186, 1984, 2982, 2187, 1985, 2983, 2752, 3079, 1986, 
       2984, 2188, 1987, 2985, 2189, 1988, 2986, 2190, 1989, 2987, 2191, 1990,
        2843, 2988, 2192, 2312, 2851, 3186, 2336, 2320, 2335, 2193, 2282}], 
      Line3DBox[{1991, 2280, 2753, 3171, 2382, 2381, 1150, 1992, 2989, 2194, 
       1993, 2862, 2990, 2195, 2384, 2842, 2991, 2380, 2385, 2386, 2379, 3196,
        2377, 2391, 2196, 1994, 2992, 2197, 1995, 2993, 2754, 3080, 1996, 
       2755, 3081, 1997, 2994, 2198, 1998, 2995, 2199, 1999, 2996, 2200, 2000,
        2844, 2997, 2201, 2313, 3183, 2337, 2283, 2321, 2351, 2352, 2350}], 
      Line3DBox[{2002, 2756, 3082, 2001, 2757, 3083, 2003, 2998, 2202, 2004, 
       2999, 2203, 2005, 3195, 2378, 2204, 2390, 3198, 2389, 2205, 2006, 3000,
        2206, 2007, 3001, 2758, 3084, 2008, 2759, 3085, 2009, 2760, 3086, 
       2010, 3002, 2207, 2011, 3003, 2208, 2012, 3172, 2284, 2209, 2314, 2852,
        3187, 2285, 2322, 2354, 2355, 2353}], 
      Line3DBox[{2014, 2761, 3087, 2013, 2762, 3088, 2015, 2763, 3089, 2016, 
       2764, 3090, 2017, 3004, 2210, 2018, 3005, 2211, 2019, 3006, 2212, 2020,
        3007, 2765, 3091, 2021, 2766, 3092, 2022, 2767, 3093, 2023, 2768, 
       3094, 2024, 3008, 2213, 2025, 3173, 2286, 2287, 2026, 2853, 3174, 2288,
        2323, 2289, 2369, 2027}], 
      Line3DBox[{2029, 2769, 3095, 2028, 2770, 3096, 2030, 2771, 3097, 2031, 
       2772, 3098, 2032, 2773, 3099, 2033, 3009, 2214, 2034, 3010, 2215, 2035,
        3011, 2774, 3100, 2036, 2775, 3101, 2037, 2776, 3102, 2038, 2777, 
       3103, 2039, 2778, 3104, 2040, 3175, 2290, 2291, 2041, 2854, 3176, 2292,
        2324, 2293, 2370, 2042}], 
      Line3DBox[{2044, 2779, 3105, 2043, 2780, 3106, 2045, 2781, 3107, 2046, 
       2782, 3108, 2047, 2783, 3109, 2048, 2784, 3110, 2049, 3012, 2216, 2050,
        3013, 2785, 3111, 2051, 2786, 3112, 2052, 2787, 3113, 2053, 2788, 
       3114, 2054, 2789, 3115, 2055, 2845, 3116, 2294, 2056, 3188, 2338, 2339,
        2325, 2372, 2371, 2057}], 
      Line3DBox[{2061, 3014, 2217, 2059, 3015, 2218, 2063, 3016, 2219, 2065, 
       3017, 2220, 2067, 3018, 2221, 2069, 3019, 2222, 2071, 3020, 2223, 2073,
        3022, 3023, 2224, 2075, 3024, 2225, 2077, 3025, 2226, 2079, 3026, 
       2227, 2081, 3027, 2228, 2083, 2847, 3028, 2229, 2315, 2856, 3189, 2341,
        2327, 2357, 2230, 2356}], 
      Line3DBox[{2085, 2373, 2374, 2326, 2340, 3185, 2855, 2084, 2295, 3129, 
       2846, 2082, 3128, 2801, 2080, 3127, 2800, 2078, 3126, 2799, 2076, 3125,
        2798, 2074, 3124, 2797, 3021, 2072, 3123, 2796, 2070, 3122, 2795, 
       2068, 3121, 2794, 2066, 3120, 2793, 2064, 3119, 2792, 2062, 3118, 2791,
        2058, 3117, 2790, 2060}], 
      Line3DBox[{2087, 3029, 2231, 2086, 3030, 2232, 2088, 3031, 2233, 2089, 
       3032, 2234, 2090, 3033, 2235, 2091, 3034, 2236, 2092, 3035, 2237, 2093,
        3036, 1230, 2094, 3037, 2238, 2095, 3038, 2239, 2096, 3039, 2240, 
       2097, 3040, 2241, 2098, 2848, 3041, 2242, 2316, 2857, 3190, 2342, 2328,
        2359, 2243, 2358}], 
      Line3DBox[{2100, 2802, 3130, 2099, 3042, 2244, 2101, 3043, 2245, 2102, 
       3044, 2246, 2103, 3045, 2247, 2104, 3046, 2248, 2105, 3047, 2249, 2106,
        3048, 2803, 3131, 2107, 1244, 2108, 3049, 2250, 2109, 3050, 2251, 
       2110, 3051, 2252, 2111, 2849, 3052, 2253, 2317, 3184, 2343, 2344, 2329,
        2361, 2254, 2360}], 
      Line3DBox[{2113, 2804, 3132, 2112, 2805, 3133, 2114, 3053, 2255, 2115, 
       3054, 2256, 2116, 3055, 2257, 2117, 3056, 2258, 2118, 3057, 2259, 2119,
        3058, 2806, 3134, 2120, 2807, 3135, 2121, 3059, 2260, 2122, 3060, 
       2261, 2123, 3061, 2262, 2124, 3177, 2296, 2263, 2318, 2858, 3191, 2297,
        2330, 2363, 2364, 2362}], 
      Line3DBox[{2126, 2808, 3136, 2125, 2809, 3137, 2127, 2810, 3138, 2128, 
       3062, 2264, 2129, 3063, 2265, 2130, 3064, 2266, 2131, 3065, 2267, 2132,
        3066, 2811, 3139, 2133, 2812, 3140, 2134, 2813, 3141, 2135, 3067, 
       2268, 2136, 3068, 2269, 2137, 3178, 2298, 2270, 2319, 2859, 3192, 2299,
        2331, 2366, 2367, 2365}], 
      Line3DBox[{2139, 2814, 3142, 2138, 2815, 3143, 2140, 2816, 3144, 2141, 
       2817, 3145, 2142, 3069, 2271, 2143, 3070, 2272, 2144, 3071, 2273, 2145,
        3072, 2818, 3146, 2146, 2819, 3147, 2147, 2820, 3148, 2148, 2821, 
       3149, 2149, 3073, 2274, 2150, 3179, 2300, 2301, 2151, 2860, 3180, 2302,
        2332, 2303, 2375, 2152}], 
      Line3DBox[{2154, 2822, 3150, 2153, 2823, 3151, 2155, 2824, 3152, 2156, 
       2825, 3153, 2157, 2826, 3154, 2158, 3074, 2275, 2159, 3075, 2276, 2160,
        3076, 2827, 3155, 2161, 2828, 3156, 2162, 2829, 3157, 2163, 2830, 
       3158, 2164, 2831, 3159, 2165, 3181, 2304, 2305, 2166, 3193, 2345, 2306,
        2333, 2307, 2376, 2167}], 
      Line3DBox[{2181, 2348, 2349, 2334, 2347, 2346, 3194, 2180, 2311, 3170, 
       2850, 2179, 3169, 2841, 2178, 3168, 2840, 2177, 3167, 2839, 2176, 3166,
        2838, 2175, 3165, 2837, 3078, 2174, 2277, 3077, 2173, 3164, 2836, 
       2172, 3163, 2835, 2171, 3162, 2834, 2170, 3161, 2833, 2169, 3160, 2832,
        2168, 3182, 2309, 2308, 2310}], 
      Line3DBox[{2392, 2712, 2713, 2681, 2864, 3392, 2690, 2698, 2699, 2682, 
       3378, 2585, 2691, 2700, 2701, 2683, 3379, 2586, 2692, 2702, 2703, 2684,
        3381, 2587, 2693, 2704, 2705, 3393, 2685, 2588, 2709, 2710, 3388, 
       2976, 2686, 2589, 2708, 2967, 3377, 2590, 2723, 3400, 2977}], 
      Line3DBox[{2394, 2671, 2866, 3199, 2393, 2672, 2867, 3200, 2395, 2673, 
       3380, 2597, 2396, 2674, 3382, 2598, 2397, 2968, 3383, 2599, 2398, 2969,
        3384, 2600, 2399, 3299, 2601, 2400, 3300, 2726}], 
      Line3DBox[{2407, 2870, 3202, 2406, 2871, 3203, 2408, 2872, 3204, 2409, 
       3303, 2607, 2410, 3304, 2608, 2411, 3305, 2609, 2412, 3306, 2610, 2413,
        3307, 2727}], 
      Line3DBox[{2422, 2876, 3208, 2421, 2877, 3209, 2423, 2878, 3210, 2424, 
       2879, 3211, 2425, 3312, 2615, 2426, 3313, 2616, 2427, 3314, 2617, 2428,
        3315, 2728}], 
      Line3DBox[{2437, 2884, 3216, 2436, 2885, 3217, 2438, 2886, 3218, 2439, 
       2887, 3219, 2440, 2888, 3220, 2441, 3319, 2621, 2442, 3320, 2622, 2443,
        3321, 2729}], 
      Line3DBox[{2452, 2894, 3226, 2451, 2895, 3227, 2453, 2896, 3228, 2454, 
       2897, 3229, 2455, 2898, 3230, 2456, 2899, 3231, 2457, 3324, 2625, 2458,
        3325, 2730}], 
      Line3DBox[{510, 1547, 511, 1548, 512, 1549, 513, 1550, 514, 1551, 515, 
       1552, 516, 1553, 517}], 
      Line3DBox[{2467, 2906, 3238, 2466, 2907, 3239, 2468, 2908, 3240, 2469, 
       2909, 3241, 2470, 2910, 3242, 2471, 2911, 3243, 2472, 2912, 3244, 2473,
        3327, 2731}], 
      Line3DBox[{2482, 1745, 2481, 3328, 2627, 2483, 3329, 2628, 2484, 3330, 
       2629, 2485, 3331, 2630, 2486, 3332, 2631, 2487, 3333, 2632, 2488, 3334,
        2732}], 
      Line3DBox[{2497, 2921, 3253, 2496, 1760, 2498, 3341, 2639, 2499, 3342, 
       2640, 2500, 3343, 2641, 2501, 3344, 2642, 2502, 3345, 2643, 2503, 3346,
        2733}], 
      Line3DBox[{2512, 2924, 3256, 2511, 2925, 3257, 2513, 1775, 2514, 3352, 
       2649, 2515, 3353, 2650, 2516, 3354, 2651, 2517, 3355, 2652, 2518, 3356,
        2734}], 
      Line3DBox[{2527, 2929, 3261, 2526, 2930, 3262, 2528, 2931, 3263, 2529, 
       1790, 2530, 3361, 2657, 2531, 3362, 2658, 2532, 3363, 2659, 2533, 3364,
        2735}], 
      Line3DBox[{2542, 2936, 3268, 2541, 2937, 3269, 2543, 2938, 3270, 2544, 
       2939, 3271, 2545, 1805, 2546, 3368, 2663, 2547, 3369, 2664, 2548, 3370,
        2736}], 
      Line3DBox[{2557, 2945, 3277, 2556, 2946, 3278, 2558, 2947, 3279, 2559, 
       2948, 3280, 2560, 2949, 3281, 2561, 1820, 2562, 3373, 2667, 2563, 3374,
        2737}], 
      Line3DBox[{2679, 2678, 1869, 2571, 2956, 3288, 2572, 2957, 3289, 2573, 
       2958, 3290, 2574, 2959, 3291, 2575, 2960, 3292, 2576, 1835, 2577, 3376,
        2738}], Line3DBox[{883, 1924}]}, {
      Line3DBox[{934, 1313, 1139, 3197, 935, 1438, 1150, 960, 3083, 1160, 972,
        3088, 1171, 986, 3096, 1184, 1000, 3106, 1197, 1014, 3118, 1210, 3015,
        1028, 1223, 3030, 1042, 1236, 3042, 1056, 3133, 1249, 1070, 3137, 
       1262, 1084, 3143, 1275, 1098, 3151, 1288, 1112, 3160, 1301, 1126}], 
      Line3DBox[{936, 1140, 2978, 937, 1151, 2989, 961, 1161, 2998, 973, 3089,
        1172, 987, 3097, 1185, 1001, 3107, 1198, 1015, 3119, 1211, 3016, 1029,
        1224, 3031, 1043, 1237, 3043, 1057, 1250, 3053, 1071, 3138, 1263, 
       1085, 3144, 1276, 1099, 3152, 1289, 1113, 3161, 1302, 1127}], 
      Line3DBox[{938, 1141, 2979, 939, 1445, 1446, 2990, 962, 1162, 2999, 974,
        3090, 1173, 988, 3098, 1186, 1002, 3108, 1199, 1016, 3120, 1212, 3017,
        1030, 1225, 3032, 1044, 1238, 3044, 1058, 1251, 3054, 1072, 1264, 
       3062, 1086, 3145, 1277, 1100, 3153, 1290, 1114, 3162, 1303, 1128}], 
      Line3DBox[{940, 1442, 1443, 2980, 1444, 1448, 1314, 1447, 1315, 2991, 
       1437, 1434, 3195, 1435, 975, 1174, 3004, 989, 3099, 1187, 1003, 3109, 
       1200, 1017, 3121, 1213, 3018, 1031, 1226, 3033, 1045, 1239, 3045, 1059,
        1252, 3055, 1073, 1265, 3063, 1087, 1278, 3069, 1101, 3154, 1291, 
       1115, 3163, 1304, 1129}], 
      Line3DBox[{941, 1450, 1451, 2981, 1452, 1453, 1454, 1436, 3196, 1433, 
       1457, 1458, 1459, 1456, 3198, 1455, 976, 1175, 3005, 990, 1188, 3009, 
       1004, 3110, 1201, 1018, 3122, 1214, 3019, 1032, 1227, 3034, 1046, 1240,
        3046, 1060, 1253, 3056, 1074, 1266, 3064, 1088, 1279, 3070, 1102, 
       1292, 3074, 1116, 3164, 1305, 1130}], 
      Line3DBox[{942, 1142, 2982, 943, 1152, 2992, 963, 1163, 3000, 977, 1176,
        3006, 991, 1189, 3010, 1005, 1202, 3012, 1019, 3123, 1215, 3020, 1033,
        1228, 3035, 1047, 1241, 3047, 1061, 1254, 3057, 1075, 1267, 3065, 
       1089, 1280, 3071, 1103, 1293, 3075, 1117, 1306, 3077, 1131}], 
      Line3DBox[{944, 1143, 2983, 946, 1153, 2993, 964, 1164, 3001, 978, 1177,
        3007, 992, 1190, 3011, 1006, 1203, 3013, 1020, 1216, 3021, 3022, 1034,
        1229, 3036, 1048, 1242, 3048, 1062, 1255, 3058, 1076, 1268, 3066, 
       1090, 1281, 3072, 1104, 1294, 3076, 1118, 1307, 3078, 1132}], 
      Line3DBox[{948, 1145, 2984, 949, 3081, 1155, 966, 3085, 1166, 980, 3092,
        1179, 994, 3101, 1192, 1008, 3112, 1205, 1022, 3125, 1218, 3024, 1036,
        1231, 3037, 1050, 1244, 1064, 3135, 1257, 1078, 3140, 1270, 1092, 
       3147, 1283, 1106, 3156, 1296, 1120, 3166, 1309, 1134}], 
      Line3DBox[{950, 1146, 2985, 951, 1156, 2994, 967, 3086, 1167, 981, 3093,
        1180, 995, 3102, 1193, 1009, 3113, 1206, 1023, 3126, 1219, 3025, 1037,
        1232, 3038, 1051, 1245, 3049, 1065, 1258, 3059, 1079, 3141, 1271, 
       1093, 3148, 1284, 1107, 3157, 1297, 1121, 3167, 1310, 1135}], 
      Line3DBox[{952, 1147, 2986, 953, 1157, 2995, 968, 1168, 3002, 982, 3094,
        1181, 996, 3103, 1194, 1010, 3114, 1207, 1024, 3127, 1220, 3026, 1038,
        1233, 3039, 1052, 1246, 3050, 1066, 1259, 3060, 1080, 1272, 3067, 
       1094, 3149, 1285, 1108, 3158, 1298, 1122, 3168, 1311, 1136}], 
      Line3DBox[{954, 1148, 2987, 955, 1158, 2996, 969, 1169, 3003, 983, 1182,
        3008, 997, 3104, 1195, 1011, 3115, 1208, 1025, 3128, 1221, 3027, 1039,
        1234, 3040, 1053, 1247, 3051, 1067, 1260, 3061, 1081, 1273, 3068, 
       1095, 1286, 3073, 1109, 3159, 1299, 1123, 3169, 1312, 1137}], 
      Line3DBox[{956, 1317, 1318, 2988, 957, 1319, 1320, 2997, 970, 1321, 
       3172, 1322, 984, 1323, 3173, 1324, 998, 1325, 3175, 1326, 1012, 3116, 
       1327, 1328, 1026, 3129, 1329, 1330, 3028, 1040, 1331, 1332, 3041, 1054,
        1333, 1334, 3052, 1068, 1335, 3177, 1336, 1082, 1337, 3178, 1338, 
       1096, 1339, 3179, 1340, 1110, 1341, 3181, 1342, 1124, 3170, 1344, 1345,
        1346}], Line3DBox[CompressedData["
1:eJwVz1dSQkEQBdChLP/chGsxBwyYI4qYBUQxZ0XM+UO34CZcm6c/Tt2a2696
5rUWKrlyJqVU5K8ppc/mlL5oI888Oy0pDcsFFmlniYq+IHMUWaaDXf2qXGGE
NdbjrO+Um2wwyhal+MasK3ZSZoxtavqq7I698RbGqeprco8eDtiPs35CHnJE
Lyccx9xsUp5yRh8XcY/+XE5xyRX9sVN/I6+Zps4t2dhvdicbzHDPQ/yPfkA+
8cgsz/EW/Ysc5I1X5niPt5l9yCF++OaXf70ZL5Q=
       "]], 
      Line3DBox[{1125, 1300, 3182, 1343, 1111, 1287, 3150, 1097, 1274, 3142, 
       1083, 1261, 3136, 1069, 1248, 3132, 1055, 1235, 3130, 1041, 3029, 1222,
        1027, 3014, 1209, 3117, 1013, 1196, 3105, 999, 1183, 3095, 985, 1170, 
       3087, 971, 1159, 3082, 959, 1149, 3171, 1439, 1441, 1440, 933, 1138, 
       1428, 1430, 1429, 1316}], 
      Line3DBox[{1133, 1308, 3165, 1119, 1295, 3155, 1105, 1282, 3146, 1091, 
       1269, 3139, 1077, 1256, 3134, 1063, 1243, 3131, 1049, 1230, 1035, 3023,
        1217, 3124, 1021, 1204, 3111, 1007, 1191, 3100, 993, 1178, 3091, 979, 
       1165, 3084, 965, 1154, 3080, 947, 1144, 3079, 945}], 
      Line3DBox[{1955, 1472}], Line3DBox[{1960, 1474}], 
      Line3DBox[{1961, 1475}], Line3DBox[{1954, 1476}], 
      Line3DBox[{1645, 1829, 1869, 1631, 1815, 3277, 1617, 1801, 3268, 1603, 
       1787, 3261, 1589, 1773, 3256, 1575, 1759, 3253, 1561, 1745, 1547, 1731,
        3238, 1533, 1717, 3226, 1519, 1703, 3216, 1505, 1689, 3208, 1491, 
       1675, 3202, 1477, 1666, 3199, 1846, 1460, 1658, 3392, 1879, 1887, 1886,
        1953}], 
      Line3DBox[{1646, 1830, 3288, 1632, 1816, 3278, 1618, 1802, 3269, 1604, 
       1788, 3262, 1590, 1774, 3257, 1576, 1760, 1562, 3328, 1746, 1548, 1732,
        3239, 1534, 1718, 3227, 1520, 1704, 3217, 1506, 1690, 3209, 1492, 
       1676, 3203, 1478, 1667, 3200, 1847, 1461, 3378, 1659, 1880, 1907, 1906,
        1958}], 
      Line3DBox[{1647, 1831, 3289, 1633, 1817, 3279, 1619, 1803, 3270, 1605, 
       1789, 3263, 1591, 1775, 1577, 3341, 1761, 1563, 3329, 1747, 1549, 1733,
        3240, 1535, 1719, 3228, 1521, 1705, 3218, 1507, 1691, 3210, 1493, 
       1677, 3204, 1479, 3380, 1668, 1849, 1462, 3379, 1660, 1881, 1848, 1908,
        1959}], 
      Line3DBox[{1648, 1832, 3290, 1634, 1818, 3280, 1620, 1804, 3271, 1606, 
       1790, 1592, 3352, 1776, 1578, 3342, 1762, 1564, 3330, 1748, 1550, 1734,
        3241, 1536, 1720, 3229, 1522, 1706, 3219, 1508, 1692, 3211, 1494, 
       3303, 1678, 1480, 3382, 1669, 1851, 1463, 3381, 1661, 1882, 1850, 
       1975}], Line3DBox[{1649, 1833, 3291, 1635, 1819, 3281, 1621, 1805, 
       1607, 3361, 1791, 1593, 3353, 1777, 1579, 3343, 1763, 1565, 3331, 1749,
        1551, 1735, 3242, 1537, 1721, 3230, 1523, 1707, 3220, 1509, 3312, 
       1693, 1495, 3304, 1679, 1481, 3383, 1855, 1854, 1874, 1888, 3393, 1853,
        1883, 1852, 1974}], 
      Line3DBox[{1650, 1834, 3292, 1636, 1820, 1622, 3368, 1806, 1608, 3362, 
       1792, 1594, 3354, 1778, 1580, 3344, 1764, 1566, 3332, 1750, 1552, 1736,
        3243, 1538, 1722, 3231, 1524, 3319, 1708, 1510, 3313, 1694, 1496, 
       3305, 1680, 1482, 3384, 1857, 1856, 1875, 3388, 1896, 1843, 1895, 1842,
        1973}], 
      Line3DBox[{1651, 1835, 1637, 3373, 1821, 1623, 3369, 1807, 1609, 3363, 
       1793, 1595, 3355, 1779, 1581, 3345, 1765, 1567, 3333, 1751, 1553, 1737,
        3244, 1539, 3324, 1723, 1525, 3320, 1709, 1511, 3314, 1695, 1497, 
       3306, 1681, 1483, 3299, 1670, 1467, 3377, 1844, 1894, 1956}], 
      Line3DBox[{1965, 1897}], Line3DBox[{1966, 1912}], 
      Line3DBox[{1917, 1946, 1964}], 
      Line3DBox[{1931, 3376, 1944, 1930, 3374, 1943, 1929, 3370, 1942, 1928, 
       3364, 1941, 1927, 3356, 1940, 1926, 3346, 1939, 1925, 3334, 1938, 1924,
        3327, 1937, 1923, 3325, 1936, 1922, 3321, 1935, 1921, 3315, 1934, 
       1920, 3307, 1933, 1919, 3300, 1932, 1918, 1947, 3400, 
       1971}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXdUVMu29t0IooAgKiCCgCKCGRMIKk6VIIgkRQEBQVBRRAwYUAyIgEiS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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{359.378534289469, 145.34878172782152`},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 0.5}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{-0.800761773594684, -3.276689967761127, -0.26848358818197093`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.6043506547346854`*^9, 3.60435074572889*^9, 
  3.604350886730955*^9, 3.6043509967662487`*^9, 3.612977923225749*^9, 
  3.6129780334310527`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Simplify", " ", "the", " ", "complex", " ", "ecpression"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"FitDisneyDiffuseComplex", "[", 
    RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6043509500485764`*^9, 3.6043509550128603`*^9}, {
   3.6043510172384195`*^9, 3.604351019070524*^9}, {3.612977952622431*^9, 
   3.612977961238923*^9}, 3.612978010519742*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"0.08630177573518154`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.17260355147036308`", " ", "Cos\[Theta]V"}]}], ")"}], " ", 
  RowBox[{"Log", "[", 
   RowBox[{"0.7896915070171395`", "\[VeryThinSpace]", "+", 
    RowBox[{"28.04254269803164`", " ", "Roughness"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.6043510228337393`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Look", " ", "for", " ", "a", " ", "simpler", " ", "expression", " ", 
    "than", " ", "the", " ", "one", " ", "above"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FitDisneyDiffuseSimple", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", "=", " ", 
   RowBox[{"Lerp", "[", 
    RowBox[{
     RowBox[{"0.28", "*", "Roughness"}], ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "*", " ", "Cos\[Theta]V"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.60435124890767*^9, 3.604351266071652*^9}, {
  3.6043513292512655`*^9, 3.6043513691855497`*^9}, {3.6129779647591248`*^9, 
  3.6129779799109917`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.28`", " ", "Roughness"}], "-", 
  RowBox[{"0.56`", " ", "Cos\[Theta]V", " ", "Roughness"}]}]], "Output",
 CellChangeTimes->{3.6043513695085683`*^9, 3.612978038953368*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "the", " ", "final", " ", "fitting"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], ",", " ", 
      RowBox[{"FitDisneyDiffuseSimple", "[", 
       RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}]}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.5"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6043513745318556`*^9, 3.6043513790121117`*^9}, {
  3.612978018824217*^9, 3.612978023687495*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJzsnVdYVEsTrhFzxpww54SIOS4jYkAFc845R0TBiIqJJAiCIFmSCKgISBIE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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmgfUVDXXhe+8c71534yIiKJYKAo27L338vlZsAOCnWIFC1ixgCAISrcj
CIggdkAURQFBBQSkib1gBRGwYVf+Z7Oz/m+tyTr7ZpI7meTknJN90viiTqd3
rMqy7JlylvHJJudZdlEpy15EtqN8Rl1bZG/qOlMqlC6UExJeGrJsF9pcgVyB
3JC6jZDXpjaR8i7fbUPdxcj7eNcm1F2O3J+yhPre/HANdYHyOc8f026CxoT8
iPIYeCxyMWUmeBHyVPqeAK6h73s8H6zfRP5F2ZH3rET+SN3G4P8iP+T5XuRw
5Bf0uRDcAHkF359J+Z3nNTxfhdwF+RPlGvDuyJn0aQX+qMiyDfjdPuBjqO9I
v5aUv3kO1N+NPI76AtwXfCz4DfpeAv6NvpfT9nTKrzwv4bvTkLWRq/Qu8M7I
7ylXgndCrqZ0AjdDrtRYwTsiV1AuA2+PfJdyuv4n8jvK5eAdkB/wu3eChyC/
q/E8vFp4HBrPSuoOpq4J5V+ez2HMQ5DN6dsGPAp8LvhN+v+T5v9Q2jalZJTl
wXKj6iybBV6X1usC+k4H30jfb4PfXaHNGn5vC9ofRF0j5F6UX/huUG48EFkq
uc3r1P9Auz2FkQ2Re1B+or6MrE9ZCO6fe22vR55P3Q6UKsqKYDkXeR7fjafN
5YxnA8axLfVfaU4oOXgB8mzaXEebvaUXJeuPvlubWVc1Xz9T6pSsB+/T53pk
L+T+Jb/zT+kA798O/DX1P1Mag79E1lR7nr8BH1hyG+lMS363J/JI6Vualy+Q
p5WMNT/VtLkHeTxtzij5ndKfZcHfa35qaNMP/B/a1AYPBp8C3gg8CHwyeBbl
aHAV8i3KUVo+rS/lyCxbv/nrlbzW2icTed4Z+T3GYQJ4J+kMuDZt1mTe85eA
T6L8AJ5OmwORf1bZljQFfwM+nu+/B39HqVWyjZB9eDXtWenkcNpvCP6E9kNl
C8DvgZ/gu33AV9F2GPUV7UHqXym7/hfwy+C9tT7gyeC9wD+B5/Dfv9Z+RP7I
C7cFD+V99VmLKdTtzcsep/2O1K+g/Tjw7uDV4Dv5fiPG2gH5JPV7yDZQPxq8
A3g5uCnvWcT3+/KeSdQfTv0/1L8E3hP8I7gT7zgn7a/x1B+A/J3658D7gX8F
Pw/eX/YBPJP3dZPOI1+k/gjq/6X+BfBh4L/B/XLvhXuQj1Afqf+A+gfB2pIL
wT+CrwbvhvyNchN4X+TPlGvBeyD/oHQF74/8m3Ib+CDkX5RbwQci11G6gQ9F
/km5BXwA8hdKZ/CeyE0Zyx+Z90MtxjQQeRL1m1H/V2YbtJbnLsi9kFW06QE+
Qs4G3B1xmGwe7c9O+6hE/R3Iw6n/nXIzeD/k9OD9Ppd1HMNzfdl1/u/DPDcG
t+P7weB64PPAI2mzidrTZhD1m8mmUX9/8nVvU9+/cJtzqH+gvH5I2TzpAGPp
SdmU57uQt5asTx3kTyirwY8U1vNL6Duq7N9dTN+x4C3BH0uHwVuBP62yTq3K
7AsHyeZRbqE8Vfb4v6LN02Xr6tfgvrn3yHWaj9z9OiNfCd5znyEP4PldjZF+
h4A/AN8D/g/vLSgbUA6m/n3q79YeBS8F99FeAc8FdwcfBH4P3Be8G3g2+Fbw
+Nz29hrtGco86u+QzqB4TXh+g71VsAf2BL8D3gc5nzY9aHMjbT6TPjHO/ahf
IH3geV+1BffU2tJmGfJ22mxP/WvUd5H9AL+q/6s9B56qeQC/FDyHijdepDQA
t5Ve0GZr8OfM2/c8b82YP0E2KxlrvT4NluuQ7Uq2TSt5Poq+nyIHa8+BPwYP
BDcCTwZ30v4GfwQeIJsBniadB+8KngW+BbwL+C1wV3Az8Jvgm8HbMD+n8DyF
330mt4+7Grmz5o82N9HmJHAz8CrG37Di+Gaa9Crajj8OfkN6QN83kZ8z19vR
vpH8b25dnY1cnFuvlmq+Kf3lK7Vu8iPg+chjKb3AbyNHaO7B0zV27c1U36Ri
Xz4/2F/Kx/2iWI/6wbKpqqvYv84Bz2MvnEqbTRjPntRPoP5P6v+mHCO/gnyN
NqeA69DmBb4/DjwJuSXPrykOoN/U3HtNY17Gf/+S8T3Jf10O/gH8PHg1OMpG
1ti/yifW4x316f+o9K3G8d+O6Xd/of3m0ifqvwP/Q5sJ4P8qXlHMQd+DFSuA
Nwe/q1gozeEM6i9L/2sq+NI0/rrVjuc2Rc6j/urUdxPGcBj9PuT9C6m/Jr1/
s2rHmhrnq/z+sTJ/ZevFQeC/WPdd+X6b5E+vTHHFDfLBvOtB2u3Ku1eBHwHv
VrEtkm5rDyh23irFz9eVvP+3LNleyG50Q3bJ7bd75h6X4qUZmf3zTiX76I4p
PuklPc4dC4xA3p475npe65M7Pn8CeVvueO3p3PtO72mb5mN7ykTpdPDvN2XM
NzH/n8vfpLlsQDkk8xruk2IbnRGE70UOz+1Dbs6td4q/bpD+pv+i/zQ5/G9/
99Hc0Pcu5K/BY9+B3x2V/ov+0zDKASXP44254zv91g3p/YpFteaKO0/MHF/K
78jnXpdsst4v/6647j6eH+J5v5LX6eHc/vCm3DZa61nFul9Vcvw8mufm6f2K
aWex9nWQM2h/PEXnsZdy63Ij8BdUbF1t/9MY2ZDvXtJa8X0D7QPpi+Jt+RDK
xvIx1E+SnVR8B/5EPgd8drAdXo4evRwcy+nc1L7k/Sh7eHTuc98Q+RFwLfka
xnCsYliNh/JKbn27Ftm25O+Wy2/VOKbdIHieFR9cqbXgXXfJ1sr38vwA+FTw
yNyxQkfZtOD5eA35TY3PI5uAN9RcgFspBpROgFvKV4MfBJ8G3gL8DLi9fC/4
OfllxQjgZ+W3y16juvzWFci12KIO1H/J7/zLdwPA/1W8wHdPgC8A1wGPBZ+v
2Cf3OXS0bHHuWLkTcmPKGMUbZcf92jtrkVN5Pp76ArmYcgF467LnuH3aa7I9
Om/kKabokPay6vTdosw27MKEj099tUbau+en/btxtfWnFb/bnf31Lb/TE3w7
+GvwHcF25ZJkW05KeFfwbbT5ijbdg+2b5l/rcGuyvd20d8HfgHskv9oh+VOd
78UFVJfMG1xcst5KF6QTJe2L6HjuEfo+En1+HqFYKzq+fBj8cHRcOAw8KDpm
vQ88IDp2HAx+UIEubYYGz4P8d2357OgY8X6d76Pj1AeD9VTjka5+mZnT0L4a
Eh37PpDsveZQZ8We0efqu8RRRMfBD4HvAC8H3xm8djek+Zd9lZ1dDP43OnZ5
C136JrV/DvxWOv/qHPx5inPGUf9Vms9nwF+k+X8K/Gu0vk6VX0tr9zQ4VByr
LQB/Qv2n1I8Bf5Zs6RPgn6L19RXwj9F6+TL40xSDjQX/EL2XJoO/BZ+ZW/+/
TjrzLPjn6D0wBbxBxbHgfHB1xfHfQnBecdwzD/xntD2aAa6qOO55G/xb9D6c
Bv4rOpaaqYNdxfHTbPC66NhuFvif6JjvTfDv0fZrOviPaBv3OrhUccw0B1xT
cay5CFypOL5cAt6okmJccK1Kio/BseK4czG4dzTPcjfrUq44bptL/dpoO/Ia
uFc059JXPEo0t9IHfFc0X3NPOqcr5jknM69zRvJfsuvNk+8YFs0HjQxuqz46
tzdKWH3VT/0vBQ+P5pJGBcdKzZOPKFd735aqzSe0Aj8azF2dVTJ/pbanpN/N
qx079A72sScnP6v3CMsfNU5j1u8+Gs01PBZ8DrsyxR7bJqxz2bzwP36lTcn+
TL5sYeJSxKk0TfXa/J2TfRBPWLuSzhjM7WPRPMWY4O87JxsinyL8cm7bIg5x
WWaOrWOKSRRHaby/F47BNH8fF47TNK/Lkg1We3EsG9KmdckclHy1fPZ6vith
+e410X7lpRqPv3X6X+qrdjHFq+ItllU5ppU9bikeKPk+/WXZ5uOTbVfsJRuh
89dNCctWiA89If3fG1N72TH5zmOTvVLcdG7JsVOfaB6wH791d/TZvj+4drXb
iH/rH30mH0T9PdHc5YBg23Ze8hH9os//A6m/OY1hWfIvRyUfNDtk/8/tictq
Ab436UOLpAPyIycm31FUe03URtya9FD6pvVqlea/utpzLF3Nqt13XcLyef+m
M9ERJceQ4yiHlRxbPpnizPXxZoo/FYfK9x2R7LbOpxq/4lLNifSyFvLZFJcq
Pv2D3ziyZK5vVXTcMIm1/j46FnkBvCI6RhlfY9+4TfqPY5Lfl/8/VLZHY6Dd
pGj+qBvtX4zmj7qDX4rmjO4AvxDNGd0OnhLNAfWS7a3xue9ExrOsxufWB9Hh
CcGxW7/CZ6aY9OSd4P9ygmLJGnMSA2nzU405DXEbDysGAi9FP5cEz1UL5CvR
HNOdiveiuaee4AnRfW4BLwAvkC8GvwN+R75P5xfwQvBQ8CLwIvAj4MXRMc0w
8Lvg98CPgueD58v/gqdGc1h9wK9Fc2R3gZ8EN1ZMxtieAG8Ffgo8BryZ1hw8
Drw1+Gnwq9H8V2/6PgXeVrEd9RODYx7FPs9QvxP1z1P3LHh38Hjw++AP6TuK
vnvIN9L+Gp43L5mv1rpqvC2R9ZDzKC1kY8rmpcX3XiY94vlk7V3kNMXE4ICc
ofObXFrZvJw49kvlPxTnKQZGvk9pq7i97LG0B29X9ryeJztR9ny3AW+B/IDS
Tna37DU5F1xffQuP8wv+y0dlx65Nyp77i+VPkDMpzWW3kHMV64M3Rb5NOQtc
t+w5Hgo+C7ypzirgM8H1FKOBzwbXBT8kv1T2+owAty7brrdJtl1z/DLw6rLX
c5xirLLX50nFXvrd4P0rzn8Oz2eCN0G+QTkVXAu5TbXPOA1kY2nXUDEj/7V7
br64fW5dGEl9m3JaZ/Bl4O2kO+C2Zevm+eCtNCfR8ziSuXo8+n+OE1/Bb/Qp
+QylvSMupCXfz819bpbfua3kNk0ycyYMJVtQZV727pK5kjlV5gzFmfRN9dJF
8RbiCrUnm1SbbxEPqXeK7xPXJ25B716Sm2tRe53rBiAHl8wnDkzt1a4rsl/J
3OKS1Ff89YeM+/Q86QP4Y/7vaPDH4E/Aj8s2VNLZD7wl+N6yzwh1K4nPUixa
49zHr+Laqb+vbC50ZfS5aGKN/ZL8nGLqOpXEM8oOVRJfBq5XSTwaeMeKz0i/
iw8A358737RzxefzFeDtK+bZ19Bm94rt/uoac1aav3eQm1fSWVS5I/DFuc+t
S6P31Qi9p9r8f6dgTl7zqHzBrGg9G0ybN6P36kDwnGhdvBc8OlrXnwhew25p
HXWO7l7yWVqcvLDO5uLfNtDYWP+3ovfbIN4zN3q/3Q+eF21HHgC/Hb337pO9
j7YjA8Azos+H/cDTo/mgu8Ezo+1Lf/Dr0XbknhrbfHF+LaK5vrqyW1XWnR5J
36Tb0r+tqs2nSdc0J6/m5gmnyW9WW5/EV4v/E8ctXyI+UDqonMkH0fblsRpz
h9K9rkkfb0s6qdjh5hTXNaw2JyleXVykfqtDms++ab+Iq1Qe5qLoOEjxkLjp
IUnntWYbVxJPXeOYSLGReCnlzBS3/YYcGZ1jGA2+vzDHfgF4NvWzGfMQ+naJ
zokOl54gL1I8Ljtc2B7KFzRN9vMMnX8K22Gdjz4Dt868j5YVtr06Z31Q2C9o
Tt4Fn5HZ331S2G5rrylvp5hefODSwrZO+qm8lPRTuaKnCuebFAM8yxj2Ba/l
+ycL55Xkoy+Nzp/1AI+jfvvM/np64RyT9G1q4XyQ9Hka+NDMevVeYTsvu7eo
sI2Vj15Y2C/Idy8o7LPk09tG51EuFf8Tnau4HHxJdB6iI/iC6DxKe3C76NzG
ZYoto7lj5VyuTzanK7hzdG77JvBl0bnDq8EdovMcV4KHF45VFDt9Xdhu6ww7
uzBnor3zeuH8l/bvtdH5S62v1lnzXwf5puKkzHtZOT/l/sQjv1WYX9W+m1/Y
dyu2mVPYdys+2Tz5/dNo/w71J2WOeWYV9t3ay6ML+yPFdeLlxc+fqHiwsM9S
jCduSxzX0NwclrisR3PndpX/apWbbxLv9EDuXLPyZS1yn79/ky/OzSWJU3os
dz79XGTjivPvrcGNkv3W+UB3M44KjkUV5xwYnHNX/COfqzy6OHnlj3aXf0JO
ZA4fo/9tNeZLdynZ9k6O1kXpm3L0T8leVJx/HwBuluyu+GXdA1HsehFyw4rj
UuXjlSNQfkh5oudyc4LiBicir0u+6WbaXJU79hqb23etTXtwStnrWEYuid63
2r/PM8+7ZY79Xiy8X2QnO0XngPsq3i6cS5WdFIcuLv3k3PdCTgA3B08unGOV
vR1fOJ+ruPS5wjlfxaVjCudtpZ9jC+uS9F/+8EvwMbm50BWyf7njQsWHmqP2
KVZRLkP3WnRnYEjuXJX0ZauK72BoHRpUfO9F50LNozhYjXdr6i/JnV/vnTv3
rHxhD70zOh9/jeY5On9/o+YzOu9+PXhN4ThTnNLKwnZPnNKqwvGheKSfC8ef
4qZ+LBxnivPpG333RbkV5Ub66z8iDwnmkMXn7B/Mqc5OMYN0tgf99g3mXcV9
HR7MS4sXUq7mdvDBigmDeVpxSs2Dc4uKH04KzpGJq1F+5mlwO/nR6Jy0cjRH
BOfgxEE9HR3zKeeo3OMU6q+l3T7BfcUd6cx4eMl6fFgwNy5up1Ew5yx+bL9g
Tli806HgFzJzSmcG5y4Vw5wenBtVbHNGcN5TcZTOaTqvXUTdWcF5TMUn9xXO
R58vP1X47oTs5KjCdkN29YHCueALNQdVzkFLr3QvQTlf2dgBhf176+Aznvxz
G53HKTdmPp/qbo32+/m5+XbZkoHMzW60eTwzb1YreP4Vv63PR4H702/3YE5b
fN1psheZ48Dno8+3ylvtEcyBi6/bNZjfFv+mnMuuST91dtUZVtzajsGcvHjL
IcX6o/36c6XsjfzXt1W+d6E4QjFIq+j7Cl1p0zr6HoP8+DnR9z80hw/pnEbf
JfQ9Kzpnrzk5OzpPrzm5ODrvLpumOx7Kf15I3bDCfXXu1vla+/W86PO17Ock
5NXRd19uAF8RfW+jM/jK6HskXYLzx+tzx+m8KTuwHePvGH3v5LrgM4viROUc
20TfU9H6nht9r0V6Mj76/+j/jo0+aykXKV5C9nIP9v6I6Hs8ymnuFJzvEHd6
XHDuW7zlc9HnWOXZe5Wdx7mQ51OCc9DrY6fg3LS4UN150t0n+ZKTg3PT4t92
AA/LzHM2ViyVmStWDl/60I1+RwfvL3HOxwbn5cW1Ku+qvi10NgzOm4hP3jLY
bohD2xTcOzOvckM0X31LcE5H/nAodd8WzomID9c9s1GZ/dwxwXl/8cxdo+/q
Kf9bNzh/JN5G54l9kz99ufC9GsXMIwrfU1I8o/sSzZL93D74nChuQfnEA5OP
3ib4bKt4cq/g86x4CeUrd07rrnyr8o+6T9ck+Jyr80LT4HOuzpUNg8cvPrNB
8FlV+XrdY5S/07lm72D+QdxFs+AzrHgP5SUPTn4/D74bIx6vHHwHRnzd5sHn
dHHIyi3un+KNLYLP8uKKp0X7UflE5T0PSjHzLsE6IC5F+YhDSj6X1Q8+74vv
VX5Z+Urda/ur8H0bcd1/FL47pJzIp4XvFsqPf1X4jqLWdHnhO4rK535R+I6i
4sAlhe9YKg7UvR3dn9N9hl8K3wVSfuqnwveIlFf6vvCdJeWbfih8T0l5q+8K
38nU/ZBvCt+T1H0S3Zfbu+R7CBML32HT/tW9Mt371F2LKYVjAPnH1YXvcyrP
9UbhO5PyoTML38OUHdA9UvlfnU8nFb4vt36PF74vJ5ugvKbym8pJPVs43pBf
fqbw/TfFurqDenTJ9x9KwXeoxNnqjK2ztnJJVcF3n8TTrit8/0ocb71g7kU5
sprge6TKbf1b+F6W8g6V4DuBynPVDr5zpTzahsH3AJW3qhN8D1B5txh8N1U5
L+VTlVdVrm3j4PuByqn9U/h+l3Ii4jwPTXFadfB9V+Xj/i58Z0w5kf8DFLnH
DA==
         "]], Polygon3DBox[CompressedData["
1:eJw1m3nAVlMXxe/znOve976vORRFoUFlzFSGFAmZx4QMmROKkKlSSkKGCJnS
YEhkKENSStKsWTIlQqUUUeZv/azz/XF7z7r73OG555y91177tGuHa0+7ppwk
Sd2QJKn+rhHYU39/0nGCTjxamSTHyjZAePM8SQYVSXK02pvp3EzZHhc+VrhC
eI7wY8LHCOfCs4Wv1VFW+yidezNLkkdkb6V2qnMzZHtd547AJjxB+FHZWwtn
wrOEz9dxnN5jpc5drOePkr2D2nVkXy7bA8KHC/+l9/5Q+FXdr7nwWNnfE35S
Rztd/6fOPaPrb1f/CrUXqf8bsm2vc4/zPuqzRvglXX+Q8Ku6fpzwnTrOlG2j
zt2lvrV0cY9Skryvcx1ke0T9dcvkSfU/R3iU8MHCrwm/K/yE8LbCQ4UvFB4k
rD/JU8Ln8r2EN+fdhNsLP1T4e/yj9/tI+MHCv+dv4anC2+j5J+n5P+vcRL3P
QNlbqP2v7NNk7yNcX/iHst9/Z/Xvqf7P6v4X8H1kvyyO93d8bz2/Svhp4fOE
38o8PuOF3xe+X/2bCv+u+00Rni77WcKz4vi8kfn5bwlPFO6qd2oZ36eT8A3C
Rwonsl9d6W/Gt9tdp5bp3jfmnhsl2a+RbaXObaX3vUJ9GunFRuv+jeNcrCX8
iuyXCO+m/t+q/8U6vtOz6vFN1ffFzO1XZL9Stot4Z13bR/e8XM+6TUcn2RvI
fpNsz6h/A+ERwmOFt5T9Ab6/8OpK33MH4WHBz9pC9vsZD+FVwtX1fbvo3mN0
7lDZXsj8297TM5vofa/RuSbC6/WOV6j/fYXn10bhycJTZP9V+DT1Xyp8nfAh
wn/IfpVwDd3/Ot3/A51rI1vfwu+7suz5NaDwfNsk/IHwXcJ7CK8SHi88Te9z
pvDMuF4/Ej5DeEZcfy9nHt/Xg/v30/V7C68te/30F95XeF3Z43uv8IHCvwlP
Eu6id2oW50dH4Xdlf0z4VN3vZ+HrdWyt9mk696Gedav6X6V2fZ27Uba71X8f
/E3Z63+08KXCu8u+gvcTvlh4V+FvmE86dlH7Ip1bqPtVy/28oO/3I+tFR1u1
f9e5h2Vry28W3o7foHs9peNktbfQPebLtp/6vIM/wUcI76Dv3Unfe5POfSPb
24XHu436/4Q/ET4JXyg8T3gf9XlLeBeeKfxO4flzvOzrhBvI/rJwddk3CD8t
+ynCW8q+QLiW7EO4X+r+J+v8I8wvHefo3CzZy3qfLqwZzaft9H5XCf8m+3LZ
Mh13Mx66bqWu30n4aeFK9V8rfIDweNa78F84HuGefAv1/0G4pvAzwlWpf9/z
er/2wjvJ/oXwEOHThbcVXiS8l/q/Kbyz+m8Sfk7284R3lP1z4RHC5wrXEP5M
eFhhf7G98BLhZ3WcpfZTXKN7DS08P7fTuU/wl8In8j7Cc4WHC7cV3kH4U64v
PH+rCS8Wbq+/w/E3Os7TOzXVPV9Tu6Har8i+h/ArvI/wr8KNhF/l9+HT4/iP
ZH4JvyQ8VvfvJ3xk8HxqIvtL+BvZRwnvy5wQri38h3BD4dH8FuHfhN8sPB5H
BceTF3T+8BIOLkk6q91S/ccJ7qP2aOKf+t8sfEAcv9oa3ztLnrPM3cmZ5+uU
4HhQV/YBsn8s+9nEv8xx+zHZzxJ+O3N8fi94ffbU/asLLy7bv03M/H0nB8fL
e3QconYPvqFsUzOP93Sdmy7bpMzz/YPg+NNOx4KyfeJA2Salji/36Jih8/vj
VxOvv7Nk66Xn12auyvaWru0tXIe1Jfy28LjMfGFisP+aU/ZaxV9P0/UfZF4v
HwbHt/uz/0JJ8qj+OVP4Dt2vhvASXfcm81X2HYWfl/0S4Rdlv0C4lvBXjIfw
+cI1hb8U3lbfs6OedbzOzda1dTQ+z6u9tZ69XvYx+nuU7BU6rld7TOH1c1iM
D7ur/4usD9l+Ed6NGCC8TWr/xxgxVtvr3M+6dqSOC1k/un4Z76/+XYT3Eu6O
/8jMfyYExwfe7xQ9ewNjoL6Ddf0JrG/ZP5b9b51rFd9vtdrvZuZj7wfH65b6
2zcx/zlb7/Gmjtbqu0r4MrWfzswXhqvfmErHzA36lgckjqWrdKzUcZvO345d
z2gY4wvfd4ZwSfe7QPfarcox+sTUMYzYXVv4VOYqMUh4Z+GThY8THi+8i/C9
wvvoHhN0r4VwnOA5uEj2GbL1le0uHUezhtVnd7VvVXtvXfum8HL1fUTX7CR8
NetSuKn6PK32HNmD2hepXVf2mjqOT80phun+G2TfTfZbdG4v2S4V3jXOT/jS
WcJfsZ5lry77UcIzhfcTzoQXCue6/mLhGsIH6lig9gM6V09jt0uF5/sQvd+O
si2W7eGS7fTbVefa6+/r6rNn7jUXgjkYa3Fb2e8IfuapzDX1ba5r6+vonprT
wDdWlM11umt+fMv6Tv08OMqhwXMW7kJMOC44phErPtOxg+71nPrvUWU+t59s
bwfzt0d0/grmt/oMUvsdnfu+7DkzUn0f1Ll2zHfZH1L7NR3z8IfCr6eej/CD
Sbpf50rPsYVl+yTm3uvC88vm5A8LvwanwdcLn4KvxofBVfDJwmPVZ3+1x0W+
OF7n1ieeU8wtOOuvZXMUuOz7sv+SeA4yF4l5rDXWHLHwGuKimofofYeq/TIc
DO6uc/vLvlTH9tHWQNe/IPslso+Svb5sYzLzu3civ30uM196Kdi/scZYa410
j15qD9dxqNr/6Ny1ak/PPZ4jWQO6fyvhWbI1Ec6r/H2byF5HRzd8kuz7q/2w
2nvKflVqLnBAHJ+OqX1FkzgezGnmNj75x8JrhrWDT1gDtxN+NfV4Had7H6Rj
Ar9N5/7R+3dKzYUOkn2w2vfp2Fft2jpuUvvK1LkI5waovV+VfWZN4bbMzQrH
hm3UZ0zub8i35Hv/JtxY+IHU82dW5jXKWp2r/sfmnn/8tl113Bx9DL5mkuzN
8Hc69patf8wX9tcxUe3bdG7HCn8jvhXz9zPdvw/fTe2dddwQOfqE1GMId787
9f120XGj2i10/2n4Z7VT9Z2Z2hcRo4jRJ8n+CfNH7a1kby48VbixcFn4MOEP
GX/hkvDRwrOZW8IVwiP09zB8hY7bI395X/Y9COpVXsOs5TtK9iXwh+ky7a1z
m8l2hPBH+A7hINxaeA7zQbgQnqe/3UuOP3PVPkb2j9U+UO1K2c8U/pK1JbyD
8Gn4BOEjhKtFf/Wgrq+LP1a7js6dq7/D4EDqe4KORfhbnduiymPG2B0kXEUs
EF7MWAlvie8XXiJ8qPDWVfZpS4Wbp/Z1pwt/LtxCeLsq+wB8wWHMEeEzhL8Q
bklMjb/v/pLHm3FfJPsWca3Vk31T7u87Ivq3xYXH57bg9yEnIf+cFpyr3Jw7
V9lK+LpK+zh8yehg3/dhbi3gDN3v+0rHKPSIxcGxq5vspybm910qzbkvDc4B
4OKfZM5fl0T+ujhzfvNJ5NcHqs97wvV0/7+FDxaeKNxA+N9KrznW3n467ld7
WmH+eUWwfU7hfKZz8PyYXZivXhs8f2cVzleuCZ4v5K/nl5xjzNazFmTmJwti
ftJVz6glW2MdvdWeWvi3XBb8ftML8+krg+frR4X59uXB/oP78T0WCnet9Jpi
bRHv71F7ZuF84urg9XJTbm5QEePF/Mz8bX7M15YKXy782f/zAeGdWLvClwp/
mlnfWBrzDXKmUXrOESXnUpcR72X/tmw9pqNwI+HVZV9/VW5u8KPwZcJX546H
5L+XV5oz1BJuk5pLDBWuCVcK7r8kc/76acxnbsmdq+4cfz85K/NrUXAuC79F
L5ka58u8zPx0Xswvp2TWTz6K8xEOxfc5JcYzOBRc66QY/9CHrtRvPUznJsCf
MudPs4P1uDmZ87WPI3+E0+3Jt07M9eZmzv/mxvyL58Hd5gTrezM0XmOFOwX7
M3wovnQvOJram+tcB3yT8HxyHfV/lPcN5tNfFfY/fYP51BeF/eGdweuZnEKX
JY8H5xoX5Obz8Hv0tQtzj/fSsvUz9Av46BvB+kOH3OPzZdl62kW5x+fzsvUt
9JQL9W6pjnm541kb2beO8WthYf/bLdh/LSi8/m4K9pdf6T6bl6xHHqv+nxb2
xz2C/dOSwvGie7B/+6wwd+sV7E/hB/DLUcHz6fPC8b53sL9bVDhe3BrsT+cX
jsc3BvvzxXrnLfX8vnp2feEvC/v7PsH++5PC8eD24Hj0fOb5/nKw/vSyrpss
XEP3eEXtfvDmksfrYOHxhfXQ04LzmQmF9YSzg/NnOCfck/X0UmpuAX8+WMcT
ak8srCe0C86He8CbZGupY7Tav+j9D1T7UbUb6v3G6e+yxHzhXbWnFM6nLgrW
Yz4onE9dGJxvw13g/810PJNaUyZXeTdYa75N5+qWzLGGwRN0/XOynx+sV5yr
51cTnlV2/vg1OXewD1+te72S2R+MCdbfzssd68lLya8nF84PLwjWe+YV9tc3
BMdzNJ62wd8M7Ycc4fpgDYbcgRhPrEcTeF7t9wvrP+cE6xFzC/ftGsz/iGHE
MvjjmtxziLnEnCFWk++i9z0XnP+SU+Jr8DnkbeS45Lr40BXC3YT3CNZAl2fm
qOQ6zEnmJjkyuTIx4Hvh4Zn1uZHB+TsaHFocMeynzBoeWl5H4WWZNVW0VTS+
LzNr9Gj1xLg1mTVbtFt85PrMmgfaxy2JtSw0P7Q/fPgvsj9WaS0NTQ1tlm/E
t3o2sZaDD8GXwDnI1VgDrAV8DNyGOchc5Buj1aB5o30TQ37NPKeZ28xZtKJl
ueMTPhR9/XHZT5D9QThBbk0J34CPgKvBAeoF50hwAzQVahFo9mgt5IR3BedE
5Irr4u/hfmh/aG5t4u9Di2uvo7eerUuThzJjuBuaENoQ+R7aCDlxnZhfwg3R
YND6h8jeTu2z0QQqzIfHp+ZvNSt80O4v+24Vzlfnp86p6gt3zmPumjj/37XC
fal5UPvoGufXfxxB9puFG5L7EFOpJVQ4tzlH/TdX+4XcWiY5Jrlm95h/EXOI
PcwptKE6iefaLcKNyO2Ev8scM4gdaLxoM/BPdFHuOVX4Vtkbs/aFf8jss/Bd
gxNrM2hwaHH9E9d60PTQ9tDo0I7RcNBy7ojzC80G7RofiJYDJ0P7RHOEqw3W
sXXiHHts7phF7MIHw01X5vaPXSKfwmfju4khcHN8BL4Cn04ugKbYJVgTRGsk
xtwU5xdcHZ+F78LnoL3iE/GNIxNrl3AuuNdrcT7iI/GV+FC0SvK/x1Pnb2gd
+Cx8Fz4V7RqOBleDQ5L7EfOY3+RXcHk4CFo3GiTcBE0XbRcO8UXmPvS9MHXu
BidDq4UzwNXgA7cEx7TvC/s0fBs+k1wXjto5/n5yGzgp3BTOSm6DRkpsnR7t
cA64B5yR3ArOCHeE05J7wXHhunBgcjc4MdwYjgqXhrPCXeGocG04Ito0HAnu
OEDHD4k1pTdyc2C4/KlxvqNXkfPCF1YV1pymaf5+n1iLuivmB9VkX5J7/axI
nIOx3uCEaN1o4nBFYjSxGs5ALgkHgAvAiciF4BDd4+8nd4Jj8D1mJM6NqGmi
7aFRoFVQ80B73U7409w5Blo5Gju5B/G/RckxuUfM2eAa5ETkcqty266L/Igc
iVwJTkEud33u2jA1uk/4vjrWCrcRRsSBE8ON1wi+zfjo3DruLXsg18itHaNh
o2WjF1Lb457jZOuU+1o4DlyHmi9ci5yO3I4aWfVgzYna2QFV1p3RGNAayOep
vd0uvFOFOSjcJtOxgN+D0KT2eTq2qnB+QG0FPvRTYT2OOgL1hGmMp553kJ53
q/CfmWti1MaIidSa0RTQFn6N79OXHC7Gs98zaxpoG2hQk8jtMs8dNKv3hM9m
zZes4f6Fb4/xkJrAH+q7MfNc2hjjC/VoNPYb8UGF9ZRnU9eMGP87ZN9X9uuF
12XOecl9hyf2v2gycC00S+JRP3JM9b9N9r/ITYl/iXO+H3PHk0GJOVWh79VP
uFtizrdZhTkcugz6DNzuEb5ZYo6Wy95b929CrqNzG8hVcn9rNOOZufnNHeQQ
iceX5zfk2cJv5daHyHPJd9cJT87dJgf+Wu25ubklc5a5i4a8T9RviOVo4mjj
aPh/5q5RUasix/k6cw0N/QxN7efcOSLcFh+OL6cGiP51YPx96GdPpdaX0aLR
nKhVM8fRouDk/2lMiefv5+R7Jdfsqul7bBI+o+Qa4/YVXj/Hl5xDfYk/xmcn
Psd6+iK3ftgwjgc1UmqlaIzsnaBGR62OnPGbzOvtxPj7v8JfVjgXPDGuv2/j
7zkzjh/jSZt3SiusB8LT+aa/5675kvuSA6MNoxGiFaKpfxzHu63aZ7HGdH0v
9d9P79NV/X+GX+peF8v2HfEsdQ2KWhQ1G2rv8P+usvfTMUvtB2RvoevvlD3V
vb9W324l1yzGpq55U/uG87LXgpoM49s15g9vpfbdPPMdte9T/8NjfC/pfvcL
HyHcWzjkrhdTI+kjvKLw3gS4Dv4DP7JQx8CSNXv0rytycyPONdDv3aLCtf/2
0Z9gR4vCx7F34Nrc90JDg1/hf9rH+fVDbs5ObkuOOyTyp3NLzhG+x/8Ld1D7
m8T6aU/130fve53wWvXvIbx3sJ79Y+Y9H+z9aJB4L0ulrh+R+J7wMfT5I9Xe
A86o9gD1b67re6lPWfe/LnVuTB/0+w9Sa7dwzCmpa0rU+tH00fbxubzboGBf
TP9eJcdD4uLD6n+0bPcIF7m1TLhTr3i/73Lr7+2if7lb/ZvCDXXub/Kx3L64
uuyfq70id32nbfQv/dW/mfp317l/1H+gcKvI9yqYn8Kthe8VrsxdY2SvBHse
xsX5yf6nDnG+/JHbV6Bho2XfG/lhT/VBmGCPBLUvNAe0h4civ4RPkr/Ar4n1
aJFw70GyHyP7fVC13DVZ9k6wB4RaLfHwvpI1D7QPan7sDWFPB7VA5gxzh1oR
XJ1aIrETzRM9F02MvQzUSNHKqGF3jvwHfkjNlr1D7CmilosmgjaCJsLeIzQR
tBE0FfYCsd9qWdkayteFNZalcX6yd+mCmC/WSZxvUHOi9oTGsJ5cW7hD5Kd1
9fyhOp6Ay5ATyzacnFrtoTq3C2sjd+5ATkpuSp2GWEl8J86j0X0b81P2UlHv
ZO7OTxwvid1ol3Aa9Iytc6/tktqDK835mQubCT8FN809F7PU78M7DITPpH63
tblzbXwuvhd/h16CT8Q3Ds+9d+FMcspK78egNnNOYv9eI/dYV6S2s5+E2Hhl
Yn9fPfdczGV/ptI5ILngFsJDya2EH4L/oLFXOl6TO74R5yN7JtiLV6TeS8F+
qtapOSb52YjcuTE5Mvd7MfdYkDOMEB6Zez8DY8RY8YxzYz7Ns+vH37dD6lrX
S7lrXReTg1R6zxx759jzxt63J+P7kiOTKz8Rfw85Lrn73bm5EJwGboOmyN4O
9hSgNbLHYWrqnJf8lnr5nNRrAn7YJzd3IKYQW+5MrUXDOS9Xe21h38DeCupn
L+eupXZkDvL7K50fwf/RC56K431i8Px4PnctgznJ+A8TflL4jODxeTZ3LklO
yfzZ8//9U3PFp4UfFj5J9icqrVEuifGN7zMqd27GO/AufEO+JWNQL/c7doz5
W2Ph53KvDcaEsakd70/OS+7bPzcXhWPCNcnpyO2I6cT21YW1iJujvgb/nZI4
ByMXg6+ytgamro19XLbWwPf/MHX+Qq0QjgnXJJ+gVkiMJFZmcTw3Bvs+Yiix
fkNwbCWGwD1/CY4t8N82iTkcXC6N4/lrcKz/prAWg4aClkLtD27BnEc3mVu2
b2Q+zE5dI6Z2PDi4dkyMJFZS4/kIPps6N4F/oUePiPky+TB6APOH3AK+ST2D
/RDkFlsm5hf4PmzkIOQxFfF7bwqOLT8U1pp4N7SdJ1PnWnwz9E/GnLF/Init
XJKaaxc6Lk29H4j5Ch9H/xuSOnfjG6NnUh9GK4HPo18uL5xL4wvJfU5PnWtc
Eb8ZMY1Y+UdwrOP3o8XDR+Glu8f5Wy1+i7rRH2+Xev3Xi/N9+9Rz86fc9VE4
LFx2m9xcrJx6flNLhSvDmak9b8xdyyWGE8sfS82VmY+d4u9rFu3U2vleaMXE
cPZqNI7zvVbqtQCnbhrtxPpG0Z/VTL1+0ODgKmx6wt+Qk6Flrg7O1agNk1vg
s28O5nxwpZ+DuSAxGK7wZ3BsJn/mW7Pvjr3CcBRyod+DuQuaENzx3+jPmIxw
rfXB3IAcD61zVVyP5FDEsx+DcytyuI7CK6P/g9Ogba0J5jpwFrSrtcFchvyF
ejoaA1rDPfF9Doq/Dx+HryOHZe8AY4LvwacxVq/l1mPQcNAqO0a+Bt/5j6/E
8Twirlc07j8in0P7poZF7atR4toWOQS5BDVx8htqZKsj/6H2Rk1qq6iPUKsa
mJtLt4jr+8EYj5tHfzA4xq9j4vdHg0eLZ480e7uoUbF3nD1M1K7I/1mPrEu4
ySWRf8H/4cuMGWOHj/yOvZpxvA6L4/NAnC+Hx/FvFuPD+an3ElDPR1slfrK/
iD0l7EWm5sZeE3w+vh89EC5BzWZdzL/Qy6mprI/5EbWWdrn5MtwXbYgYQixh
zRH74QRwB9YcXIEcgFygeRxPap4V8ffDr6kJbhn5HbVC9rmgHeBTi2DNCa6N
JolexR4UNsi1TLw35Zzc3xaNBH4OJ4AbDEnMPcg5yT1Z8+/kjonERmI6XAqO
BHfDh8CdWqXm+3Dm6frn8ch3Wkf/Q42EWgk1FvYmPhb5ztFxPe0f+cTuqffa
vJp7rw0aKFoo/8eAvYh/Bf/fg94xnpDzkPv0yL1e0IjRinvmrl2iAaMFd8+9
vtCk0aapcbJXjj2P1D7vjPEKjQStpG9uLQWNAq0CTW0G8yX1XiT2HLKXvWX8
/uyZ5v8usMeSvdTsyWSvfovEezWPjL9n39R7l6jBXCS8PHgPHXuw+b8TrRPv
zX49Pg9ND62zV/RX5HTkdp3i87k/+fe90d8fHP0Lezb5/T8F7+UcEL9fs+hP
BkX+e1SM16Nza63kCOQKaChoKeyBZH/hfdE/No3+iT3+/F+MYxLv/X808udW
MR7OifOVmjS14v8Br8Zbkg==
         "]], Polygon3DBox[CompressedData["
1:eJwt2Afcj+Uex/E/z+P59/xxEi1URkIRpdBCp72oNE4drUN1TouyGjblVFZG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         "]], Polygon3DBox[{{1782, 1781, 2531, 1108, 1109, 2532}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl2e0FtUVhmeG73we7iBVY0W52KVjBKRzLYELUq7EJXBBokkEaYqJIhgC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         "]], Polygon3DBox[CompressedData["
1:eJwtmHm4VVUZxs/dnLXd+6DM5qwMUhFcBExQ5kuazJM8JnBBglSGCyiVgJRB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         "]], Polygon3DBox[CompressedData["
1:eJwt1WeMFVUUAOBH2cfiojQRRJCOSC/Sy1IN7NJFQhMQLHQQLAiIomJsUWJB
QGIvgIpRlKKoERSwB1CKNKkabPSmgt/JvB8nmfO9c+fO3HfvmSojJvadUDCV
Sk0SWaLtRanUqHQqNU8ywA87s1Opjmwie5G9IC7kpFLlWUnWQV5A3YPqurMZ
7G02jv3F2rOx7Hk2mO1mLdhwNoc9Kc65Xzs2ms2XD1S3Q11N1oSNZCPEHnXN
2RD2uLy7uh/UXcxSrCE7UiCVmsw6sHFsIRuibg8rydKsGWsqNrhfIXbEdWXx
i7E3qSvOCqprzI6xO1guG8MWsEHut4uVYIVYE3Zc3Z2sK5vKFrFR6g6zHmwm
W8reEQWLpVLF2AXXDcTfxk5RV4u1VjeW1TH2XVaOFWe5se7qZrE0Oy6vJvaz
W1gem6ZuCRtj7B8six2TVxX71N3M6rE8ddNYK3WfsqtZGzaO1WVLWW3WkU1m
t4nD1qowO+q6itjrfiPVXcIKqGvEjrLbWTd2N1vMRrvf7yyfTWdvsbHsT9aQ
9WGz2H2xhuZowLqzGfI26j7LrN896WTvxR6co64su4S1k5837/3qKrDSrBMr
ZOxD7Bo2kD3CurHvWDM2mD3G8tn3mT0+IZ3sx9iXs83RlA1ij8rz1H2r7gpW
inWM/5HNZvVZPpvOWrNP2L9FrZG8pNjo+a5n1dVVV9ePXSc2m6O/uvHsCXkv
Y/eq68uGsntZe7aJ9WE3sJksl21k/4mPYt8Wdr7MUV9+RnwYz692Lqsl72xs
e/mNsReM/SD2C+vBJsQeZJ/Hf8R6somsIVvDTrNN8a5ijftdy06yr+Pcmves
WOQ9zrDNse5irbousf/YF/Ltat5gLaJHsF7mmMQbmWNtdnJG4qzcxR+O9bFO
59gKNT8bO8/YOvJ/xEq2k81ndWOdxSq2my1g9TLrXM19OvMu4lbPd9a827KS
543nbpOT9JfG6eS/iP9kdE7ybl+5PqDmoGjBjrOP4wzJ94tmOcn56JBO+lL0
p/GZOba7LiqyxbKcpNcNSyf7O/b5dFaEnXJdVpSLvRVjPfdy19vc/znvUVt+
uboSxraPxmx9HmAXzPFr5v4xT0djK6q7NJ30tOhtw3OSXpfFasqvivfLSc5b
73RynuNcT8mMLZNO1inW6xt23hz7XZeOPepZ+mcna7A6K1mTWJuF8W6sgbG9
Y597vlfVtWQNWR9Wir3GmrP6rBcrwV6JPsSqZM5RnNVn41yyeqwnK85eZq1Y
I9Y3noe9zuqyyplvT5zBZ1gdVimzVvE9ejqzVr9l1jjWerVnruF966obIq+g
7qXof+oqZnpJ9Ng5rAYrzGqwQ2xq9ER2ZaYXx//xVJx9VjXTcwqzufGdYT/J
T1mnFcZ2Y6XYFnaarWR5rDTbys6wVSw/+gs7xIrE94kNim8Za2uOoaySOd6L
fsXasWHx7WLvs04slw2PHs2WsRNsbfRWcyxzv+asPDvI0mI9Gxi9hO2L/0xs
Yv1i/7ED8iyxjg1gldkJeRmxhY2K7yD7UX7SHMtZ1/hGsS/ZDvYma8mKsHVs
V/QM1ooVZRvie8KWsDYsm61ne9hi1ppVYSfZZWIrG52dnKPTmf0d+3yt//d/
PFcIzA==
         "]]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl2mQFtUVhrs/5jY9c8eljA6bYtxYTaIwCAPiNsNiFJAZNjWJsrrLjqAg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         "]], Polygon3DBox[CompressedData["
1:eJwtl3ewF9Udxff3k73u3X2gM0pHsdJt8JAOGuCBE2kPHg81UUHAxCSAUqIJ
SCwBwZgZWxILCpqmoklmEjUSQTOxY8mMDcWSRAkCYkxUVIo5nzn3jzu/Pfu9
u7/de8/3nLNHz5rfPK+eZdlRtSxro9+JRZY9p+M38ywbWWXZzRq/1PFsTfpU
tdEaf1D97zr3gGpThDcJvyP8kPAe4Ss0d6nGeTHL7tW5/brxXzRnlGqTNTbq
+G3Nf1C1ezT2qb5B50aq9ifhtqptFp5U+Hm4dqvO/VG1mcIvCn8k/Jjw+cIv
CO8W3iR8nvDzwh8KbxQ+t/C9dgk/KnyHxg793/06d4pq64T/I/x74UbhO4V3
CT8g3F94jfB24fXCJwvfonGw3q1nyLJXVPuFcBDuIfyy8E+F92luN+HNwms1
duv63+ncgMLv9KiO38r9rv8TvljXX6H5N1b+zztVfyz3szwoPED10arPE75P
40Ab3+M01a4RvlFzp2rO+8KrhG8Snia8TXil8A3CzcLvFf6Pu4Rn1f3f7GGN
tax5b3nGtTp+PPez/1d4geb+SP9/g/D9GlnuPf8a76Lj9arfp3Gd5qyGMzrX
IvzvwpxZqOOrgrnEfrypa3dqzljh5cIfCrdV/Vnhy4V3CTcIP1N5zxtycxIu
8AzrhGfW/Wx3Ca/Q3EuFzxbfmgu/y7ua87BqtwlH1XprzmuV9/wO1Tfl5gJ7
vk74r7m5wB6vEd6Ye+8/Eb5E11+p628S/kx4kfDVwj8TXiD8tuYf0Pwn4Y7G
Eh0P1JyHVXtZY4qOZ2r+0srX/Er1OXXfK2swnp3Wa77qc4SPF35IeLHwIuFG
4ScLc65VuEPdXIRz04Xb183FVYmPHfR/M1V7VWOG6h117tbCnDxTuKqbq8uF
f8xeCL9WeE/phZdy7/UWjXN03EX1NYX3aERujrN3rOlZwp3qXmt6snvuNaFX
Xxc+W7iz6rcL1/S+v07vv124TfTeXaZxjo73a/7PVZ8uvEX1GTo3t+5ruHZv
4te09Lyt0fdiDVnLJaovTuv/FL3Imic+vk7vak6L8Abhxbp2anSNe3LvadH/
zTVcGzR/G3qhc/OiOXC3ahfUzQ04Opxra+buZM0Zr9o1OrdHtW/q3Buq7RAe
I9yiemvd78i7Xq5xNTWde7WwZh0hvLVmLUNTD8mtcWjtP4TnJn78VvifwhcK
9xC+R/hfwt8S7il8r/D7whcJ9xZeL/xu4tdxwr8Rfk/428K96GHh3cKXCg8S
fqTwHOY2ik8XqbZM4yrVR+vcK/yfxvk6XqD6CtXmFX72fZrzN+GJet8m1VcI
fyr8MRwXXq751ws/AeeEm4UXCe9M+9eY+P9J4ueYtJ9PCJ+QWyPmF77nisTf
p4UnwFHV3tC5Ear9QHiP8MG6f4vwd4S3C3+u+teFvyG8RfgD3qmyB+FFzwkP
qawhh+b2HLQFD+mWW8PQMjysXW7Pwdt4537CO2tei8+EV+Zeg2fQOuHvC58q
/OfC7/CW5u7P/W4faVym48GqbyisEfB7lZ7/oAZzCm6N07lnC2vOibk1FC3C
A4/MfU+88TqNUnO76Po56f3wss25vbce3e94FHr/VWFvxPPQvyzaC/FM9PJA
up6eoDdq0d6GZ+JXk0trMx6D1wwrzRU4DtfHlNZDPAlvmlSaP2g62t5U2svw
MLxsSmmvoufovamltZJ+R0v7l/ZHNBKtHIgn1OwJeANrtjpYs1nL5tK9S6bB
jwaU5hqcQzvY823J71mrfqX5T8+gzcNLcxFOop1DS/OXnqA3xpb2WjwZbx5X
WqvQF7yRHmpJek1vHaP6l/qvYbn3p3tpvg7Go4WPEv5ceAiaU5nDvXJzGG6f
Xnj9X8SHK2e2fSlv4ZeTorkCB+EiPcvzzQp+3uP1+whc1GjSnGNLaxmaNrey
hwzK/Ux4Cz21N+U1eu1wzf9Ax300p1W19sI7hPsKzxDuULoX6ImzKmeY2Ul/
yDZ44pW51xCvPKz0u/XGAyr3ZJm7p+lVerZz7p6ll9GMhbk5gJZUpXuTHp1Y
WVPh0wXB/KuXzhINKX+UpfW5q/AEcPTasYb0RxWdtciwZNkO0VrcLuXX8dG9
imainSdF7y17jNeMiNZiNBqtHhmttWg0Wt0uOq9kyW8bovMxGY+sd0y01vVL
etpd+J2aPRavPTLaa+l5er9HtDezf3hTJ+GXatYwtKyXcEPdGYAscIbwkLo1
B+3piQfX7PF4fbdoPWc90b5DhB+vOTOSHQcKd607I5AVjojWHjwMLzs2WptO
SPrWNjo7ftXGfD1OeHfNGoaWHRT9fUEmJ48drf35QngoGUn4lOgsQwYiCx0e
ne/ZT7JirTRXquS3e6O5yn7SG2jCyuD/QCvwrOtzaxJehietza1JeNXJ0VmL
jEXW6h+ddchUZKth0V6MPuCt46K9E41H608T7lO3B+PFo6K9GM/Fe4dHezee
jrcPiM5KZCqyVWN09iJDkaXaR3sN30h8PzRFewmZk+w5Njr7oGd4aSzdK12E
z6ycmdCj2cH6NSHaO9EzvJaeYC03J3/jGq6lR74rvKywXpXB/U3mQS+q4P6m
h7omf/yeaj8srF9FcD9PTP65NfkjmRc9X5S+HfB4nr8l+HnwdN5verDX46Gs
b2uwnvHNgz9cEqy3eCL9OCPYK1cX/l7rGKyncA7u0WNoJ8+IXn2Z+h/No3fo
IfIx79g3+TnvzjNzvDfpy0/S90XnYH6yRujhF2m94SBcRHPIgtyT7N01+L+u
FS6EOwXrOxkfv5wa7GdLC/M/BusrA63lmamRkdH3C4PzJPvLfs4JzrN4H9/i
yzSuDV5v8u7i4LxMBifvLgnO1x9rbZbXncnxUDIv33d85+H350bfb3XKI7en
fNEnmJ+jUn54Prde8o1Kfnght57dmt63V3D/8I2KHy8M9nsyOllpbnD+JqPj
T/gUekqGpR+GBvcTGZj+PDW4f8jA6MOgYL0lw6K344P1Gc9FnwcG9+uatB99
g/WLzEx/Dw7WZzIx/TgkuF/JpPT72OD+4huP/m0K7j8yHXo/Lrj/yXD0+xnB
+koP4G1whN7oGJ0tyfhkfTIAWYCeIrvxzU6eujg4L8ERsgCcgDv0C3lkWnB+
geNkB3oO7sNJtJOehav0aL+Un+ld3of8MyY43/wfoNRl+A==
         "]], Polygon3DBox[CompressedData["
1:eJwt1nmQz2UcB/CvX6w9HE3JfaTD2YF1LYksuysJu9bqZJcold1F7oYwpDKN
ajoRapout0S5u8nRTDVRaKbLrXQ5Qq9nvr8/PjO/5/V7f77f5/t8n9+z27ik
NH9UIoqiUaqSqpEeRWkpUZRlcLpCFE1OjaLLWSrryP5lk9gVLJ11YmfYFJbN
ytgi9omLTkqLokvUNuOTFaNoiVw7udvlpsot5/PlJssk1Fbj43KL5drKtWMt
5W7jVeQWsgK9M9kaNob9zSrIbTE+qneR3kyWJneGNVeH2IOskdxJ40vVHlbC
rpar53q9WbrrzWXp7KxxC3VY7iF2jd4Lxo3UQVbOMuTOGbdUR9jD7Cq5/4wb
qP2sNMxP7ohxXbWX3R3uK3feuKE6wMpYf7np5rKKlZvLnyzBjhrXU/vk7mGN
WR25XixV7kl2UW0y/s0aLJRrbXylXG25PF5Z7glW030PGF+U2yzXnzWUqymX
w9fLjZVJV1+GtZNbKtdVLlXuNGum3pMbLXMZq6y3A3ufjUmL3+9niXgPhL0w
L8Na8Z1hnVxvmet1c70qbBc7xpazW1hLvZv0bVTDfDdKb1PWNiUeBx+nL4tt
83mrms6nyFXje3z+3fVWul522KdsP7vANrF+rLXe/JS4L/RPkInYYeM6ajUr
Z1XVbuMTelfo7Z7s3eL7zeFZfTfWfSO5zWGvyL0q1yY1nvMGmQ9Voe9Gyp2T
+97nDLVdro9cDfaD8Xm9G1nf1PjZis1vHv9I/8S0eF2yU+J7hnuPZ/eqOewN
NpwNNv5H7TA+F9aUlRpXV1+xU2yVe/Rwj7NsX9jzaqVcWbJ3mc9L1a+yWebc
kJ2Qqa526y3Wm8fy3PeB8PsKz8h6sV5sZPjdsA2sGavPuoTn0/s0a+M5CtgM
1j3skbCmck2T+zTs55dZptwANpNls09ZW7kWyd9qBlvAWrEmLDe5x19iPfWO
ZktYMfs5Nd6naxPxvg37t9Cz1dJ7sFJ88G0xv/zw3sJ713tDeO9sWvhN663L
bmVp+p9Krt+KRLzGYa27uF4ma57MhbNkvlxfvdPYClbK/gjnEKuVnHMKm8Ny
2Vj2Ohsa1p/lsDHsNVbCfmH92GNsJStjp8Kaum+z5HkQ5vcKu5Fdm/xNh3u8
GM5Odh+bxXLYd6wJq8KuD2ev553KCtkI9jjLk9vHBrDhbDbLZXvDWWIuGawz
O6v3UTZIbhx7gRXJHWb5cjPYajaa/cU6s6HsWZbPvmE3sWHsOVbAvg1r4Ho5
bARrytazimnxPg77ebbv7jTurNr5PFCuptybYe1ZEZvAOrLtrA8rZONYe/Z5
2C+sJxvOmrB1rIe5lLPFbAj7KbwjuVx2fzgD2QesNvvRuEI4S8ypIHlOrknE
50g4T3rbG93kOum9K5zl4TcmdzPryO4I5w57h3VhHdggVpu9zRqw48bV1C73
GMKK2CNyz7OBcodYfXbMuKraKTc47Bc2SG4iy5LbEf7+soFsPOvAvkj+DViX
iM/wcJYXm/MFvtHnubILXK9VeEd62xsX8Vqyb6XGZ+eqRHyOhPMkW2/XcEaH
dxP+7vF35a6T68HGsky2lnViJewZ1p99nfw/4uNEfPaFM3CW6/0Pd3oFLw==

         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0s1KVGEYwPHH1NEZtVy4cmF4AXoD5TpQCRERUREJXegiF0J+dAFNqZX5
Be51LyjuJMiNmKSj5teMYxsR6gLERfQ7EMwzv/97YOY9551pfDXW+bokIpbM
hEh6yNsdP6YiarnKp1xjMzfYwq9s5w/2scgbM6ofOMWKiogs67jCRq6zmVts
4S6PmbLvtDm2fsN6ky2NOLF+z1N+4E/O8IyzPOccL5J75idzqT/zivPM8wsL
XOA1F1nkcFlE2l43+rvO6irz1vxybZwZ0+Mec9aDulV/0wP6md7UNZUR/dZr
OqN79bKu1D36nU7pbj2py3SXvndWI9adOq97dYc+0G36pd7Rz3WJz7RbN+m/
9m3VDXpb/+GU9ZPkmfibk8kzPIp4rKt1UdfoAqt5xSpeMMMzpnlKW0WOR8bX
xyFTye/Nch7QccU+HWXs0SteuHj7///0Dwi/S9o=
       "]]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0bsug2EAx+FXgzC4A4tRXIDEBUisEolFQtWh9DAYDBIRg4g0qENLnYrS
g9NgNxhsBptIIw0X4A7E0xh+ef7v8H358n490fRwqiWEkNZGJIR9hzUuqrcj
hJJzPx85yGeO8I0xNrjAH67yl1l2eb7Ibj6wj08c4CuHWOcoxzpDWGJGM1rX
isptIcyywjirnGON87xhgrdM8o73StkvSnpvjUdK2FUWNG9XeKg5u8wDxe1r
5jVrXzHX/Ca71LwbTduX3NOUfcFdxexz7mjSLjKrqH3GbU3Yp9zSuH3CTR27
s+/WEL50ZDdY4CcPWecBP5jnO3PMtIewHPn/b39J/EHJ
       "]], Line3DBox[CompressedData["
1:eJwl0Tsvg2EcxuGngpD4Biarb2A3mBkMtg4WSdu3rUOJYBKRxhegTiNVbZ3P
dYjBYrYYpRHEZJK43hh+ue5n+/dtTzI9mEqEEMb01hrCmkexPYSdlhB2leoM
ocw9pe0K95Wxq6wpsus8UNY+5JFy9jFPlLdPeaZx+5wXmrAveaVJ+5o3mrIb
vFXBvuO9pu0HPmrGXmWlzW3xXcywyii+jVnWmYvvY57Lft8si/EtWtKCfjpC
GGWTw3zhAJ/YF9/LXpbZzRK7uMJf322en4z4yiSfOcQG+1njiLsL8R3a9l7k
nL59/y3vL27ygxt85zqbLCX+/6c/PmVFOQ==
       "]]}, {
      Line3DBox[{1678, 1971, 1974, 2842, 1881, 2064, 1972, 2083, 2868, 1882, 
       1679, 2645, 1883, 1680, 2646, 1884, 1681, 2544, 2647, 2079, 1885, 1682,
        2546, 2648, 2084, 1886, 1683, 2649, 2428, 2738, 1684, 2429, 2739, 
       1685, 2650, 1887, 1686, 2651, 1888, 1687, 2652, 1889, 1688, 2653, 1890,
        1689, 2529, 2654, 1891, 2005, 2853, 2029, 2030, 2013, 2028, 1892, 
       1975}], Line3DBox[{1690, 1973, 2430, 2841, 2078, 2077, 2655, 1893, 
       1691, 2656, 1894, 1692, 2545, 2657, 1895, 2080, 2528, 2658, 2076, 2081,
        2082, 2075, 2867, 2073, 2087, 1896, 1693, 2659, 2431, 2740, 1694, 
       2432, 2741, 1695, 2433, 2742, 1696, 2660, 1897, 1697, 2661, 1898, 1698,
        2662, 1899, 1699, 2843, 1976, 1900, 2006, 2854, 2031, 1977, 2014, 
       2047, 2048, 2046}], 
      Line3DBox[{1701, 2434, 2743, 1700, 2435, 2744, 1702, 2663, 1901, 1703, 
       2664, 1902, 1704, 2866, 2074, 1903, 2086, 2869, 2085, 1904, 1705, 2665,
        2436, 2745, 1706, 2437, 2746, 1707, 2438, 2747, 1708, 2439, 2748, 
       1709, 2666, 1905, 1710, 2667, 1906, 1711, 2844, 1978, 1907, 2007, 2537,
        2858, 1979, 2015, 2050, 2051, 2049}], 
      Line3DBox[{1713, 2440, 2749, 1712, 2441, 2750, 1714, 2442, 2751, 1715, 
       2668, 1908, 1716, 2669, 1909, 1717, 2670, 1910, 1718, 2671, 2443, 2752,
        1719, 2444, 2753, 1720, 2445, 2754, 1721, 2446, 2755, 1722, 2447, 
       2756, 1723, 2672, 1911, 1724, 2845, 1980, 1981, 1725, 2538, 2846, 1982,
        2016, 1983, 2065, 1726}], 
      Line3DBox[{1728, 2448, 2757, 1727, 2449, 2758, 1729, 2450, 2759, 1730, 
       2451, 2760, 1731, 2673, 1912, 1732, 2674, 1913, 1733, 2675, 2452, 2761,
        1734, 2453, 2762, 1735, 2454, 2763, 1736, 2455, 2764, 1737, 2456, 
       2765, 1738, 2457, 2766, 1739, 2847, 1984, 1985, 1740, 2859, 2032, 1986,
        2017, 1987, 2066, 1741}], 
      Line3DBox[{1743, 2458, 2767, 1742, 2459, 2768, 1744, 2460, 2769, 1745, 
       2461, 2770, 1746, 2462, 2771, 1747, 2676, 1914, 1748, 2677, 2463, 2772,
        1749, 2464, 2773, 1750, 2465, 2774, 1751, 2466, 2775, 1752, 2467, 
       2776, 1753, 2468, 2777, 1754, 2530, 2778, 1988, 1755, 2860, 2033, 2034,
        2018, 2068, 2067, 1756}], 
      Line3DBox[{1760, 2678, 1915, 1758, 2679, 1916, 1762, 2680, 1917, 1764, 
       2681, 1918, 1766, 2682, 1919, 1768, 2683, 1920, 1770, 2685, 2686, 1921,
        1772, 2687, 1922, 1774, 2688, 1923, 1776, 2689, 1924, 1778, 2690, 
       1925, 1780, 2691, 1926, 1782, 2532, 2692, 1927, 2008, 2540, 2861, 2036,
        2020, 2053, 1928, 2052}], 
      Line3DBox[{1784, 2069, 2070, 2019, 2035, 2857, 2539, 1783, 1989, 2791, 
       2531, 1781, 2790, 2480, 1779, 2789, 2479, 1777, 2788, 2478, 1775, 2787,
        2477, 1773, 2786, 2476, 1771, 2785, 2475, 2684, 1769, 2784, 2474, 
       1767, 2783, 2473, 1765, 2782, 2472, 1763, 2781, 2471, 1761, 2780, 2470,
        1757, 2779, 2469, 1759}], 
      Line3DBox[{1786, 2693, 1929, 1785, 2694, 1930, 1787, 2695, 1931, 1788, 
       2696, 1932, 1789, 2697, 1933, 1790, 2698, 1934, 1791, 2699, 2481, 2792,
        1792, 2700, 1935, 1793, 2701, 1936, 1794, 2702, 1937, 1795, 2703, 
       1938, 1796, 2704, 1939, 1797, 2533, 2705, 1940, 2009, 2541, 2862, 2037,
        2021, 2055, 1941, 2054}], 
      Line3DBox[{1799, 2482, 2793, 1798, 2706, 1942, 1800, 2707, 1943, 1801, 
       2708, 1944, 1802, 2709, 1945, 1803, 2710, 1946, 1804, 2711, 2483, 2794,
        1805, 2484, 2795, 1806, 2712, 1947, 1807, 2713, 1948, 1808, 2714, 
       1949, 1809, 2715, 1950, 1810, 2534, 2716, 1951, 2010, 2855, 2038, 2039,
        2022, 2057, 1952, 2056}], 
      Line3DBox[{1812, 2485, 2796, 1811, 2486, 2797, 1813, 2717, 1953, 1814, 
       2718, 1954, 1815, 2719, 1955, 1816, 2720, 1956, 1817, 2721, 2487, 2798,
        1818, 2488, 2799, 1819, 2489, 2800, 1820, 2722, 1957, 1821, 2723, 
       1958, 1822, 2724, 1959, 1823, 2848, 1990, 1960, 2011, 2856, 2040, 1991,
        2023, 2059, 2060, 2058}], 
      Line3DBox[{1825, 2490, 2801, 1824, 2491, 2802, 1826, 2492, 2803, 1827, 
       2725, 1961, 1828, 2726, 1962, 1829, 2727, 1963, 1830, 2728, 2493, 2804,
        1831, 2494, 2805, 1832, 2495, 2806, 1833, 2496, 2807, 1834, 2729, 
       1964, 1835, 2730, 1965, 1836, 2849, 1992, 1966, 2012, 2542, 2863, 1993,
        2024, 2062, 2063, 2061}], 
      Line3DBox[{1838, 2497, 2808, 1837, 2498, 2809, 1839, 2499, 2810, 1840, 
       2500, 2811, 1841, 2731, 1967, 1842, 2732, 1968, 1843, 2733, 2501, 2812,
        1844, 2502, 2813, 1845, 2503, 2814, 1846, 2504, 2815, 1847, 2505, 
       2816, 1848, 2734, 1969, 1849, 2850, 1994, 1995, 1850, 2543, 2851, 1996,
        2025, 1997, 2071, 1851}], 
      Line3DBox[{1853, 2506, 2817, 1852, 2507, 2818, 1854, 2508, 2819, 1855, 
       2509, 2820, 1856, 2510, 2821, 1857, 2735, 1970, 1858, 2736, 2511, 2822,
        1859, 2512, 2823, 1860, 2513, 2824, 1861, 2514, 2825, 1862, 2515, 
       2826, 1863, 2516, 2827, 1864, 2852, 1998, 1999, 1865, 2864, 2041, 2000,
        2026, 2001, 2072, 1866}], 
      Line3DBox[{1880, 2044, 2045, 2027, 2043, 2042, 2865, 1879, 2004, 2840, 
       2536, 1878, 2839, 2527, 1877, 2838, 2526, 1876, 2837, 2525, 1875, 2836,
        2524, 1874, 2835, 2523, 1873, 2834, 2522, 2737, 1872, 2833, 2521, 
       1871, 2832, 2520, 1870, 2831, 2519, 1869, 2830, 2518, 1868, 2829, 2517,
        1867, 2535, 2828, 2002, 2003}], 
      Line3DBox[{2089, 2393, 3076, 2296, 2088, 2967, 2297, 2090, 2968, 2298, 
       2091, 2969, 2299, 2092, 2970, 2300, 2093, 2971, 2301, 2094, 2972, 2547,
        2870, 2095, 2400}], 
      Line3DBox[{2103, 2548, 2871, 2102, 2979, 2309, 2104, 2980, 2310, 2105, 
       2981, 2311, 2106, 2982, 2312, 2107, 2983, 2313, 2108, 2984, 2549, 2872,
        2109, 2401}], 
      Line3DBox[{2118, 2551, 2874, 2117, 2552, 2875, 2119, 2991, 2320, 2120, 
       2992, 2321, 2121, 2993, 2322, 2122, 2994, 2323, 2123, 2995, 2553, 2876,
        2124, 2402}], 
      Line3DBox[{2133, 2556, 2879, 2132, 2557, 2880, 2134, 2558, 2881, 2135, 
       3001, 2329, 2136, 3002, 2330, 2137, 3003, 2331, 2138, 3004, 2559, 2882,
        2139, 2403}], 
      Line3DBox[{2148, 2563, 2886, 2147, 2564, 2887, 2149, 2565, 2888, 2150, 
       2566, 2889, 2151, 3009, 2336, 2152, 3010, 2337, 2153, 3011, 2567, 2890,
        2154, 2404}], 
      Line3DBox[{2163, 2572, 2895, 2162, 2573, 2896, 2164, 2574, 2897, 2165, 
       2575, 2898, 2166, 2576, 2899, 2167, 3015, 2341, 2168, 3016, 2577, 2900,
        2169, 2405}], 
      Line3DBox[{510, 1342, 511, 1343, 512, 1344, 513, 1345, 514, 1346, 515, 
       1347, 516, 1348, 1349, 517, 661}], 
      Line3DBox[{2178, 2583, 2906, 2177, 2584, 2907, 2179, 2585, 2908, 2180, 
       2586, 2909, 2181, 2587, 2910, 2182, 2588, 2911, 2183, 3019, 2589, 2912,
        2184, 2406}], 
      Line3DBox[{2193, 3021, 2345, 2192, 3022, 2346, 2194, 3023, 2347, 2195, 
       3024, 2348, 2196, 3025, 2349, 2197, 3026, 2350, 2198, 3027, 2596, 2919,
        2199, 2407}], 
      Line3DBox[{2208, 2597, 2920, 2207, 3034, 2358, 2209, 3035, 2359, 2210, 
       3036, 2360, 2211, 3037, 2361, 2212, 3038, 2362, 2213, 3039, 2598, 2921,
        2214, 2408}], 
      Line3DBox[{2223, 2600, 2923, 2222, 2601, 2924, 2224, 3046, 2369, 2225, 
       3047, 2370, 2226, 3048, 2371, 2227, 3049, 2372, 2228, 3050, 2602, 2925,
        2229, 2409}], 
      Line3DBox[{2238, 2605, 2928, 2237, 2606, 2929, 2239, 2607, 2930, 2240, 
       3056, 2378, 2241, 3057, 2379, 2242, 3058, 2380, 2243, 3059, 2608, 2931,
        2244, 2410}], 
      Line3DBox[{2253, 2612, 2935, 2252, 2613, 2936, 2254, 2614, 2937, 2255, 
       2615, 2938, 2256, 3064, 2385, 2257, 3065, 2386, 2258, 3066, 2616, 2939,
        2259, 2411}], 
      Line3DBox[{2268, 2621, 2944, 2267, 2622, 2945, 2269, 2623, 2946, 2270, 
       2624, 2947, 2271, 2625, 2948, 2272, 3070, 2390, 2273, 3071, 2626, 2949,
        2274, 2412}], 
      Line3DBox[{2397, 2396, 3077, 2644, 2282, 2632, 2955, 2283, 2633, 2956, 
       2284, 2634, 2957, 2285, 2635, 2958, 2286, 2636, 2959, 2287, 3074, 2637,
        2960, 2288, 2413}]}, {
      Line3DBox[{713, 1092, 918, 2868, 714, 1217, 929, 2655, 739, 2744, 939, 
       751, 2750, 950, 765, 2758, 963, 779, 2768, 976, 793, 2780, 989, 2679, 
       807, 1002, 2694, 821, 1015, 2706, 835, 2797, 1028, 849, 2802, 1041, 
       863, 2809, 1054, 877, 2818, 1067, 891, 2829, 1080, 905}], 
      Line3DBox[{715, 919, 2645, 716, 930, 2656, 740, 940, 2663, 752, 2751, 
       951, 766, 2759, 964, 780, 2769, 977, 794, 2781, 990, 2680, 808, 1003, 
       2695, 822, 1016, 2707, 836, 1029, 2717, 850, 2803, 1042, 864, 2810, 
       1055, 878, 2819, 1068, 892, 2830, 1081, 906}], 
      Line3DBox[{717, 920, 2646, 718, 1224, 1225, 2657, 741, 941, 2664, 753, 
       952, 2668, 767, 2760, 965, 781, 2770, 978, 795, 2782, 991, 2681, 809, 
       1004, 2696, 823, 1017, 2708, 837, 1030, 2718, 851, 1043, 2725, 865, 
       2811, 1056, 879, 2820, 1069, 893, 2831, 1082, 907}], 
      Line3DBox[{719, 1221, 1222, 2647, 1223, 1227, 1093, 1226, 1094, 2658, 
       1216, 1213, 2866, 1214, 754, 953, 2669, 768, 966, 2673, 782, 2771, 979,
        796, 2783, 992, 2682, 810, 1005, 2697, 824, 1018, 2709, 838, 1031, 
       2719, 852, 1044, 2726, 866, 1057, 2731, 880, 2821, 1070, 894, 2832, 
       1083, 908}], 
      Line3DBox[{720, 1229, 1230, 2648, 1231, 1232, 1233, 1215, 2867, 1212, 
       1236, 1237, 1238, 1235, 2869, 1234, 755, 954, 2670, 769, 967, 2674, 
       783, 980, 2676, 797, 2784, 993, 2683, 811, 1006, 2698, 825, 1019, 2710,
        839, 1032, 2720, 853, 1045, 2727, 867, 1058, 2732, 881, 1071, 2735, 
       895, 2833, 1084, 909}], 
      Line3DBox[{721, 921, 2649, 723, 931, 2659, 742, 942, 2665, 756, 955, 
       2671, 770, 968, 2675, 784, 981, 2677, 798, 994, 2684, 2685, 812, 1007, 
       2699, 826, 1020, 2711, 840, 1033, 2721, 854, 1046, 2728, 868, 1059, 
       2733, 882, 1072, 2736, 896, 1085, 2737, 910}], 
      Line3DBox[{725, 2739, 923, 726, 2741, 933, 744, 2746, 944, 758, 2753, 
       957, 772, 2762, 970, 786, 2773, 983, 800, 2786, 996, 2687, 814, 1009, 
       2700, 828, 2795, 1022, 842, 2799, 1035, 856, 2805, 1048, 870, 2813, 
       1061, 884, 2823, 1074, 898, 2835, 1087, 912}], 
      Line3DBox[{727, 924, 2650, 728, 2742, 934, 745, 2747, 945, 759, 2754, 
       958, 773, 2763, 971, 787, 2774, 984, 801, 2787, 997, 2688, 815, 1010, 
       2701, 829, 1023, 2712, 843, 2800, 1036, 857, 2806, 1049, 871, 2814, 
       1062, 885, 2824, 1075, 899, 2836, 1088, 913}], 
      Line3DBox[{729, 925, 2651, 730, 935, 2660, 746, 2748, 946, 760, 2755, 
       959, 774, 2764, 972, 788, 2775, 985, 802, 2788, 998, 2689, 816, 1011, 
       2702, 830, 1024, 2713, 844, 1037, 2722, 858, 2807, 1050, 872, 2815, 
       1063, 886, 2825, 1076, 900, 2837, 1089, 914}], 
      Line3DBox[{731, 926, 2652, 732, 936, 2661, 747, 947, 2666, 761, 2756, 
       960, 775, 2765, 973, 789, 2776, 986, 803, 2789, 999, 2690, 817, 1012, 
       2703, 831, 1025, 2714, 845, 1038, 2723, 859, 1051, 2729, 873, 2816, 
       1064, 887, 2826, 1077, 901, 2838, 1090, 915}], 
      Line3DBox[{733, 927, 2653, 734, 937, 2662, 748, 948, 2667, 762, 961, 
       2672, 776, 2766, 974, 790, 2777, 987, 804, 2790, 1000, 2691, 818, 1013,
        2704, 832, 1026, 2715, 846, 1039, 2724, 860, 1052, 2730, 874, 1065, 
       2734, 888, 2827, 1078, 902, 2839, 1091, 916}], 
      Line3DBox[{735, 1096, 1097, 2654, 736, 1098, 2843, 1099, 749, 1100, 
       2844, 1101, 763, 1102, 2845, 1103, 777, 1104, 2847, 1105, 791, 2778, 
       1106, 1107, 805, 2791, 1108, 1109, 2692, 819, 1110, 1111, 2705, 833, 
       1112, 1113, 2716, 847, 1114, 2848, 1115, 861, 1116, 2849, 1117, 875, 
       1118, 2850, 1119, 889, 1120, 2852, 1121, 903, 2840, 1123, 1124, 1125}],
       Line3DBox[CompressedData["
1:eJwNycVNBAAURdEPYUcPJITg3golEILPDO7u7u7ubgtogSbohLM4ucl72dWp
qmRaRNTwlx7xmRHxRS1j5GZGjGoH40xQxxR5vkntZJoZ6imyz+ksXcyzQJa9
QZdYpJtliu0r2sgaq/SwTolvQ5vYYpNeCu3bukMze+xSau/TfQ5IcMQhZb5+
PeaEJGfk2091gHMuSHFFge9SB7nmhhbK7Xd6yxD3PJBjb9UnHhnmmQr7i7bx
xisjvFPp+9B2fvjml39C4zaP
       "]], 
      Line3DBox[{904, 1079, 1122, 2828, 890, 1066, 2817, 876, 1053, 2808, 862,
        1040, 2801, 848, 1027, 2796, 834, 1014, 2793, 820, 2693, 1001, 806, 
       2678, 988, 2779, 792, 975, 2767, 778, 962, 2757, 764, 949, 2749, 750, 
       938, 2743, 738, 928, 2841, 1218, 1220, 1219, 712, 2842, 917, 1207, 
       1209, 1208, 1095}], 
      Line3DBox[{911, 1086, 2834, 897, 1073, 2822, 883, 1060, 2812, 869, 1047,
        2804, 855, 1034, 2798, 841, 1021, 2794, 827, 1008, 2792, 813, 2686, 
       995, 2785, 799, 982, 2772, 785, 969, 2761, 771, 956, 2752, 757, 943, 
       2745, 743, 932, 2740, 724, 922, 2738, 722}], 
      Line3DBox[{1240, 1462, 2967, 1241, 1476, 2979, 1268, 2875, 1491, 1283, 
       2880, 1506, 1298, 2887, 1521, 1313, 2896, 1536, 1328, 2907, 1551, 1343,
        1566, 3022, 1358, 1581, 3034, 1373, 2924, 1596, 1388, 2929, 1611, 
       1403, 2936, 1626, 1418, 2945, 1641, 1433, 2955, 1656, 1448}], 
      Line3DBox[{1242, 1463, 2968, 1243, 1477, 2980, 1269, 1492, 2991, 1284, 
       2881, 1507, 1299, 2888, 1522, 1314, 2897, 1537, 1329, 2908, 1552, 1344,
        1567, 3023, 1359, 1582, 3035, 1374, 1597, 3046, 1389, 2930, 1612, 
       1404, 2937, 1627, 1419, 2946, 1642, 1434, 2956, 1657, 1449}], 
      Line3DBox[{1244, 1464, 2969, 1245, 1478, 2981, 1270, 1493, 2992, 1285, 
       1508, 3001, 1300, 2889, 1523, 1315, 2898, 1538, 1330, 2909, 1553, 1345,
        1568, 3024, 1360, 1583, 3036, 1375, 1598, 3047, 1390, 1613, 3056, 
       1405, 2938, 1628, 1420, 2947, 1643, 1435, 2957, 1658, 1450}], 
      Line3DBox[{1246, 1465, 2970, 1247, 1479, 2982, 1271, 1494, 2993, 1286, 
       1509, 3002, 1301, 1524, 3009, 1316, 2899, 1539, 1331, 2910, 1554, 1346,
        1569, 3025, 1361, 1584, 3037, 1376, 1599, 3048, 1391, 1614, 3057, 
       1406, 1629, 3064, 1421, 2948, 1644, 1436, 2958, 1659, 1451}], 
      Line3DBox[{1248, 1466, 2971, 1249, 1480, 2983, 1272, 1495, 2994, 1287, 
       1510, 3003, 1302, 1525, 3010, 1317, 1540, 3015, 1332, 2911, 1555, 1347,
        1570, 3026, 1362, 1585, 3038, 1377, 1600, 3049, 1392, 1615, 3058, 
       1407, 1630, 3065, 1422, 1645, 3070, 1437, 2959, 1660, 1452}], 
      Line3DBox[{1250, 1467, 2972, 1252, 1481, 2984, 1273, 1496, 2995, 1288, 
       1511, 3004, 1303, 1526, 3011, 1318, 1541, 3016, 1333, 1556, 3019, 1348,
        1571, 3027, 1363, 1586, 3039, 1378, 1601, 3050, 1393, 1616, 3059, 
       1408, 1631, 3066, 1423, 1646, 3071, 1438, 1661, 3074, 1453}], 
      Line3DBox[{1447, 1655, 1672, 3077, 1432, 1640, 2944, 1417, 1625, 2935, 
       1402, 1610, 2928, 1387, 1595, 2923, 1372, 1580, 2920, 1357, 3021, 1565,
        1342, 1550, 2906, 1327, 1535, 2895, 1312, 1520, 2886, 1297, 1505, 
       2879, 1282, 1490, 2874, 1267, 1475, 2871, 1239, 3076, 1461, 1669, 
       1676}], Line3DBox[{1454, 1662, 2960, 1439, 1647, 2949, 1424, 1632, 
       2939, 1409, 1617, 2931, 1394, 1602, 2925, 1379, 1587, 2921, 1364, 1572,
        2919, 1349, 1557, 2912, 1334, 1542, 2900, 1319, 1527, 2890, 1304, 
       1512, 2882, 1289, 1497, 2876, 1274, 1482, 2872, 1253, 1468, 2870, 
       1251}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXk0Vf3/Nn5EKlORTEXKEKVJSSVeCJUxKU1IiqQikaFBiMwNhlRkiJSQ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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{308.9198578323197, 156.48702339918702`},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 0.5}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{-0.576594483375461, -3.287280857412911, 0.5579635886216976},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.604351408713811*^9, 3.612978066478943*^9, 
  3.612979480535822*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Look", " ", "for", " ", "a", " ", "an", " ", "expression", " ", "with", 
    " ", "good", " ", "ratio", " ", 
    RowBox[{"performance", "/", "accuracy"}], " ", "than", " ", "the", " ", 
    "one", " ", "above"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FitDisneyDiffuseMedium0", "[", "Roughness_", "]"}], "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"b", "*", 
       RowBox[{"Roughness", "^", "2"}]}], "+", 
      RowBox[{"a", "*", "Roughness"}]}], "/.", " ", 
     RowBox[{"FindFit", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", " ", 
           RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
            RowBox[{"0", ",", " ", "x"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0.001", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
       ",", 
       RowBox[{
        RowBox[{"b", "*", 
         RowBox[{"xx", "^", "2"}]}], "+", 
        RowBox[{"a", "*", "xx"}]}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", " ", "b"}], "}"}], ",", "xx"}], "]"}]}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.612979394943927*^9, 3.612979395311948*^9}, 
   3.6129794914324455`*^9, {3.6129803426161304`*^9, 3.6129803596001015`*^9}, {
   3.6129804787679176`*^9, 3.612980508472617*^9}, 3.612980590336299*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.7558678711129508`", " ", "Roughness"}], "-", 
  RowBox[{"0.511705103152965`", " ", 
   SuperscriptBox["Roughness", "2"]}]}]], "Output",
 CellChangeTimes->{3.6129805955015945`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "the", " ", "fitting"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FitDisneyDiffuseMedium0", "[", "x", "]"}], ",", " ", 
       RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
        RowBox[{"0", ",", " ", "x"}], "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.612980525816609*^9, 3.612980536920244*^9}, 
   3.61298059227141*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k81N0XB3BSKXoiDRGhhVS21JCtD0kkFaEshQhtkjaeSLIkrUqKsj2S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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxF0Wc8FXwfBnCzVMo4SFYoFDpmqOgvlJQkhCSVnYwyU4hOQiUkhbjtkb3J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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0.001, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.612980543185602*^9, 3.612980600467879*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Lerp", " ", "with", " ", "0", " ", "at", " ", "0.5"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FitDisneyDiffuseMedium", "[", 
    RowBox[{"Cos\[Theta]V_", ",", " ", "Roughness_"}], "]"}], " ", "=", " ", 
   RowBox[{"Lerp", "[", 
    RowBox[{
     RowBox[{"FitDisneyDiffuseMedium0", "[", "Roughness", "]"}], ",", " ", 
     "0", ",", " ", 
     RowBox[{"2", " ", "*", " ", "Cos\[Theta]V"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.612980372991868*^9, 3.6129803766640778`*^9}, {
  3.612980562934732*^9, 3.6129805969836793`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.7558678711129508`", " ", "Roughness"}], "-", 
  RowBox[{"0.511705103152965`", " ", 
   SuperscriptBox["Roughness", "2"]}], "+", 
  RowBox[{"2", " ", "Cos\[Theta]V", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.7558678711129508`"}], " ", "Roughness"}], "+", 
     RowBox[{"0.511705103152965`", " ", 
      SuperscriptBox["Roughness", "2"]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{3.6129806093823886`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.7558678711129508`", " ", "Roughness"}], "-", 
  RowBox[{"0.511705103152965`", " ", 
   SuperscriptBox["Roughness", "2"]}], "+", 
  RowBox[{"2", " ", "Cos\[Theta]V", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.7558678711129508`"}], " ", "Roughness"}], "+", 
     RowBox[{"0.511705103152965`", " ", 
      SuperscriptBox["Roughness", "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.6129806094153905`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "the", " ", "final", " ", "fitting"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"GetLerpFactorDisneyDiffuse", "[", 
        RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], ",", " ", 
       RowBox[{"FitDisneyDiffuseMedium", "[", 
        RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"Cos\[Theta]V", ",", " ", "0", ",", " ", "0.9999"}], "}"}], ",",
      " ", 
     RowBox[{"{", 
      RowBox[{"Roughness", ",", " ", "0.001", ",", " ", "1"}], "}"}], ",", 
     " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}]}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.5"}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.61298057024715*^9, {3.6129806163767886`*^9, 3.612980619640975*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJzsnWVYVdsXrwmxA7uwu7A7li0GBip2N2JgIQYWKhYSoggGUlIiJYrSqQgK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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmgfUVDXXhe+8c71534yIiKJYKAo27L338vlZsAOCnWIFC1ixgCAISrcj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         "]], Polygon3DBox[CompressedData["
1:eJw1m3nAVlMXxe/znOve976vORRFoUFlzFSGFAmZx4QMmROKkKlSSkKGCJnS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         "]], Polygon3DBox[CompressedData["
1:eJwt2Afcj+Uex/E/z+P59/xxEi1URkIRpdBCp72oNE4drUN1TouyGjblVFZG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         "]], Polygon3DBox[{{1782, 1781, 2531, 1108, 1109, 2532}}]}]}, 
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl2e0FtUVhmeG73we7iBVY0W52KVjBKRzLYELUq7EJXBBokkEaYqJIhgC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         "]], Polygon3DBox[CompressedData["
1:eJwtmHm4VVUZxs/dnLXd+6DM5qwMUhFcBExQ5kuazJM8JnBBglSGCyiVgJRB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         "]], Polygon3DBox[CompressedData["
1:eJwt1WeMFVUUAOBH2cfiojQRRJCOSC/Sy1IN7NJFQhMQLHQQLAiIomJsUWJB
QGIvgIpRlKKoERSwB1CKNKkabPSmgt/JvB8nmfO9c+fO3HfvmSojJvadUDCV
Sk0SWaLtRanUqHQqNU8ywA87s1Opjmwie5G9IC7kpFLlWUnWQV5A3YPqurMZ
7G02jv3F2rOx7Hk2mO1mLdhwNoc9Kc65Xzs2ms2XD1S3Q11N1oSNZCPEHnXN
2RD2uLy7uh/UXcxSrCE7UiCVmsw6sHFsIRuibg8rydKsGWsqNrhfIXbEdWXx
i7E3qSvOCqprzI6xO1guG8MWsEHut4uVYIVYE3Zc3Z2sK5vKFrFR6g6zHmwm
W8reEQWLpVLF2AXXDcTfxk5RV4u1VjeW1TH2XVaOFWe5se7qZrE0Oy6vJvaz
W1gem6ZuCRtj7B8six2TVxX71N3M6rE8ddNYK3WfsqtZGzaO1WVLWW3WkU1m
t4nD1qowO+q6itjrfiPVXcIKqGvEjrLbWTd2N1vMRrvf7yyfTWdvsbHsT9aQ
9WGz2H2xhuZowLqzGfI26j7LrN896WTvxR6co64su4S1k5837/3qKrDSrBMr
ZOxD7Bo2kD3CurHvWDM2mD3G8tn3mT0+IZ3sx9iXs83RlA1ij8rz1H2r7gpW
inWM/5HNZvVZPpvOWrNP2L9FrZG8pNjo+a5n1dVVV9ePXSc2m6O/uvHsCXkv
Y/eq68uGsntZe7aJ9WE3sJksl21k/4mPYt8Wdr7MUV9+RnwYz692Lqsl72xs
e/mNsReM/SD2C+vBJsQeZJ/Hf8R6somsIVvDTrNN8a5ijftdy06yr+Pcmves
WOQ9zrDNse5irbousf/YF/Ltat5gLaJHsF7mmMQbmWNtdnJG4qzcxR+O9bFO
59gKNT8bO8/YOvJ/xEq2k81ndWOdxSq2my1g9TLrXM19OvMu4lbPd9a827KS
543nbpOT9JfG6eS/iP9kdE7ybl+5PqDmoGjBjrOP4wzJ94tmOcn56JBO+lL0
p/GZOba7LiqyxbKcpNcNSyf7O/b5dFaEnXJdVpSLvRVjPfdy19vc/znvUVt+
uboSxraPxmx9HmAXzPFr5v4xT0djK6q7NJ30tOhtw3OSXpfFasqvivfLSc5b
73RynuNcT8mMLZNO1inW6xt23hz7XZeOPepZ+mcna7A6K1mTWJuF8W6sgbG9
Y597vlfVtWQNWR9Wir3GmrP6rBcrwV6JPsSqZM5RnNVn41yyeqwnK85eZq1Y
I9Y3noe9zuqyyplvT5zBZ1gdVimzVvE9ejqzVr9l1jjWerVnruF966obIq+g
7qXof+oqZnpJ9Ng5rAYrzGqwQ2xq9ER2ZaYXx//xVJx9VjXTcwqzufGdYT/J
T1mnFcZ2Y6XYFnaarWR5rDTbys6wVSw/+gs7xIrE94kNim8Za2uOoaySOd6L
fsXasWHx7WLvs04slw2PHs2WsRNsbfRWcyxzv+asPDvI0mI9Gxi9hO2L/0xs
Yv1i/7ED8iyxjg1gldkJeRmxhY2K7yD7UX7SHMtZ1/hGsS/ZDvYma8mKsHVs
V/QM1ooVZRvie8KWsDYsm61ne9hi1ppVYSfZZWIrG52dnKPTmf0d+3yt//d/
PFcIzA==
         "]]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl2mQFtUVhrs/5jY9c8eljA6bYtxYTaIwCAPiNsNiFJAZNjWJsrrLjqAg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         "]], Polygon3DBox[CompressedData["
1:eJwtl3ewF9Udxff3k73u3X2gM0pHsdJt8JAOGuCBE2kPHg81UUHAxCSAUqIJ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         "]], Polygon3DBox[CompressedData["
1:eJwt1nmQz2UcB/CvX6w9HE3JfaTD2YF1LYksuysJu9bqZJcold1F7oYwpDKN
ajoRapout0S5u8nRTDVRaKbLrXQ5Qq9nvr8/PjO/5/V7f77f5/t8n9+z27ik
NH9UIoqiUaqSqpEeRWkpUZRlcLpCFE1OjaLLWSrryP5lk9gVLJ11YmfYFJbN
ytgi9omLTkqLokvUNuOTFaNoiVw7udvlpsot5/PlJssk1Fbj43KL5drKtWMt
5W7jVeQWsgK9M9kaNob9zSrIbTE+qneR3kyWJneGNVeH2IOskdxJ40vVHlbC
rpar53q9WbrrzWXp7KxxC3VY7iF2jd4Lxo3UQVbOMuTOGbdUR9jD7Cq5/4wb
qP2sNMxP7ohxXbWX3R3uK3feuKE6wMpYf7np5rKKlZvLnyzBjhrXU/vk7mGN
WR25XixV7kl2UW0y/s0aLJRrbXylXG25PF5Z7glW030PGF+U2yzXnzWUqymX
w9fLjZVJV1+GtZNbKtdVLlXuNGum3pMbLXMZq6y3A3ufjUmL3+9niXgPhL0w
L8Na8Z1hnVxvmet1c70qbBc7xpazW1hLvZv0bVTDfDdKb1PWNiUeBx+nL4tt
83mrms6nyFXje3z+3fVWul522KdsP7vANrF+rLXe/JS4L/RPkInYYeM6ajUr
Z1XVbuMTelfo7Z7s3eL7zeFZfTfWfSO5zWGvyL0q1yY1nvMGmQ9Voe9Gyp2T
+97nDLVdro9cDfaD8Xm9G1nf1PjZis1vHv9I/8S0eF2yU+J7hnuPZ/eqOewN
NpwNNv5H7TA+F9aUlRpXV1+xU2yVe/Rwj7NsX9jzaqVcWbJ3mc9L1a+yWebc
kJ2Qqa526y3Wm8fy3PeB8PsKz8h6sV5sZPjdsA2sGavPuoTn0/s0a+M5CtgM
1j3skbCmck2T+zTs55dZptwANpNls09ZW7kWyd9qBlvAWrEmLDe5x19iPfWO
ZktYMfs5Nd6naxPxvg37t9Cz1dJ7sFJ88G0xv/zw3sJ713tDeO9sWvhN663L
bmVp+p9Krt+KRLzGYa27uF4ma57MhbNkvlxfvdPYClbK/gjnEKuVnHMKm8Ny
2Vj2Ohsa1p/lsDHsNVbCfmH92GNsJStjp8Kaum+z5HkQ5vcKu5Fdm/xNh3u8
GM5Odh+bxXLYd6wJq8KuD2ev553KCtkI9jjLk9vHBrDhbDbLZXvDWWIuGawz
O6v3UTZIbhx7gRXJHWb5cjPYajaa/cU6s6HsWZbPvmE3sWHsOVbAvg1r4Ho5
bARrytazimnxPg77ebbv7jTurNr5PFCuptybYe1ZEZvAOrLtrA8rZONYe/Z5
2C+sJxvOmrB1rIe5lLPFbAj7KbwjuVx2fzgD2QesNvvRuEI4S8ypIHlOrknE
50g4T3rbG93kOum9K5zl4TcmdzPryO4I5w57h3VhHdggVpu9zRqw48bV1C73
GMKK2CNyz7OBcodYfXbMuKraKTc47Bc2SG4iy5LbEf7+soFsPOvAvkj+DViX
iM/wcJYXm/MFvtHnubILXK9VeEd62xsX8Vqyb6XGZ+eqRHyOhPMkW2/XcEaH
dxP+7vF35a6T68HGsky2lnViJewZ1p99nfw/4uNEfPaFM3CW6/0Pd3oFLw==

         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0s1KVGEYwPHH1NEZtVy4cmF4AXoD5TpQCRERUREJXegiF0J+dAFNqZX5
Be51LyjuJMiNmKSj5teMYxsR6gLERfQ7EMwzv/97YOY9551pfDXW+bokIpbM
hEh6yNsdP6YiarnKp1xjMzfYwq9s5w/2scgbM6ofOMWKiogs67jCRq6zmVts
4S6PmbLvtDm2fsN6ky2NOLF+z1N+4E/O8IyzPOccL5J75idzqT/zivPM8wsL
XOA1F1nkcFlE2l43+rvO6irz1vxybZwZ0+Mec9aDulV/0wP6md7UNZUR/dZr
OqN79bKu1D36nU7pbj2py3SXvndWI9adOq97dYc+0G36pd7Rz3WJz7RbN+m/
9m3VDXpb/+GU9ZPkmfibk8kzPIp4rKt1UdfoAqt5xSpeMMMzpnlKW0WOR8bX
xyFTye/Nch7QccU+HWXs0SteuHj7///0Dwi/S9o=
       "]]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0bsug2EAx+FXgzC4A4tRXIDEBUisEolFQtWh9DAYDBIRg4g0qENLnYrS
g9NgNxhsBptIIw0X4A7E0xh+ef7v8H358n490fRwqiWEkNZGJIR9hzUuqrcj
hJJzPx85yGeO8I0xNrjAH67yl1l2eb7Ibj6wj08c4CuHWOcoxzpDWGJGM1rX
isptIcyywjirnGON87xhgrdM8o73StkvSnpvjUdK2FUWNG9XeKg5u8wDxe1r
5jVrXzHX/Ca71LwbTduX3NOUfcFdxexz7mjSLjKrqH3GbU3Yp9zSuH3CTR27
s+/WEL50ZDdY4CcPWecBP5jnO3PMtIewHPn/b39J/EHJ
       "]], Line3DBox[CompressedData["
1:eJwl0Tsvg2EcxuGngpD4Biarb2A3mBkMtg4WSdu3rUOJYBKRxhegTiNVbZ3P
dYjBYrYYpRHEZJK43hh+ue5n+/dtTzI9mEqEEMb01hrCmkexPYSdlhB2leoM
ocw9pe0K95Wxq6wpsus8UNY+5JFy9jFPlLdPeaZx+5wXmrAveaVJ+5o3mrIb
vFXBvuO9pu0HPmrGXmWlzW3xXcywyii+jVnWmYvvY57Lft8si/EtWtKCfjpC
GGWTw3zhAJ/YF9/LXpbZzRK7uMJf322en4z4yiSfOcQG+1njiLsL8R3a9l7k
nL59/y3vL27ygxt85zqbLCX+/6c/PmVFOQ==
       "]]}, {
      Line3DBox[{1678, 1971, 1974, 2842, 1881, 2064, 1972, 2083, 2868, 1882, 
       1679, 2645, 1883, 1680, 2646, 1884, 1681, 2544, 2647, 2079, 1885, 1682,
        2546, 2648, 2084, 1886, 1683, 2649, 2428, 2738, 1684, 2429, 2739, 
       1685, 2650, 1887, 1686, 2651, 1888, 1687, 2652, 1889, 1688, 2653, 1890,
        1689, 2529, 2654, 1891, 2005, 2853, 2029, 2030, 2013, 2028, 1892, 
       1975}], Line3DBox[{1690, 1973, 2430, 2841, 2078, 2077, 2655, 1893, 
       1691, 2656, 1894, 1692, 2545, 2657, 1895, 2080, 2528, 2658, 2076, 2081,
        2082, 2075, 2867, 2073, 2087, 1896, 1693, 2659, 2431, 2740, 1694, 
       2432, 2741, 1695, 2433, 2742, 1696, 2660, 1897, 1697, 2661, 1898, 1698,
        2662, 1899, 1699, 2843, 1976, 1900, 2006, 2854, 2031, 1977, 2014, 
       2047, 2048, 2046}], 
      Line3DBox[{1701, 2434, 2743, 1700, 2435, 2744, 1702, 2663, 1901, 1703, 
       2664, 1902, 1704, 2866, 2074, 1903, 2086, 2869, 2085, 1904, 1705, 2665,
        2436, 2745, 1706, 2437, 2746, 1707, 2438, 2747, 1708, 2439, 2748, 
       1709, 2666, 1905, 1710, 2667, 1906, 1711, 2844, 1978, 1907, 2007, 2537,
        2858, 1979, 2015, 2050, 2051, 2049}], 
      Line3DBox[{1713, 2440, 2749, 1712, 2441, 2750, 1714, 2442, 2751, 1715, 
       2668, 1908, 1716, 2669, 1909, 1717, 2670, 1910, 1718, 2671, 2443, 2752,
        1719, 2444, 2753, 1720, 2445, 2754, 1721, 2446, 2755, 1722, 2447, 
       2756, 1723, 2672, 1911, 1724, 2845, 1980, 1981, 1725, 2538, 2846, 1982,
        2016, 1983, 2065, 1726}], 
      Line3DBox[{1728, 2448, 2757, 1727, 2449, 2758, 1729, 2450, 2759, 1730, 
       2451, 2760, 1731, 2673, 1912, 1732, 2674, 1913, 1733, 2675, 2452, 2761,
        1734, 2453, 2762, 1735, 2454, 2763, 1736, 2455, 2764, 1737, 2456, 
       2765, 1738, 2457, 2766, 1739, 2847, 1984, 1985, 1740, 2859, 2032, 1986,
        2017, 1987, 2066, 1741}], 
      Line3DBox[{1743, 2458, 2767, 1742, 2459, 2768, 1744, 2460, 2769, 1745, 
       2461, 2770, 1746, 2462, 2771, 1747, 2676, 1914, 1748, 2677, 2463, 2772,
        1749, 2464, 2773, 1750, 2465, 2774, 1751, 2466, 2775, 1752, 2467, 
       2776, 1753, 2468, 2777, 1754, 2530, 2778, 1988, 1755, 2860, 2033, 2034,
        2018, 2068, 2067, 1756}], 
      Line3DBox[{1760, 2678, 1915, 1758, 2679, 1916, 1762, 2680, 1917, 1764, 
       2681, 1918, 1766, 2682, 1919, 1768, 2683, 1920, 1770, 2685, 2686, 1921,
        1772, 2687, 1922, 1774, 2688, 1923, 1776, 2689, 1924, 1778, 2690, 
       1925, 1780, 2691, 1926, 1782, 2532, 2692, 1927, 2008, 2540, 2861, 2036,
        2020, 2053, 1928, 2052}], 
      Line3DBox[{1784, 2069, 2070, 2019, 2035, 2857, 2539, 1783, 1989, 2791, 
       2531, 1781, 2790, 2480, 1779, 2789, 2479, 1777, 2788, 2478, 1775, 2787,
        2477, 1773, 2786, 2476, 1771, 2785, 2475, 2684, 1769, 2784, 2474, 
       1767, 2783, 2473, 1765, 2782, 2472, 1763, 2781, 2471, 1761, 2780, 2470,
        1757, 2779, 2469, 1759}], 
      Line3DBox[{1786, 2693, 1929, 1785, 2694, 1930, 1787, 2695, 1931, 1788, 
       2696, 1932, 1789, 2697, 1933, 1790, 2698, 1934, 1791, 2699, 2481, 2792,
        1792, 2700, 1935, 1793, 2701, 1936, 1794, 2702, 1937, 1795, 2703, 
       1938, 1796, 2704, 1939, 1797, 2533, 2705, 1940, 2009, 2541, 2862, 2037,
        2021, 2055, 1941, 2054}], 
      Line3DBox[{1799, 2482, 2793, 1798, 2706, 1942, 1800, 2707, 1943, 1801, 
       2708, 1944, 1802, 2709, 1945, 1803, 2710, 1946, 1804, 2711, 2483, 2794,
        1805, 2484, 2795, 1806, 2712, 1947, 1807, 2713, 1948, 1808, 2714, 
       1949, 1809, 2715, 1950, 1810, 2534, 2716, 1951, 2010, 2855, 2038, 2039,
        2022, 2057, 1952, 2056}], 
      Line3DBox[{1812, 2485, 2796, 1811, 2486, 2797, 1813, 2717, 1953, 1814, 
       2718, 1954, 1815, 2719, 1955, 1816, 2720, 1956, 1817, 2721, 2487, 2798,
        1818, 2488, 2799, 1819, 2489, 2800, 1820, 2722, 1957, 1821, 2723, 
       1958, 1822, 2724, 1959, 1823, 2848, 1990, 1960, 2011, 2856, 2040, 1991,
        2023, 2059, 2060, 2058}], 
      Line3DBox[{1825, 2490, 2801, 1824, 2491, 2802, 1826, 2492, 2803, 1827, 
       2725, 1961, 1828, 2726, 1962, 1829, 2727, 1963, 1830, 2728, 2493, 2804,
        1831, 2494, 2805, 1832, 2495, 2806, 1833, 2496, 2807, 1834, 2729, 
       1964, 1835, 2730, 1965, 1836, 2849, 1992, 1966, 2012, 2542, 2863, 1993,
        2024, 2062, 2063, 2061}], 
      Line3DBox[{1838, 2497, 2808, 1837, 2498, 2809, 1839, 2499, 2810, 1840, 
       2500, 2811, 1841, 2731, 1967, 1842, 2732, 1968, 1843, 2733, 2501, 2812,
        1844, 2502, 2813, 1845, 2503, 2814, 1846, 2504, 2815, 1847, 2505, 
       2816, 1848, 2734, 1969, 1849, 2850, 1994, 1995, 1850, 2543, 2851, 1996,
        2025, 1997, 2071, 1851}], 
      Line3DBox[{1853, 2506, 2817, 1852, 2507, 2818, 1854, 2508, 2819, 1855, 
       2509, 2820, 1856, 2510, 2821, 1857, 2735, 1970, 1858, 2736, 2511, 2822,
        1859, 2512, 2823, 1860, 2513, 2824, 1861, 2514, 2825, 1862, 2515, 
       2826, 1863, 2516, 2827, 1864, 2852, 1998, 1999, 1865, 2864, 2041, 2000,
        2026, 2001, 2072, 1866}], 
      Line3DBox[{1880, 2044, 2045, 2027, 2043, 2042, 2865, 1879, 2004, 2840, 
       2536, 1878, 2839, 2527, 1877, 2838, 2526, 1876, 2837, 2525, 1875, 2836,
        2524, 1874, 2835, 2523, 1873, 2834, 2522, 2737, 1872, 2833, 2521, 
       1871, 2832, 2520, 1870, 2831, 2519, 1869, 2830, 2518, 1868, 2829, 2517,
        1867, 2535, 2828, 2002, 2003}], 
      Line3DBox[{2089, 2393, 3076, 2296, 2088, 2967, 2297, 2090, 2968, 2298, 
       2091, 2969, 2299, 2092, 2970, 2300, 2093, 2971, 2301, 2094, 2972, 2547,
        2870, 2095, 2400}], 
      Line3DBox[{2103, 2548, 2871, 2102, 2979, 2309, 2104, 2980, 2310, 2105, 
       2981, 2311, 2106, 2982, 2312, 2107, 2983, 2313, 2108, 2984, 2549, 2872,
        2109, 2401}], 
      Line3DBox[{2118, 2551, 2874, 2117, 2552, 2875, 2119, 2991, 2320, 2120, 
       2992, 2321, 2121, 2993, 2322, 2122, 2994, 2323, 2123, 2995, 2553, 2876,
        2124, 2402}], 
      Line3DBox[{2133, 2556, 2879, 2132, 2557, 2880, 2134, 2558, 2881, 2135, 
       3001, 2329, 2136, 3002, 2330, 2137, 3003, 2331, 2138, 3004, 2559, 2882,
        2139, 2403}], 
      Line3DBox[{2148, 2563, 2886, 2147, 2564, 2887, 2149, 2565, 2888, 2150, 
       2566, 2889, 2151, 3009, 2336, 2152, 3010, 2337, 2153, 3011, 2567, 2890,
        2154, 2404}], 
      Line3DBox[{2163, 2572, 2895, 2162, 2573, 2896, 2164, 2574, 2897, 2165, 
       2575, 2898, 2166, 2576, 2899, 2167, 3015, 2341, 2168, 3016, 2577, 2900,
        2169, 2405}], 
      Line3DBox[{510, 1342, 511, 1343, 512, 1344, 513, 1345, 514, 1346, 515, 
       1347, 516, 1348, 1349, 517, 661}], 
      Line3DBox[{2178, 2583, 2906, 2177, 2584, 2907, 2179, 2585, 2908, 2180, 
       2586, 2909, 2181, 2587, 2910, 2182, 2588, 2911, 2183, 3019, 2589, 2912,
        2184, 2406}], 
      Line3DBox[{2193, 3021, 2345, 2192, 3022, 2346, 2194, 3023, 2347, 2195, 
       3024, 2348, 2196, 3025, 2349, 2197, 3026, 2350, 2198, 3027, 2596, 2919,
        2199, 2407}], 
      Line3DBox[{2208, 2597, 2920, 2207, 3034, 2358, 2209, 3035, 2359, 2210, 
       3036, 2360, 2211, 3037, 2361, 2212, 3038, 2362, 2213, 3039, 2598, 2921,
        2214, 2408}], 
      Line3DBox[{2223, 2600, 2923, 2222, 2601, 2924, 2224, 3046, 2369, 2225, 
       3047, 2370, 2226, 3048, 2371, 2227, 3049, 2372, 2228, 3050, 2602, 2925,
        2229, 2409}], 
      Line3DBox[{2238, 2605, 2928, 2237, 2606, 2929, 2239, 2607, 2930, 2240, 
       3056, 2378, 2241, 3057, 2379, 2242, 3058, 2380, 2243, 3059, 2608, 2931,
        2244, 2410}], 
      Line3DBox[{2253, 2612, 2935, 2252, 2613, 2936, 2254, 2614, 2937, 2255, 
       2615, 2938, 2256, 3064, 2385, 2257, 3065, 2386, 2258, 3066, 2616, 2939,
        2259, 2411}], 
      Line3DBox[{2268, 2621, 2944, 2267, 2622, 2945, 2269, 2623, 2946, 2270, 
       2624, 2947, 2271, 2625, 2948, 2272, 3070, 2390, 2273, 3071, 2626, 2949,
        2274, 2412}], 
      Line3DBox[{2397, 2396, 3077, 2644, 2282, 2632, 2955, 2283, 2633, 2956, 
       2284, 2634, 2957, 2285, 2635, 2958, 2286, 2636, 2959, 2287, 3074, 2637,
        2960, 2288, 2413}]}, {
      Line3DBox[{713, 1092, 918, 2868, 714, 1217, 929, 2655, 739, 2744, 939, 
       751, 2750, 950, 765, 2758, 963, 779, 2768, 976, 793, 2780, 989, 2679, 
       807, 1002, 2694, 821, 1015, 2706, 835, 2797, 1028, 849, 2802, 1041, 
       863, 2809, 1054, 877, 2818, 1067, 891, 2829, 1080, 905}], 
      Line3DBox[{715, 919, 2645, 716, 930, 2656, 740, 940, 2663, 752, 2751, 
       951, 766, 2759, 964, 780, 2769, 977, 794, 2781, 990, 2680, 808, 1003, 
       2695, 822, 1016, 2707, 836, 1029, 2717, 850, 2803, 1042, 864, 2810, 
       1055, 878, 2819, 1068, 892, 2830, 1081, 906}], 
      Line3DBox[{717, 920, 2646, 718, 1224, 1225, 2657, 741, 941, 2664, 753, 
       952, 2668, 767, 2760, 965, 781, 2770, 978, 795, 2782, 991, 2681, 809, 
       1004, 2696, 823, 1017, 2708, 837, 1030, 2718, 851, 1043, 2725, 865, 
       2811, 1056, 879, 2820, 1069, 893, 2831, 1082, 907}], 
      Line3DBox[{719, 1221, 1222, 2647, 1223, 1227, 1093, 1226, 1094, 2658, 
       1216, 1213, 2866, 1214, 754, 953, 2669, 768, 966, 2673, 782, 2771, 979,
        796, 2783, 992, 2682, 810, 1005, 2697, 824, 1018, 2709, 838, 1031, 
       2719, 852, 1044, 2726, 866, 1057, 2731, 880, 2821, 1070, 894, 2832, 
       1083, 908}], 
      Line3DBox[{720, 1229, 1230, 2648, 1231, 1232, 1233, 1215, 2867, 1212, 
       1236, 1237, 1238, 1235, 2869, 1234, 755, 954, 2670, 769, 967, 2674, 
       783, 980, 2676, 797, 2784, 993, 2683, 811, 1006, 2698, 825, 1019, 2710,
        839, 1032, 2720, 853, 1045, 2727, 867, 1058, 2732, 881, 1071, 2735, 
       895, 2833, 1084, 909}], 
      Line3DBox[{721, 921, 2649, 723, 931, 2659, 742, 942, 2665, 756, 955, 
       2671, 770, 968, 2675, 784, 981, 2677, 798, 994, 2684, 2685, 812, 1007, 
       2699, 826, 1020, 2711, 840, 1033, 2721, 854, 1046, 2728, 868, 1059, 
       2733, 882, 1072, 2736, 896, 1085, 2737, 910}], 
      Line3DBox[{725, 2739, 923, 726, 2741, 933, 744, 2746, 944, 758, 2753, 
       957, 772, 2762, 970, 786, 2773, 983, 800, 2786, 996, 2687, 814, 1009, 
       2700, 828, 2795, 1022, 842, 2799, 1035, 856, 2805, 1048, 870, 2813, 
       1061, 884, 2823, 1074, 898, 2835, 1087, 912}], 
      Line3DBox[{727, 924, 2650, 728, 2742, 934, 745, 2747, 945, 759, 2754, 
       958, 773, 2763, 971, 787, 2774, 984, 801, 2787, 997, 2688, 815, 1010, 
       2701, 829, 1023, 2712, 843, 2800, 1036, 857, 2806, 1049, 871, 2814, 
       1062, 885, 2824, 1075, 899, 2836, 1088, 913}], 
      Line3DBox[{729, 925, 2651, 730, 935, 2660, 746, 2748, 946, 760, 2755, 
       959, 774, 2764, 972, 788, 2775, 985, 802, 2788, 998, 2689, 816, 1011, 
       2702, 830, 1024, 2713, 844, 1037, 2722, 858, 2807, 1050, 872, 2815, 
       1063, 886, 2825, 1076, 900, 2837, 1089, 914}], 
      Line3DBox[{731, 926, 2652, 732, 936, 2661, 747, 947, 2666, 761, 2756, 
       960, 775, 2765, 973, 789, 2776, 986, 803, 2789, 999, 2690, 817, 1012, 
       2703, 831, 1025, 2714, 845, 1038, 2723, 859, 1051, 2729, 873, 2816, 
       1064, 887, 2826, 1077, 901, 2838, 1090, 915}], 
      Line3DBox[{733, 927, 2653, 734, 937, 2662, 748, 948, 2667, 762, 961, 
       2672, 776, 2766, 974, 790, 2777, 987, 804, 2790, 1000, 2691, 818, 1013,
        2704, 832, 1026, 2715, 846, 1039, 2724, 860, 1052, 2730, 874, 1065, 
       2734, 888, 2827, 1078, 902, 2839, 1091, 916}], 
      Line3DBox[{735, 1096, 1097, 2654, 736, 1098, 2843, 1099, 749, 1100, 
       2844, 1101, 763, 1102, 2845, 1103, 777, 1104, 2847, 1105, 791, 2778, 
       1106, 1107, 805, 2791, 1108, 1109, 2692, 819, 1110, 1111, 2705, 833, 
       1112, 1113, 2716, 847, 1114, 2848, 1115, 861, 1116, 2849, 1117, 875, 
       1118, 2850, 1119, 889, 1120, 2852, 1121, 903, 2840, 1123, 1124, 1125}],
       Line3DBox[CompressedData["
1:eJwNycVNBAAURdEPYUcPJITg3golEILPDO7u7u7ubgtogSbohLM4ucl72dWp
qmRaRNTwlx7xmRHxRS1j5GZGjGoH40xQxxR5vkntZJoZ6imyz+ksXcyzQJa9
QZdYpJtliu0r2sgaq/SwTolvQ5vYYpNeCu3bukMze+xSau/TfQ5IcMQhZb5+
PeaEJGfk2091gHMuSHFFge9SB7nmhhbK7Xd6yxD3PJBjb9UnHhnmmQr7i7bx
xisjvFPp+9B2fvjml39C4zaP
       "]], 
      Line3DBox[{904, 1079, 1122, 2828, 890, 1066, 2817, 876, 1053, 2808, 862,
        1040, 2801, 848, 1027, 2796, 834, 1014, 2793, 820, 2693, 1001, 806, 
       2678, 988, 2779, 792, 975, 2767, 778, 962, 2757, 764, 949, 2749, 750, 
       938, 2743, 738, 928, 2841, 1218, 1220, 1219, 712, 2842, 917, 1207, 
       1209, 1208, 1095}], 
      Line3DBox[{911, 1086, 2834, 897, 1073, 2822, 883, 1060, 2812, 869, 1047,
        2804, 855, 1034, 2798, 841, 1021, 2794, 827, 1008, 2792, 813, 2686, 
       995, 2785, 799, 982, 2772, 785, 969, 2761, 771, 956, 2752, 757, 943, 
       2745, 743, 932, 2740, 724, 922, 2738, 722}], 
      Line3DBox[{1240, 1462, 2967, 1241, 1476, 2979, 1268, 2875, 1491, 1283, 
       2880, 1506, 1298, 2887, 1521, 1313, 2896, 1536, 1328, 2907, 1551, 1343,
        1566, 3022, 1358, 1581, 3034, 1373, 2924, 1596, 1388, 2929, 1611, 
       1403, 2936, 1626, 1418, 2945, 1641, 1433, 2955, 1656, 1448}], 
      Line3DBox[{1242, 1463, 2968, 1243, 1477, 2980, 1269, 1492, 2991, 1284, 
       2881, 1507, 1299, 2888, 1522, 1314, 2897, 1537, 1329, 2908, 1552, 1344,
        1567, 3023, 1359, 1582, 3035, 1374, 1597, 3046, 1389, 2930, 1612, 
       1404, 2937, 1627, 1419, 2946, 1642, 1434, 2956, 1657, 1449}], 
      Line3DBox[{1244, 1464, 2969, 1245, 1478, 2981, 1270, 1493, 2992, 1285, 
       1508, 3001, 1300, 2889, 1523, 1315, 2898, 1538, 1330, 2909, 1553, 1345,
        1568, 3024, 1360, 1583, 3036, 1375, 1598, 3047, 1390, 1613, 3056, 
       1405, 2938, 1628, 1420, 2947, 1643, 1435, 2957, 1658, 1450}], 
      Line3DBox[{1246, 1465, 2970, 1247, 1479, 2982, 1271, 1494, 2993, 1286, 
       1509, 3002, 1301, 1524, 3009, 1316, 2899, 1539, 1331, 2910, 1554, 1346,
        1569, 3025, 1361, 1584, 3037, 1376, 1599, 3048, 1391, 1614, 3057, 
       1406, 1629, 3064, 1421, 2948, 1644, 1436, 2958, 1659, 1451}], 
      Line3DBox[{1248, 1466, 2971, 1249, 1480, 2983, 1272, 1495, 2994, 1287, 
       1510, 3003, 1302, 1525, 3010, 1317, 1540, 3015, 1332, 2911, 1555, 1347,
        1570, 3026, 1362, 1585, 3038, 1377, 1600, 3049, 1392, 1615, 3058, 
       1407, 1630, 3065, 1422, 1645, 3070, 1437, 2959, 1660, 1452}], 
      Line3DBox[{1250, 1467, 2972, 1252, 1481, 2984, 1273, 1496, 2995, 1288, 
       1511, 3004, 1303, 1526, 3011, 1318, 1541, 3016, 1333, 1556, 3019, 1348,
        1571, 3027, 1363, 1586, 3039, 1378, 1601, 3050, 1393, 1616, 3059, 
       1408, 1631, 3066, 1423, 1646, 3071, 1438, 1661, 3074, 1453}], 
      Line3DBox[{1447, 1655, 1672, 3077, 1432, 1640, 2944, 1417, 1625, 2935, 
       1402, 1610, 2928, 1387, 1595, 2923, 1372, 1580, 2920, 1357, 3021, 1565,
        1342, 1550, 2906, 1327, 1535, 2895, 1312, 1520, 2886, 1297, 1505, 
       2879, 1282, 1490, 2874, 1267, 1475, 2871, 1239, 3076, 1461, 1669, 
       1676}], Line3DBox[{1454, 1662, 2960, 1439, 1647, 2949, 1424, 1632, 
       2939, 1409, 1617, 2931, 1394, 1602, 2925, 1379, 1587, 2921, 1364, 1572,
        2919, 1349, 1557, 2912, 1334, 1542, 2900, 1319, 1527, 2890, 1304, 
       1512, 2882, 1289, 1497, 2876, 1274, 1482, 2872, 1253, 1468, 2870, 
       1251}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXk0Vn3fNn5KqQiVjCXJWCmV0iA+FIqSDEkZSlFpkoqkkgyJTBHKGElk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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{304.6902836109369, 178.00884083001475`},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 0.9999}, {0.001, 1}, {0, 0.5}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  ViewPoint->{0.49746664080597675`, -3.2395770142446847`, 0.8412298794400062},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.612980647226553*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"FitDisneyDiffuseMedium", "[", 
   RowBox[{"Cos\[Theta]V", ",", " ", "Roughness"}], "]"}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{{3.612980394735111*^9, 3.612980455399581*^9}, 
   3.6129806271434045`*^9}],

Cell[BoxData[
 RowBox[{"Roughness", " ", 
  RowBox[{"(", 
   RowBox[{"0.7558678711129508`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.511705103152965`", " ", "Roughness"}], "+", 
    RowBox[{"Cos\[Theta]V", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1.5117357422259017`"}], "+", 
       RowBox[{"1.02341020630593`", " ", "Roughness"}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.612980402991584*^9, 3.6129804559456124`*^9}, 
   3.61298064734256*^9}]
}, Open  ]]
},
WindowSize->{1920, 1178},
WindowMargins->{{Automatic, 1912}, {Automatic, -65}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 614, 16, 52, "Input"],
Cell[CellGroupData[{
Cell[1196, 40, 487, 13, 52, "Input"],
Cell[1686, 55, 286, 8, 31, "Output"]
}, Open  ]],
Cell[1987, 66, 1587, 41, 52, "Input"],
Cell[3577, 109, 235, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[3837, 117, 441, 13, 31, "Input"],
Cell[4281, 132, 501, 12, 31, "Output"]
}, Open  ]],
Cell[4797, 147, 576, 16, 31, "Input"],
Cell[5376, 165, 1336, 35, 72, "Input"],
Cell[6715, 202, 1100, 30, 52, "Input"],
Cell[7818, 234, 1953, 44, 52, "Input"],
Cell[9774, 280, 1192, 31, 72, "Input"],
Cell[10969, 313, 9828, 223, 412, "Input"],
Cell[CellGroupData[{
Cell[20822, 540, 1682, 40, 72, "Input"],
Cell[22507, 582, 2410, 45, 344, "Output"]
}, Open  ]],
Cell[24932, 630, 651, 8, 52, "Input"],
Cell[25586, 640, 4837, 106, 372, "Input"],
Cell[CellGroupData[{
Cell[30448, 750, 1811, 38, 52, "Input"],
Cell[32262, 790, 143263, 2314, 190, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175562, 3109, 2788, 56, 72, "Input"],
Cell[178353, 3167, 641, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179031, 3183, 1019, 28, 31, "Input"],
Cell[180053, 3213, 374, 7, 31, "Output"]
}, Open  ]],
Cell[180442, 3223, 272, 6, 31, "Input"],
Cell[CellGroupData[{
Cell[180739, 3233, 1045, 21, 31, "Input"],
Cell[181787, 3256, 13749, 235, 253, 6585, 117, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195573, 3496, 1312, 30, 31, "Input"],
Cell[196888, 3528, 484, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197409, 3541, 1091, 30, 52, "Input"],
Cell[198503, 3573, 326, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[198866, 3584, 1158, 25, 52, "Input"],
Cell[200027, 3611, 14039, 239, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214103, 3855, 980, 19, 52, "Input"],
Cell[215086, 3876, 525, 16, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215648, 3897, 602, 13, 72, "Input"],
Cell[216253, 3912, 916, 20, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217206, 3937, 1309, 31, 52, "Input"],
Cell[218518, 3970, 191434, 3114, 296, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[409989, 7089, 569, 11, 52, "Input"],
Cell[410561, 7102, 779, 15, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[411377, 7122, 1783, 40, 72, "Input"],
Cell[413163, 7164, 106233, 1752, 302, "Output"]
}, Open  ]],
Cell[519411, 8919, 2092, 50, 72, "Input"],
Cell[521506, 8971, 8109, 181, 352, "Input"],
Cell[CellGroupData[{
Cell[529640, 9156, 899, 22, 52, "Input"],
Cell[530542, 9180, 2165, 41, 318, "Output"]
}, Open  ]],
Cell[532722, 9224, 4735, 105, 332, "Input"],
Cell[CellGroupData[{
Cell[537482, 9333, 1377, 26, 31, "Input"],
Cell[538862, 9361, 62777, 1023, 252, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[601676, 10389, 1573, 39, 52, "Input"],
Cell[603252, 10430, 351, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[603640, 10441, 761, 19, 52, "Input"],
Cell[604404, 10462, 6491, 114, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[610932, 10581, 872, 17, 52, "Input"],
Cell[611807, 10600, 560, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[612404, 10616, 1073, 26, 52, "Input"],
Cell[613480, 10644, 141925, 2317, 160, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[755442, 12966, 503, 10, 52, "Input"],
Cell[755948, 12978, 377, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[756362, 12991, 700, 16, 52, "Input"],
Cell[757065, 13009, 207, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[757309, 13018, 1047, 26, 72, "Input"],
Cell[758359, 13046, 131741, 2156, 171, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[890137, 15207, 1424, 36, 92, "Input"],
Cell[891564, 15245, 216, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[891817, 15255, 736, 20, 72, "Input"],
Cell[892556, 15277, 9498, 163, 253, "Output"]
}, Open  ]],
Cell[902069, 15443, 613, 14, 52, "Input"],
Cell[902685, 15459, 471, 12, 33, InheritFromParent],
Cell[903159, 15473, 472, 12, 33, "Output"],
Cell[CellGroupData[{
Cell[903656, 15489, 1086, 29, 92, "Input"],
Cell[904745, 15520, 131494, 2151, 193, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1036276, 17676, 260, 6, 31, "Input"],
Cell[1036539, 17684, 482, 12, 63, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
